From 36b9ce7876f84c457bb98114e51785127ef944ad Mon Sep 17 00:00:00 2001
From: Alexander Borisov <lex.borisov@gmail.com>
Date: Thu, 30 Jan 2025 16:20:28 +0300
Subject: [PATCH v5 2/2] Optimization for lower(), upper(), casefold()
 functions.

The changes made allow for:
1. Removed storing Unicode codepoints (unsigned int) in all tables.
2. Reduce the main table from 3003 to 1677 (duplicates removed) records.
3. Replace pointer (essentially uint64_t) with uin8_t in the main table.
4. Partitioning the main table into tables by case type.
5. Reduced the time to find a record in the table.
6. Reduce the size of the final object file.

How it works.

Group Unicode codepoints into ranges in which the difference between
neighboring elements does not exceed the specified limit.
For example, if there are numbers 1, 2, 3, 5, 6 and limit = 1, then there is
a difference of 2 between 3 and 5, which is greater than 1, so there will be
ranges 1-3 and 5-6.

Then we form a table (let's call it an index table) by combining the obtained
ranges.  The table contains uint16_t index of the main tables.

Then from the previously obtained diapasons we form a function (case_index())
to get the index of the main tables.  The function, in fact, contains only
IF/ELSE IF constructs imitating binary search.

Because we are not directly accessing the main tables with data, we can exclude
duplicates from it, and there are almost half of them.  Also, because
case_index() contains all the information about Unicode ranges, we
don't need to store Unicode codepoints in the main tables.
---
 .../unicode/generate-unicode_case_table.pl    |   308 +-
 src/common/unicode_case.c                     |    80 +-
 src/include/common/unicode_case_table.h       | 16368 +++++++++++++---
 3 files changed, 13546 insertions(+), 3210 deletions(-)

diff --git a/src/common/unicode/generate-unicode_case_table.pl b/src/common/unicode/generate-unicode_case_table.pl
index 953ebef2fe6..35d1d8bca44 100644
--- a/src/common/unicode/generate-unicode_case_table.pl
+++ b/src/common/unicode/generate-unicode_case_table.pl
@@ -231,7 +231,8 @@ while (my $line = <$FH>)
 close $FH;
 
 # assign sequential array indexes to the special mappings
-my $special_idx = 0;
+# 0 reserved for NULL
+my $special_idx = 1;
 foreach my $code (sort { $a <=> $b } (keys %special))
 {
 	$special{$code}{Index} = $special_idx++;
@@ -241,14 +242,7 @@ foreach my $code (sort { $a <=> $b } (keys %special))
 open my $OT, '>', $output_table_file
   or die "Could not open output file $output_table_file: $!\n";
 
-# determine size of array given that codepoints <= 0x80 are dense and
-# the rest of the entries are sparse
-my $num_simple = 0x80;
-foreach my $code (sort { $a <=> $b } (keys %simple))
-{
-	$num_simple++ unless $code < 0x80;
-}
-
+# determine size of array
 my $num_special = scalar(keys %special) + 1;
 
 print $OT <<"EOS";
@@ -298,24 +292,17 @@ typedef enum
 
 typedef struct
 {
-	pg_wchar	codepoint;		/* Unicode codepoint */
 	int16		conditions;
 	pg_wchar	map[NCaseKind][MAX_CASE_EXPANSION];
 } pg_special_case;
 
-typedef struct
-{
-	pg_wchar	codepoint;		/* Unicode codepoint */
-	pg_wchar	simplemap[NCaseKind];
-	const pg_special_case *special_case;
-} pg_case_map;
-
 /*
  * Special case mappings that aren't representable in the simple map.
  * Entries are referenced from simple_case_map.
  */
 static const pg_special_case special_case[$num_special] =
 {
+	{0, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}},
 EOS
 
 foreach my $code (sort { $a <=> $b } (keys %special))
@@ -332,23 +319,19 @@ foreach my $code (sort { $a <=> $b } (keys %special))
 	  (map { sprintf "0x%06x", $_ } @{ $special{$code}{Uppercase} });
 	my $fold = join ", ",
 	  (map { sprintf "0x%06x", $_ } @{ $special{$code}{Foldcase} });
-	printf $OT "\t{0x%06x, %s, ", $code, $special{$code}{Conditions};
+	printf $OT "\t{%s, ", $special{$code}{Conditions};
 	printf $OT "{{%s}, {%s}, {%s}, {%s}}},\n", $lower, $title, $upper, $fold;
 }
+print $OT "};\n";
 
-print $OT "\t{0, 0, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\n";
-print $OT <<"EOS";
-};
+my %types;
+my %duplicates;
+my @types = ("lower",  "title", "upper", "fold", "special");
+my $index = 1;
 
-/*
- * Case mapping table. Dense for codepoints < 0x80 (enabling fast lookup),
- * sparse for higher codepoints (requiring scan or binary search).
- */
-static const pg_case_map case_map[$num_simple] =
-{
-EOS
+# The first element at index 0 is reserved for handling a missing value (as NULL).
+$types{$_} = [[0, 0]] foreach @types;
 
-printf $OT "\t/* begin dense entries for codepoints < 0x80 */\n";
 for (my $code = 0; $code < 0x80; $code++)
 {
 	my $lc = ($simple{$code}{Simple_Lowercase} || $code);
@@ -358,26 +341,271 @@ for (my $code = 0; $code < 0x80; $code++)
 
 	die "unexpected special case for code $code"
 	  if defined $special{$code};
-	printf $OT
-	  "\t{0x%06x, {[CaseLower] = 0x%06x,[CaseTitle] = 0x%06x,[CaseUpper] = 0x%06x,[CaseFold] = 0x%06x}, NULL},\n",
-	  $code, $lc, $tc, $uc, $fc;
+
+	push @{$types{lower}}, [$lc, $code];
+	push @{$types{title}}, [$tc, $code];
+	push @{$types{upper}}, [$uc, $code];
+	push @{$types{fold}},  [$fc, $code];
+	push @{$types{special}}, [0, $code];
+
+	my $key = join ",", $lc, $tc, $uc, $fc, 0;
+
+	$simple{$code}{Index} = $index;
+	$duplicates{$key} = $index++;
 }
-printf $OT "\n";
 
-printf $OT "\t/* begin sparse entries for codepoints >= 0x80 */\n";
 foreach my $code (sort { $a <=> $b } (keys %simple))
 {
 	next unless $code >= 0x80;    # already output above
 
 	my $map = $simple{$code};
-	my $special_case = "NULL";
+	my $special_case = 0;
 	if (exists $special{$code})
 	{
-		$special_case = sprintf "&special_case[%d]", $special{$code}{Index};
+		$special_case = $special{$code}{Index};
 	}
-	printf $OT
-	  "\t{0x%06x, {[CaseLower] = 0x%06x,[CaseTitle] = 0x%06x,[CaseUpper] = 0x%06x,[CaseFold] = 0x%06x}, %s},\n",
-	  $code, $map->{Simple_Lowercase}, $map->{Simple_Titlecase},
+
+	# Almost half of the records in the table are duplicates. It makes no sense
+	# to store them separately.
+	my $key = join ",", $map->{Simple_Lowercase}, $map->{Simple_Titlecase},
 	  $map->{Simple_Uppercase}, $map->{Simple_Foldcase}, $special_case;
+
+	unless (exists $duplicates{$key})
+	{
+		$duplicates{$key} = $index++;
+
+		push @{$types{lower}}, [$map->{Simple_Lowercase}, $code];
+		push @{$types{title}}, [$map->{Simple_Titlecase}, $code];
+		push @{$types{upper}}, [$map->{Simple_Uppercase}, $code];
+		push @{$types{fold}}, [$map->{Simple_Foldcase}, $code];
+		push @{$types{special}}, [$special_case, $code];
+	}
+
+	$simple{$code}{Index} = $duplicates{$key};
+}
+
+my @casekind_index;
+
+# Create tables for each case type + one table with mapping to special characters.
+foreach my $name (@types)
+{
+	my $type = "uint32";
+	my $lines = join "\n", map {sprintf("\t0x%06x, /* 0x%06x */", @$_)} @{$types{$name}};
+	my $casename = "case_map_" . $name;
+
+	if ($name ne "special")
+	{
+		push @casekind_index, $casename;
+	} else
+	{
+		# The table with special cases does not exceed 110 entries, which fits
+		# into uint8_t. But we make a check because this table may increase in
+		# the future.
+		my $max = (sort {$b->[0] <=> $a->[0]} @{$types{$name}})[0][0];
+
+		if ($max < (2 ** 8))
+		{
+			$type = "uint8";
+		}
+		elsif ($max < (2 ** 16))
+		{
+			$type = "uint16";
+		}
+	}
+
+print $OT <<"EOS";
+
+/*
+ * Case mapping table for $name.
+ */
+static $type $casename\[$index] =
+{
+$lines
+};
+EOS
+}
+
+my $names = join ",\n\t", @casekind_index;
+
+print $OT <<"EOS";
+
+/*
+ * Case mapping.
+ */
+static uint32 *casekind_map[NCaseKind] =
+{
+	$names
+};
+EOS
+
+my $sub = sub {
+	my $code = shift;
+	return 0 unless exists $simple{$code};
+
+	return $simple{$code}{Index};
+};
+
+my @codepoints = keys %simple;
+my $range = make_range(\@codepoints, 500);
+my $table = range_tables($range, $sub);
+my $func = branch_function($range, 1);
+
+print $OT "\n$table\n$func\n";
+close $OT;
+
+sub branch_function
+{
+	my ($range, $fpath) = @_;
+	my ($first, @result);
+
+	push @result, "static inline uint16";
+	push @result, "case_index(pg_wchar cp)";
+	push @result, "{";
+
+	if ($fpath)
+	{
+		my $name = table_name();
+		$first = shift @$range;
+
+		push @result, sprintf("\t/* Fast path for codepoints < 0x%04X */", $first->[1]);
+		push @result, sprintf("\tif (cp < 0x%04X) {", $first->[1]);
+		push @result, "\t\treturn $name\[cp];";
+		push @result, "\t}\n";
+	}
+
+	push @result, join("\n", @{branch($range, 0, $#$range, 1)});
+	push @result, "\n\treturn 0;";
+	push @result, "}";
+
+	unshift @$range, $first if $fpath;
+
+	return join "\n", @result;
+}
+
+# The function generates C code with a series of nested if-else conditions
+# using binary search over sorted ranges.
+sub branch
+{
+	my ($range, $from, $to, $ind) = @_;
+	my ($idx, $space, $entry, $table, @result);
+
+	$idx = ($from + int(($to - $from) / 2));
+	return \@result unless exists $range->[$idx];
+
+	$space = join "", map {"\t"} 1..$ind;
+
+	$entry = $range->[$idx];
+	$table = table_name();
+
+	# IF state
+	if ($idx <= $from)
+	{
+		if ($idx == 0 && $entry->[0] != 0)
+		{
+			push @result, sprintf("%sif (cp >= 0x%04X && cp < 0x%04X) {",
+								  $space, $entry->[0], $entry->[1]);
+		} else
+		{
+			push @result, sprintf("%sif (cp < 0x%04X) {", $space, $entry->[1]);
+		}
+
+		push @result, sprintf("%s\treturn %s[cp - 0x%04X + 0x%04X];",
+							  $space, $table, $entry->[0], $entry->[3]);
+	} else
+	{
+		push @result, sprintf("%sif (cp < 0x%04X) {", $space, $entry->[1]);
+		push @result, @{branch($range, $from, $idx - 1, $ind + 1)};
+	}
+
+	push @result, $space. "}";
+
+	return \@result if $entry->[1] >= $range->[-1]->[1];
+
+	# ELSE state
+	push @result, sprintf("%selse if (cp >= 0x%04X) {", $space, $entry->[2]);
+
+	if ($idx == $to)
+	{
+		push @result, sprintf("%s\treturn $table\[cp - 0x%04X + 0x%04X];",
+							  $space, $entry->[2], $range->[$idx + 1]->[3]);
+	} else
+	{
+		push @result, @{branch($range, $idx + 1, $to, $ind + 1)};
+	}
+
+	push @result, $space. "}";
+
+	return \@result;
+}
+
+# The function groups numbers into ranges where the difference between
+# neighboring elements does not exceed $limit. If the difference is greater,
+# a new range is created. This is used to break the sequence into intervals
+# where the gaps between numbers are greater than limit, and then separate
+# ranges are formed.
+# For example, if there are numbers 1, 2, 3, 5, 6 and limit = 1,
+# then there is a difference of 2 between 3 and 5, which is greater than 1,
+# so there will be ranges 1-3 and 5-6.
+sub make_range
+{
+	my ($nums, $limit, $min) = @_;
+	my ($prev, $first, $last, $total, @sorted, @range);
+
+	@sorted = sort {$a <=> $b} @$nums;
+	$prev = defined $min ? $min : 0;
+	$first = $prev;
+	$last = $sorted[-1] + 1;
+	$total = 0;
+
+	foreach my $val (@sorted, $last)
+	{
+		my $dif = $val - $prev;
+
+		if ($dif > $limit || $val == $last)
+		{
+			# [FROM, TO, VALUE, OFFSET]
+			push @range, [$first, $prev, $val, $total];
+
+			$total += $prev - $first;
+			$first = $val;
+		}
+
+		$prev = $val + 1;
+	}
+
+	return \@range;
+}
+
+# The function combines all ranges into a single table.
+sub range_tables
+{
+	my ($range, $sub) = @_;
+	my (@lines, @result);
+
+	foreach my $entry (@$range)
+	{
+		my $from = $entry->[0];
+		my $to = $entry->[1] - 1;
+
+		foreach my $cp ($from..$to)
+		{
+			push @lines, sprintf("\t%s, /* U+%06X */", $sub->($cp), $cp);
+		}
+	}
+
+	my $name = table_name();
+	my $length = scalar @lines;
+	my $type = ($length < (2 ** 16)) ? "uint16_t" : "uint32_t";
+
+	push @result, "static const $type $name\[$length] =";
+	push @result, "{";
+	push @result, join("\n", @lines);
+	push @result, "};\n";
+
+	return join "\n", @result;
+}
+
+sub table_name
+{
+	return "case_map";
 }
-print $OT "};\n";
diff --git a/src/common/unicode_case.c b/src/common/unicode_case.c
index 2b3b4cdc2e7..6efed804881 100644
--- a/src/common/unicode_case.c
+++ b/src/common/unicode_case.c
@@ -27,7 +27,7 @@ enum CaseMapResult
 	CASEMAP_SPECIAL,
 };
 
-static const pg_case_map *find_case_map(pg_wchar ucs);
+static pg_wchar find_case_map(pg_wchar ucs, uint32 *map);
 static size_t convert_case(char *dst, size_t dstsize, const char *src, ssize_t srclen,
 						   CaseKind str_casekind, bool full, WordBoundaryNext wbnext,
 						   void *wbstate);
@@ -38,33 +38,33 @@ static enum CaseMapResult casemap(pg_wchar u1, CaseKind casekind, bool full,
 pg_wchar
 unicode_lowercase_simple(pg_wchar code)
 {
-	const pg_case_map *map = find_case_map(code);
+	pg_wchar	cp = find_case_map(code, case_map_lower);
 
-	return map ? map->simplemap[CaseLower] : code;
+	return cp != 0 ? cp : code;
 }
 
 pg_wchar
 unicode_titlecase_simple(pg_wchar code)
 {
-	const pg_case_map *map = find_case_map(code);
+	pg_wchar	cp = find_case_map(code, case_map_title);
 
-	return map ? map->simplemap[CaseTitle] : code;
+	return cp != 0 ? cp : code;
 }
 
 pg_wchar
 unicode_uppercase_simple(pg_wchar code)
 {
-	const pg_case_map *map = find_case_map(code);
+	pg_wchar	cp = find_case_map(code, case_map_upper);
 
-	return map ? map->simplemap[CaseUpper] : code;
+	return cp != 0 ? cp : code;
 }
 
 pg_wchar
 unicode_casefold_simple(pg_wchar code)
 {
-	const pg_case_map *map = find_case_map(code);
+	pg_wchar	cp = find_case_map(code, case_map_fold);
 
-	return map ? map->simplemap[CaseFold] : code;
+	return cp != 0 ? cp : code;
 }
 
 /*
@@ -388,64 +388,48 @@ casemap(pg_wchar u1, CaseKind casekind, bool full,
 		const char *src, size_t srclen, size_t srcoff,
 		pg_wchar *simple, const pg_wchar **special)
 {
-	const pg_case_map *map;
+	pg_wchar	idx;
 
+	/* Fast path for codepoints < 0x80 */
 	if (u1 < 0x80)
 	{
-		*simple = case_map[u1].simplemap[casekind];
+		/*
+		 * The first elements in all tables are reserved as 0 (as NULL). The
+		 * data starts at index 1, not 0.
+		 */
+		*simple = casekind_map[casekind][u1 + 1];
 
 		return CASEMAP_SIMPLE;
 	}
 
-	map = find_case_map(u1);
+	idx = case_index(u1);
 
-	if (map == NULL)
+	if (idx == 0)
 		return CASEMAP_SELF;
 
-	if (full && map->special_case != NULL &&
-		check_special_conditions(map->special_case->conditions,
+	if (full && case_map_special[idx] &&
+		check_special_conditions(special_case[case_map_special[idx]].conditions,
 								 src, srclen, srcoff))
 	{
-		*special = map->special_case->map[casekind];
+		*special = special_case[case_map_special[idx]].map[casekind];
 		return CASEMAP_SPECIAL;
 	}
 
-	*simple = map->simplemap[casekind];
+	*simple = casekind_map[casekind][idx];
 
 	return CASEMAP_SIMPLE;
 }
 
-/* find entry in simple case map, if any */
-static const pg_case_map *
-find_case_map(pg_wchar ucs)
+/*
+ * Find entry in simple case map.
+ * If the entry does not exist, 0 will be returned.
+ */
+static pg_wchar
+find_case_map(pg_wchar ucs, uint32 *map)
 {
-	int			min;
-	int			mid;
-	int			max;
-
-	/* all chars <= 0x80 are stored in array for fast lookup */
-	Assert(lengthof(case_map) >= 0x80);
+	/* Fast path for codepoints < 0x80 */
 	if (ucs < 0x80)
-	{
-		const pg_case_map *map = &case_map[ucs];
-
-		Assert(map->codepoint == ucs);
-		return map;
-	}
-
-	/* otherwise, binary search */
-	min = 0x80;
-	max = lengthof(case_map) - 1;
-	while (max >= min)
-	{
-		mid = (min + max) / 2;
-		if (ucs > case_map[mid].codepoint)
-			min = mid + 1;
-		else if (ucs < case_map[mid].codepoint)
-			max = mid - 1;
-		else
-			return &case_map[mid];
-	}
-
-	return NULL;
+		/* The first elements in all tables are reserved as 0 (as NULL). */
+		return map[ucs + 1];
+	return map[case_index(ucs)];
 }
diff --git a/src/include/common/unicode_case_table.h b/src/include/common/unicode_case_table.h
index 7ad284913d7..f95c704eeac 100644
--- a/src/include/common/unicode_case_table.h
+++ b/src/include/common/unicode_case_table.h
@@ -44,3142 +44,13266 @@ typedef enum
 
 typedef struct
 {
-	pg_wchar	codepoint;		/* Unicode codepoint */
 	int16		conditions;
 	pg_wchar	map[NCaseKind][MAX_CASE_EXPANSION];
 } pg_special_case;
 
-typedef struct
-{
-	pg_wchar	codepoint;		/* Unicode codepoint */
-	pg_wchar	simplemap[NCaseKind];
-	const pg_special_case *special_case;
-} pg_case_map;
-
 /*
  * Special case mappings that aren't representable in the simple map.
  * Entries are referenced from simple_case_map.
  */
 static const pg_special_case special_case[106] =
 {
-	{0x0000df, 0, {{0x0000df, 0x000000, 0x000000}, {0x000053, 0x000073, 0x000000}, {0x000053, 0x000053, 0x000000}, {0x000073, 0x000073, 0x000000}}},
-	{0x000130, 0, {{0x000069, 0x000307, 0x000000}, {0x000130, 0x000000, 0x000000}, {0x000130, 0x000000, 0x000000}, {0x000069, 0x000307, 0x000000}}},
-	{0x000149, 0, {{0x000149, 0x000000, 0x000000}, {0x0002bc, 0x00004e, 0x000000}, {0x0002bc, 0x00004e, 0x000000}, {0x0002bc, 0x00006e, 0x000000}}},
-	{0x0001f0, 0, {{0x0001f0, 0x000000, 0x000000}, {0x00004a, 0x00030c, 0x000000}, {0x00004a, 0x00030c, 0x000000}, {0x00006a, 0x00030c, 0x000000}}},
-	{0x000390, 0, {{0x000390, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000301}, {0x000399, 0x000308, 0x000301}, {0x0003b9, 0x000308, 0x000301}}},
-	{0x0003a3, PG_U_FINAL_SIGMA, {{0x0003c2, 0x000000, 0x000000}, {0x0003a3, 0x000000, 0x000000}, {0x0003a3, 0x000000, 0x000000}, {0x0003c3, 0x000000, 0x000000}}},
-	{0x0003b0, 0, {{0x0003b0, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000301}, {0x0003a5, 0x000308, 0x000301}, {0x0003c5, 0x000308, 0x000301}}},
-	{0x000587, 0, {{0x000587, 0x000000, 0x000000}, {0x000535, 0x000582, 0x000000}, {0x000535, 0x000552, 0x000000}, {0x000565, 0x000582, 0x000000}}},
-	{0x001e96, 0, {{0x001e96, 0x000000, 0x000000}, {0x000048, 0x000331, 0x000000}, {0x000048, 0x000331, 0x000000}, {0x000068, 0x000331, 0x000000}}},
-	{0x001e97, 0, {{0x001e97, 0x000000, 0x000000}, {0x000054, 0x000308, 0x000000}, {0x000054, 0x000308, 0x000000}, {0x000074, 0x000308, 0x000000}}},
-	{0x001e98, 0, {{0x001e98, 0x000000, 0x000000}, {0x000057, 0x00030a, 0x000000}, {0x000057, 0x00030a, 0x000000}, {0x000077, 0x00030a, 0x000000}}},
-	{0x001e99, 0, {{0x001e99, 0x000000, 0x000000}, {0x000059, 0x00030a, 0x000000}, {0x000059, 0x00030a, 0x000000}, {0x000079, 0x00030a, 0x000000}}},
-	{0x001e9a, 0, {{0x001e9a, 0x000000, 0x000000}, {0x000041, 0x0002be, 0x000000}, {0x000041, 0x0002be, 0x000000}, {0x000061, 0x0002be, 0x000000}}},
-	{0x001e9e, 0, {{0x0000df, 0x000000, 0x000000}, {0x001e9e, 0x000000, 0x000000}, {0x001e9e, 0x000000, 0x000000}, {0x000073, 0x000073, 0x000000}}},
-	{0x001f50, 0, {{0x001f50, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000000}, {0x0003a5, 0x000313, 0x000000}, {0x0003c5, 0x000313, 0x000000}}},
-	{0x001f52, 0, {{0x001f52, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000300}, {0x0003a5, 0x000313, 0x000300}, {0x0003c5, 0x000313, 0x000300}}},
-	{0x001f54, 0, {{0x001f54, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000301}, {0x0003a5, 0x000313, 0x000301}, {0x0003c5, 0x000313, 0x000301}}},
-	{0x001f56, 0, {{0x001f56, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000342}, {0x0003a5, 0x000313, 0x000342}, {0x0003c5, 0x000313, 0x000342}}},
-	{0x001f80, 0, {{0x001f80, 0x000000, 0x000000}, {0x001f88, 0x000000, 0x000000}, {0x001f08, 0x000399, 0x000000}, {0x001f00, 0x0003b9, 0x000000}}},
-	{0x001f81, 0, {{0x001f81, 0x000000, 0x000000}, {0x001f89, 0x000000, 0x000000}, {0x001f09, 0x000399, 0x000000}, {0x001f01, 0x0003b9, 0x000000}}},
-	{0x001f82, 0, {{0x001f82, 0x000000, 0x000000}, {0x001f8a, 0x000000, 0x000000}, {0x001f0a, 0x000399, 0x000000}, {0x001f02, 0x0003b9, 0x000000}}},
-	{0x001f83, 0, {{0x001f83, 0x000000, 0x000000}, {0x001f8b, 0x000000, 0x000000}, {0x001f0b, 0x000399, 0x000000}, {0x001f03, 0x0003b9, 0x000000}}},
-	{0x001f84, 0, {{0x001f84, 0x000000, 0x000000}, {0x001f8c, 0x000000, 0x000000}, {0x001f0c, 0x000399, 0x000000}, {0x001f04, 0x0003b9, 0x000000}}},
-	{0x001f85, 0, {{0x001f85, 0x000000, 0x000000}, {0x001f8d, 0x000000, 0x000000}, {0x001f0d, 0x000399, 0x000000}, {0x001f05, 0x0003b9, 0x000000}}},
-	{0x001f86, 0, {{0x001f86, 0x000000, 0x000000}, {0x001f8e, 0x000000, 0x000000}, {0x001f0e, 0x000399, 0x000000}, {0x001f06, 0x0003b9, 0x000000}}},
-	{0x001f87, 0, {{0x001f87, 0x000000, 0x000000}, {0x001f8f, 0x000000, 0x000000}, {0x001f0f, 0x000399, 0x000000}, {0x001f07, 0x0003b9, 0x000000}}},
-	{0x001f88, 0, {{0x001f80, 0x000000, 0x000000}, {0x001f88, 0x000000, 0x000000}, {0x001f08, 0x000399, 0x000000}, {0x001f00, 0x0003b9, 0x000000}}},
-	{0x001f89, 0, {{0x001f81, 0x000000, 0x000000}, {0x001f89, 0x000000, 0x000000}, {0x001f09, 0x000399, 0x000000}, {0x001f01, 0x0003b9, 0x000000}}},
-	{0x001f8a, 0, {{0x001f82, 0x000000, 0x000000}, {0x001f8a, 0x000000, 0x000000}, {0x001f0a, 0x000399, 0x000000}, {0x001f02, 0x0003b9, 0x000000}}},
-	{0x001f8b, 0, {{0x001f83, 0x000000, 0x000000}, {0x001f8b, 0x000000, 0x000000}, {0x001f0b, 0x000399, 0x000000}, {0x001f03, 0x0003b9, 0x000000}}},
-	{0x001f8c, 0, {{0x001f84, 0x000000, 0x000000}, {0x001f8c, 0x000000, 0x000000}, {0x001f0c, 0x000399, 0x000000}, {0x001f04, 0x0003b9, 0x000000}}},
-	{0x001f8d, 0, {{0x001f85, 0x000000, 0x000000}, {0x001f8d, 0x000000, 0x000000}, {0x001f0d, 0x000399, 0x000000}, {0x001f05, 0x0003b9, 0x000000}}},
-	{0x001f8e, 0, {{0x001f86, 0x000000, 0x000000}, {0x001f8e, 0x000000, 0x000000}, {0x001f0e, 0x000399, 0x000000}, {0x001f06, 0x0003b9, 0x000000}}},
-	{0x001f8f, 0, {{0x001f87, 0x000000, 0x000000}, {0x001f8f, 0x000000, 0x000000}, {0x001f0f, 0x000399, 0x000000}, {0x001f07, 0x0003b9, 0x000000}}},
-	{0x001f90, 0, {{0x001f90, 0x000000, 0x000000}, {0x001f98, 0x000000, 0x000000}, {0x001f28, 0x000399, 0x000000}, {0x001f20, 0x0003b9, 0x000000}}},
-	{0x001f91, 0, {{0x001f91, 0x000000, 0x000000}, {0x001f99, 0x000000, 0x000000}, {0x001f29, 0x000399, 0x000000}, {0x001f21, 0x0003b9, 0x000000}}},
-	{0x001f92, 0, {{0x001f92, 0x000000, 0x000000}, {0x001f9a, 0x000000, 0x000000}, {0x001f2a, 0x000399, 0x000000}, {0x001f22, 0x0003b9, 0x000000}}},
-	{0x001f93, 0, {{0x001f93, 0x000000, 0x000000}, {0x001f9b, 0x000000, 0x000000}, {0x001f2b, 0x000399, 0x000000}, {0x001f23, 0x0003b9, 0x000000}}},
-	{0x001f94, 0, {{0x001f94, 0x000000, 0x000000}, {0x001f9c, 0x000000, 0x000000}, {0x001f2c, 0x000399, 0x000000}, {0x001f24, 0x0003b9, 0x000000}}},
-	{0x001f95, 0, {{0x001f95, 0x000000, 0x000000}, {0x001f9d, 0x000000, 0x000000}, {0x001f2d, 0x000399, 0x000000}, {0x001f25, 0x0003b9, 0x000000}}},
-	{0x001f96, 0, {{0x001f96, 0x000000, 0x000000}, {0x001f9e, 0x000000, 0x000000}, {0x001f2e, 0x000399, 0x000000}, {0x001f26, 0x0003b9, 0x000000}}},
-	{0x001f97, 0, {{0x001f97, 0x000000, 0x000000}, {0x001f9f, 0x000000, 0x000000}, {0x001f2f, 0x000399, 0x000000}, {0x001f27, 0x0003b9, 0x000000}}},
-	{0x001f98, 0, {{0x001f90, 0x000000, 0x000000}, {0x001f98, 0x000000, 0x000000}, {0x001f28, 0x000399, 0x000000}, {0x001f20, 0x0003b9, 0x000000}}},
-	{0x001f99, 0, {{0x001f91, 0x000000, 0x000000}, {0x001f99, 0x000000, 0x000000}, {0x001f29, 0x000399, 0x000000}, {0x001f21, 0x0003b9, 0x000000}}},
-	{0x001f9a, 0, {{0x001f92, 0x000000, 0x000000}, {0x001f9a, 0x000000, 0x000000}, {0x001f2a, 0x000399, 0x000000}, {0x001f22, 0x0003b9, 0x000000}}},
-	{0x001f9b, 0, {{0x001f93, 0x000000, 0x000000}, {0x001f9b, 0x000000, 0x000000}, {0x001f2b, 0x000399, 0x000000}, {0x001f23, 0x0003b9, 0x000000}}},
-	{0x001f9c, 0, {{0x001f94, 0x000000, 0x000000}, {0x001f9c, 0x000000, 0x000000}, {0x001f2c, 0x000399, 0x000000}, {0x001f24, 0x0003b9, 0x000000}}},
-	{0x001f9d, 0, {{0x001f95, 0x000000, 0x000000}, {0x001f9d, 0x000000, 0x000000}, {0x001f2d, 0x000399, 0x000000}, {0x001f25, 0x0003b9, 0x000000}}},
-	{0x001f9e, 0, {{0x001f96, 0x000000, 0x000000}, {0x001f9e, 0x000000, 0x000000}, {0x001f2e, 0x000399, 0x000000}, {0x001f26, 0x0003b9, 0x000000}}},
-	{0x001f9f, 0, {{0x001f97, 0x000000, 0x000000}, {0x001f9f, 0x000000, 0x000000}, {0x001f2f, 0x000399, 0x000000}, {0x001f27, 0x0003b9, 0x000000}}},
-	{0x001fa0, 0, {{0x001fa0, 0x000000, 0x000000}, {0x001fa8, 0x000000, 0x000000}, {0x001f68, 0x000399, 0x000000}, {0x001f60, 0x0003b9, 0x000000}}},
-	{0x001fa1, 0, {{0x001fa1, 0x000000, 0x000000}, {0x001fa9, 0x000000, 0x000000}, {0x001f69, 0x000399, 0x000000}, {0x001f61, 0x0003b9, 0x000000}}},
-	{0x001fa2, 0, {{0x001fa2, 0x000000, 0x000000}, {0x001faa, 0x000000, 0x000000}, {0x001f6a, 0x000399, 0x000000}, {0x001f62, 0x0003b9, 0x000000}}},
-	{0x001fa3, 0, {{0x001fa3, 0x000000, 0x000000}, {0x001fab, 0x000000, 0x000000}, {0x001f6b, 0x000399, 0x000000}, {0x001f63, 0x0003b9, 0x000000}}},
-	{0x001fa4, 0, {{0x001fa4, 0x000000, 0x000000}, {0x001fac, 0x000000, 0x000000}, {0x001f6c, 0x000399, 0x000000}, {0x001f64, 0x0003b9, 0x000000}}},
-	{0x001fa5, 0, {{0x001fa5, 0x000000, 0x000000}, {0x001fad, 0x000000, 0x000000}, {0x001f6d, 0x000399, 0x000000}, {0x001f65, 0x0003b9, 0x000000}}},
-	{0x001fa6, 0, {{0x001fa6, 0x000000, 0x000000}, {0x001fae, 0x000000, 0x000000}, {0x001f6e, 0x000399, 0x000000}, {0x001f66, 0x0003b9, 0x000000}}},
-	{0x001fa7, 0, {{0x001fa7, 0x000000, 0x000000}, {0x001faf, 0x000000, 0x000000}, {0x001f6f, 0x000399, 0x000000}, {0x001f67, 0x0003b9, 0x000000}}},
-	{0x001fa8, 0, {{0x001fa0, 0x000000, 0x000000}, {0x001fa8, 0x000000, 0x000000}, {0x001f68, 0x000399, 0x000000}, {0x001f60, 0x0003b9, 0x000000}}},
-	{0x001fa9, 0, {{0x001fa1, 0x000000, 0x000000}, {0x001fa9, 0x000000, 0x000000}, {0x001f69, 0x000399, 0x000000}, {0x001f61, 0x0003b9, 0x000000}}},
-	{0x001faa, 0, {{0x001fa2, 0x000000, 0x000000}, {0x001faa, 0x000000, 0x000000}, {0x001f6a, 0x000399, 0x000000}, {0x001f62, 0x0003b9, 0x000000}}},
-	{0x001fab, 0, {{0x001fa3, 0x000000, 0x000000}, {0x001fab, 0x000000, 0x000000}, {0x001f6b, 0x000399, 0x000000}, {0x001f63, 0x0003b9, 0x000000}}},
-	{0x001fac, 0, {{0x001fa4, 0x000000, 0x000000}, {0x001fac, 0x000000, 0x000000}, {0x001f6c, 0x000399, 0x000000}, {0x001f64, 0x0003b9, 0x000000}}},
-	{0x001fad, 0, {{0x001fa5, 0x000000, 0x000000}, {0x001fad, 0x000000, 0x000000}, {0x001f6d, 0x000399, 0x000000}, {0x001f65, 0x0003b9, 0x000000}}},
-	{0x001fae, 0, {{0x001fa6, 0x000000, 0x000000}, {0x001fae, 0x000000, 0x000000}, {0x001f6e, 0x000399, 0x000000}, {0x001f66, 0x0003b9, 0x000000}}},
-	{0x001faf, 0, {{0x001fa7, 0x000000, 0x000000}, {0x001faf, 0x000000, 0x000000}, {0x001f6f, 0x000399, 0x000000}, {0x001f67, 0x0003b9, 0x000000}}},
-	{0x001fb2, 0, {{0x001fb2, 0x000000, 0x000000}, {0x001fba, 0x000345, 0x000000}, {0x001fba, 0x000399, 0x000000}, {0x001f70, 0x0003b9, 0x000000}}},
-	{0x001fb3, 0, {{0x001fb3, 0x000000, 0x000000}, {0x001fbc, 0x000000, 0x000000}, {0x000391, 0x000399, 0x000000}, {0x0003b1, 0x0003b9, 0x000000}}},
-	{0x001fb4, 0, {{0x001fb4, 0x000000, 0x000000}, {0x000386, 0x000345, 0x000000}, {0x000386, 0x000399, 0x000000}, {0x0003ac, 0x0003b9, 0x000000}}},
-	{0x001fb6, 0, {{0x001fb6, 0x000000, 0x000000}, {0x000391, 0x000342, 0x000000}, {0x000391, 0x000342, 0x000000}, {0x0003b1, 0x000342, 0x000000}}},
-	{0x001fb7, 0, {{0x001fb7, 0x000000, 0x000000}, {0x000391, 0x000342, 0x000345}, {0x000391, 0x000342, 0x000399}, {0x0003b1, 0x000342, 0x0003b9}}},
-	{0x001fbc, 0, {{0x001fb3, 0x000000, 0x000000}, {0x001fbc, 0x000000, 0x000000}, {0x000391, 0x000399, 0x000000}, {0x0003b1, 0x0003b9, 0x000000}}},
-	{0x001fc2, 0, {{0x001fc2, 0x000000, 0x000000}, {0x001fca, 0x000345, 0x000000}, {0x001fca, 0x000399, 0x000000}, {0x001f74, 0x0003b9, 0x000000}}},
-	{0x001fc3, 0, {{0x001fc3, 0x000000, 0x000000}, {0x001fcc, 0x000000, 0x000000}, {0x000397, 0x000399, 0x000000}, {0x0003b7, 0x0003b9, 0x000000}}},
-	{0x001fc4, 0, {{0x001fc4, 0x000000, 0x000000}, {0x000389, 0x000345, 0x000000}, {0x000389, 0x000399, 0x000000}, {0x0003ae, 0x0003b9, 0x000000}}},
-	{0x001fc6, 0, {{0x001fc6, 0x000000, 0x000000}, {0x000397, 0x000342, 0x000000}, {0x000397, 0x000342, 0x000000}, {0x0003b7, 0x000342, 0x000000}}},
-	{0x001fc7, 0, {{0x001fc7, 0x000000, 0x000000}, {0x000397, 0x000342, 0x000345}, {0x000397, 0x000342, 0x000399}, {0x0003b7, 0x000342, 0x0003b9}}},
-	{0x001fcc, 0, {{0x001fc3, 0x000000, 0x000000}, {0x001fcc, 0x000000, 0x000000}, {0x000397, 0x000399, 0x000000}, {0x0003b7, 0x0003b9, 0x000000}}},
-	{0x001fd2, 0, {{0x001fd2, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000300}, {0x000399, 0x000308, 0x000300}, {0x0003b9, 0x000308, 0x000300}}},
-	{0x001fd3, 0, {{0x001fd3, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000301}, {0x000399, 0x000308, 0x000301}, {0x0003b9, 0x000308, 0x000301}}},
-	{0x001fd6, 0, {{0x001fd6, 0x000000, 0x000000}, {0x000399, 0x000342, 0x000000}, {0x000399, 0x000342, 0x000000}, {0x0003b9, 0x000342, 0x000000}}},
-	{0x001fd7, 0, {{0x001fd7, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000342}, {0x000399, 0x000308, 0x000342}, {0x0003b9, 0x000308, 0x000342}}},
-	{0x001fe2, 0, {{0x001fe2, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000300}, {0x0003a5, 0x000308, 0x000300}, {0x0003c5, 0x000308, 0x000300}}},
-	{0x001fe3, 0, {{0x001fe3, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000301}, {0x0003a5, 0x000308, 0x000301}, {0x0003c5, 0x000308, 0x000301}}},
-	{0x001fe4, 0, {{0x001fe4, 0x000000, 0x000000}, {0x0003a1, 0x000313, 0x000000}, {0x0003a1, 0x000313, 0x000000}, {0x0003c1, 0x000313, 0x000000}}},
-	{0x001fe6, 0, {{0x001fe6, 0x000000, 0x000000}, {0x0003a5, 0x000342, 0x000000}, {0x0003a5, 0x000342, 0x000000}, {0x0003c5, 0x000342, 0x000000}}},
-	{0x001fe7, 0, {{0x001fe7, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000342}, {0x0003a5, 0x000308, 0x000342}, {0x0003c5, 0x000308, 0x000342}}},
-	{0x001ff2, 0, {{0x001ff2, 0x000000, 0x000000}, {0x001ffa, 0x000345, 0x000000}, {0x001ffa, 0x000399, 0x000000}, {0x001f7c, 0x0003b9, 0x000000}}},
-	{0x001ff3, 0, {{0x001ff3, 0x000000, 0x000000}, {0x001ffc, 0x000000, 0x000000}, {0x0003a9, 0x000399, 0x000000}, {0x0003c9, 0x0003b9, 0x000000}}},
-	{0x001ff4, 0, {{0x001ff4, 0x000000, 0x000000}, {0x00038f, 0x000345, 0x000000}, {0x00038f, 0x000399, 0x000000}, {0x0003ce, 0x0003b9, 0x000000}}},
-	{0x001ff6, 0, {{0x001ff6, 0x000000, 0x000000}, {0x0003a9, 0x000342, 0x000000}, {0x0003a9, 0x000342, 0x000000}, {0x0003c9, 0x000342, 0x000000}}},
-	{0x001ff7, 0, {{0x001ff7, 0x000000, 0x000000}, {0x0003a9, 0x000342, 0x000345}, {0x0003a9, 0x000342, 0x000399}, {0x0003c9, 0x000342, 0x0003b9}}},
-	{0x001ffc, 0, {{0x001ff3, 0x000000, 0x000000}, {0x001ffc, 0x000000, 0x000000}, {0x0003a9, 0x000399, 0x000000}, {0x0003c9, 0x0003b9, 0x000000}}},
-	{0x00fb00, 0, {{0x00fb00, 0x000000, 0x000000}, {0x000046, 0x000066, 0x000000}, {0x000046, 0x000046, 0x000000}, {0x000066, 0x000066, 0x000000}}},
-	{0x00fb01, 0, {{0x00fb01, 0x000000, 0x000000}, {0x000046, 0x000069, 0x000000}, {0x000046, 0x000049, 0x000000}, {0x000066, 0x000069, 0x000000}}},
-	{0x00fb02, 0, {{0x00fb02, 0x000000, 0x000000}, {0x000046, 0x00006c, 0x000000}, {0x000046, 0x00004c, 0x000000}, {0x000066, 0x00006c, 0x000000}}},
-	{0x00fb03, 0, {{0x00fb03, 0x000000, 0x000000}, {0x000046, 0x000066, 0x000069}, {0x000046, 0x000046, 0x000049}, {0x000066, 0x000066, 0x000069}}},
-	{0x00fb04, 0, {{0x00fb04, 0x000000, 0x000000}, {0x000046, 0x000066, 0x00006c}, {0x000046, 0x000046, 0x00004c}, {0x000066, 0x000066, 0x00006c}}},
-	{0x00fb05, 0, {{0x00fb05, 0x000000, 0x000000}, {0x000053, 0x000074, 0x000000}, {0x000053, 0x000054, 0x000000}, {0x000073, 0x000074, 0x000000}}},
-	{0x00fb06, 0, {{0x00fb06, 0x000000, 0x000000}, {0x000053, 0x000074, 0x000000}, {0x000053, 0x000054, 0x000000}, {0x000073, 0x000074, 0x000000}}},
-	{0x00fb13, 0, {{0x00fb13, 0x000000, 0x000000}, {0x000544, 0x000576, 0x000000}, {0x000544, 0x000546, 0x000000}, {0x000574, 0x000576, 0x000000}}},
-	{0x00fb14, 0, {{0x00fb14, 0x000000, 0x000000}, {0x000544, 0x000565, 0x000000}, {0x000544, 0x000535, 0x000000}, {0x000574, 0x000565, 0x000000}}},
-	{0x00fb15, 0, {{0x00fb15, 0x000000, 0x000000}, {0x000544, 0x00056b, 0x000000}, {0x000544, 0x00053b, 0x000000}, {0x000574, 0x00056b, 0x000000}}},
-	{0x00fb16, 0, {{0x00fb16, 0x000000, 0x000000}, {0x00054e, 0x000576, 0x000000}, {0x00054e, 0x000546, 0x000000}, {0x00057e, 0x000576, 0x000000}}},
-	{0x00fb17, 0, {{0x00fb17, 0x000000, 0x000000}, {0x000544, 0x00056d, 0x000000}, {0x000544, 0x00053d, 0x000000}, {0x000574, 0x00056d, 0x000000}}},
-	{0, 0, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}
+	{0, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}},
+	{0, {{0x0000df, 0x000000, 0x000000}, {0x000053, 0x000073, 0x000000}, {0x000053, 0x000053, 0x000000}, {0x000073, 0x000073, 0x000000}}},
+	{0, {{0x000069, 0x000307, 0x000000}, {0x000130, 0x000000, 0x000000}, {0x000130, 0x000000, 0x000000}, {0x000069, 0x000307, 0x000000}}},
+	{0, {{0x000149, 0x000000, 0x000000}, {0x0002bc, 0x00004e, 0x000000}, {0x0002bc, 0x00004e, 0x000000}, {0x0002bc, 0x00006e, 0x000000}}},
+	{0, {{0x0001f0, 0x000000, 0x000000}, {0x00004a, 0x00030c, 0x000000}, {0x00004a, 0x00030c, 0x000000}, {0x00006a, 0x00030c, 0x000000}}},
+	{0, {{0x000390, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000301}, {0x000399, 0x000308, 0x000301}, {0x0003b9, 0x000308, 0x000301}}},
+	{PG_U_FINAL_SIGMA, {{0x0003c2, 0x000000, 0x000000}, {0x0003a3, 0x000000, 0x000000}, {0x0003a3, 0x000000, 0x000000}, {0x0003c3, 0x000000, 0x000000}}},
+	{0, {{0x0003b0, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000301}, {0x0003a5, 0x000308, 0x000301}, {0x0003c5, 0x000308, 0x000301}}},
+	{0, {{0x000587, 0x000000, 0x000000}, {0x000535, 0x000582, 0x000000}, {0x000535, 0x000552, 0x000000}, {0x000565, 0x000582, 0x000000}}},
+	{0, {{0x001e96, 0x000000, 0x000000}, {0x000048, 0x000331, 0x000000}, {0x000048, 0x000331, 0x000000}, {0x000068, 0x000331, 0x000000}}},
+	{0, {{0x001e97, 0x000000, 0x000000}, {0x000054, 0x000308, 0x000000}, {0x000054, 0x000308, 0x000000}, {0x000074, 0x000308, 0x000000}}},
+	{0, {{0x001e98, 0x000000, 0x000000}, {0x000057, 0x00030a, 0x000000}, {0x000057, 0x00030a, 0x000000}, {0x000077, 0x00030a, 0x000000}}},
+	{0, {{0x001e99, 0x000000, 0x000000}, {0x000059, 0x00030a, 0x000000}, {0x000059, 0x00030a, 0x000000}, {0x000079, 0x00030a, 0x000000}}},
+	{0, {{0x001e9a, 0x000000, 0x000000}, {0x000041, 0x0002be, 0x000000}, {0x000041, 0x0002be, 0x000000}, {0x000061, 0x0002be, 0x000000}}},
+	{0, {{0x0000df, 0x000000, 0x000000}, {0x001e9e, 0x000000, 0x000000}, {0x001e9e, 0x000000, 0x000000}, {0x000073, 0x000073, 0x000000}}},
+	{0, {{0x001f50, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000000}, {0x0003a5, 0x000313, 0x000000}, {0x0003c5, 0x000313, 0x000000}}},
+	{0, {{0x001f52, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000300}, {0x0003a5, 0x000313, 0x000300}, {0x0003c5, 0x000313, 0x000300}}},
+	{0, {{0x001f54, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000301}, {0x0003a5, 0x000313, 0x000301}, {0x0003c5, 0x000313, 0x000301}}},
+	{0, {{0x001f56, 0x000000, 0x000000}, {0x0003a5, 0x000313, 0x000342}, {0x0003a5, 0x000313, 0x000342}, {0x0003c5, 0x000313, 0x000342}}},
+	{0, {{0x001f80, 0x000000, 0x000000}, {0x001f88, 0x000000, 0x000000}, {0x001f08, 0x000399, 0x000000}, {0x001f00, 0x0003b9, 0x000000}}},
+	{0, {{0x001f81, 0x000000, 0x000000}, {0x001f89, 0x000000, 0x000000}, {0x001f09, 0x000399, 0x000000}, {0x001f01, 0x0003b9, 0x000000}}},
+	{0, {{0x001f82, 0x000000, 0x000000}, {0x001f8a, 0x000000, 0x000000}, {0x001f0a, 0x000399, 0x000000}, {0x001f02, 0x0003b9, 0x000000}}},
+	{0, {{0x001f83, 0x000000, 0x000000}, {0x001f8b, 0x000000, 0x000000}, {0x001f0b, 0x000399, 0x000000}, {0x001f03, 0x0003b9, 0x000000}}},
+	{0, {{0x001f84, 0x000000, 0x000000}, {0x001f8c, 0x000000, 0x000000}, {0x001f0c, 0x000399, 0x000000}, {0x001f04, 0x0003b9, 0x000000}}},
+	{0, {{0x001f85, 0x000000, 0x000000}, {0x001f8d, 0x000000, 0x000000}, {0x001f0d, 0x000399, 0x000000}, {0x001f05, 0x0003b9, 0x000000}}},
+	{0, {{0x001f86, 0x000000, 0x000000}, {0x001f8e, 0x000000, 0x000000}, {0x001f0e, 0x000399, 0x000000}, {0x001f06, 0x0003b9, 0x000000}}},
+	{0, {{0x001f87, 0x000000, 0x000000}, {0x001f8f, 0x000000, 0x000000}, {0x001f0f, 0x000399, 0x000000}, {0x001f07, 0x0003b9, 0x000000}}},
+	{0, {{0x001f80, 0x000000, 0x000000}, {0x001f88, 0x000000, 0x000000}, {0x001f08, 0x000399, 0x000000}, {0x001f00, 0x0003b9, 0x000000}}},
+	{0, {{0x001f81, 0x000000, 0x000000}, {0x001f89, 0x000000, 0x000000}, {0x001f09, 0x000399, 0x000000}, {0x001f01, 0x0003b9, 0x000000}}},
+	{0, {{0x001f82, 0x000000, 0x000000}, {0x001f8a, 0x000000, 0x000000}, {0x001f0a, 0x000399, 0x000000}, {0x001f02, 0x0003b9, 0x000000}}},
+	{0, {{0x001f83, 0x000000, 0x000000}, {0x001f8b, 0x000000, 0x000000}, {0x001f0b, 0x000399, 0x000000}, {0x001f03, 0x0003b9, 0x000000}}},
+	{0, {{0x001f84, 0x000000, 0x000000}, {0x001f8c, 0x000000, 0x000000}, {0x001f0c, 0x000399, 0x000000}, {0x001f04, 0x0003b9, 0x000000}}},
+	{0, {{0x001f85, 0x000000, 0x000000}, {0x001f8d, 0x000000, 0x000000}, {0x001f0d, 0x000399, 0x000000}, {0x001f05, 0x0003b9, 0x000000}}},
+	{0, {{0x001f86, 0x000000, 0x000000}, {0x001f8e, 0x000000, 0x000000}, {0x001f0e, 0x000399, 0x000000}, {0x001f06, 0x0003b9, 0x000000}}},
+	{0, {{0x001f87, 0x000000, 0x000000}, {0x001f8f, 0x000000, 0x000000}, {0x001f0f, 0x000399, 0x000000}, {0x001f07, 0x0003b9, 0x000000}}},
+	{0, {{0x001f90, 0x000000, 0x000000}, {0x001f98, 0x000000, 0x000000}, {0x001f28, 0x000399, 0x000000}, {0x001f20, 0x0003b9, 0x000000}}},
+	{0, {{0x001f91, 0x000000, 0x000000}, {0x001f99, 0x000000, 0x000000}, {0x001f29, 0x000399, 0x000000}, {0x001f21, 0x0003b9, 0x000000}}},
+	{0, {{0x001f92, 0x000000, 0x000000}, {0x001f9a, 0x000000, 0x000000}, {0x001f2a, 0x000399, 0x000000}, {0x001f22, 0x0003b9, 0x000000}}},
+	{0, {{0x001f93, 0x000000, 0x000000}, {0x001f9b, 0x000000, 0x000000}, {0x001f2b, 0x000399, 0x000000}, {0x001f23, 0x0003b9, 0x000000}}},
+	{0, {{0x001f94, 0x000000, 0x000000}, {0x001f9c, 0x000000, 0x000000}, {0x001f2c, 0x000399, 0x000000}, {0x001f24, 0x0003b9, 0x000000}}},
+	{0, {{0x001f95, 0x000000, 0x000000}, {0x001f9d, 0x000000, 0x000000}, {0x001f2d, 0x000399, 0x000000}, {0x001f25, 0x0003b9, 0x000000}}},
+	{0, {{0x001f96, 0x000000, 0x000000}, {0x001f9e, 0x000000, 0x000000}, {0x001f2e, 0x000399, 0x000000}, {0x001f26, 0x0003b9, 0x000000}}},
+	{0, {{0x001f97, 0x000000, 0x000000}, {0x001f9f, 0x000000, 0x000000}, {0x001f2f, 0x000399, 0x000000}, {0x001f27, 0x0003b9, 0x000000}}},
+	{0, {{0x001f90, 0x000000, 0x000000}, {0x001f98, 0x000000, 0x000000}, {0x001f28, 0x000399, 0x000000}, {0x001f20, 0x0003b9, 0x000000}}},
+	{0, {{0x001f91, 0x000000, 0x000000}, {0x001f99, 0x000000, 0x000000}, {0x001f29, 0x000399, 0x000000}, {0x001f21, 0x0003b9, 0x000000}}},
+	{0, {{0x001f92, 0x000000, 0x000000}, {0x001f9a, 0x000000, 0x000000}, {0x001f2a, 0x000399, 0x000000}, {0x001f22, 0x0003b9, 0x000000}}},
+	{0, {{0x001f93, 0x000000, 0x000000}, {0x001f9b, 0x000000, 0x000000}, {0x001f2b, 0x000399, 0x000000}, {0x001f23, 0x0003b9, 0x000000}}},
+	{0, {{0x001f94, 0x000000, 0x000000}, {0x001f9c, 0x000000, 0x000000}, {0x001f2c, 0x000399, 0x000000}, {0x001f24, 0x0003b9, 0x000000}}},
+	{0, {{0x001f95, 0x000000, 0x000000}, {0x001f9d, 0x000000, 0x000000}, {0x001f2d, 0x000399, 0x000000}, {0x001f25, 0x0003b9, 0x000000}}},
+	{0, {{0x001f96, 0x000000, 0x000000}, {0x001f9e, 0x000000, 0x000000}, {0x001f2e, 0x000399, 0x000000}, {0x001f26, 0x0003b9, 0x000000}}},
+	{0, {{0x001f97, 0x000000, 0x000000}, {0x001f9f, 0x000000, 0x000000}, {0x001f2f, 0x000399, 0x000000}, {0x001f27, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa0, 0x000000, 0x000000}, {0x001fa8, 0x000000, 0x000000}, {0x001f68, 0x000399, 0x000000}, {0x001f60, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa1, 0x000000, 0x000000}, {0x001fa9, 0x000000, 0x000000}, {0x001f69, 0x000399, 0x000000}, {0x001f61, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa2, 0x000000, 0x000000}, {0x001faa, 0x000000, 0x000000}, {0x001f6a, 0x000399, 0x000000}, {0x001f62, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa3, 0x000000, 0x000000}, {0x001fab, 0x000000, 0x000000}, {0x001f6b, 0x000399, 0x000000}, {0x001f63, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa4, 0x000000, 0x000000}, {0x001fac, 0x000000, 0x000000}, {0x001f6c, 0x000399, 0x000000}, {0x001f64, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa5, 0x000000, 0x000000}, {0x001fad, 0x000000, 0x000000}, {0x001f6d, 0x000399, 0x000000}, {0x001f65, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa6, 0x000000, 0x000000}, {0x001fae, 0x000000, 0x000000}, {0x001f6e, 0x000399, 0x000000}, {0x001f66, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa7, 0x000000, 0x000000}, {0x001faf, 0x000000, 0x000000}, {0x001f6f, 0x000399, 0x000000}, {0x001f67, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa0, 0x000000, 0x000000}, {0x001fa8, 0x000000, 0x000000}, {0x001f68, 0x000399, 0x000000}, {0x001f60, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa1, 0x000000, 0x000000}, {0x001fa9, 0x000000, 0x000000}, {0x001f69, 0x000399, 0x000000}, {0x001f61, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa2, 0x000000, 0x000000}, {0x001faa, 0x000000, 0x000000}, {0x001f6a, 0x000399, 0x000000}, {0x001f62, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa3, 0x000000, 0x000000}, {0x001fab, 0x000000, 0x000000}, {0x001f6b, 0x000399, 0x000000}, {0x001f63, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa4, 0x000000, 0x000000}, {0x001fac, 0x000000, 0x000000}, {0x001f6c, 0x000399, 0x000000}, {0x001f64, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa5, 0x000000, 0x000000}, {0x001fad, 0x000000, 0x000000}, {0x001f6d, 0x000399, 0x000000}, {0x001f65, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa6, 0x000000, 0x000000}, {0x001fae, 0x000000, 0x000000}, {0x001f6e, 0x000399, 0x000000}, {0x001f66, 0x0003b9, 0x000000}}},
+	{0, {{0x001fa7, 0x000000, 0x000000}, {0x001faf, 0x000000, 0x000000}, {0x001f6f, 0x000399, 0x000000}, {0x001f67, 0x0003b9, 0x000000}}},
+	{0, {{0x001fb2, 0x000000, 0x000000}, {0x001fba, 0x000345, 0x000000}, {0x001fba, 0x000399, 0x000000}, {0x001f70, 0x0003b9, 0x000000}}},
+	{0, {{0x001fb3, 0x000000, 0x000000}, {0x001fbc, 0x000000, 0x000000}, {0x000391, 0x000399, 0x000000}, {0x0003b1, 0x0003b9, 0x000000}}},
+	{0, {{0x001fb4, 0x000000, 0x000000}, {0x000386, 0x000345, 0x000000}, {0x000386, 0x000399, 0x000000}, {0x0003ac, 0x0003b9, 0x000000}}},
+	{0, {{0x001fb6, 0x000000, 0x000000}, {0x000391, 0x000342, 0x000000}, {0x000391, 0x000342, 0x000000}, {0x0003b1, 0x000342, 0x000000}}},
+	{0, {{0x001fb7, 0x000000, 0x000000}, {0x000391, 0x000342, 0x000345}, {0x000391, 0x000342, 0x000399}, {0x0003b1, 0x000342, 0x0003b9}}},
+	{0, {{0x001fb3, 0x000000, 0x000000}, {0x001fbc, 0x000000, 0x000000}, {0x000391, 0x000399, 0x000000}, {0x0003b1, 0x0003b9, 0x000000}}},
+	{0, {{0x001fc2, 0x000000, 0x000000}, {0x001fca, 0x000345, 0x000000}, {0x001fca, 0x000399, 0x000000}, {0x001f74, 0x0003b9, 0x000000}}},
+	{0, {{0x001fc3, 0x000000, 0x000000}, {0x001fcc, 0x000000, 0x000000}, {0x000397, 0x000399, 0x000000}, {0x0003b7, 0x0003b9, 0x000000}}},
+	{0, {{0x001fc4, 0x000000, 0x000000}, {0x000389, 0x000345, 0x000000}, {0x000389, 0x000399, 0x000000}, {0x0003ae, 0x0003b9, 0x000000}}},
+	{0, {{0x001fc6, 0x000000, 0x000000}, {0x000397, 0x000342, 0x000000}, {0x000397, 0x000342, 0x000000}, {0x0003b7, 0x000342, 0x000000}}},
+	{0, {{0x001fc7, 0x000000, 0x000000}, {0x000397, 0x000342, 0x000345}, {0x000397, 0x000342, 0x000399}, {0x0003b7, 0x000342, 0x0003b9}}},
+	{0, {{0x001fc3, 0x000000, 0x000000}, {0x001fcc, 0x000000, 0x000000}, {0x000397, 0x000399, 0x000000}, {0x0003b7, 0x0003b9, 0x000000}}},
+	{0, {{0x001fd2, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000300}, {0x000399, 0x000308, 0x000300}, {0x0003b9, 0x000308, 0x000300}}},
+	{0, {{0x001fd3, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000301}, {0x000399, 0x000308, 0x000301}, {0x0003b9, 0x000308, 0x000301}}},
+	{0, {{0x001fd6, 0x000000, 0x000000}, {0x000399, 0x000342, 0x000000}, {0x000399, 0x000342, 0x000000}, {0x0003b9, 0x000342, 0x000000}}},
+	{0, {{0x001fd7, 0x000000, 0x000000}, {0x000399, 0x000308, 0x000342}, {0x000399, 0x000308, 0x000342}, {0x0003b9, 0x000308, 0x000342}}},
+	{0, {{0x001fe2, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000300}, {0x0003a5, 0x000308, 0x000300}, {0x0003c5, 0x000308, 0x000300}}},
+	{0, {{0x001fe3, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000301}, {0x0003a5, 0x000308, 0x000301}, {0x0003c5, 0x000308, 0x000301}}},
+	{0, {{0x001fe4, 0x000000, 0x000000}, {0x0003a1, 0x000313, 0x000000}, {0x0003a1, 0x000313, 0x000000}, {0x0003c1, 0x000313, 0x000000}}},
+	{0, {{0x001fe6, 0x000000, 0x000000}, {0x0003a5, 0x000342, 0x000000}, {0x0003a5, 0x000342, 0x000000}, {0x0003c5, 0x000342, 0x000000}}},
+	{0, {{0x001fe7, 0x000000, 0x000000}, {0x0003a5, 0x000308, 0x000342}, {0x0003a5, 0x000308, 0x000342}, {0x0003c5, 0x000308, 0x000342}}},
+	{0, {{0x001ff2, 0x000000, 0x000000}, {0x001ffa, 0x000345, 0x000000}, {0x001ffa, 0x000399, 0x000000}, {0x001f7c, 0x0003b9, 0x000000}}},
+	{0, {{0x001ff3, 0x000000, 0x000000}, {0x001ffc, 0x000000, 0x000000}, {0x0003a9, 0x000399, 0x000000}, {0x0003c9, 0x0003b9, 0x000000}}},
+	{0, {{0x001ff4, 0x000000, 0x000000}, {0x00038f, 0x000345, 0x000000}, {0x00038f, 0x000399, 0x000000}, {0x0003ce, 0x0003b9, 0x000000}}},
+	{0, {{0x001ff6, 0x000000, 0x000000}, {0x0003a9, 0x000342, 0x000000}, {0x0003a9, 0x000342, 0x000000}, {0x0003c9, 0x000342, 0x000000}}},
+	{0, {{0x001ff7, 0x000000, 0x000000}, {0x0003a9, 0x000342, 0x000345}, {0x0003a9, 0x000342, 0x000399}, {0x0003c9, 0x000342, 0x0003b9}}},
+	{0, {{0x001ff3, 0x000000, 0x000000}, {0x001ffc, 0x000000, 0x000000}, {0x0003a9, 0x000399, 0x000000}, {0x0003c9, 0x0003b9, 0x000000}}},
+	{0, {{0x00fb00, 0x000000, 0x000000}, {0x000046, 0x000066, 0x000000}, {0x000046, 0x000046, 0x000000}, {0x000066, 0x000066, 0x000000}}},
+	{0, {{0x00fb01, 0x000000, 0x000000}, {0x000046, 0x000069, 0x000000}, {0x000046, 0x000049, 0x000000}, {0x000066, 0x000069, 0x000000}}},
+	{0, {{0x00fb02, 0x000000, 0x000000}, {0x000046, 0x00006c, 0x000000}, {0x000046, 0x00004c, 0x000000}, {0x000066, 0x00006c, 0x000000}}},
+	{0, {{0x00fb03, 0x000000, 0x000000}, {0x000046, 0x000066, 0x000069}, {0x000046, 0x000046, 0x000049}, {0x000066, 0x000066, 0x000069}}},
+	{0, {{0x00fb04, 0x000000, 0x000000}, {0x000046, 0x000066, 0x00006c}, {0x000046, 0x000046, 0x00004c}, {0x000066, 0x000066, 0x00006c}}},
+	{0, {{0x00fb05, 0x000000, 0x000000}, {0x000053, 0x000074, 0x000000}, {0x000053, 0x000054, 0x000000}, {0x000073, 0x000074, 0x000000}}},
+	{0, {{0x00fb06, 0x000000, 0x000000}, {0x000053, 0x000074, 0x000000}, {0x000053, 0x000054, 0x000000}, {0x000073, 0x000074, 0x000000}}},
+	{0, {{0x00fb13, 0x000000, 0x000000}, {0x000544, 0x000576, 0x000000}, {0x000544, 0x000546, 0x000000}, {0x000574, 0x000576, 0x000000}}},
+	{0, {{0x00fb14, 0x000000, 0x000000}, {0x000544, 0x000565, 0x000000}, {0x000544, 0x000535, 0x000000}, {0x000574, 0x000565, 0x000000}}},
+	{0, {{0x00fb15, 0x000000, 0x000000}, {0x000544, 0x00056b, 0x000000}, {0x000544, 0x00053b, 0x000000}, {0x000574, 0x00056b, 0x000000}}},
+	{0, {{0x00fb16, 0x000000, 0x000000}, {0x00054e, 0x000576, 0x000000}, {0x00054e, 0x000546, 0x000000}, {0x00057e, 0x000576, 0x000000}}},
+	{0, {{0x00fb17, 0x000000, 0x000000}, {0x000544, 0x00056d, 0x000000}, {0x000544, 0x00053d, 0x000000}, {0x000574, 0x00056d, 0x000000}}},
+};
+
+/*
+ * Case mapping table for lower.
+ */
+static uint32 case_map_lower[1677] =
+{
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000000 */
+	0x000001, /* 0x000001 */
+	0x000002, /* 0x000002 */
+	0x000003, /* 0x000003 */
+	0x000004, /* 0x000004 */
+	0x000005, /* 0x000005 */
+	0x000006, /* 0x000006 */
+	0x000007, /* 0x000007 */
+	0x000008, /* 0x000008 */
+	0x000009, /* 0x000009 */
+	0x00000a, /* 0x00000a */
+	0x00000b, /* 0x00000b */
+	0x00000c, /* 0x00000c */
+	0x00000d, /* 0x00000d */
+	0x00000e, /* 0x00000e */
+	0x00000f, /* 0x00000f */
+	0x000010, /* 0x000010 */
+	0x000011, /* 0x000011 */
+	0x000012, /* 0x000012 */
+	0x000013, /* 0x000013 */
+	0x000014, /* 0x000014 */
+	0x000015, /* 0x000015 */
+	0x000016, /* 0x000016 */
+	0x000017, /* 0x000017 */
+	0x000018, /* 0x000018 */
+	0x000019, /* 0x000019 */
+	0x00001a, /* 0x00001a */
+	0x00001b, /* 0x00001b */
+	0x00001c, /* 0x00001c */
+	0x00001d, /* 0x00001d */
+	0x00001e, /* 0x00001e */
+	0x00001f, /* 0x00001f */
+	0x000020, /* 0x000020 */
+	0x000021, /* 0x000021 */
+	0x000022, /* 0x000022 */
+	0x000023, /* 0x000023 */
+	0x000024, /* 0x000024 */
+	0x000025, /* 0x000025 */
+	0x000026, /* 0x000026 */
+	0x000027, /* 0x000027 */
+	0x000028, /* 0x000028 */
+	0x000029, /* 0x000029 */
+	0x00002a, /* 0x00002a */
+	0x00002b, /* 0x00002b */
+	0x00002c, /* 0x00002c */
+	0x00002d, /* 0x00002d */
+	0x00002e, /* 0x00002e */
+	0x00002f, /* 0x00002f */
+	0x000030, /* 0x000030 */
+	0x000031, /* 0x000031 */
+	0x000032, /* 0x000032 */
+	0x000033, /* 0x000033 */
+	0x000034, /* 0x000034 */
+	0x000035, /* 0x000035 */
+	0x000036, /* 0x000036 */
+	0x000037, /* 0x000037 */
+	0x000038, /* 0x000038 */
+	0x000039, /* 0x000039 */
+	0x00003a, /* 0x00003a */
+	0x00003b, /* 0x00003b */
+	0x00003c, /* 0x00003c */
+	0x00003d, /* 0x00003d */
+	0x00003e, /* 0x00003e */
+	0x00003f, /* 0x00003f */
+	0x000040, /* 0x000040 */
+	0x000061, /* 0x000041 */
+	0x000062, /* 0x000042 */
+	0x000063, /* 0x000043 */
+	0x000064, /* 0x000044 */
+	0x000065, /* 0x000045 */
+	0x000066, /* 0x000046 */
+	0x000067, /* 0x000047 */
+	0x000068, /* 0x000048 */
+	0x000069, /* 0x000049 */
+	0x00006a, /* 0x00004a */
+	0x00006b, /* 0x00004b */
+	0x00006c, /* 0x00004c */
+	0x00006d, /* 0x00004d */
+	0x00006e, /* 0x00004e */
+	0x00006f, /* 0x00004f */
+	0x000070, /* 0x000050 */
+	0x000071, /* 0x000051 */
+	0x000072, /* 0x000052 */
+	0x000073, /* 0x000053 */
+	0x000074, /* 0x000054 */
+	0x000075, /* 0x000055 */
+	0x000076, /* 0x000056 */
+	0x000077, /* 0x000057 */
+	0x000078, /* 0x000058 */
+	0x000079, /* 0x000059 */
+	0x00007a, /* 0x00005a */
+	0x00005b, /* 0x00005b */
+	0x00005c, /* 0x00005c */
+	0x00005d, /* 0x00005d */
+	0x00005e, /* 0x00005e */
+	0x00005f, /* 0x00005f */
+	0x000060, /* 0x000060 */
+	0x000061, /* 0x000061 */
+	0x000062, /* 0x000062 */
+	0x000063, /* 0x000063 */
+	0x000064, /* 0x000064 */
+	0x000065, /* 0x000065 */
+	0x000066, /* 0x000066 */
+	0x000067, /* 0x000067 */
+	0x000068, /* 0x000068 */
+	0x000069, /* 0x000069 */
+	0x00006a, /* 0x00006a */
+	0x00006b, /* 0x00006b */
+	0x00006c, /* 0x00006c */
+	0x00006d, /* 0x00006d */
+	0x00006e, /* 0x00006e */
+	0x00006f, /* 0x00006f */
+	0x000070, /* 0x000070 */
+	0x000071, /* 0x000071 */
+	0x000072, /* 0x000072 */
+	0x000073, /* 0x000073 */
+	0x000074, /* 0x000074 */
+	0x000075, /* 0x000075 */
+	0x000076, /* 0x000076 */
+	0x000077, /* 0x000077 */
+	0x000078, /* 0x000078 */
+	0x000079, /* 0x000079 */
+	0x00007a, /* 0x00007a */
+	0x00007b, /* 0x00007b */
+	0x00007c, /* 0x00007c */
+	0x00007d, /* 0x00007d */
+	0x00007e, /* 0x00007e */
+	0x00007f, /* 0x00007f */
+	0x0000b5, /* 0x0000b5 */
+	0x0000e0, /* 0x0000c0 */
+	0x0000e1, /* 0x0000c1 */
+	0x0000e2, /* 0x0000c2 */
+	0x0000e3, /* 0x0000c3 */
+	0x0000e4, /* 0x0000c4 */
+	0x0000e5, /* 0x0000c5 */
+	0x0000e6, /* 0x0000c6 */
+	0x0000e7, /* 0x0000c7 */
+	0x0000e8, /* 0x0000c8 */
+	0x0000e9, /* 0x0000c9 */
+	0x0000ea, /* 0x0000ca */
+	0x0000eb, /* 0x0000cb */
+	0x0000ec, /* 0x0000cc */
+	0x0000ed, /* 0x0000cd */
+	0x0000ee, /* 0x0000ce */
+	0x0000ef, /* 0x0000cf */
+	0x0000f0, /* 0x0000d0 */
+	0x0000f1, /* 0x0000d1 */
+	0x0000f2, /* 0x0000d2 */
+	0x0000f3, /* 0x0000d3 */
+	0x0000f4, /* 0x0000d4 */
+	0x0000f5, /* 0x0000d5 */
+	0x0000f6, /* 0x0000d6 */
+	0x0000f8, /* 0x0000d8 */
+	0x0000f9, /* 0x0000d9 */
+	0x0000fa, /* 0x0000da */
+	0x0000fb, /* 0x0000db */
+	0x0000fc, /* 0x0000dc */
+	0x0000fd, /* 0x0000dd */
+	0x0000fe, /* 0x0000de */
+	0x0000df, /* 0x0000df */
+	0x0000ff, /* 0x0000ff */
+	0x000101, /* 0x000100 */
+	0x000103, /* 0x000102 */
+	0x000105, /* 0x000104 */
+	0x000107, /* 0x000106 */
+	0x000109, /* 0x000108 */
+	0x00010b, /* 0x00010a */
+	0x00010d, /* 0x00010c */
+	0x00010f, /* 0x00010e */
+	0x000111, /* 0x000110 */
+	0x000113, /* 0x000112 */
+	0x000115, /* 0x000114 */
+	0x000117, /* 0x000116 */
+	0x000119, /* 0x000118 */
+	0x00011b, /* 0x00011a */
+	0x00011d, /* 0x00011c */
+	0x00011f, /* 0x00011e */
+	0x000121, /* 0x000120 */
+	0x000123, /* 0x000122 */
+	0x000125, /* 0x000124 */
+	0x000127, /* 0x000126 */
+	0x000129, /* 0x000128 */
+	0x00012b, /* 0x00012a */
+	0x00012d, /* 0x00012c */
+	0x00012f, /* 0x00012e */
+	0x000069, /* 0x000130 */
+	0x000131, /* 0x000131 */
+	0x000133, /* 0x000132 */
+	0x000135, /* 0x000134 */
+	0x000137, /* 0x000136 */
+	0x00013a, /* 0x000139 */
+	0x00013c, /* 0x00013b */
+	0x00013e, /* 0x00013d */
+	0x000140, /* 0x00013f */
+	0x000142, /* 0x000141 */
+	0x000144, /* 0x000143 */
+	0x000146, /* 0x000145 */
+	0x000148, /* 0x000147 */
+	0x000149, /* 0x000149 */
+	0x00014b, /* 0x00014a */
+	0x00014d, /* 0x00014c */
+	0x00014f, /* 0x00014e */
+	0x000151, /* 0x000150 */
+	0x000153, /* 0x000152 */
+	0x000155, /* 0x000154 */
+	0x000157, /* 0x000156 */
+	0x000159, /* 0x000158 */
+	0x00015b, /* 0x00015a */
+	0x00015d, /* 0x00015c */
+	0x00015f, /* 0x00015e */
+	0x000161, /* 0x000160 */
+	0x000163, /* 0x000162 */
+	0x000165, /* 0x000164 */
+	0x000167, /* 0x000166 */
+	0x000169, /* 0x000168 */
+	0x00016b, /* 0x00016a */
+	0x00016d, /* 0x00016c */
+	0x00016f, /* 0x00016e */
+	0x000171, /* 0x000170 */
+	0x000173, /* 0x000172 */
+	0x000175, /* 0x000174 */
+	0x000177, /* 0x000176 */
+	0x00017a, /* 0x000179 */
+	0x00017c, /* 0x00017b */
+	0x00017e, /* 0x00017d */
+	0x00017f, /* 0x00017f */
+	0x000180, /* 0x000180 */
+	0x000253, /* 0x000181 */
+	0x000183, /* 0x000182 */
+	0x000185, /* 0x000184 */
+	0x000254, /* 0x000186 */
+	0x000188, /* 0x000187 */
+	0x000256, /* 0x000189 */
+	0x000257, /* 0x00018a */
+	0x00018c, /* 0x00018b */
+	0x0001dd, /* 0x00018e */
+	0x000259, /* 0x00018f */
+	0x00025b, /* 0x000190 */
+	0x000192, /* 0x000191 */
+	0x000260, /* 0x000193 */
+	0x000263, /* 0x000194 */
+	0x000195, /* 0x000195 */
+	0x000269, /* 0x000196 */
+	0x000268, /* 0x000197 */
+	0x000199, /* 0x000198 */
+	0x00019a, /* 0x00019a */
+	0x00026f, /* 0x00019c */
+	0x000272, /* 0x00019d */
+	0x00019e, /* 0x00019e */
+	0x000275, /* 0x00019f */
+	0x0001a1, /* 0x0001a0 */
+	0x0001a3, /* 0x0001a2 */
+	0x0001a5, /* 0x0001a4 */
+	0x000280, /* 0x0001a6 */
+	0x0001a8, /* 0x0001a7 */
+	0x000283, /* 0x0001a9 */
+	0x0001ad, /* 0x0001ac */
+	0x000288, /* 0x0001ae */
+	0x0001b0, /* 0x0001af */
+	0x00028a, /* 0x0001b1 */
+	0x00028b, /* 0x0001b2 */
+	0x0001b4, /* 0x0001b3 */
+	0x0001b6, /* 0x0001b5 */
+	0x000292, /* 0x0001b7 */
+	0x0001b9, /* 0x0001b8 */
+	0x0001bd, /* 0x0001bc */
+	0x0001bf, /* 0x0001bf */
+	0x0001c6, /* 0x0001c4 */
+	0x0001c9, /* 0x0001c7 */
+	0x0001cc, /* 0x0001ca */
+	0x0001ce, /* 0x0001cd */
+	0x0001d0, /* 0x0001cf */
+	0x0001d2, /* 0x0001d1 */
+	0x0001d4, /* 0x0001d3 */
+	0x0001d6, /* 0x0001d5 */
+	0x0001d8, /* 0x0001d7 */
+	0x0001da, /* 0x0001d9 */
+	0x0001dc, /* 0x0001db */
+	0x0001df, /* 0x0001de */
+	0x0001e1, /* 0x0001e0 */
+	0x0001e3, /* 0x0001e2 */
+	0x0001e5, /* 0x0001e4 */
+	0x0001e7, /* 0x0001e6 */
+	0x0001e9, /* 0x0001e8 */
+	0x0001eb, /* 0x0001ea */
+	0x0001ed, /* 0x0001ec */
+	0x0001ef, /* 0x0001ee */
+	0x0001f0, /* 0x0001f0 */
+	0x0001f3, /* 0x0001f1 */
+	0x0001f5, /* 0x0001f4 */
+	0x0001f9, /* 0x0001f8 */
+	0x0001fb, /* 0x0001fa */
+	0x0001fd, /* 0x0001fc */
+	0x0001ff, /* 0x0001fe */
+	0x000201, /* 0x000200 */
+	0x000203, /* 0x000202 */
+	0x000205, /* 0x000204 */
+	0x000207, /* 0x000206 */
+	0x000209, /* 0x000208 */
+	0x00020b, /* 0x00020a */
+	0x00020d, /* 0x00020c */
+	0x00020f, /* 0x00020e */
+	0x000211, /* 0x000210 */
+	0x000213, /* 0x000212 */
+	0x000215, /* 0x000214 */
+	0x000217, /* 0x000216 */
+	0x000219, /* 0x000218 */
+	0x00021b, /* 0x00021a */
+	0x00021d, /* 0x00021c */
+	0x00021f, /* 0x00021e */
+	0x000223, /* 0x000222 */
+	0x000225, /* 0x000224 */
+	0x000227, /* 0x000226 */
+	0x000229, /* 0x000228 */
+	0x00022b, /* 0x00022a */
+	0x00022d, /* 0x00022c */
+	0x00022f, /* 0x00022e */
+	0x000231, /* 0x000230 */
+	0x000233, /* 0x000232 */
+	0x002c65, /* 0x00023a */
+	0x00023c, /* 0x00023b */
+	0x002c66, /* 0x00023e */
+	0x00023f, /* 0x00023f */
+	0x000240, /* 0x000240 */
+	0x000242, /* 0x000241 */
+	0x000289, /* 0x000244 */
+	0x00028c, /* 0x000245 */
+	0x000247, /* 0x000246 */
+	0x000249, /* 0x000248 */
+	0x00024b, /* 0x00024a */
+	0x00024d, /* 0x00024c */
+	0x00024f, /* 0x00024e */
+	0x000250, /* 0x000250 */
+	0x000251, /* 0x000251 */
+	0x000252, /* 0x000252 */
+	0x00025c, /* 0x00025c */
+	0x000261, /* 0x000261 */
+	0x000265, /* 0x000265 */
+	0x000266, /* 0x000266 */
+	0x00026a, /* 0x00026a */
+	0x00026b, /* 0x00026b */
+	0x00026c, /* 0x00026c */
+	0x000271, /* 0x000271 */
+	0x00027d, /* 0x00027d */
+	0x000282, /* 0x000282 */
+	0x000287, /* 0x000287 */
+	0x00029d, /* 0x00029d */
+	0x00029e, /* 0x00029e */
+	0x000345, /* 0x000345 */
+	0x000371, /* 0x000370 */
+	0x000373, /* 0x000372 */
+	0x000377, /* 0x000376 */
+	0x00037b, /* 0x00037b */
+	0x00037c, /* 0x00037c */
+	0x00037d, /* 0x00037d */
+	0x0003f3, /* 0x00037f */
+	0x0003ac, /* 0x000386 */
+	0x0003ad, /* 0x000388 */
+	0x0003ae, /* 0x000389 */
+	0x0003af, /* 0x00038a */
+	0x0003cc, /* 0x00038c */
+	0x0003cd, /* 0x00038e */
+	0x0003ce, /* 0x00038f */
+	0x000390, /* 0x000390 */
+	0x0003b1, /* 0x000391 */
+	0x0003b2, /* 0x000392 */
+	0x0003b3, /* 0x000393 */
+	0x0003b4, /* 0x000394 */
+	0x0003b5, /* 0x000395 */
+	0x0003b6, /* 0x000396 */
+	0x0003b7, /* 0x000397 */
+	0x0003b8, /* 0x000398 */
+	0x0003b9, /* 0x000399 */
+	0x0003ba, /* 0x00039a */
+	0x0003bb, /* 0x00039b */
+	0x0003bc, /* 0x00039c */
+	0x0003bd, /* 0x00039d */
+	0x0003be, /* 0x00039e */
+	0x0003bf, /* 0x00039f */
+	0x0003c0, /* 0x0003a0 */
+	0x0003c1, /* 0x0003a1 */
+	0x0003c3, /* 0x0003a3 */
+	0x0003c4, /* 0x0003a4 */
+	0x0003c5, /* 0x0003a5 */
+	0x0003c6, /* 0x0003a6 */
+	0x0003c7, /* 0x0003a7 */
+	0x0003c8, /* 0x0003a8 */
+	0x0003c9, /* 0x0003a9 */
+	0x0003ca, /* 0x0003aa */
+	0x0003cb, /* 0x0003ab */
+	0x0003b0, /* 0x0003b0 */
+	0x0003c2, /* 0x0003c2 */
+	0x0003c3, /* 0x0003c3 */
+	0x0003d7, /* 0x0003cf */
+	0x0003d0, /* 0x0003d0 */
+	0x0003d1, /* 0x0003d1 */
+	0x0003d5, /* 0x0003d5 */
+	0x0003d6, /* 0x0003d6 */
+	0x0003d9, /* 0x0003d8 */
+	0x0003db, /* 0x0003da */
+	0x0003dd, /* 0x0003dc */
+	0x0003df, /* 0x0003de */
+	0x0003e1, /* 0x0003e0 */
+	0x0003e3, /* 0x0003e2 */
+	0x0003e5, /* 0x0003e4 */
+	0x0003e7, /* 0x0003e6 */
+	0x0003e9, /* 0x0003e8 */
+	0x0003eb, /* 0x0003ea */
+	0x0003ed, /* 0x0003ec */
+	0x0003ef, /* 0x0003ee */
+	0x0003f0, /* 0x0003f0 */
+	0x0003f1, /* 0x0003f1 */
+	0x0003f2, /* 0x0003f2 */
+	0x0003b8, /* 0x0003f4 */
+	0x0003f5, /* 0x0003f5 */
+	0x0003f8, /* 0x0003f7 */
+	0x0003fb, /* 0x0003fa */
+	0x000450, /* 0x000400 */
+	0x000451, /* 0x000401 */
+	0x000452, /* 0x000402 */
+	0x000453, /* 0x000403 */
+	0x000454, /* 0x000404 */
+	0x000455, /* 0x000405 */
+	0x000456, /* 0x000406 */
+	0x000457, /* 0x000407 */
+	0x000458, /* 0x000408 */
+	0x000459, /* 0x000409 */
+	0x00045a, /* 0x00040a */
+	0x00045b, /* 0x00040b */
+	0x00045c, /* 0x00040c */
+	0x00045d, /* 0x00040d */
+	0x00045e, /* 0x00040e */
+	0x00045f, /* 0x00040f */
+	0x000430, /* 0x000410 */
+	0x000431, /* 0x000411 */
+	0x000432, /* 0x000412 */
+	0x000433, /* 0x000413 */
+	0x000434, /* 0x000414 */
+	0x000435, /* 0x000415 */
+	0x000436, /* 0x000416 */
+	0x000437, /* 0x000417 */
+	0x000438, /* 0x000418 */
+	0x000439, /* 0x000419 */
+	0x00043a, /* 0x00041a */
+	0x00043b, /* 0x00041b */
+	0x00043c, /* 0x00041c */
+	0x00043d, /* 0x00041d */
+	0x00043e, /* 0x00041e */
+	0x00043f, /* 0x00041f */
+	0x000440, /* 0x000420 */
+	0x000441, /* 0x000421 */
+	0x000442, /* 0x000422 */
+	0x000443, /* 0x000423 */
+	0x000444, /* 0x000424 */
+	0x000445, /* 0x000425 */
+	0x000446, /* 0x000426 */
+	0x000447, /* 0x000427 */
+	0x000448, /* 0x000428 */
+	0x000449, /* 0x000429 */
+	0x00044a, /* 0x00042a */
+	0x00044b, /* 0x00042b */
+	0x00044c, /* 0x00042c */
+	0x00044d, /* 0x00042d */
+	0x00044e, /* 0x00042e */
+	0x00044f, /* 0x00042f */
+	0x000461, /* 0x000460 */
+	0x000463, /* 0x000462 */
+	0x000465, /* 0x000464 */
+	0x000467, /* 0x000466 */
+	0x000469, /* 0x000468 */
+	0x00046b, /* 0x00046a */
+	0x00046d, /* 0x00046c */
+	0x00046f, /* 0x00046e */
+	0x000471, /* 0x000470 */
+	0x000473, /* 0x000472 */
+	0x000475, /* 0x000474 */
+	0x000477, /* 0x000476 */
+	0x000479, /* 0x000478 */
+	0x00047b, /* 0x00047a */
+	0x00047d, /* 0x00047c */
+	0x00047f, /* 0x00047e */
+	0x000481, /* 0x000480 */
+	0x00048b, /* 0x00048a */
+	0x00048d, /* 0x00048c */
+	0x00048f, /* 0x00048e */
+	0x000491, /* 0x000490 */
+	0x000493, /* 0x000492 */
+	0x000495, /* 0x000494 */
+	0x000497, /* 0x000496 */
+	0x000499, /* 0x000498 */
+	0x00049b, /* 0x00049a */
+	0x00049d, /* 0x00049c */
+	0x00049f, /* 0x00049e */
+	0x0004a1, /* 0x0004a0 */
+	0x0004a3, /* 0x0004a2 */
+	0x0004a5, /* 0x0004a4 */
+	0x0004a7, /* 0x0004a6 */
+	0x0004a9, /* 0x0004a8 */
+	0x0004ab, /* 0x0004aa */
+	0x0004ad, /* 0x0004ac */
+	0x0004af, /* 0x0004ae */
+	0x0004b1, /* 0x0004b0 */
+	0x0004b3, /* 0x0004b2 */
+	0x0004b5, /* 0x0004b4 */
+	0x0004b7, /* 0x0004b6 */
+	0x0004b9, /* 0x0004b8 */
+	0x0004bb, /* 0x0004ba */
+	0x0004bd, /* 0x0004bc */
+	0x0004bf, /* 0x0004be */
+	0x0004cf, /* 0x0004c0 */
+	0x0004c2, /* 0x0004c1 */
+	0x0004c4, /* 0x0004c3 */
+	0x0004c6, /* 0x0004c5 */
+	0x0004c8, /* 0x0004c7 */
+	0x0004ca, /* 0x0004c9 */
+	0x0004cc, /* 0x0004cb */
+	0x0004ce, /* 0x0004cd */
+	0x0004d1, /* 0x0004d0 */
+	0x0004d3, /* 0x0004d2 */
+	0x0004d5, /* 0x0004d4 */
+	0x0004d7, /* 0x0004d6 */
+	0x0004d9, /* 0x0004d8 */
+	0x0004db, /* 0x0004da */
+	0x0004dd, /* 0x0004dc */
+	0x0004df, /* 0x0004de */
+	0x0004e1, /* 0x0004e0 */
+	0x0004e3, /* 0x0004e2 */
+	0x0004e5, /* 0x0004e4 */
+	0x0004e7, /* 0x0004e6 */
+	0x0004e9, /* 0x0004e8 */
+	0x0004eb, /* 0x0004ea */
+	0x0004ed, /* 0x0004ec */
+	0x0004ef, /* 0x0004ee */
+	0x0004f1, /* 0x0004f0 */
+	0x0004f3, /* 0x0004f2 */
+	0x0004f5, /* 0x0004f4 */
+	0x0004f7, /* 0x0004f6 */
+	0x0004f9, /* 0x0004f8 */
+	0x0004fb, /* 0x0004fa */
+	0x0004fd, /* 0x0004fc */
+	0x0004ff, /* 0x0004fe */
+	0x000501, /* 0x000500 */
+	0x000503, /* 0x000502 */
+	0x000505, /* 0x000504 */
+	0x000507, /* 0x000506 */
+	0x000509, /* 0x000508 */
+	0x00050b, /* 0x00050a */
+	0x00050d, /* 0x00050c */
+	0x00050f, /* 0x00050e */
+	0x000511, /* 0x000510 */
+	0x000513, /* 0x000512 */
+	0x000515, /* 0x000514 */
+	0x000517, /* 0x000516 */
+	0x000519, /* 0x000518 */
+	0x00051b, /* 0x00051a */
+	0x00051d, /* 0x00051c */
+	0x00051f, /* 0x00051e */
+	0x000521, /* 0x000520 */
+	0x000523, /* 0x000522 */
+	0x000525, /* 0x000524 */
+	0x000527, /* 0x000526 */
+	0x000529, /* 0x000528 */
+	0x00052b, /* 0x00052a */
+	0x00052d, /* 0x00052c */
+	0x00052f, /* 0x00052e */
+	0x000561, /* 0x000531 */
+	0x000562, /* 0x000532 */
+	0x000563, /* 0x000533 */
+	0x000564, /* 0x000534 */
+	0x000565, /* 0x000535 */
+	0x000566, /* 0x000536 */
+	0x000567, /* 0x000537 */
+	0x000568, /* 0x000538 */
+	0x000569, /* 0x000539 */
+	0x00056a, /* 0x00053a */
+	0x00056b, /* 0x00053b */
+	0x00056c, /* 0x00053c */
+	0x00056d, /* 0x00053d */
+	0x00056e, /* 0x00053e */
+	0x00056f, /* 0x00053f */
+	0x000570, /* 0x000540 */
+	0x000571, /* 0x000541 */
+	0x000572, /* 0x000542 */
+	0x000573, /* 0x000543 */
+	0x000574, /* 0x000544 */
+	0x000575, /* 0x000545 */
+	0x000576, /* 0x000546 */
+	0x000577, /* 0x000547 */
+	0x000578, /* 0x000548 */
+	0x000579, /* 0x000549 */
+	0x00057a, /* 0x00054a */
+	0x00057b, /* 0x00054b */
+	0x00057c, /* 0x00054c */
+	0x00057d, /* 0x00054d */
+	0x00057e, /* 0x00054e */
+	0x00057f, /* 0x00054f */
+	0x000580, /* 0x000550 */
+	0x000581, /* 0x000551 */
+	0x000582, /* 0x000552 */
+	0x000583, /* 0x000553 */
+	0x000584, /* 0x000554 */
+	0x000585, /* 0x000555 */
+	0x000586, /* 0x000556 */
+	0x000587, /* 0x000587 */
+	0x002d00, /* 0x0010a0 */
+	0x002d01, /* 0x0010a1 */
+	0x002d02, /* 0x0010a2 */
+	0x002d03, /* 0x0010a3 */
+	0x002d04, /* 0x0010a4 */
+	0x002d05, /* 0x0010a5 */
+	0x002d06, /* 0x0010a6 */
+	0x002d07, /* 0x0010a7 */
+	0x002d08, /* 0x0010a8 */
+	0x002d09, /* 0x0010a9 */
+	0x002d0a, /* 0x0010aa */
+	0x002d0b, /* 0x0010ab */
+	0x002d0c, /* 0x0010ac */
+	0x002d0d, /* 0x0010ad */
+	0x002d0e, /* 0x0010ae */
+	0x002d0f, /* 0x0010af */
+	0x002d10, /* 0x0010b0 */
+	0x002d11, /* 0x0010b1 */
+	0x002d12, /* 0x0010b2 */
+	0x002d13, /* 0x0010b3 */
+	0x002d14, /* 0x0010b4 */
+	0x002d15, /* 0x0010b5 */
+	0x002d16, /* 0x0010b6 */
+	0x002d17, /* 0x0010b7 */
+	0x002d18, /* 0x0010b8 */
+	0x002d19, /* 0x0010b9 */
+	0x002d1a, /* 0x0010ba */
+	0x002d1b, /* 0x0010bb */
+	0x002d1c, /* 0x0010bc */
+	0x002d1d, /* 0x0010bd */
+	0x002d1e, /* 0x0010be */
+	0x002d1f, /* 0x0010bf */
+	0x002d20, /* 0x0010c0 */
+	0x002d21, /* 0x0010c1 */
+	0x002d22, /* 0x0010c2 */
+	0x002d23, /* 0x0010c3 */
+	0x002d24, /* 0x0010c4 */
+	0x002d25, /* 0x0010c5 */
+	0x002d27, /* 0x0010c7 */
+	0x002d2d, /* 0x0010cd */
+	0x0010d0, /* 0x0010d0 */
+	0x0010d1, /* 0x0010d1 */
+	0x0010d2, /* 0x0010d2 */
+	0x0010d3, /* 0x0010d3 */
+	0x0010d4, /* 0x0010d4 */
+	0x0010d5, /* 0x0010d5 */
+	0x0010d6, /* 0x0010d6 */
+	0x0010d7, /* 0x0010d7 */
+	0x0010d8, /* 0x0010d8 */
+	0x0010d9, /* 0x0010d9 */
+	0x0010da, /* 0x0010da */
+	0x0010db, /* 0x0010db */
+	0x0010dc, /* 0x0010dc */
+	0x0010dd, /* 0x0010dd */
+	0x0010de, /* 0x0010de */
+	0x0010df, /* 0x0010df */
+	0x0010e0, /* 0x0010e0 */
+	0x0010e1, /* 0x0010e1 */
+	0x0010e2, /* 0x0010e2 */
+	0x0010e3, /* 0x0010e3 */
+	0x0010e4, /* 0x0010e4 */
+	0x0010e5, /* 0x0010e5 */
+	0x0010e6, /* 0x0010e6 */
+	0x0010e7, /* 0x0010e7 */
+	0x0010e8, /* 0x0010e8 */
+	0x0010e9, /* 0x0010e9 */
+	0x0010ea, /* 0x0010ea */
+	0x0010eb, /* 0x0010eb */
+	0x0010ec, /* 0x0010ec */
+	0x0010ed, /* 0x0010ed */
+	0x0010ee, /* 0x0010ee */
+	0x0010ef, /* 0x0010ef */
+	0x0010f0, /* 0x0010f0 */
+	0x0010f1, /* 0x0010f1 */
+	0x0010f2, /* 0x0010f2 */
+	0x0010f3, /* 0x0010f3 */
+	0x0010f4, /* 0x0010f4 */
+	0x0010f5, /* 0x0010f5 */
+	0x0010f6, /* 0x0010f6 */
+	0x0010f7, /* 0x0010f7 */
+	0x0010f8, /* 0x0010f8 */
+	0x0010f9, /* 0x0010f9 */
+	0x0010fa, /* 0x0010fa */
+	0x0010fd, /* 0x0010fd */
+	0x0010fe, /* 0x0010fe */
+	0x0010ff, /* 0x0010ff */
+	0x00ab70, /* 0x0013a0 */
+	0x00ab71, /* 0x0013a1 */
+	0x00ab72, /* 0x0013a2 */
+	0x00ab73, /* 0x0013a3 */
+	0x00ab74, /* 0x0013a4 */
+	0x00ab75, /* 0x0013a5 */
+	0x00ab76, /* 0x0013a6 */
+	0x00ab77, /* 0x0013a7 */
+	0x00ab78, /* 0x0013a8 */
+	0x00ab79, /* 0x0013a9 */
+	0x00ab7a, /* 0x0013aa */
+	0x00ab7b, /* 0x0013ab */
+	0x00ab7c, /* 0x0013ac */
+	0x00ab7d, /* 0x0013ad */
+	0x00ab7e, /* 0x0013ae */
+	0x00ab7f, /* 0x0013af */
+	0x00ab80, /* 0x0013b0 */
+	0x00ab81, /* 0x0013b1 */
+	0x00ab82, /* 0x0013b2 */
+	0x00ab83, /* 0x0013b3 */
+	0x00ab84, /* 0x0013b4 */
+	0x00ab85, /* 0x0013b5 */
+	0x00ab86, /* 0x0013b6 */
+	0x00ab87, /* 0x0013b7 */
+	0x00ab88, /* 0x0013b8 */
+	0x00ab89, /* 0x0013b9 */
+	0x00ab8a, /* 0x0013ba */
+	0x00ab8b, /* 0x0013bb */
+	0x00ab8c, /* 0x0013bc */
+	0x00ab8d, /* 0x0013bd */
+	0x00ab8e, /* 0x0013be */
+	0x00ab8f, /* 0x0013bf */
+	0x00ab90, /* 0x0013c0 */
+	0x00ab91, /* 0x0013c1 */
+	0x00ab92, /* 0x0013c2 */
+	0x00ab93, /* 0x0013c3 */
+	0x00ab94, /* 0x0013c4 */
+	0x00ab95, /* 0x0013c5 */
+	0x00ab96, /* 0x0013c6 */
+	0x00ab97, /* 0x0013c7 */
+	0x00ab98, /* 0x0013c8 */
+	0x00ab99, /* 0x0013c9 */
+	0x00ab9a, /* 0x0013ca */
+	0x00ab9b, /* 0x0013cb */
+	0x00ab9c, /* 0x0013cc */
+	0x00ab9d, /* 0x0013cd */
+	0x00ab9e, /* 0x0013ce */
+	0x00ab9f, /* 0x0013cf */
+	0x00aba0, /* 0x0013d0 */
+	0x00aba1, /* 0x0013d1 */
+	0x00aba2, /* 0x0013d2 */
+	0x00aba3, /* 0x0013d3 */
+	0x00aba4, /* 0x0013d4 */
+	0x00aba5, /* 0x0013d5 */
+	0x00aba6, /* 0x0013d6 */
+	0x00aba7, /* 0x0013d7 */
+	0x00aba8, /* 0x0013d8 */
+	0x00aba9, /* 0x0013d9 */
+	0x00abaa, /* 0x0013da */
+	0x00abab, /* 0x0013db */
+	0x00abac, /* 0x0013dc */
+	0x00abad, /* 0x0013dd */
+	0x00abae, /* 0x0013de */
+	0x00abaf, /* 0x0013df */
+	0x00abb0, /* 0x0013e0 */
+	0x00abb1, /* 0x0013e1 */
+	0x00abb2, /* 0x0013e2 */
+	0x00abb3, /* 0x0013e3 */
+	0x00abb4, /* 0x0013e4 */
+	0x00abb5, /* 0x0013e5 */
+	0x00abb6, /* 0x0013e6 */
+	0x00abb7, /* 0x0013e7 */
+	0x00abb8, /* 0x0013e8 */
+	0x00abb9, /* 0x0013e9 */
+	0x00abba, /* 0x0013ea */
+	0x00abbb, /* 0x0013eb */
+	0x00abbc, /* 0x0013ec */
+	0x00abbd, /* 0x0013ed */
+	0x00abbe, /* 0x0013ee */
+	0x00abbf, /* 0x0013ef */
+	0x0013f8, /* 0x0013f0 */
+	0x0013f9, /* 0x0013f1 */
+	0x0013fa, /* 0x0013f2 */
+	0x0013fb, /* 0x0013f3 */
+	0x0013fc, /* 0x0013f4 */
+	0x0013fd, /* 0x0013f5 */
+	0x001c80, /* 0x001c80 */
+	0x001c81, /* 0x001c81 */
+	0x001c82, /* 0x001c82 */
+	0x001c83, /* 0x001c83 */
+	0x001c84, /* 0x001c84 */
+	0x001c85, /* 0x001c85 */
+	0x001c86, /* 0x001c86 */
+	0x001c87, /* 0x001c87 */
+	0x001c88, /* 0x001c88 */
+	0x0010d0, /* 0x001c90 */
+	0x0010d1, /* 0x001c91 */
+	0x0010d2, /* 0x001c92 */
+	0x0010d3, /* 0x001c93 */
+	0x0010d4, /* 0x001c94 */
+	0x0010d5, /* 0x001c95 */
+	0x0010d6, /* 0x001c96 */
+	0x0010d7, /* 0x001c97 */
+	0x0010d8, /* 0x001c98 */
+	0x0010d9, /* 0x001c99 */
+	0x0010da, /* 0x001c9a */
+	0x0010db, /* 0x001c9b */
+	0x0010dc, /* 0x001c9c */
+	0x0010dd, /* 0x001c9d */
+	0x0010de, /* 0x001c9e */
+	0x0010df, /* 0x001c9f */
+	0x0010e0, /* 0x001ca0 */
+	0x0010e1, /* 0x001ca1 */
+	0x0010e2, /* 0x001ca2 */
+	0x0010e3, /* 0x001ca3 */
+	0x0010e4, /* 0x001ca4 */
+	0x0010e5, /* 0x001ca5 */
+	0x0010e6, /* 0x001ca6 */
+	0x0010e7, /* 0x001ca7 */
+	0x0010e8, /* 0x001ca8 */
+	0x0010e9, /* 0x001ca9 */
+	0x0010ea, /* 0x001caa */
+	0x0010eb, /* 0x001cab */
+	0x0010ec, /* 0x001cac */
+	0x0010ed, /* 0x001cad */
+	0x0010ee, /* 0x001cae */
+	0x0010ef, /* 0x001caf */
+	0x0010f0, /* 0x001cb0 */
+	0x0010f1, /* 0x001cb1 */
+	0x0010f2, /* 0x001cb2 */
+	0x0010f3, /* 0x001cb3 */
+	0x0010f4, /* 0x001cb4 */
+	0x0010f5, /* 0x001cb5 */
+	0x0010f6, /* 0x001cb6 */
+	0x0010f7, /* 0x001cb7 */
+	0x0010f8, /* 0x001cb8 */
+	0x0010f9, /* 0x001cb9 */
+	0x0010fa, /* 0x001cba */
+	0x0010fd, /* 0x001cbd */
+	0x0010fe, /* 0x001cbe */
+	0x0010ff, /* 0x001cbf */
+	0x001d79, /* 0x001d79 */
+	0x001d7d, /* 0x001d7d */
+	0x001d8e, /* 0x001d8e */
+	0x001e01, /* 0x001e00 */
+	0x001e03, /* 0x001e02 */
+	0x001e05, /* 0x001e04 */
+	0x001e07, /* 0x001e06 */
+	0x001e09, /* 0x001e08 */
+	0x001e0b, /* 0x001e0a */
+	0x001e0d, /* 0x001e0c */
+	0x001e0f, /* 0x001e0e */
+	0x001e11, /* 0x001e10 */
+	0x001e13, /* 0x001e12 */
+	0x001e15, /* 0x001e14 */
+	0x001e17, /* 0x001e16 */
+	0x001e19, /* 0x001e18 */
+	0x001e1b, /* 0x001e1a */
+	0x001e1d, /* 0x001e1c */
+	0x001e1f, /* 0x001e1e */
+	0x001e21, /* 0x001e20 */
+	0x001e23, /* 0x001e22 */
+	0x001e25, /* 0x001e24 */
+	0x001e27, /* 0x001e26 */
+	0x001e29, /* 0x001e28 */
+	0x001e2b, /* 0x001e2a */
+	0x001e2d, /* 0x001e2c */
+	0x001e2f, /* 0x001e2e */
+	0x001e31, /* 0x001e30 */
+	0x001e33, /* 0x001e32 */
+	0x001e35, /* 0x001e34 */
+	0x001e37, /* 0x001e36 */
+	0x001e39, /* 0x001e38 */
+	0x001e3b, /* 0x001e3a */
+	0x001e3d, /* 0x001e3c */
+	0x001e3f, /* 0x001e3e */
+	0x001e41, /* 0x001e40 */
+	0x001e43, /* 0x001e42 */
+	0x001e45, /* 0x001e44 */
+	0x001e47, /* 0x001e46 */
+	0x001e49, /* 0x001e48 */
+	0x001e4b, /* 0x001e4a */
+	0x001e4d, /* 0x001e4c */
+	0x001e4f, /* 0x001e4e */
+	0x001e51, /* 0x001e50 */
+	0x001e53, /* 0x001e52 */
+	0x001e55, /* 0x001e54 */
+	0x001e57, /* 0x001e56 */
+	0x001e59, /* 0x001e58 */
+	0x001e5b, /* 0x001e5a */
+	0x001e5d, /* 0x001e5c */
+	0x001e5f, /* 0x001e5e */
+	0x001e61, /* 0x001e60 */
+	0x001e63, /* 0x001e62 */
+	0x001e65, /* 0x001e64 */
+	0x001e67, /* 0x001e66 */
+	0x001e69, /* 0x001e68 */
+	0x001e6b, /* 0x001e6a */
+	0x001e6d, /* 0x001e6c */
+	0x001e6f, /* 0x001e6e */
+	0x001e71, /* 0x001e70 */
+	0x001e73, /* 0x001e72 */
+	0x001e75, /* 0x001e74 */
+	0x001e77, /* 0x001e76 */
+	0x001e79, /* 0x001e78 */
+	0x001e7b, /* 0x001e7a */
+	0x001e7d, /* 0x001e7c */
+	0x001e7f, /* 0x001e7e */
+	0x001e81, /* 0x001e80 */
+	0x001e83, /* 0x001e82 */
+	0x001e85, /* 0x001e84 */
+	0x001e87, /* 0x001e86 */
+	0x001e89, /* 0x001e88 */
+	0x001e8b, /* 0x001e8a */
+	0x001e8d, /* 0x001e8c */
+	0x001e8f, /* 0x001e8e */
+	0x001e91, /* 0x001e90 */
+	0x001e93, /* 0x001e92 */
+	0x001e95, /* 0x001e94 */
+	0x001e96, /* 0x001e96 */
+	0x001e97, /* 0x001e97 */
+	0x001e98, /* 0x001e98 */
+	0x001e99, /* 0x001e99 */
+	0x001e9a, /* 0x001e9a */
+	0x001e9b, /* 0x001e9b */
+	0x0000df, /* 0x001e9e */
+	0x001ea1, /* 0x001ea0 */
+	0x001ea3, /* 0x001ea2 */
+	0x001ea5, /* 0x001ea4 */
+	0x001ea7, /* 0x001ea6 */
+	0x001ea9, /* 0x001ea8 */
+	0x001eab, /* 0x001eaa */
+	0x001ead, /* 0x001eac */
+	0x001eaf, /* 0x001eae */
+	0x001eb1, /* 0x001eb0 */
+	0x001eb3, /* 0x001eb2 */
+	0x001eb5, /* 0x001eb4 */
+	0x001eb7, /* 0x001eb6 */
+	0x001eb9, /* 0x001eb8 */
+	0x001ebb, /* 0x001eba */
+	0x001ebd, /* 0x001ebc */
+	0x001ebf, /* 0x001ebe */
+	0x001ec1, /* 0x001ec0 */
+	0x001ec3, /* 0x001ec2 */
+	0x001ec5, /* 0x001ec4 */
+	0x001ec7, /* 0x001ec6 */
+	0x001ec9, /* 0x001ec8 */
+	0x001ecb, /* 0x001eca */
+	0x001ecd, /* 0x001ecc */
+	0x001ecf, /* 0x001ece */
+	0x001ed1, /* 0x001ed0 */
+	0x001ed3, /* 0x001ed2 */
+	0x001ed5, /* 0x001ed4 */
+	0x001ed7, /* 0x001ed6 */
+	0x001ed9, /* 0x001ed8 */
+	0x001edb, /* 0x001eda */
+	0x001edd, /* 0x001edc */
+	0x001edf, /* 0x001ede */
+	0x001ee1, /* 0x001ee0 */
+	0x001ee3, /* 0x001ee2 */
+	0x001ee5, /* 0x001ee4 */
+	0x001ee7, /* 0x001ee6 */
+	0x001ee9, /* 0x001ee8 */
+	0x001eeb, /* 0x001eea */
+	0x001eed, /* 0x001eec */
+	0x001eef, /* 0x001eee */
+	0x001ef1, /* 0x001ef0 */
+	0x001ef3, /* 0x001ef2 */
+	0x001ef5, /* 0x001ef4 */
+	0x001ef7, /* 0x001ef6 */
+	0x001ef9, /* 0x001ef8 */
+	0x001efb, /* 0x001efa */
+	0x001efd, /* 0x001efc */
+	0x001eff, /* 0x001efe */
+	0x001f00, /* 0x001f00 */
+	0x001f01, /* 0x001f01 */
+	0x001f02, /* 0x001f02 */
+	0x001f03, /* 0x001f03 */
+	0x001f04, /* 0x001f04 */
+	0x001f05, /* 0x001f05 */
+	0x001f06, /* 0x001f06 */
+	0x001f07, /* 0x001f07 */
+	0x001f10, /* 0x001f10 */
+	0x001f11, /* 0x001f11 */
+	0x001f12, /* 0x001f12 */
+	0x001f13, /* 0x001f13 */
+	0x001f14, /* 0x001f14 */
+	0x001f15, /* 0x001f15 */
+	0x001f20, /* 0x001f20 */
+	0x001f21, /* 0x001f21 */
+	0x001f22, /* 0x001f22 */
+	0x001f23, /* 0x001f23 */
+	0x001f24, /* 0x001f24 */
+	0x001f25, /* 0x001f25 */
+	0x001f26, /* 0x001f26 */
+	0x001f27, /* 0x001f27 */
+	0x001f30, /* 0x001f30 */
+	0x001f31, /* 0x001f31 */
+	0x001f32, /* 0x001f32 */
+	0x001f33, /* 0x001f33 */
+	0x001f34, /* 0x001f34 */
+	0x001f35, /* 0x001f35 */
+	0x001f36, /* 0x001f36 */
+	0x001f37, /* 0x001f37 */
+	0x001f40, /* 0x001f40 */
+	0x001f41, /* 0x001f41 */
+	0x001f42, /* 0x001f42 */
+	0x001f43, /* 0x001f43 */
+	0x001f44, /* 0x001f44 */
+	0x001f45, /* 0x001f45 */
+	0x001f50, /* 0x001f50 */
+	0x001f51, /* 0x001f51 */
+	0x001f52, /* 0x001f52 */
+	0x001f53, /* 0x001f53 */
+	0x001f54, /* 0x001f54 */
+	0x001f55, /* 0x001f55 */
+	0x001f56, /* 0x001f56 */
+	0x001f57, /* 0x001f57 */
+	0x001f60, /* 0x001f60 */
+	0x001f61, /* 0x001f61 */
+	0x001f62, /* 0x001f62 */
+	0x001f63, /* 0x001f63 */
+	0x001f64, /* 0x001f64 */
+	0x001f65, /* 0x001f65 */
+	0x001f66, /* 0x001f66 */
+	0x001f67, /* 0x001f67 */
+	0x001f70, /* 0x001f70 */
+	0x001f71, /* 0x001f71 */
+	0x001f72, /* 0x001f72 */
+	0x001f73, /* 0x001f73 */
+	0x001f74, /* 0x001f74 */
+	0x001f75, /* 0x001f75 */
+	0x001f76, /* 0x001f76 */
+	0x001f77, /* 0x001f77 */
+	0x001f78, /* 0x001f78 */
+	0x001f79, /* 0x001f79 */
+	0x001f7a, /* 0x001f7a */
+	0x001f7b, /* 0x001f7b */
+	0x001f7c, /* 0x001f7c */
+	0x001f7d, /* 0x001f7d */
+	0x001f80, /* 0x001f80 */
+	0x001f81, /* 0x001f81 */
+	0x001f82, /* 0x001f82 */
+	0x001f83, /* 0x001f83 */
+	0x001f84, /* 0x001f84 */
+	0x001f85, /* 0x001f85 */
+	0x001f86, /* 0x001f86 */
+	0x001f87, /* 0x001f87 */
+	0x001f80, /* 0x001f88 */
+	0x001f81, /* 0x001f89 */
+	0x001f82, /* 0x001f8a */
+	0x001f83, /* 0x001f8b */
+	0x001f84, /* 0x001f8c */
+	0x001f85, /* 0x001f8d */
+	0x001f86, /* 0x001f8e */
+	0x001f87, /* 0x001f8f */
+	0x001f90, /* 0x001f90 */
+	0x001f91, /* 0x001f91 */
+	0x001f92, /* 0x001f92 */
+	0x001f93, /* 0x001f93 */
+	0x001f94, /* 0x001f94 */
+	0x001f95, /* 0x001f95 */
+	0x001f96, /* 0x001f96 */
+	0x001f97, /* 0x001f97 */
+	0x001f90, /* 0x001f98 */
+	0x001f91, /* 0x001f99 */
+	0x001f92, /* 0x001f9a */
+	0x001f93, /* 0x001f9b */
+	0x001f94, /* 0x001f9c */
+	0x001f95, /* 0x001f9d */
+	0x001f96, /* 0x001f9e */
+	0x001f97, /* 0x001f9f */
+	0x001fa0, /* 0x001fa0 */
+	0x001fa1, /* 0x001fa1 */
+	0x001fa2, /* 0x001fa2 */
+	0x001fa3, /* 0x001fa3 */
+	0x001fa4, /* 0x001fa4 */
+	0x001fa5, /* 0x001fa5 */
+	0x001fa6, /* 0x001fa6 */
+	0x001fa7, /* 0x001fa7 */
+	0x001fa0, /* 0x001fa8 */
+	0x001fa1, /* 0x001fa9 */
+	0x001fa2, /* 0x001faa */
+	0x001fa3, /* 0x001fab */
+	0x001fa4, /* 0x001fac */
+	0x001fa5, /* 0x001fad */
+	0x001fa6, /* 0x001fae */
+	0x001fa7, /* 0x001faf */
+	0x001fb0, /* 0x001fb0 */
+	0x001fb1, /* 0x001fb1 */
+	0x001fb2, /* 0x001fb2 */
+	0x001fb3, /* 0x001fb3 */
+	0x001fb4, /* 0x001fb4 */
+	0x001fb6, /* 0x001fb6 */
+	0x001fb7, /* 0x001fb7 */
+	0x001fb3, /* 0x001fbc */
+	0x001fbe, /* 0x001fbe */
+	0x001fc2, /* 0x001fc2 */
+	0x001fc3, /* 0x001fc3 */
+	0x001fc4, /* 0x001fc4 */
+	0x001fc6, /* 0x001fc6 */
+	0x001fc7, /* 0x001fc7 */
+	0x001fc3, /* 0x001fcc */
+	0x001fd0, /* 0x001fd0 */
+	0x001fd1, /* 0x001fd1 */
+	0x001fd2, /* 0x001fd2 */
+	0x001fd3, /* 0x001fd3 */
+	0x001fd6, /* 0x001fd6 */
+	0x001fd7, /* 0x001fd7 */
+	0x001fe0, /* 0x001fe0 */
+	0x001fe1, /* 0x001fe1 */
+	0x001fe2, /* 0x001fe2 */
+	0x001fe3, /* 0x001fe3 */
+	0x001fe4, /* 0x001fe4 */
+	0x001fe5, /* 0x001fe5 */
+	0x001fe6, /* 0x001fe6 */
+	0x001fe7, /* 0x001fe7 */
+	0x001ff2, /* 0x001ff2 */
+	0x001ff3, /* 0x001ff3 */
+	0x001ff4, /* 0x001ff4 */
+	0x001ff6, /* 0x001ff6 */
+	0x001ff7, /* 0x001ff7 */
+	0x001ff3, /* 0x001ffc */
+	0x0003c9, /* 0x002126 */
+	0x00006b, /* 0x00212a */
+	0x0000e5, /* 0x00212b */
+	0x00214e, /* 0x002132 */
+	0x002170, /* 0x002160 */
+	0x002171, /* 0x002161 */
+	0x002172, /* 0x002162 */
+	0x002173, /* 0x002163 */
+	0x002174, /* 0x002164 */
+	0x002175, /* 0x002165 */
+	0x002176, /* 0x002166 */
+	0x002177, /* 0x002167 */
+	0x002178, /* 0x002168 */
+	0x002179, /* 0x002169 */
+	0x00217a, /* 0x00216a */
+	0x00217b, /* 0x00216b */
+	0x00217c, /* 0x00216c */
+	0x00217d, /* 0x00216d */
+	0x00217e, /* 0x00216e */
+	0x00217f, /* 0x00216f */
+	0x002184, /* 0x002183 */
+	0x0024d0, /* 0x0024b6 */
+	0x0024d1, /* 0x0024b7 */
+	0x0024d2, /* 0x0024b8 */
+	0x0024d3, /* 0x0024b9 */
+	0x0024d4, /* 0x0024ba */
+	0x0024d5, /* 0x0024bb */
+	0x0024d6, /* 0x0024bc */
+	0x0024d7, /* 0x0024bd */
+	0x0024d8, /* 0x0024be */
+	0x0024d9, /* 0x0024bf */
+	0x0024da, /* 0x0024c0 */
+	0x0024db, /* 0x0024c1 */
+	0x0024dc, /* 0x0024c2 */
+	0x0024dd, /* 0x0024c3 */
+	0x0024de, /* 0x0024c4 */
+	0x0024df, /* 0x0024c5 */
+	0x0024e0, /* 0x0024c6 */
+	0x0024e1, /* 0x0024c7 */
+	0x0024e2, /* 0x0024c8 */
+	0x0024e3, /* 0x0024c9 */
+	0x0024e4, /* 0x0024ca */
+	0x0024e5, /* 0x0024cb */
+	0x0024e6, /* 0x0024cc */
+	0x0024e7, /* 0x0024cd */
+	0x0024e8, /* 0x0024ce */
+	0x0024e9, /* 0x0024cf */
+	0x002c30, /* 0x002c00 */
+	0x002c31, /* 0x002c01 */
+	0x002c32, /* 0x002c02 */
+	0x002c33, /* 0x002c03 */
+	0x002c34, /* 0x002c04 */
+	0x002c35, /* 0x002c05 */
+	0x002c36, /* 0x002c06 */
+	0x002c37, /* 0x002c07 */
+	0x002c38, /* 0x002c08 */
+	0x002c39, /* 0x002c09 */
+	0x002c3a, /* 0x002c0a */
+	0x002c3b, /* 0x002c0b */
+	0x002c3c, /* 0x002c0c */
+	0x002c3d, /* 0x002c0d */
+	0x002c3e, /* 0x002c0e */
+	0x002c3f, /* 0x002c0f */
+	0x002c40, /* 0x002c10 */
+	0x002c41, /* 0x002c11 */
+	0x002c42, /* 0x002c12 */
+	0x002c43, /* 0x002c13 */
+	0x002c44, /* 0x002c14 */
+	0x002c45, /* 0x002c15 */
+	0x002c46, /* 0x002c16 */
+	0x002c47, /* 0x002c17 */
+	0x002c48, /* 0x002c18 */
+	0x002c49, /* 0x002c19 */
+	0x002c4a, /* 0x002c1a */
+	0x002c4b, /* 0x002c1b */
+	0x002c4c, /* 0x002c1c */
+	0x002c4d, /* 0x002c1d */
+	0x002c4e, /* 0x002c1e */
+	0x002c4f, /* 0x002c1f */
+	0x002c50, /* 0x002c20 */
+	0x002c51, /* 0x002c21 */
+	0x002c52, /* 0x002c22 */
+	0x002c53, /* 0x002c23 */
+	0x002c54, /* 0x002c24 */
+	0x002c55, /* 0x002c25 */
+	0x002c56, /* 0x002c26 */
+	0x002c57, /* 0x002c27 */
+	0x002c58, /* 0x002c28 */
+	0x002c59, /* 0x002c29 */
+	0x002c5a, /* 0x002c2a */
+	0x002c5b, /* 0x002c2b */
+	0x002c5c, /* 0x002c2c */
+	0x002c5d, /* 0x002c2d */
+	0x002c5e, /* 0x002c2e */
+	0x002c5f, /* 0x002c2f */
+	0x002c61, /* 0x002c60 */
+	0x002c68, /* 0x002c67 */
+	0x002c6a, /* 0x002c69 */
+	0x002c6c, /* 0x002c6b */
+	0x002c73, /* 0x002c72 */
+	0x002c76, /* 0x002c75 */
+	0x002c81, /* 0x002c80 */
+	0x002c83, /* 0x002c82 */
+	0x002c85, /* 0x002c84 */
+	0x002c87, /* 0x002c86 */
+	0x002c89, /* 0x002c88 */
+	0x002c8b, /* 0x002c8a */
+	0x002c8d, /* 0x002c8c */
+	0x002c8f, /* 0x002c8e */
+	0x002c91, /* 0x002c90 */
+	0x002c93, /* 0x002c92 */
+	0x002c95, /* 0x002c94 */
+	0x002c97, /* 0x002c96 */
+	0x002c99, /* 0x002c98 */
+	0x002c9b, /* 0x002c9a */
+	0x002c9d, /* 0x002c9c */
+	0x002c9f, /* 0x002c9e */
+	0x002ca1, /* 0x002ca0 */
+	0x002ca3, /* 0x002ca2 */
+	0x002ca5, /* 0x002ca4 */
+	0x002ca7, /* 0x002ca6 */
+	0x002ca9, /* 0x002ca8 */
+	0x002cab, /* 0x002caa */
+	0x002cad, /* 0x002cac */
+	0x002caf, /* 0x002cae */
+	0x002cb1, /* 0x002cb0 */
+	0x002cb3, /* 0x002cb2 */
+	0x002cb5, /* 0x002cb4 */
+	0x002cb7, /* 0x002cb6 */
+	0x002cb9, /* 0x002cb8 */
+	0x002cbb, /* 0x002cba */
+	0x002cbd, /* 0x002cbc */
+	0x002cbf, /* 0x002cbe */
+	0x002cc1, /* 0x002cc0 */
+	0x002cc3, /* 0x002cc2 */
+	0x002cc5, /* 0x002cc4 */
+	0x002cc7, /* 0x002cc6 */
+	0x002cc9, /* 0x002cc8 */
+	0x002ccb, /* 0x002cca */
+	0x002ccd, /* 0x002ccc */
+	0x002ccf, /* 0x002cce */
+	0x002cd1, /* 0x002cd0 */
+	0x002cd3, /* 0x002cd2 */
+	0x002cd5, /* 0x002cd4 */
+	0x002cd7, /* 0x002cd6 */
+	0x002cd9, /* 0x002cd8 */
+	0x002cdb, /* 0x002cda */
+	0x002cdd, /* 0x002cdc */
+	0x002cdf, /* 0x002cde */
+	0x002ce1, /* 0x002ce0 */
+	0x002ce3, /* 0x002ce2 */
+	0x002cec, /* 0x002ceb */
+	0x002cee, /* 0x002ced */
+	0x002cf3, /* 0x002cf2 */
+	0x00a641, /* 0x00a640 */
+	0x00a643, /* 0x00a642 */
+	0x00a645, /* 0x00a644 */
+	0x00a647, /* 0x00a646 */
+	0x00a649, /* 0x00a648 */
+	0x00a64b, /* 0x00a64a */
+	0x00a64d, /* 0x00a64c */
+	0x00a64f, /* 0x00a64e */
+	0x00a651, /* 0x00a650 */
+	0x00a653, /* 0x00a652 */
+	0x00a655, /* 0x00a654 */
+	0x00a657, /* 0x00a656 */
+	0x00a659, /* 0x00a658 */
+	0x00a65b, /* 0x00a65a */
+	0x00a65d, /* 0x00a65c */
+	0x00a65f, /* 0x00a65e */
+	0x00a661, /* 0x00a660 */
+	0x00a663, /* 0x00a662 */
+	0x00a665, /* 0x00a664 */
+	0x00a667, /* 0x00a666 */
+	0x00a669, /* 0x00a668 */
+	0x00a66b, /* 0x00a66a */
+	0x00a66d, /* 0x00a66c */
+	0x00a681, /* 0x00a680 */
+	0x00a683, /* 0x00a682 */
+	0x00a685, /* 0x00a684 */
+	0x00a687, /* 0x00a686 */
+	0x00a689, /* 0x00a688 */
+	0x00a68b, /* 0x00a68a */
+	0x00a68d, /* 0x00a68c */
+	0x00a68f, /* 0x00a68e */
+	0x00a691, /* 0x00a690 */
+	0x00a693, /* 0x00a692 */
+	0x00a695, /* 0x00a694 */
+	0x00a697, /* 0x00a696 */
+	0x00a699, /* 0x00a698 */
+	0x00a69b, /* 0x00a69a */
+	0x00a723, /* 0x00a722 */
+	0x00a725, /* 0x00a724 */
+	0x00a727, /* 0x00a726 */
+	0x00a729, /* 0x00a728 */
+	0x00a72b, /* 0x00a72a */
+	0x00a72d, /* 0x00a72c */
+	0x00a72f, /* 0x00a72e */
+	0x00a733, /* 0x00a732 */
+	0x00a735, /* 0x00a734 */
+	0x00a737, /* 0x00a736 */
+	0x00a739, /* 0x00a738 */
+	0x00a73b, /* 0x00a73a */
+	0x00a73d, /* 0x00a73c */
+	0x00a73f, /* 0x00a73e */
+	0x00a741, /* 0x00a740 */
+	0x00a743, /* 0x00a742 */
+	0x00a745, /* 0x00a744 */
+	0x00a747, /* 0x00a746 */
+	0x00a749, /* 0x00a748 */
+	0x00a74b, /* 0x00a74a */
+	0x00a74d, /* 0x00a74c */
+	0x00a74f, /* 0x00a74e */
+	0x00a751, /* 0x00a750 */
+	0x00a753, /* 0x00a752 */
+	0x00a755, /* 0x00a754 */
+	0x00a757, /* 0x00a756 */
+	0x00a759, /* 0x00a758 */
+	0x00a75b, /* 0x00a75a */
+	0x00a75d, /* 0x00a75c */
+	0x00a75f, /* 0x00a75e */
+	0x00a761, /* 0x00a760 */
+	0x00a763, /* 0x00a762 */
+	0x00a765, /* 0x00a764 */
+	0x00a767, /* 0x00a766 */
+	0x00a769, /* 0x00a768 */
+	0x00a76b, /* 0x00a76a */
+	0x00a76d, /* 0x00a76c */
+	0x00a76f, /* 0x00a76e */
+	0x00a77a, /* 0x00a779 */
+	0x00a77c, /* 0x00a77b */
+	0x00a77f, /* 0x00a77e */
+	0x00a781, /* 0x00a780 */
+	0x00a783, /* 0x00a782 */
+	0x00a785, /* 0x00a784 */
+	0x00a787, /* 0x00a786 */
+	0x00a78c, /* 0x00a78b */
+	0x00a791, /* 0x00a790 */
+	0x00a793, /* 0x00a792 */
+	0x00a794, /* 0x00a794 */
+	0x00a797, /* 0x00a796 */
+	0x00a799, /* 0x00a798 */
+	0x00a79b, /* 0x00a79a */
+	0x00a79d, /* 0x00a79c */
+	0x00a79f, /* 0x00a79e */
+	0x00a7a1, /* 0x00a7a0 */
+	0x00a7a3, /* 0x00a7a2 */
+	0x00a7a5, /* 0x00a7a4 */
+	0x00a7a7, /* 0x00a7a6 */
+	0x00a7a9, /* 0x00a7a8 */
+	0x00ab53, /* 0x00a7b3 */
+	0x00a7b5, /* 0x00a7b4 */
+	0x00a7b7, /* 0x00a7b6 */
+	0x00a7b9, /* 0x00a7b8 */
+	0x00a7bb, /* 0x00a7ba */
+	0x00a7bd, /* 0x00a7bc */
+	0x00a7bf, /* 0x00a7be */
+	0x00a7c1, /* 0x00a7c0 */
+	0x00a7c3, /* 0x00a7c2 */
+	0x00a7c8, /* 0x00a7c7 */
+	0x00a7ca, /* 0x00a7c9 */
+	0x00a7d1, /* 0x00a7d0 */
+	0x00a7d7, /* 0x00a7d6 */
+	0x00a7d9, /* 0x00a7d8 */
+	0x00a7f6, /* 0x00a7f5 */
+	0x00fb00, /* 0x00fb00 */
+	0x00fb01, /* 0x00fb01 */
+	0x00fb02, /* 0x00fb02 */
+	0x00fb03, /* 0x00fb03 */
+	0x00fb04, /* 0x00fb04 */
+	0x00fb05, /* 0x00fb05 */
+	0x00fb06, /* 0x00fb06 */
+	0x00fb13, /* 0x00fb13 */
+	0x00fb14, /* 0x00fb14 */
+	0x00fb15, /* 0x00fb15 */
+	0x00fb16, /* 0x00fb16 */
+	0x00fb17, /* 0x00fb17 */
+	0x00ff41, /* 0x00ff21 */
+	0x00ff42, /* 0x00ff22 */
+	0x00ff43, /* 0x00ff23 */
+	0x00ff44, /* 0x00ff24 */
+	0x00ff45, /* 0x00ff25 */
+	0x00ff46, /* 0x00ff26 */
+	0x00ff47, /* 0x00ff27 */
+	0x00ff48, /* 0x00ff28 */
+	0x00ff49, /* 0x00ff29 */
+	0x00ff4a, /* 0x00ff2a */
+	0x00ff4b, /* 0x00ff2b */
+	0x00ff4c, /* 0x00ff2c */
+	0x00ff4d, /* 0x00ff2d */
+	0x00ff4e, /* 0x00ff2e */
+	0x00ff4f, /* 0x00ff2f */
+	0x00ff50, /* 0x00ff30 */
+	0x00ff51, /* 0x00ff31 */
+	0x00ff52, /* 0x00ff32 */
+	0x00ff53, /* 0x00ff33 */
+	0x00ff54, /* 0x00ff34 */
+	0x00ff55, /* 0x00ff35 */
+	0x00ff56, /* 0x00ff36 */
+	0x00ff57, /* 0x00ff37 */
+	0x00ff58, /* 0x00ff38 */
+	0x00ff59, /* 0x00ff39 */
+	0x00ff5a, /* 0x00ff3a */
+	0x010428, /* 0x010400 */
+	0x010429, /* 0x010401 */
+	0x01042a, /* 0x010402 */
+	0x01042b, /* 0x010403 */
+	0x01042c, /* 0x010404 */
+	0x01042d, /* 0x010405 */
+	0x01042e, /* 0x010406 */
+	0x01042f, /* 0x010407 */
+	0x010430, /* 0x010408 */
+	0x010431, /* 0x010409 */
+	0x010432, /* 0x01040a */
+	0x010433, /* 0x01040b */
+	0x010434, /* 0x01040c */
+	0x010435, /* 0x01040d */
+	0x010436, /* 0x01040e */
+	0x010437, /* 0x01040f */
+	0x010438, /* 0x010410 */
+	0x010439, /* 0x010411 */
+	0x01043a, /* 0x010412 */
+	0x01043b, /* 0x010413 */
+	0x01043c, /* 0x010414 */
+	0x01043d, /* 0x010415 */
+	0x01043e, /* 0x010416 */
+	0x01043f, /* 0x010417 */
+	0x010440, /* 0x010418 */
+	0x010441, /* 0x010419 */
+	0x010442, /* 0x01041a */
+	0x010443, /* 0x01041b */
+	0x010444, /* 0x01041c */
+	0x010445, /* 0x01041d */
+	0x010446, /* 0x01041e */
+	0x010447, /* 0x01041f */
+	0x010448, /* 0x010420 */
+	0x010449, /* 0x010421 */
+	0x01044a, /* 0x010422 */
+	0x01044b, /* 0x010423 */
+	0x01044c, /* 0x010424 */
+	0x01044d, /* 0x010425 */
+	0x01044e, /* 0x010426 */
+	0x01044f, /* 0x010427 */
+	0x0104d8, /* 0x0104b0 */
+	0x0104d9, /* 0x0104b1 */
+	0x0104da, /* 0x0104b2 */
+	0x0104db, /* 0x0104b3 */
+	0x0104dc, /* 0x0104b4 */
+	0x0104dd, /* 0x0104b5 */
+	0x0104de, /* 0x0104b6 */
+	0x0104df, /* 0x0104b7 */
+	0x0104e0, /* 0x0104b8 */
+	0x0104e1, /* 0x0104b9 */
+	0x0104e2, /* 0x0104ba */
+	0x0104e3, /* 0x0104bb */
+	0x0104e4, /* 0x0104bc */
+	0x0104e5, /* 0x0104bd */
+	0x0104e6, /* 0x0104be */
+	0x0104e7, /* 0x0104bf */
+	0x0104e8, /* 0x0104c0 */
+	0x0104e9, /* 0x0104c1 */
+	0x0104ea, /* 0x0104c2 */
+	0x0104eb, /* 0x0104c3 */
+	0x0104ec, /* 0x0104c4 */
+	0x0104ed, /* 0x0104c5 */
+	0x0104ee, /* 0x0104c6 */
+	0x0104ef, /* 0x0104c7 */
+	0x0104f0, /* 0x0104c8 */
+	0x0104f1, /* 0x0104c9 */
+	0x0104f2, /* 0x0104ca */
+	0x0104f3, /* 0x0104cb */
+	0x0104f4, /* 0x0104cc */
+	0x0104f5, /* 0x0104cd */
+	0x0104f6, /* 0x0104ce */
+	0x0104f7, /* 0x0104cf */
+	0x0104f8, /* 0x0104d0 */
+	0x0104f9, /* 0x0104d1 */
+	0x0104fa, /* 0x0104d2 */
+	0x0104fb, /* 0x0104d3 */
+	0x010597, /* 0x010570 */
+	0x010598, /* 0x010571 */
+	0x010599, /* 0x010572 */
+	0x01059a, /* 0x010573 */
+	0x01059b, /* 0x010574 */
+	0x01059c, /* 0x010575 */
+	0x01059d, /* 0x010576 */
+	0x01059e, /* 0x010577 */
+	0x01059f, /* 0x010578 */
+	0x0105a0, /* 0x010579 */
+	0x0105a1, /* 0x01057a */
+	0x0105a3, /* 0x01057c */
+	0x0105a4, /* 0x01057d */
+	0x0105a5, /* 0x01057e */
+	0x0105a6, /* 0x01057f */
+	0x0105a7, /* 0x010580 */
+	0x0105a8, /* 0x010581 */
+	0x0105a9, /* 0x010582 */
+	0x0105aa, /* 0x010583 */
+	0x0105ab, /* 0x010584 */
+	0x0105ac, /* 0x010585 */
+	0x0105ad, /* 0x010586 */
+	0x0105ae, /* 0x010587 */
+	0x0105af, /* 0x010588 */
+	0x0105b0, /* 0x010589 */
+	0x0105b1, /* 0x01058a */
+	0x0105b3, /* 0x01058c */
+	0x0105b4, /* 0x01058d */
+	0x0105b5, /* 0x01058e */
+	0x0105b6, /* 0x01058f */
+	0x0105b7, /* 0x010590 */
+	0x0105b8, /* 0x010591 */
+	0x0105b9, /* 0x010592 */
+	0x0105bb, /* 0x010594 */
+	0x0105bc, /* 0x010595 */
+	0x010cc0, /* 0x010c80 */
+	0x010cc1, /* 0x010c81 */
+	0x010cc2, /* 0x010c82 */
+	0x010cc3, /* 0x010c83 */
+	0x010cc4, /* 0x010c84 */
+	0x010cc5, /* 0x010c85 */
+	0x010cc6, /* 0x010c86 */
+	0x010cc7, /* 0x010c87 */
+	0x010cc8, /* 0x010c88 */
+	0x010cc9, /* 0x010c89 */
+	0x010cca, /* 0x010c8a */
+	0x010ccb, /* 0x010c8b */
+	0x010ccc, /* 0x010c8c */
+	0x010ccd, /* 0x010c8d */
+	0x010cce, /* 0x010c8e */
+	0x010ccf, /* 0x010c8f */
+	0x010cd0, /* 0x010c90 */
+	0x010cd1, /* 0x010c91 */
+	0x010cd2, /* 0x010c92 */
+	0x010cd3, /* 0x010c93 */
+	0x010cd4, /* 0x010c94 */
+	0x010cd5, /* 0x010c95 */
+	0x010cd6, /* 0x010c96 */
+	0x010cd7, /* 0x010c97 */
+	0x010cd8, /* 0x010c98 */
+	0x010cd9, /* 0x010c99 */
+	0x010cda, /* 0x010c9a */
+	0x010cdb, /* 0x010c9b */
+	0x010cdc, /* 0x010c9c */
+	0x010cdd, /* 0x010c9d */
+	0x010cde, /* 0x010c9e */
+	0x010cdf, /* 0x010c9f */
+	0x010ce0, /* 0x010ca0 */
+	0x010ce1, /* 0x010ca1 */
+	0x010ce2, /* 0x010ca2 */
+	0x010ce3, /* 0x010ca3 */
+	0x010ce4, /* 0x010ca4 */
+	0x010ce5, /* 0x010ca5 */
+	0x010ce6, /* 0x010ca6 */
+	0x010ce7, /* 0x010ca7 */
+	0x010ce8, /* 0x010ca8 */
+	0x010ce9, /* 0x010ca9 */
+	0x010cea, /* 0x010caa */
+	0x010ceb, /* 0x010cab */
+	0x010cec, /* 0x010cac */
+	0x010ced, /* 0x010cad */
+	0x010cee, /* 0x010cae */
+	0x010cef, /* 0x010caf */
+	0x010cf0, /* 0x010cb0 */
+	0x010cf1, /* 0x010cb1 */
+	0x010cf2, /* 0x010cb2 */
+	0x0118c0, /* 0x0118a0 */
+	0x0118c1, /* 0x0118a1 */
+	0x0118c2, /* 0x0118a2 */
+	0x0118c3, /* 0x0118a3 */
+	0x0118c4, /* 0x0118a4 */
+	0x0118c5, /* 0x0118a5 */
+	0x0118c6, /* 0x0118a6 */
+	0x0118c7, /* 0x0118a7 */
+	0x0118c8, /* 0x0118a8 */
+	0x0118c9, /* 0x0118a9 */
+	0x0118ca, /* 0x0118aa */
+	0x0118cb, /* 0x0118ab */
+	0x0118cc, /* 0x0118ac */
+	0x0118cd, /* 0x0118ad */
+	0x0118ce, /* 0x0118ae */
+	0x0118cf, /* 0x0118af */
+	0x0118d0, /* 0x0118b0 */
+	0x0118d1, /* 0x0118b1 */
+	0x0118d2, /* 0x0118b2 */
+	0x0118d3, /* 0x0118b3 */
+	0x0118d4, /* 0x0118b4 */
+	0x0118d5, /* 0x0118b5 */
+	0x0118d6, /* 0x0118b6 */
+	0x0118d7, /* 0x0118b7 */
+	0x0118d8, /* 0x0118b8 */
+	0x0118d9, /* 0x0118b9 */
+	0x0118da, /* 0x0118ba */
+	0x0118db, /* 0x0118bb */
+	0x0118dc, /* 0x0118bc */
+	0x0118dd, /* 0x0118bd */
+	0x0118de, /* 0x0118be */
+	0x0118df, /* 0x0118bf */
+	0x016e60, /* 0x016e40 */
+	0x016e61, /* 0x016e41 */
+	0x016e62, /* 0x016e42 */
+	0x016e63, /* 0x016e43 */
+	0x016e64, /* 0x016e44 */
+	0x016e65, /* 0x016e45 */
+	0x016e66, /* 0x016e46 */
+	0x016e67, /* 0x016e47 */
+	0x016e68, /* 0x016e48 */
+	0x016e69, /* 0x016e49 */
+	0x016e6a, /* 0x016e4a */
+	0x016e6b, /* 0x016e4b */
+	0x016e6c, /* 0x016e4c */
+	0x016e6d, /* 0x016e4d */
+	0x016e6e, /* 0x016e4e */
+	0x016e6f, /* 0x016e4f */
+	0x016e70, /* 0x016e50 */
+	0x016e71, /* 0x016e51 */
+	0x016e72, /* 0x016e52 */
+	0x016e73, /* 0x016e53 */
+	0x016e74, /* 0x016e54 */
+	0x016e75, /* 0x016e55 */
+	0x016e76, /* 0x016e56 */
+	0x016e77, /* 0x016e57 */
+	0x016e78, /* 0x016e58 */
+	0x016e79, /* 0x016e59 */
+	0x016e7a, /* 0x016e5a */
+	0x016e7b, /* 0x016e5b */
+	0x016e7c, /* 0x016e5c */
+	0x016e7d, /* 0x016e5d */
+	0x016e7e, /* 0x016e5e */
+	0x016e7f, /* 0x016e5f */
+	0x01e922, /* 0x01e900 */
+	0x01e923, /* 0x01e901 */
+	0x01e924, /* 0x01e902 */
+	0x01e925, /* 0x01e903 */
+	0x01e926, /* 0x01e904 */
+	0x01e927, /* 0x01e905 */
+	0x01e928, /* 0x01e906 */
+	0x01e929, /* 0x01e907 */
+	0x01e92a, /* 0x01e908 */
+	0x01e92b, /* 0x01e909 */
+	0x01e92c, /* 0x01e90a */
+	0x01e92d, /* 0x01e90b */
+	0x01e92e, /* 0x01e90c */
+	0x01e92f, /* 0x01e90d */
+	0x01e930, /* 0x01e90e */
+	0x01e931, /* 0x01e90f */
+	0x01e932, /* 0x01e910 */
+	0x01e933, /* 0x01e911 */
+	0x01e934, /* 0x01e912 */
+	0x01e935, /* 0x01e913 */
+	0x01e936, /* 0x01e914 */
+	0x01e937, /* 0x01e915 */
+	0x01e938, /* 0x01e916 */
+	0x01e939, /* 0x01e917 */
+	0x01e93a, /* 0x01e918 */
+	0x01e93b, /* 0x01e919 */
+	0x01e93c, /* 0x01e91a */
+	0x01e93d, /* 0x01e91b */
+	0x01e93e, /* 0x01e91c */
+	0x01e93f, /* 0x01e91d */
+	0x01e940, /* 0x01e91e */
+	0x01e941, /* 0x01e91f */
+	0x01e942, /* 0x01e920 */
+	0x01e943, /* 0x01e921 */
+};
+
+/*
+ * Case mapping table for title.
+ */
+static uint32 case_map_title[1677] =
+{
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000000 */
+	0x000001, /* 0x000001 */
+	0x000002, /* 0x000002 */
+	0x000003, /* 0x000003 */
+	0x000004, /* 0x000004 */
+	0x000005, /* 0x000005 */
+	0x000006, /* 0x000006 */
+	0x000007, /* 0x000007 */
+	0x000008, /* 0x000008 */
+	0x000009, /* 0x000009 */
+	0x00000a, /* 0x00000a */
+	0x00000b, /* 0x00000b */
+	0x00000c, /* 0x00000c */
+	0x00000d, /* 0x00000d */
+	0x00000e, /* 0x00000e */
+	0x00000f, /* 0x00000f */
+	0x000010, /* 0x000010 */
+	0x000011, /* 0x000011 */
+	0x000012, /* 0x000012 */
+	0x000013, /* 0x000013 */
+	0x000014, /* 0x000014 */
+	0x000015, /* 0x000015 */
+	0x000016, /* 0x000016 */
+	0x000017, /* 0x000017 */
+	0x000018, /* 0x000018 */
+	0x000019, /* 0x000019 */
+	0x00001a, /* 0x00001a */
+	0x00001b, /* 0x00001b */
+	0x00001c, /* 0x00001c */
+	0x00001d, /* 0x00001d */
+	0x00001e, /* 0x00001e */
+	0x00001f, /* 0x00001f */
+	0x000020, /* 0x000020 */
+	0x000021, /* 0x000021 */
+	0x000022, /* 0x000022 */
+	0x000023, /* 0x000023 */
+	0x000024, /* 0x000024 */
+	0x000025, /* 0x000025 */
+	0x000026, /* 0x000026 */
+	0x000027, /* 0x000027 */
+	0x000028, /* 0x000028 */
+	0x000029, /* 0x000029 */
+	0x00002a, /* 0x00002a */
+	0x00002b, /* 0x00002b */
+	0x00002c, /* 0x00002c */
+	0x00002d, /* 0x00002d */
+	0x00002e, /* 0x00002e */
+	0x00002f, /* 0x00002f */
+	0x000030, /* 0x000030 */
+	0x000031, /* 0x000031 */
+	0x000032, /* 0x000032 */
+	0x000033, /* 0x000033 */
+	0x000034, /* 0x000034 */
+	0x000035, /* 0x000035 */
+	0x000036, /* 0x000036 */
+	0x000037, /* 0x000037 */
+	0x000038, /* 0x000038 */
+	0x000039, /* 0x000039 */
+	0x00003a, /* 0x00003a */
+	0x00003b, /* 0x00003b */
+	0x00003c, /* 0x00003c */
+	0x00003d, /* 0x00003d */
+	0x00003e, /* 0x00003e */
+	0x00003f, /* 0x00003f */
+	0x000040, /* 0x000040 */
+	0x000041, /* 0x000041 */
+	0x000042, /* 0x000042 */
+	0x000043, /* 0x000043 */
+	0x000044, /* 0x000044 */
+	0x000045, /* 0x000045 */
+	0x000046, /* 0x000046 */
+	0x000047, /* 0x000047 */
+	0x000048, /* 0x000048 */
+	0x000049, /* 0x000049 */
+	0x00004a, /* 0x00004a */
+	0x00004b, /* 0x00004b */
+	0x00004c, /* 0x00004c */
+	0x00004d, /* 0x00004d */
+	0x00004e, /* 0x00004e */
+	0x00004f, /* 0x00004f */
+	0x000050, /* 0x000050 */
+	0x000051, /* 0x000051 */
+	0x000052, /* 0x000052 */
+	0x000053, /* 0x000053 */
+	0x000054, /* 0x000054 */
+	0x000055, /* 0x000055 */
+	0x000056, /* 0x000056 */
+	0x000057, /* 0x000057 */
+	0x000058, /* 0x000058 */
+	0x000059, /* 0x000059 */
+	0x00005a, /* 0x00005a */
+	0x00005b, /* 0x00005b */
+	0x00005c, /* 0x00005c */
+	0x00005d, /* 0x00005d */
+	0x00005e, /* 0x00005e */
+	0x00005f, /* 0x00005f */
+	0x000060, /* 0x000060 */
+	0x000041, /* 0x000061 */
+	0x000042, /* 0x000062 */
+	0x000043, /* 0x000063 */
+	0x000044, /* 0x000064 */
+	0x000045, /* 0x000065 */
+	0x000046, /* 0x000066 */
+	0x000047, /* 0x000067 */
+	0x000048, /* 0x000068 */
+	0x000049, /* 0x000069 */
+	0x00004a, /* 0x00006a */
+	0x00004b, /* 0x00006b */
+	0x00004c, /* 0x00006c */
+	0x00004d, /* 0x00006d */
+	0x00004e, /* 0x00006e */
+	0x00004f, /* 0x00006f */
+	0x000050, /* 0x000070 */
+	0x000051, /* 0x000071 */
+	0x000052, /* 0x000072 */
+	0x000053, /* 0x000073 */
+	0x000054, /* 0x000074 */
+	0x000055, /* 0x000075 */
+	0x000056, /* 0x000076 */
+	0x000057, /* 0x000077 */
+	0x000058, /* 0x000078 */
+	0x000059, /* 0x000079 */
+	0x00005a, /* 0x00007a */
+	0x00007b, /* 0x00007b */
+	0x00007c, /* 0x00007c */
+	0x00007d, /* 0x00007d */
+	0x00007e, /* 0x00007e */
+	0x00007f, /* 0x00007f */
+	0x00039c, /* 0x0000b5 */
+	0x0000c0, /* 0x0000c0 */
+	0x0000c1, /* 0x0000c1 */
+	0x0000c2, /* 0x0000c2 */
+	0x0000c3, /* 0x0000c3 */
+	0x0000c4, /* 0x0000c4 */
+	0x0000c5, /* 0x0000c5 */
+	0x0000c6, /* 0x0000c6 */
+	0x0000c7, /* 0x0000c7 */
+	0x0000c8, /* 0x0000c8 */
+	0x0000c9, /* 0x0000c9 */
+	0x0000ca, /* 0x0000ca */
+	0x0000cb, /* 0x0000cb */
+	0x0000cc, /* 0x0000cc */
+	0x0000cd, /* 0x0000cd */
+	0x0000ce, /* 0x0000ce */
+	0x0000cf, /* 0x0000cf */
+	0x0000d0, /* 0x0000d0 */
+	0x0000d1, /* 0x0000d1 */
+	0x0000d2, /* 0x0000d2 */
+	0x0000d3, /* 0x0000d3 */
+	0x0000d4, /* 0x0000d4 */
+	0x0000d5, /* 0x0000d5 */
+	0x0000d6, /* 0x0000d6 */
+	0x0000d8, /* 0x0000d8 */
+	0x0000d9, /* 0x0000d9 */
+	0x0000da, /* 0x0000da */
+	0x0000db, /* 0x0000db */
+	0x0000dc, /* 0x0000dc */
+	0x0000dd, /* 0x0000dd */
+	0x0000de, /* 0x0000de */
+	0x0000df, /* 0x0000df */
+	0x000178, /* 0x0000ff */
+	0x000100, /* 0x000100 */
+	0x000102, /* 0x000102 */
+	0x000104, /* 0x000104 */
+	0x000106, /* 0x000106 */
+	0x000108, /* 0x000108 */
+	0x00010a, /* 0x00010a */
+	0x00010c, /* 0x00010c */
+	0x00010e, /* 0x00010e */
+	0x000110, /* 0x000110 */
+	0x000112, /* 0x000112 */
+	0x000114, /* 0x000114 */
+	0x000116, /* 0x000116 */
+	0x000118, /* 0x000118 */
+	0x00011a, /* 0x00011a */
+	0x00011c, /* 0x00011c */
+	0x00011e, /* 0x00011e */
+	0x000120, /* 0x000120 */
+	0x000122, /* 0x000122 */
+	0x000124, /* 0x000124 */
+	0x000126, /* 0x000126 */
+	0x000128, /* 0x000128 */
+	0x00012a, /* 0x00012a */
+	0x00012c, /* 0x00012c */
+	0x00012e, /* 0x00012e */
+	0x000130, /* 0x000130 */
+	0x000049, /* 0x000131 */
+	0x000132, /* 0x000132 */
+	0x000134, /* 0x000134 */
+	0x000136, /* 0x000136 */
+	0x000139, /* 0x000139 */
+	0x00013b, /* 0x00013b */
+	0x00013d, /* 0x00013d */
+	0x00013f, /* 0x00013f */
+	0x000141, /* 0x000141 */
+	0x000143, /* 0x000143 */
+	0x000145, /* 0x000145 */
+	0x000147, /* 0x000147 */
+	0x000149, /* 0x000149 */
+	0x00014a, /* 0x00014a */
+	0x00014c, /* 0x00014c */
+	0x00014e, /* 0x00014e */
+	0x000150, /* 0x000150 */
+	0x000152, /* 0x000152 */
+	0x000154, /* 0x000154 */
+	0x000156, /* 0x000156 */
+	0x000158, /* 0x000158 */
+	0x00015a, /* 0x00015a */
+	0x00015c, /* 0x00015c */
+	0x00015e, /* 0x00015e */
+	0x000160, /* 0x000160 */
+	0x000162, /* 0x000162 */
+	0x000164, /* 0x000164 */
+	0x000166, /* 0x000166 */
+	0x000168, /* 0x000168 */
+	0x00016a, /* 0x00016a */
+	0x00016c, /* 0x00016c */
+	0x00016e, /* 0x00016e */
+	0x000170, /* 0x000170 */
+	0x000172, /* 0x000172 */
+	0x000174, /* 0x000174 */
+	0x000176, /* 0x000176 */
+	0x000179, /* 0x000179 */
+	0x00017b, /* 0x00017b */
+	0x00017d, /* 0x00017d */
+	0x000053, /* 0x00017f */
+	0x000243, /* 0x000180 */
+	0x000181, /* 0x000181 */
+	0x000182, /* 0x000182 */
+	0x000184, /* 0x000184 */
+	0x000186, /* 0x000186 */
+	0x000187, /* 0x000187 */
+	0x000189, /* 0x000189 */
+	0x00018a, /* 0x00018a */
+	0x00018b, /* 0x00018b */
+	0x00018e, /* 0x00018e */
+	0x00018f, /* 0x00018f */
+	0x000190, /* 0x000190 */
+	0x000191, /* 0x000191 */
+	0x000193, /* 0x000193 */
+	0x000194, /* 0x000194 */
+	0x0001f6, /* 0x000195 */
+	0x000196, /* 0x000196 */
+	0x000197, /* 0x000197 */
+	0x000198, /* 0x000198 */
+	0x00023d, /* 0x00019a */
+	0x00019c, /* 0x00019c */
+	0x00019d, /* 0x00019d */
+	0x000220, /* 0x00019e */
+	0x00019f, /* 0x00019f */
+	0x0001a0, /* 0x0001a0 */
+	0x0001a2, /* 0x0001a2 */
+	0x0001a4, /* 0x0001a4 */
+	0x0001a6, /* 0x0001a6 */
+	0x0001a7, /* 0x0001a7 */
+	0x0001a9, /* 0x0001a9 */
+	0x0001ac, /* 0x0001ac */
+	0x0001ae, /* 0x0001ae */
+	0x0001af, /* 0x0001af */
+	0x0001b1, /* 0x0001b1 */
+	0x0001b2, /* 0x0001b2 */
+	0x0001b3, /* 0x0001b3 */
+	0x0001b5, /* 0x0001b5 */
+	0x0001b7, /* 0x0001b7 */
+	0x0001b8, /* 0x0001b8 */
+	0x0001bc, /* 0x0001bc */
+	0x0001f7, /* 0x0001bf */
+	0x0001c5, /* 0x0001c4 */
+	0x0001c8, /* 0x0001c7 */
+	0x0001cb, /* 0x0001ca */
+	0x0001cd, /* 0x0001cd */
+	0x0001cf, /* 0x0001cf */
+	0x0001d1, /* 0x0001d1 */
+	0x0001d3, /* 0x0001d3 */
+	0x0001d5, /* 0x0001d5 */
+	0x0001d7, /* 0x0001d7 */
+	0x0001d9, /* 0x0001d9 */
+	0x0001db, /* 0x0001db */
+	0x0001de, /* 0x0001de */
+	0x0001e0, /* 0x0001e0 */
+	0x0001e2, /* 0x0001e2 */
+	0x0001e4, /* 0x0001e4 */
+	0x0001e6, /* 0x0001e6 */
+	0x0001e8, /* 0x0001e8 */
+	0x0001ea, /* 0x0001ea */
+	0x0001ec, /* 0x0001ec */
+	0x0001ee, /* 0x0001ee */
+	0x0001f0, /* 0x0001f0 */
+	0x0001f2, /* 0x0001f1 */
+	0x0001f4, /* 0x0001f4 */
+	0x0001f8, /* 0x0001f8 */
+	0x0001fa, /* 0x0001fa */
+	0x0001fc, /* 0x0001fc */
+	0x0001fe, /* 0x0001fe */
+	0x000200, /* 0x000200 */
+	0x000202, /* 0x000202 */
+	0x000204, /* 0x000204 */
+	0x000206, /* 0x000206 */
+	0x000208, /* 0x000208 */
+	0x00020a, /* 0x00020a */
+	0x00020c, /* 0x00020c */
+	0x00020e, /* 0x00020e */
+	0x000210, /* 0x000210 */
+	0x000212, /* 0x000212 */
+	0x000214, /* 0x000214 */
+	0x000216, /* 0x000216 */
+	0x000218, /* 0x000218 */
+	0x00021a, /* 0x00021a */
+	0x00021c, /* 0x00021c */
+	0x00021e, /* 0x00021e */
+	0x000222, /* 0x000222 */
+	0x000224, /* 0x000224 */
+	0x000226, /* 0x000226 */
+	0x000228, /* 0x000228 */
+	0x00022a, /* 0x00022a */
+	0x00022c, /* 0x00022c */
+	0x00022e, /* 0x00022e */
+	0x000230, /* 0x000230 */
+	0x000232, /* 0x000232 */
+	0x00023a, /* 0x00023a */
+	0x00023b, /* 0x00023b */
+	0x00023e, /* 0x00023e */
+	0x002c7e, /* 0x00023f */
+	0x002c7f, /* 0x000240 */
+	0x000241, /* 0x000241 */
+	0x000244, /* 0x000244 */
+	0x000245, /* 0x000245 */
+	0x000246, /* 0x000246 */
+	0x000248, /* 0x000248 */
+	0x00024a, /* 0x00024a */
+	0x00024c, /* 0x00024c */
+	0x00024e, /* 0x00024e */
+	0x002c6f, /* 0x000250 */
+	0x002c6d, /* 0x000251 */
+	0x002c70, /* 0x000252 */
+	0x00a7ab, /* 0x00025c */
+	0x00a7ac, /* 0x000261 */
+	0x00a78d, /* 0x000265 */
+	0x00a7aa, /* 0x000266 */
+	0x00a7ae, /* 0x00026a */
+	0x002c62, /* 0x00026b */
+	0x00a7ad, /* 0x00026c */
+	0x002c6e, /* 0x000271 */
+	0x002c64, /* 0x00027d */
+	0x00a7c5, /* 0x000282 */
+	0x00a7b1, /* 0x000287 */
+	0x00a7b2, /* 0x00029d */
+	0x00a7b0, /* 0x00029e */
+	0x000399, /* 0x000345 */
+	0x000370, /* 0x000370 */
+	0x000372, /* 0x000372 */
+	0x000376, /* 0x000376 */
+	0x0003fd, /* 0x00037b */
+	0x0003fe, /* 0x00037c */
+	0x0003ff, /* 0x00037d */
+	0x00037f, /* 0x00037f */
+	0x000386, /* 0x000386 */
+	0x000388, /* 0x000388 */
+	0x000389, /* 0x000389 */
+	0x00038a, /* 0x00038a */
+	0x00038c, /* 0x00038c */
+	0x00038e, /* 0x00038e */
+	0x00038f, /* 0x00038f */
+	0x000390, /* 0x000390 */
+	0x000391, /* 0x000391 */
+	0x000392, /* 0x000392 */
+	0x000393, /* 0x000393 */
+	0x000394, /* 0x000394 */
+	0x000395, /* 0x000395 */
+	0x000396, /* 0x000396 */
+	0x000397, /* 0x000397 */
+	0x000398, /* 0x000398 */
+	0x000399, /* 0x000399 */
+	0x00039a, /* 0x00039a */
+	0x00039b, /* 0x00039b */
+	0x00039c, /* 0x00039c */
+	0x00039d, /* 0x00039d */
+	0x00039e, /* 0x00039e */
+	0x00039f, /* 0x00039f */
+	0x0003a0, /* 0x0003a0 */
+	0x0003a1, /* 0x0003a1 */
+	0x0003a3, /* 0x0003a3 */
+	0x0003a4, /* 0x0003a4 */
+	0x0003a5, /* 0x0003a5 */
+	0x0003a6, /* 0x0003a6 */
+	0x0003a7, /* 0x0003a7 */
+	0x0003a8, /* 0x0003a8 */
+	0x0003a9, /* 0x0003a9 */
+	0x0003aa, /* 0x0003aa */
+	0x0003ab, /* 0x0003ab */
+	0x0003b0, /* 0x0003b0 */
+	0x0003a3, /* 0x0003c2 */
+	0x0003a3, /* 0x0003c3 */
+	0x0003cf, /* 0x0003cf */
+	0x000392, /* 0x0003d0 */
+	0x000398, /* 0x0003d1 */
+	0x0003a6, /* 0x0003d5 */
+	0x0003a0, /* 0x0003d6 */
+	0x0003d8, /* 0x0003d8 */
+	0x0003da, /* 0x0003da */
+	0x0003dc, /* 0x0003dc */
+	0x0003de, /* 0x0003de */
+	0x0003e0, /* 0x0003e0 */
+	0x0003e2, /* 0x0003e2 */
+	0x0003e4, /* 0x0003e4 */
+	0x0003e6, /* 0x0003e6 */
+	0x0003e8, /* 0x0003e8 */
+	0x0003ea, /* 0x0003ea */
+	0x0003ec, /* 0x0003ec */
+	0x0003ee, /* 0x0003ee */
+	0x00039a, /* 0x0003f0 */
+	0x0003a1, /* 0x0003f1 */
+	0x0003f9, /* 0x0003f2 */
+	0x0003f4, /* 0x0003f4 */
+	0x000395, /* 0x0003f5 */
+	0x0003f7, /* 0x0003f7 */
+	0x0003fa, /* 0x0003fa */
+	0x000400, /* 0x000400 */
+	0x000401, /* 0x000401 */
+	0x000402, /* 0x000402 */
+	0x000403, /* 0x000403 */
+	0x000404, /* 0x000404 */
+	0x000405, /* 0x000405 */
+	0x000406, /* 0x000406 */
+	0x000407, /* 0x000407 */
+	0x000408, /* 0x000408 */
+	0x000409, /* 0x000409 */
+	0x00040a, /* 0x00040a */
+	0x00040b, /* 0x00040b */
+	0x00040c, /* 0x00040c */
+	0x00040d, /* 0x00040d */
+	0x00040e, /* 0x00040e */
+	0x00040f, /* 0x00040f */
+	0x000410, /* 0x000410 */
+	0x000411, /* 0x000411 */
+	0x000412, /* 0x000412 */
+	0x000413, /* 0x000413 */
+	0x000414, /* 0x000414 */
+	0x000415, /* 0x000415 */
+	0x000416, /* 0x000416 */
+	0x000417, /* 0x000417 */
+	0x000418, /* 0x000418 */
+	0x000419, /* 0x000419 */
+	0x00041a, /* 0x00041a */
+	0x00041b, /* 0x00041b */
+	0x00041c, /* 0x00041c */
+	0x00041d, /* 0x00041d */
+	0x00041e, /* 0x00041e */
+	0x00041f, /* 0x00041f */
+	0x000420, /* 0x000420 */
+	0x000421, /* 0x000421 */
+	0x000422, /* 0x000422 */
+	0x000423, /* 0x000423 */
+	0x000424, /* 0x000424 */
+	0x000425, /* 0x000425 */
+	0x000426, /* 0x000426 */
+	0x000427, /* 0x000427 */
+	0x000428, /* 0x000428 */
+	0x000429, /* 0x000429 */
+	0x00042a, /* 0x00042a */
+	0x00042b, /* 0x00042b */
+	0x00042c, /* 0x00042c */
+	0x00042d, /* 0x00042d */
+	0x00042e, /* 0x00042e */
+	0x00042f, /* 0x00042f */
+	0x000460, /* 0x000460 */
+	0x000462, /* 0x000462 */
+	0x000464, /* 0x000464 */
+	0x000466, /* 0x000466 */
+	0x000468, /* 0x000468 */
+	0x00046a, /* 0x00046a */
+	0x00046c, /* 0x00046c */
+	0x00046e, /* 0x00046e */
+	0x000470, /* 0x000470 */
+	0x000472, /* 0x000472 */
+	0x000474, /* 0x000474 */
+	0x000476, /* 0x000476 */
+	0x000478, /* 0x000478 */
+	0x00047a, /* 0x00047a */
+	0x00047c, /* 0x00047c */
+	0x00047e, /* 0x00047e */
+	0x000480, /* 0x000480 */
+	0x00048a, /* 0x00048a */
+	0x00048c, /* 0x00048c */
+	0x00048e, /* 0x00048e */
+	0x000490, /* 0x000490 */
+	0x000492, /* 0x000492 */
+	0x000494, /* 0x000494 */
+	0x000496, /* 0x000496 */
+	0x000498, /* 0x000498 */
+	0x00049a, /* 0x00049a */
+	0x00049c, /* 0x00049c */
+	0x00049e, /* 0x00049e */
+	0x0004a0, /* 0x0004a0 */
+	0x0004a2, /* 0x0004a2 */
+	0x0004a4, /* 0x0004a4 */
+	0x0004a6, /* 0x0004a6 */
+	0x0004a8, /* 0x0004a8 */
+	0x0004aa, /* 0x0004aa */
+	0x0004ac, /* 0x0004ac */
+	0x0004ae, /* 0x0004ae */
+	0x0004b0, /* 0x0004b0 */
+	0x0004b2, /* 0x0004b2 */
+	0x0004b4, /* 0x0004b4 */
+	0x0004b6, /* 0x0004b6 */
+	0x0004b8, /* 0x0004b8 */
+	0x0004ba, /* 0x0004ba */
+	0x0004bc, /* 0x0004bc */
+	0x0004be, /* 0x0004be */
+	0x0004c0, /* 0x0004c0 */
+	0x0004c1, /* 0x0004c1 */
+	0x0004c3, /* 0x0004c3 */
+	0x0004c5, /* 0x0004c5 */
+	0x0004c7, /* 0x0004c7 */
+	0x0004c9, /* 0x0004c9 */
+	0x0004cb, /* 0x0004cb */
+	0x0004cd, /* 0x0004cd */
+	0x0004d0, /* 0x0004d0 */
+	0x0004d2, /* 0x0004d2 */
+	0x0004d4, /* 0x0004d4 */
+	0x0004d6, /* 0x0004d6 */
+	0x0004d8, /* 0x0004d8 */
+	0x0004da, /* 0x0004da */
+	0x0004dc, /* 0x0004dc */
+	0x0004de, /* 0x0004de */
+	0x0004e0, /* 0x0004e0 */
+	0x0004e2, /* 0x0004e2 */
+	0x0004e4, /* 0x0004e4 */
+	0x0004e6, /* 0x0004e6 */
+	0x0004e8, /* 0x0004e8 */
+	0x0004ea, /* 0x0004ea */
+	0x0004ec, /* 0x0004ec */
+	0x0004ee, /* 0x0004ee */
+	0x0004f0, /* 0x0004f0 */
+	0x0004f2, /* 0x0004f2 */
+	0x0004f4, /* 0x0004f4 */
+	0x0004f6, /* 0x0004f6 */
+	0x0004f8, /* 0x0004f8 */
+	0x0004fa, /* 0x0004fa */
+	0x0004fc, /* 0x0004fc */
+	0x0004fe, /* 0x0004fe */
+	0x000500, /* 0x000500 */
+	0x000502, /* 0x000502 */
+	0x000504, /* 0x000504 */
+	0x000506, /* 0x000506 */
+	0x000508, /* 0x000508 */
+	0x00050a, /* 0x00050a */
+	0x00050c, /* 0x00050c */
+	0x00050e, /* 0x00050e */
+	0x000510, /* 0x000510 */
+	0x000512, /* 0x000512 */
+	0x000514, /* 0x000514 */
+	0x000516, /* 0x000516 */
+	0x000518, /* 0x000518 */
+	0x00051a, /* 0x00051a */
+	0x00051c, /* 0x00051c */
+	0x00051e, /* 0x00051e */
+	0x000520, /* 0x000520 */
+	0x000522, /* 0x000522 */
+	0x000524, /* 0x000524 */
+	0x000526, /* 0x000526 */
+	0x000528, /* 0x000528 */
+	0x00052a, /* 0x00052a */
+	0x00052c, /* 0x00052c */
+	0x00052e, /* 0x00052e */
+	0x000531, /* 0x000531 */
+	0x000532, /* 0x000532 */
+	0x000533, /* 0x000533 */
+	0x000534, /* 0x000534 */
+	0x000535, /* 0x000535 */
+	0x000536, /* 0x000536 */
+	0x000537, /* 0x000537 */
+	0x000538, /* 0x000538 */
+	0x000539, /* 0x000539 */
+	0x00053a, /* 0x00053a */
+	0x00053b, /* 0x00053b */
+	0x00053c, /* 0x00053c */
+	0x00053d, /* 0x00053d */
+	0x00053e, /* 0x00053e */
+	0x00053f, /* 0x00053f */
+	0x000540, /* 0x000540 */
+	0x000541, /* 0x000541 */
+	0x000542, /* 0x000542 */
+	0x000543, /* 0x000543 */
+	0x000544, /* 0x000544 */
+	0x000545, /* 0x000545 */
+	0x000546, /* 0x000546 */
+	0x000547, /* 0x000547 */
+	0x000548, /* 0x000548 */
+	0x000549, /* 0x000549 */
+	0x00054a, /* 0x00054a */
+	0x00054b, /* 0x00054b */
+	0x00054c, /* 0x00054c */
+	0x00054d, /* 0x00054d */
+	0x00054e, /* 0x00054e */
+	0x00054f, /* 0x00054f */
+	0x000550, /* 0x000550 */
+	0x000551, /* 0x000551 */
+	0x000552, /* 0x000552 */
+	0x000553, /* 0x000553 */
+	0x000554, /* 0x000554 */
+	0x000555, /* 0x000555 */
+	0x000556, /* 0x000556 */
+	0x000587, /* 0x000587 */
+	0x0010a0, /* 0x0010a0 */
+	0x0010a1, /* 0x0010a1 */
+	0x0010a2, /* 0x0010a2 */
+	0x0010a3, /* 0x0010a3 */
+	0x0010a4, /* 0x0010a4 */
+	0x0010a5, /* 0x0010a5 */
+	0x0010a6, /* 0x0010a6 */
+	0x0010a7, /* 0x0010a7 */
+	0x0010a8, /* 0x0010a8 */
+	0x0010a9, /* 0x0010a9 */
+	0x0010aa, /* 0x0010aa */
+	0x0010ab, /* 0x0010ab */
+	0x0010ac, /* 0x0010ac */
+	0x0010ad, /* 0x0010ad */
+	0x0010ae, /* 0x0010ae */
+	0x0010af, /* 0x0010af */
+	0x0010b0, /* 0x0010b0 */
+	0x0010b1, /* 0x0010b1 */
+	0x0010b2, /* 0x0010b2 */
+	0x0010b3, /* 0x0010b3 */
+	0x0010b4, /* 0x0010b4 */
+	0x0010b5, /* 0x0010b5 */
+	0x0010b6, /* 0x0010b6 */
+	0x0010b7, /* 0x0010b7 */
+	0x0010b8, /* 0x0010b8 */
+	0x0010b9, /* 0x0010b9 */
+	0x0010ba, /* 0x0010ba */
+	0x0010bb, /* 0x0010bb */
+	0x0010bc, /* 0x0010bc */
+	0x0010bd, /* 0x0010bd */
+	0x0010be, /* 0x0010be */
+	0x0010bf, /* 0x0010bf */
+	0x0010c0, /* 0x0010c0 */
+	0x0010c1, /* 0x0010c1 */
+	0x0010c2, /* 0x0010c2 */
+	0x0010c3, /* 0x0010c3 */
+	0x0010c4, /* 0x0010c4 */
+	0x0010c5, /* 0x0010c5 */
+	0x0010c7, /* 0x0010c7 */
+	0x0010cd, /* 0x0010cd */
+	0x0010d0, /* 0x0010d0 */
+	0x0010d1, /* 0x0010d1 */
+	0x0010d2, /* 0x0010d2 */
+	0x0010d3, /* 0x0010d3 */
+	0x0010d4, /* 0x0010d4 */
+	0x0010d5, /* 0x0010d5 */
+	0x0010d6, /* 0x0010d6 */
+	0x0010d7, /* 0x0010d7 */
+	0x0010d8, /* 0x0010d8 */
+	0x0010d9, /* 0x0010d9 */
+	0x0010da, /* 0x0010da */
+	0x0010db, /* 0x0010db */
+	0x0010dc, /* 0x0010dc */
+	0x0010dd, /* 0x0010dd */
+	0x0010de, /* 0x0010de */
+	0x0010df, /* 0x0010df */
+	0x0010e0, /* 0x0010e0 */
+	0x0010e1, /* 0x0010e1 */
+	0x0010e2, /* 0x0010e2 */
+	0x0010e3, /* 0x0010e3 */
+	0x0010e4, /* 0x0010e4 */
+	0x0010e5, /* 0x0010e5 */
+	0x0010e6, /* 0x0010e6 */
+	0x0010e7, /* 0x0010e7 */
+	0x0010e8, /* 0x0010e8 */
+	0x0010e9, /* 0x0010e9 */
+	0x0010ea, /* 0x0010ea */
+	0x0010eb, /* 0x0010eb */
+	0x0010ec, /* 0x0010ec */
+	0x0010ed, /* 0x0010ed */
+	0x0010ee, /* 0x0010ee */
+	0x0010ef, /* 0x0010ef */
+	0x0010f0, /* 0x0010f0 */
+	0x0010f1, /* 0x0010f1 */
+	0x0010f2, /* 0x0010f2 */
+	0x0010f3, /* 0x0010f3 */
+	0x0010f4, /* 0x0010f4 */
+	0x0010f5, /* 0x0010f5 */
+	0x0010f6, /* 0x0010f6 */
+	0x0010f7, /* 0x0010f7 */
+	0x0010f8, /* 0x0010f8 */
+	0x0010f9, /* 0x0010f9 */
+	0x0010fa, /* 0x0010fa */
+	0x0010fd, /* 0x0010fd */
+	0x0010fe, /* 0x0010fe */
+	0x0010ff, /* 0x0010ff */
+	0x0013a0, /* 0x0013a0 */
+	0x0013a1, /* 0x0013a1 */
+	0x0013a2, /* 0x0013a2 */
+	0x0013a3, /* 0x0013a3 */
+	0x0013a4, /* 0x0013a4 */
+	0x0013a5, /* 0x0013a5 */
+	0x0013a6, /* 0x0013a6 */
+	0x0013a7, /* 0x0013a7 */
+	0x0013a8, /* 0x0013a8 */
+	0x0013a9, /* 0x0013a9 */
+	0x0013aa, /* 0x0013aa */
+	0x0013ab, /* 0x0013ab */
+	0x0013ac, /* 0x0013ac */
+	0x0013ad, /* 0x0013ad */
+	0x0013ae, /* 0x0013ae */
+	0x0013af, /* 0x0013af */
+	0x0013b0, /* 0x0013b0 */
+	0x0013b1, /* 0x0013b1 */
+	0x0013b2, /* 0x0013b2 */
+	0x0013b3, /* 0x0013b3 */
+	0x0013b4, /* 0x0013b4 */
+	0x0013b5, /* 0x0013b5 */
+	0x0013b6, /* 0x0013b6 */
+	0x0013b7, /* 0x0013b7 */
+	0x0013b8, /* 0x0013b8 */
+	0x0013b9, /* 0x0013b9 */
+	0x0013ba, /* 0x0013ba */
+	0x0013bb, /* 0x0013bb */
+	0x0013bc, /* 0x0013bc */
+	0x0013bd, /* 0x0013bd */
+	0x0013be, /* 0x0013be */
+	0x0013bf, /* 0x0013bf */
+	0x0013c0, /* 0x0013c0 */
+	0x0013c1, /* 0x0013c1 */
+	0x0013c2, /* 0x0013c2 */
+	0x0013c3, /* 0x0013c3 */
+	0x0013c4, /* 0x0013c4 */
+	0x0013c5, /* 0x0013c5 */
+	0x0013c6, /* 0x0013c6 */
+	0x0013c7, /* 0x0013c7 */
+	0x0013c8, /* 0x0013c8 */
+	0x0013c9, /* 0x0013c9 */
+	0x0013ca, /* 0x0013ca */
+	0x0013cb, /* 0x0013cb */
+	0x0013cc, /* 0x0013cc */
+	0x0013cd, /* 0x0013cd */
+	0x0013ce, /* 0x0013ce */
+	0x0013cf, /* 0x0013cf */
+	0x0013d0, /* 0x0013d0 */
+	0x0013d1, /* 0x0013d1 */
+	0x0013d2, /* 0x0013d2 */
+	0x0013d3, /* 0x0013d3 */
+	0x0013d4, /* 0x0013d4 */
+	0x0013d5, /* 0x0013d5 */
+	0x0013d6, /* 0x0013d6 */
+	0x0013d7, /* 0x0013d7 */
+	0x0013d8, /* 0x0013d8 */
+	0x0013d9, /* 0x0013d9 */
+	0x0013da, /* 0x0013da */
+	0x0013db, /* 0x0013db */
+	0x0013dc, /* 0x0013dc */
+	0x0013dd, /* 0x0013dd */
+	0x0013de, /* 0x0013de */
+	0x0013df, /* 0x0013df */
+	0x0013e0, /* 0x0013e0 */
+	0x0013e1, /* 0x0013e1 */
+	0x0013e2, /* 0x0013e2 */
+	0x0013e3, /* 0x0013e3 */
+	0x0013e4, /* 0x0013e4 */
+	0x0013e5, /* 0x0013e5 */
+	0x0013e6, /* 0x0013e6 */
+	0x0013e7, /* 0x0013e7 */
+	0x0013e8, /* 0x0013e8 */
+	0x0013e9, /* 0x0013e9 */
+	0x0013ea, /* 0x0013ea */
+	0x0013eb, /* 0x0013eb */
+	0x0013ec, /* 0x0013ec */
+	0x0013ed, /* 0x0013ed */
+	0x0013ee, /* 0x0013ee */
+	0x0013ef, /* 0x0013ef */
+	0x0013f0, /* 0x0013f0 */
+	0x0013f1, /* 0x0013f1 */
+	0x0013f2, /* 0x0013f2 */
+	0x0013f3, /* 0x0013f3 */
+	0x0013f4, /* 0x0013f4 */
+	0x0013f5, /* 0x0013f5 */
+	0x000412, /* 0x001c80 */
+	0x000414, /* 0x001c81 */
+	0x00041e, /* 0x001c82 */
+	0x000421, /* 0x001c83 */
+	0x000422, /* 0x001c84 */
+	0x000422, /* 0x001c85 */
+	0x00042a, /* 0x001c86 */
+	0x000462, /* 0x001c87 */
+	0x00a64a, /* 0x001c88 */
+	0x001c90, /* 0x001c90 */
+	0x001c91, /* 0x001c91 */
+	0x001c92, /* 0x001c92 */
+	0x001c93, /* 0x001c93 */
+	0x001c94, /* 0x001c94 */
+	0x001c95, /* 0x001c95 */
+	0x001c96, /* 0x001c96 */
+	0x001c97, /* 0x001c97 */
+	0x001c98, /* 0x001c98 */
+	0x001c99, /* 0x001c99 */
+	0x001c9a, /* 0x001c9a */
+	0x001c9b, /* 0x001c9b */
+	0x001c9c, /* 0x001c9c */
+	0x001c9d, /* 0x001c9d */
+	0x001c9e, /* 0x001c9e */
+	0x001c9f, /* 0x001c9f */
+	0x001ca0, /* 0x001ca0 */
+	0x001ca1, /* 0x001ca1 */
+	0x001ca2, /* 0x001ca2 */
+	0x001ca3, /* 0x001ca3 */
+	0x001ca4, /* 0x001ca4 */
+	0x001ca5, /* 0x001ca5 */
+	0x001ca6, /* 0x001ca6 */
+	0x001ca7, /* 0x001ca7 */
+	0x001ca8, /* 0x001ca8 */
+	0x001ca9, /* 0x001ca9 */
+	0x001caa, /* 0x001caa */
+	0x001cab, /* 0x001cab */
+	0x001cac, /* 0x001cac */
+	0x001cad, /* 0x001cad */
+	0x001cae, /* 0x001cae */
+	0x001caf, /* 0x001caf */
+	0x001cb0, /* 0x001cb0 */
+	0x001cb1, /* 0x001cb1 */
+	0x001cb2, /* 0x001cb2 */
+	0x001cb3, /* 0x001cb3 */
+	0x001cb4, /* 0x001cb4 */
+	0x001cb5, /* 0x001cb5 */
+	0x001cb6, /* 0x001cb6 */
+	0x001cb7, /* 0x001cb7 */
+	0x001cb8, /* 0x001cb8 */
+	0x001cb9, /* 0x001cb9 */
+	0x001cba, /* 0x001cba */
+	0x001cbd, /* 0x001cbd */
+	0x001cbe, /* 0x001cbe */
+	0x001cbf, /* 0x001cbf */
+	0x00a77d, /* 0x001d79 */
+	0x002c63, /* 0x001d7d */
+	0x00a7c6, /* 0x001d8e */
+	0x001e00, /* 0x001e00 */
+	0x001e02, /* 0x001e02 */
+	0x001e04, /* 0x001e04 */
+	0x001e06, /* 0x001e06 */
+	0x001e08, /* 0x001e08 */
+	0x001e0a, /* 0x001e0a */
+	0x001e0c, /* 0x001e0c */
+	0x001e0e, /* 0x001e0e */
+	0x001e10, /* 0x001e10 */
+	0x001e12, /* 0x001e12 */
+	0x001e14, /* 0x001e14 */
+	0x001e16, /* 0x001e16 */
+	0x001e18, /* 0x001e18 */
+	0x001e1a, /* 0x001e1a */
+	0x001e1c, /* 0x001e1c */
+	0x001e1e, /* 0x001e1e */
+	0x001e20, /* 0x001e20 */
+	0x001e22, /* 0x001e22 */
+	0x001e24, /* 0x001e24 */
+	0x001e26, /* 0x001e26 */
+	0x001e28, /* 0x001e28 */
+	0x001e2a, /* 0x001e2a */
+	0x001e2c, /* 0x001e2c */
+	0x001e2e, /* 0x001e2e */
+	0x001e30, /* 0x001e30 */
+	0x001e32, /* 0x001e32 */
+	0x001e34, /* 0x001e34 */
+	0x001e36, /* 0x001e36 */
+	0x001e38, /* 0x001e38 */
+	0x001e3a, /* 0x001e3a */
+	0x001e3c, /* 0x001e3c */
+	0x001e3e, /* 0x001e3e */
+	0x001e40, /* 0x001e40 */
+	0x001e42, /* 0x001e42 */
+	0x001e44, /* 0x001e44 */
+	0x001e46, /* 0x001e46 */
+	0x001e48, /* 0x001e48 */
+	0x001e4a, /* 0x001e4a */
+	0x001e4c, /* 0x001e4c */
+	0x001e4e, /* 0x001e4e */
+	0x001e50, /* 0x001e50 */
+	0x001e52, /* 0x001e52 */
+	0x001e54, /* 0x001e54 */
+	0x001e56, /* 0x001e56 */
+	0x001e58, /* 0x001e58 */
+	0x001e5a, /* 0x001e5a */
+	0x001e5c, /* 0x001e5c */
+	0x001e5e, /* 0x001e5e */
+	0x001e60, /* 0x001e60 */
+	0x001e62, /* 0x001e62 */
+	0x001e64, /* 0x001e64 */
+	0x001e66, /* 0x001e66 */
+	0x001e68, /* 0x001e68 */
+	0x001e6a, /* 0x001e6a */
+	0x001e6c, /* 0x001e6c */
+	0x001e6e, /* 0x001e6e */
+	0x001e70, /* 0x001e70 */
+	0x001e72, /* 0x001e72 */
+	0x001e74, /* 0x001e74 */
+	0x001e76, /* 0x001e76 */
+	0x001e78, /* 0x001e78 */
+	0x001e7a, /* 0x001e7a */
+	0x001e7c, /* 0x001e7c */
+	0x001e7e, /* 0x001e7e */
+	0x001e80, /* 0x001e80 */
+	0x001e82, /* 0x001e82 */
+	0x001e84, /* 0x001e84 */
+	0x001e86, /* 0x001e86 */
+	0x001e88, /* 0x001e88 */
+	0x001e8a, /* 0x001e8a */
+	0x001e8c, /* 0x001e8c */
+	0x001e8e, /* 0x001e8e */
+	0x001e90, /* 0x001e90 */
+	0x001e92, /* 0x001e92 */
+	0x001e94, /* 0x001e94 */
+	0x001e96, /* 0x001e96 */
+	0x001e97, /* 0x001e97 */
+	0x001e98, /* 0x001e98 */
+	0x001e99, /* 0x001e99 */
+	0x001e9a, /* 0x001e9a */
+	0x001e60, /* 0x001e9b */
+	0x001e9e, /* 0x001e9e */
+	0x001ea0, /* 0x001ea0 */
+	0x001ea2, /* 0x001ea2 */
+	0x001ea4, /* 0x001ea4 */
+	0x001ea6, /* 0x001ea6 */
+	0x001ea8, /* 0x001ea8 */
+	0x001eaa, /* 0x001eaa */
+	0x001eac, /* 0x001eac */
+	0x001eae, /* 0x001eae */
+	0x001eb0, /* 0x001eb0 */
+	0x001eb2, /* 0x001eb2 */
+	0x001eb4, /* 0x001eb4 */
+	0x001eb6, /* 0x001eb6 */
+	0x001eb8, /* 0x001eb8 */
+	0x001eba, /* 0x001eba */
+	0x001ebc, /* 0x001ebc */
+	0x001ebe, /* 0x001ebe */
+	0x001ec0, /* 0x001ec0 */
+	0x001ec2, /* 0x001ec2 */
+	0x001ec4, /* 0x001ec4 */
+	0x001ec6, /* 0x001ec6 */
+	0x001ec8, /* 0x001ec8 */
+	0x001eca, /* 0x001eca */
+	0x001ecc, /* 0x001ecc */
+	0x001ece, /* 0x001ece */
+	0x001ed0, /* 0x001ed0 */
+	0x001ed2, /* 0x001ed2 */
+	0x001ed4, /* 0x001ed4 */
+	0x001ed6, /* 0x001ed6 */
+	0x001ed8, /* 0x001ed8 */
+	0x001eda, /* 0x001eda */
+	0x001edc, /* 0x001edc */
+	0x001ede, /* 0x001ede */
+	0x001ee0, /* 0x001ee0 */
+	0x001ee2, /* 0x001ee2 */
+	0x001ee4, /* 0x001ee4 */
+	0x001ee6, /* 0x001ee6 */
+	0x001ee8, /* 0x001ee8 */
+	0x001eea, /* 0x001eea */
+	0x001eec, /* 0x001eec */
+	0x001eee, /* 0x001eee */
+	0x001ef0, /* 0x001ef0 */
+	0x001ef2, /* 0x001ef2 */
+	0x001ef4, /* 0x001ef4 */
+	0x001ef6, /* 0x001ef6 */
+	0x001ef8, /* 0x001ef8 */
+	0x001efa, /* 0x001efa */
+	0x001efc, /* 0x001efc */
+	0x001efe, /* 0x001efe */
+	0x001f08, /* 0x001f00 */
+	0x001f09, /* 0x001f01 */
+	0x001f0a, /* 0x001f02 */
+	0x001f0b, /* 0x001f03 */
+	0x001f0c, /* 0x001f04 */
+	0x001f0d, /* 0x001f05 */
+	0x001f0e, /* 0x001f06 */
+	0x001f0f, /* 0x001f07 */
+	0x001f18, /* 0x001f10 */
+	0x001f19, /* 0x001f11 */
+	0x001f1a, /* 0x001f12 */
+	0x001f1b, /* 0x001f13 */
+	0x001f1c, /* 0x001f14 */
+	0x001f1d, /* 0x001f15 */
+	0x001f28, /* 0x001f20 */
+	0x001f29, /* 0x001f21 */
+	0x001f2a, /* 0x001f22 */
+	0x001f2b, /* 0x001f23 */
+	0x001f2c, /* 0x001f24 */
+	0x001f2d, /* 0x001f25 */
+	0x001f2e, /* 0x001f26 */
+	0x001f2f, /* 0x001f27 */
+	0x001f38, /* 0x001f30 */
+	0x001f39, /* 0x001f31 */
+	0x001f3a, /* 0x001f32 */
+	0x001f3b, /* 0x001f33 */
+	0x001f3c, /* 0x001f34 */
+	0x001f3d, /* 0x001f35 */
+	0x001f3e, /* 0x001f36 */
+	0x001f3f, /* 0x001f37 */
+	0x001f48, /* 0x001f40 */
+	0x001f49, /* 0x001f41 */
+	0x001f4a, /* 0x001f42 */
+	0x001f4b, /* 0x001f43 */
+	0x001f4c, /* 0x001f44 */
+	0x001f4d, /* 0x001f45 */
+	0x001f50, /* 0x001f50 */
+	0x001f59, /* 0x001f51 */
+	0x001f52, /* 0x001f52 */
+	0x001f5b, /* 0x001f53 */
+	0x001f54, /* 0x001f54 */
+	0x001f5d, /* 0x001f55 */
+	0x001f56, /* 0x001f56 */
+	0x001f5f, /* 0x001f57 */
+	0x001f68, /* 0x001f60 */
+	0x001f69, /* 0x001f61 */
+	0x001f6a, /* 0x001f62 */
+	0x001f6b, /* 0x001f63 */
+	0x001f6c, /* 0x001f64 */
+	0x001f6d, /* 0x001f65 */
+	0x001f6e, /* 0x001f66 */
+	0x001f6f, /* 0x001f67 */
+	0x001fba, /* 0x001f70 */
+	0x001fbb, /* 0x001f71 */
+	0x001fc8, /* 0x001f72 */
+	0x001fc9, /* 0x001f73 */
+	0x001fca, /* 0x001f74 */
+	0x001fcb, /* 0x001f75 */
+	0x001fda, /* 0x001f76 */
+	0x001fdb, /* 0x001f77 */
+	0x001ff8, /* 0x001f78 */
+	0x001ff9, /* 0x001f79 */
+	0x001fea, /* 0x001f7a */
+	0x001feb, /* 0x001f7b */
+	0x001ffa, /* 0x001f7c */
+	0x001ffb, /* 0x001f7d */
+	0x001f88, /* 0x001f80 */
+	0x001f89, /* 0x001f81 */
+	0x001f8a, /* 0x001f82 */
+	0x001f8b, /* 0x001f83 */
+	0x001f8c, /* 0x001f84 */
+	0x001f8d, /* 0x001f85 */
+	0x001f8e, /* 0x001f86 */
+	0x001f8f, /* 0x001f87 */
+	0x001f88, /* 0x001f88 */
+	0x001f89, /* 0x001f89 */
+	0x001f8a, /* 0x001f8a */
+	0x001f8b, /* 0x001f8b */
+	0x001f8c, /* 0x001f8c */
+	0x001f8d, /* 0x001f8d */
+	0x001f8e, /* 0x001f8e */
+	0x001f8f, /* 0x001f8f */
+	0x001f98, /* 0x001f90 */
+	0x001f99, /* 0x001f91 */
+	0x001f9a, /* 0x001f92 */
+	0x001f9b, /* 0x001f93 */
+	0x001f9c, /* 0x001f94 */
+	0x001f9d, /* 0x001f95 */
+	0x001f9e, /* 0x001f96 */
+	0x001f9f, /* 0x001f97 */
+	0x001f98, /* 0x001f98 */
+	0x001f99, /* 0x001f99 */
+	0x001f9a, /* 0x001f9a */
+	0x001f9b, /* 0x001f9b */
+	0x001f9c, /* 0x001f9c */
+	0x001f9d, /* 0x001f9d */
+	0x001f9e, /* 0x001f9e */
+	0x001f9f, /* 0x001f9f */
+	0x001fa8, /* 0x001fa0 */
+	0x001fa9, /* 0x001fa1 */
+	0x001faa, /* 0x001fa2 */
+	0x001fab, /* 0x001fa3 */
+	0x001fac, /* 0x001fa4 */
+	0x001fad, /* 0x001fa5 */
+	0x001fae, /* 0x001fa6 */
+	0x001faf, /* 0x001fa7 */
+	0x001fa8, /* 0x001fa8 */
+	0x001fa9, /* 0x001fa9 */
+	0x001faa, /* 0x001faa */
+	0x001fab, /* 0x001fab */
+	0x001fac, /* 0x001fac */
+	0x001fad, /* 0x001fad */
+	0x001fae, /* 0x001fae */
+	0x001faf, /* 0x001faf */
+	0x001fb8, /* 0x001fb0 */
+	0x001fb9, /* 0x001fb1 */
+	0x001fb2, /* 0x001fb2 */
+	0x001fbc, /* 0x001fb3 */
+	0x001fb4, /* 0x001fb4 */
+	0x001fb6, /* 0x001fb6 */
+	0x001fb7, /* 0x001fb7 */
+	0x001fbc, /* 0x001fbc */
+	0x000399, /* 0x001fbe */
+	0x001fc2, /* 0x001fc2 */
+	0x001fcc, /* 0x001fc3 */
+	0x001fc4, /* 0x001fc4 */
+	0x001fc6, /* 0x001fc6 */
+	0x001fc7, /* 0x001fc7 */
+	0x001fcc, /* 0x001fcc */
+	0x001fd8, /* 0x001fd0 */
+	0x001fd9, /* 0x001fd1 */
+	0x001fd2, /* 0x001fd2 */
+	0x001fd3, /* 0x001fd3 */
+	0x001fd6, /* 0x001fd6 */
+	0x001fd7, /* 0x001fd7 */
+	0x001fe8, /* 0x001fe0 */
+	0x001fe9, /* 0x001fe1 */
+	0x001fe2, /* 0x001fe2 */
+	0x001fe3, /* 0x001fe3 */
+	0x001fe4, /* 0x001fe4 */
+	0x001fec, /* 0x001fe5 */
+	0x001fe6, /* 0x001fe6 */
+	0x001fe7, /* 0x001fe7 */
+	0x001ff2, /* 0x001ff2 */
+	0x001ffc, /* 0x001ff3 */
+	0x001ff4, /* 0x001ff4 */
+	0x001ff6, /* 0x001ff6 */
+	0x001ff7, /* 0x001ff7 */
+	0x001ffc, /* 0x001ffc */
+	0x002126, /* 0x002126 */
+	0x00212a, /* 0x00212a */
+	0x00212b, /* 0x00212b */
+	0x002132, /* 0x002132 */
+	0x002160, /* 0x002160 */
+	0x002161, /* 0x002161 */
+	0x002162, /* 0x002162 */
+	0x002163, /* 0x002163 */
+	0x002164, /* 0x002164 */
+	0x002165, /* 0x002165 */
+	0x002166, /* 0x002166 */
+	0x002167, /* 0x002167 */
+	0x002168, /* 0x002168 */
+	0x002169, /* 0x002169 */
+	0x00216a, /* 0x00216a */
+	0x00216b, /* 0x00216b */
+	0x00216c, /* 0x00216c */
+	0x00216d, /* 0x00216d */
+	0x00216e, /* 0x00216e */
+	0x00216f, /* 0x00216f */
+	0x002183, /* 0x002183 */
+	0x0024b6, /* 0x0024b6 */
+	0x0024b7, /* 0x0024b7 */
+	0x0024b8, /* 0x0024b8 */
+	0x0024b9, /* 0x0024b9 */
+	0x0024ba, /* 0x0024ba */
+	0x0024bb, /* 0x0024bb */
+	0x0024bc, /* 0x0024bc */
+	0x0024bd, /* 0x0024bd */
+	0x0024be, /* 0x0024be */
+	0x0024bf, /* 0x0024bf */
+	0x0024c0, /* 0x0024c0 */
+	0x0024c1, /* 0x0024c1 */
+	0x0024c2, /* 0x0024c2 */
+	0x0024c3, /* 0x0024c3 */
+	0x0024c4, /* 0x0024c4 */
+	0x0024c5, /* 0x0024c5 */
+	0x0024c6, /* 0x0024c6 */
+	0x0024c7, /* 0x0024c7 */
+	0x0024c8, /* 0x0024c8 */
+	0x0024c9, /* 0x0024c9 */
+	0x0024ca, /* 0x0024ca */
+	0x0024cb, /* 0x0024cb */
+	0x0024cc, /* 0x0024cc */
+	0x0024cd, /* 0x0024cd */
+	0x0024ce, /* 0x0024ce */
+	0x0024cf, /* 0x0024cf */
+	0x002c00, /* 0x002c00 */
+	0x002c01, /* 0x002c01 */
+	0x002c02, /* 0x002c02 */
+	0x002c03, /* 0x002c03 */
+	0x002c04, /* 0x002c04 */
+	0x002c05, /* 0x002c05 */
+	0x002c06, /* 0x002c06 */
+	0x002c07, /* 0x002c07 */
+	0x002c08, /* 0x002c08 */
+	0x002c09, /* 0x002c09 */
+	0x002c0a, /* 0x002c0a */
+	0x002c0b, /* 0x002c0b */
+	0x002c0c, /* 0x002c0c */
+	0x002c0d, /* 0x002c0d */
+	0x002c0e, /* 0x002c0e */
+	0x002c0f, /* 0x002c0f */
+	0x002c10, /* 0x002c10 */
+	0x002c11, /* 0x002c11 */
+	0x002c12, /* 0x002c12 */
+	0x002c13, /* 0x002c13 */
+	0x002c14, /* 0x002c14 */
+	0x002c15, /* 0x002c15 */
+	0x002c16, /* 0x002c16 */
+	0x002c17, /* 0x002c17 */
+	0x002c18, /* 0x002c18 */
+	0x002c19, /* 0x002c19 */
+	0x002c1a, /* 0x002c1a */
+	0x002c1b, /* 0x002c1b */
+	0x002c1c, /* 0x002c1c */
+	0x002c1d, /* 0x002c1d */
+	0x002c1e, /* 0x002c1e */
+	0x002c1f, /* 0x002c1f */
+	0x002c20, /* 0x002c20 */
+	0x002c21, /* 0x002c21 */
+	0x002c22, /* 0x002c22 */
+	0x002c23, /* 0x002c23 */
+	0x002c24, /* 0x002c24 */
+	0x002c25, /* 0x002c25 */
+	0x002c26, /* 0x002c26 */
+	0x002c27, /* 0x002c27 */
+	0x002c28, /* 0x002c28 */
+	0x002c29, /* 0x002c29 */
+	0x002c2a, /* 0x002c2a */
+	0x002c2b, /* 0x002c2b */
+	0x002c2c, /* 0x002c2c */
+	0x002c2d, /* 0x002c2d */
+	0x002c2e, /* 0x002c2e */
+	0x002c2f, /* 0x002c2f */
+	0x002c60, /* 0x002c60 */
+	0x002c67, /* 0x002c67 */
+	0x002c69, /* 0x002c69 */
+	0x002c6b, /* 0x002c6b */
+	0x002c72, /* 0x002c72 */
+	0x002c75, /* 0x002c75 */
+	0x002c80, /* 0x002c80 */
+	0x002c82, /* 0x002c82 */
+	0x002c84, /* 0x002c84 */
+	0x002c86, /* 0x002c86 */
+	0x002c88, /* 0x002c88 */
+	0x002c8a, /* 0x002c8a */
+	0x002c8c, /* 0x002c8c */
+	0x002c8e, /* 0x002c8e */
+	0x002c90, /* 0x002c90 */
+	0x002c92, /* 0x002c92 */
+	0x002c94, /* 0x002c94 */
+	0x002c96, /* 0x002c96 */
+	0x002c98, /* 0x002c98 */
+	0x002c9a, /* 0x002c9a */
+	0x002c9c, /* 0x002c9c */
+	0x002c9e, /* 0x002c9e */
+	0x002ca0, /* 0x002ca0 */
+	0x002ca2, /* 0x002ca2 */
+	0x002ca4, /* 0x002ca4 */
+	0x002ca6, /* 0x002ca6 */
+	0x002ca8, /* 0x002ca8 */
+	0x002caa, /* 0x002caa */
+	0x002cac, /* 0x002cac */
+	0x002cae, /* 0x002cae */
+	0x002cb0, /* 0x002cb0 */
+	0x002cb2, /* 0x002cb2 */
+	0x002cb4, /* 0x002cb4 */
+	0x002cb6, /* 0x002cb6 */
+	0x002cb8, /* 0x002cb8 */
+	0x002cba, /* 0x002cba */
+	0x002cbc, /* 0x002cbc */
+	0x002cbe, /* 0x002cbe */
+	0x002cc0, /* 0x002cc0 */
+	0x002cc2, /* 0x002cc2 */
+	0x002cc4, /* 0x002cc4 */
+	0x002cc6, /* 0x002cc6 */
+	0x002cc8, /* 0x002cc8 */
+	0x002cca, /* 0x002cca */
+	0x002ccc, /* 0x002ccc */
+	0x002cce, /* 0x002cce */
+	0x002cd0, /* 0x002cd0 */
+	0x002cd2, /* 0x002cd2 */
+	0x002cd4, /* 0x002cd4 */
+	0x002cd6, /* 0x002cd6 */
+	0x002cd8, /* 0x002cd8 */
+	0x002cda, /* 0x002cda */
+	0x002cdc, /* 0x002cdc */
+	0x002cde, /* 0x002cde */
+	0x002ce0, /* 0x002ce0 */
+	0x002ce2, /* 0x002ce2 */
+	0x002ceb, /* 0x002ceb */
+	0x002ced, /* 0x002ced */
+	0x002cf2, /* 0x002cf2 */
+	0x00a640, /* 0x00a640 */
+	0x00a642, /* 0x00a642 */
+	0x00a644, /* 0x00a644 */
+	0x00a646, /* 0x00a646 */
+	0x00a648, /* 0x00a648 */
+	0x00a64a, /* 0x00a64a */
+	0x00a64c, /* 0x00a64c */
+	0x00a64e, /* 0x00a64e */
+	0x00a650, /* 0x00a650 */
+	0x00a652, /* 0x00a652 */
+	0x00a654, /* 0x00a654 */
+	0x00a656, /* 0x00a656 */
+	0x00a658, /* 0x00a658 */
+	0x00a65a, /* 0x00a65a */
+	0x00a65c, /* 0x00a65c */
+	0x00a65e, /* 0x00a65e */
+	0x00a660, /* 0x00a660 */
+	0x00a662, /* 0x00a662 */
+	0x00a664, /* 0x00a664 */
+	0x00a666, /* 0x00a666 */
+	0x00a668, /* 0x00a668 */
+	0x00a66a, /* 0x00a66a */
+	0x00a66c, /* 0x00a66c */
+	0x00a680, /* 0x00a680 */
+	0x00a682, /* 0x00a682 */
+	0x00a684, /* 0x00a684 */
+	0x00a686, /* 0x00a686 */
+	0x00a688, /* 0x00a688 */
+	0x00a68a, /* 0x00a68a */
+	0x00a68c, /* 0x00a68c */
+	0x00a68e, /* 0x00a68e */
+	0x00a690, /* 0x00a690 */
+	0x00a692, /* 0x00a692 */
+	0x00a694, /* 0x00a694 */
+	0x00a696, /* 0x00a696 */
+	0x00a698, /* 0x00a698 */
+	0x00a69a, /* 0x00a69a */
+	0x00a722, /* 0x00a722 */
+	0x00a724, /* 0x00a724 */
+	0x00a726, /* 0x00a726 */
+	0x00a728, /* 0x00a728 */
+	0x00a72a, /* 0x00a72a */
+	0x00a72c, /* 0x00a72c */
+	0x00a72e, /* 0x00a72e */
+	0x00a732, /* 0x00a732 */
+	0x00a734, /* 0x00a734 */
+	0x00a736, /* 0x00a736 */
+	0x00a738, /* 0x00a738 */
+	0x00a73a, /* 0x00a73a */
+	0x00a73c, /* 0x00a73c */
+	0x00a73e, /* 0x00a73e */
+	0x00a740, /* 0x00a740 */
+	0x00a742, /* 0x00a742 */
+	0x00a744, /* 0x00a744 */
+	0x00a746, /* 0x00a746 */
+	0x00a748, /* 0x00a748 */
+	0x00a74a, /* 0x00a74a */
+	0x00a74c, /* 0x00a74c */
+	0x00a74e, /* 0x00a74e */
+	0x00a750, /* 0x00a750 */
+	0x00a752, /* 0x00a752 */
+	0x00a754, /* 0x00a754 */
+	0x00a756, /* 0x00a756 */
+	0x00a758, /* 0x00a758 */
+	0x00a75a, /* 0x00a75a */
+	0x00a75c, /* 0x00a75c */
+	0x00a75e, /* 0x00a75e */
+	0x00a760, /* 0x00a760 */
+	0x00a762, /* 0x00a762 */
+	0x00a764, /* 0x00a764 */
+	0x00a766, /* 0x00a766 */
+	0x00a768, /* 0x00a768 */
+	0x00a76a, /* 0x00a76a */
+	0x00a76c, /* 0x00a76c */
+	0x00a76e, /* 0x00a76e */
+	0x00a779, /* 0x00a779 */
+	0x00a77b, /* 0x00a77b */
+	0x00a77e, /* 0x00a77e */
+	0x00a780, /* 0x00a780 */
+	0x00a782, /* 0x00a782 */
+	0x00a784, /* 0x00a784 */
+	0x00a786, /* 0x00a786 */
+	0x00a78b, /* 0x00a78b */
+	0x00a790, /* 0x00a790 */
+	0x00a792, /* 0x00a792 */
+	0x00a7c4, /* 0x00a794 */
+	0x00a796, /* 0x00a796 */
+	0x00a798, /* 0x00a798 */
+	0x00a79a, /* 0x00a79a */
+	0x00a79c, /* 0x00a79c */
+	0x00a79e, /* 0x00a79e */
+	0x00a7a0, /* 0x00a7a0 */
+	0x00a7a2, /* 0x00a7a2 */
+	0x00a7a4, /* 0x00a7a4 */
+	0x00a7a6, /* 0x00a7a6 */
+	0x00a7a8, /* 0x00a7a8 */
+	0x00a7b3, /* 0x00a7b3 */
+	0x00a7b4, /* 0x00a7b4 */
+	0x00a7b6, /* 0x00a7b6 */
+	0x00a7b8, /* 0x00a7b8 */
+	0x00a7ba, /* 0x00a7ba */
+	0x00a7bc, /* 0x00a7bc */
+	0x00a7be, /* 0x00a7be */
+	0x00a7c0, /* 0x00a7c0 */
+	0x00a7c2, /* 0x00a7c2 */
+	0x00a7c7, /* 0x00a7c7 */
+	0x00a7c9, /* 0x00a7c9 */
+	0x00a7d0, /* 0x00a7d0 */
+	0x00a7d6, /* 0x00a7d6 */
+	0x00a7d8, /* 0x00a7d8 */
+	0x00a7f5, /* 0x00a7f5 */
+	0x00fb00, /* 0x00fb00 */
+	0x00fb01, /* 0x00fb01 */
+	0x00fb02, /* 0x00fb02 */
+	0x00fb03, /* 0x00fb03 */
+	0x00fb04, /* 0x00fb04 */
+	0x00fb05, /* 0x00fb05 */
+	0x00fb06, /* 0x00fb06 */
+	0x00fb13, /* 0x00fb13 */
+	0x00fb14, /* 0x00fb14 */
+	0x00fb15, /* 0x00fb15 */
+	0x00fb16, /* 0x00fb16 */
+	0x00fb17, /* 0x00fb17 */
+	0x00ff21, /* 0x00ff21 */
+	0x00ff22, /* 0x00ff22 */
+	0x00ff23, /* 0x00ff23 */
+	0x00ff24, /* 0x00ff24 */
+	0x00ff25, /* 0x00ff25 */
+	0x00ff26, /* 0x00ff26 */
+	0x00ff27, /* 0x00ff27 */
+	0x00ff28, /* 0x00ff28 */
+	0x00ff29, /* 0x00ff29 */
+	0x00ff2a, /* 0x00ff2a */
+	0x00ff2b, /* 0x00ff2b */
+	0x00ff2c, /* 0x00ff2c */
+	0x00ff2d, /* 0x00ff2d */
+	0x00ff2e, /* 0x00ff2e */
+	0x00ff2f, /* 0x00ff2f */
+	0x00ff30, /* 0x00ff30 */
+	0x00ff31, /* 0x00ff31 */
+	0x00ff32, /* 0x00ff32 */
+	0x00ff33, /* 0x00ff33 */
+	0x00ff34, /* 0x00ff34 */
+	0x00ff35, /* 0x00ff35 */
+	0x00ff36, /* 0x00ff36 */
+	0x00ff37, /* 0x00ff37 */
+	0x00ff38, /* 0x00ff38 */
+	0x00ff39, /* 0x00ff39 */
+	0x00ff3a, /* 0x00ff3a */
+	0x010400, /* 0x010400 */
+	0x010401, /* 0x010401 */
+	0x010402, /* 0x010402 */
+	0x010403, /* 0x010403 */
+	0x010404, /* 0x010404 */
+	0x010405, /* 0x010405 */
+	0x010406, /* 0x010406 */
+	0x010407, /* 0x010407 */
+	0x010408, /* 0x010408 */
+	0x010409, /* 0x010409 */
+	0x01040a, /* 0x01040a */
+	0x01040b, /* 0x01040b */
+	0x01040c, /* 0x01040c */
+	0x01040d, /* 0x01040d */
+	0x01040e, /* 0x01040e */
+	0x01040f, /* 0x01040f */
+	0x010410, /* 0x010410 */
+	0x010411, /* 0x010411 */
+	0x010412, /* 0x010412 */
+	0x010413, /* 0x010413 */
+	0x010414, /* 0x010414 */
+	0x010415, /* 0x010415 */
+	0x010416, /* 0x010416 */
+	0x010417, /* 0x010417 */
+	0x010418, /* 0x010418 */
+	0x010419, /* 0x010419 */
+	0x01041a, /* 0x01041a */
+	0x01041b, /* 0x01041b */
+	0x01041c, /* 0x01041c */
+	0x01041d, /* 0x01041d */
+	0x01041e, /* 0x01041e */
+	0x01041f, /* 0x01041f */
+	0x010420, /* 0x010420 */
+	0x010421, /* 0x010421 */
+	0x010422, /* 0x010422 */
+	0x010423, /* 0x010423 */
+	0x010424, /* 0x010424 */
+	0x010425, /* 0x010425 */
+	0x010426, /* 0x010426 */
+	0x010427, /* 0x010427 */
+	0x0104b0, /* 0x0104b0 */
+	0x0104b1, /* 0x0104b1 */
+	0x0104b2, /* 0x0104b2 */
+	0x0104b3, /* 0x0104b3 */
+	0x0104b4, /* 0x0104b4 */
+	0x0104b5, /* 0x0104b5 */
+	0x0104b6, /* 0x0104b6 */
+	0x0104b7, /* 0x0104b7 */
+	0x0104b8, /* 0x0104b8 */
+	0x0104b9, /* 0x0104b9 */
+	0x0104ba, /* 0x0104ba */
+	0x0104bb, /* 0x0104bb */
+	0x0104bc, /* 0x0104bc */
+	0x0104bd, /* 0x0104bd */
+	0x0104be, /* 0x0104be */
+	0x0104bf, /* 0x0104bf */
+	0x0104c0, /* 0x0104c0 */
+	0x0104c1, /* 0x0104c1 */
+	0x0104c2, /* 0x0104c2 */
+	0x0104c3, /* 0x0104c3 */
+	0x0104c4, /* 0x0104c4 */
+	0x0104c5, /* 0x0104c5 */
+	0x0104c6, /* 0x0104c6 */
+	0x0104c7, /* 0x0104c7 */
+	0x0104c8, /* 0x0104c8 */
+	0x0104c9, /* 0x0104c9 */
+	0x0104ca, /* 0x0104ca */
+	0x0104cb, /* 0x0104cb */
+	0x0104cc, /* 0x0104cc */
+	0x0104cd, /* 0x0104cd */
+	0x0104ce, /* 0x0104ce */
+	0x0104cf, /* 0x0104cf */
+	0x0104d0, /* 0x0104d0 */
+	0x0104d1, /* 0x0104d1 */
+	0x0104d2, /* 0x0104d2 */
+	0x0104d3, /* 0x0104d3 */
+	0x010570, /* 0x010570 */
+	0x010571, /* 0x010571 */
+	0x010572, /* 0x010572 */
+	0x010573, /* 0x010573 */
+	0x010574, /* 0x010574 */
+	0x010575, /* 0x010575 */
+	0x010576, /* 0x010576 */
+	0x010577, /* 0x010577 */
+	0x010578, /* 0x010578 */
+	0x010579, /* 0x010579 */
+	0x01057a, /* 0x01057a */
+	0x01057c, /* 0x01057c */
+	0x01057d, /* 0x01057d */
+	0x01057e, /* 0x01057e */
+	0x01057f, /* 0x01057f */
+	0x010580, /* 0x010580 */
+	0x010581, /* 0x010581 */
+	0x010582, /* 0x010582 */
+	0x010583, /* 0x010583 */
+	0x010584, /* 0x010584 */
+	0x010585, /* 0x010585 */
+	0x010586, /* 0x010586 */
+	0x010587, /* 0x010587 */
+	0x010588, /* 0x010588 */
+	0x010589, /* 0x010589 */
+	0x01058a, /* 0x01058a */
+	0x01058c, /* 0x01058c */
+	0x01058d, /* 0x01058d */
+	0x01058e, /* 0x01058e */
+	0x01058f, /* 0x01058f */
+	0x010590, /* 0x010590 */
+	0x010591, /* 0x010591 */
+	0x010592, /* 0x010592 */
+	0x010594, /* 0x010594 */
+	0x010595, /* 0x010595 */
+	0x010c80, /* 0x010c80 */
+	0x010c81, /* 0x010c81 */
+	0x010c82, /* 0x010c82 */
+	0x010c83, /* 0x010c83 */
+	0x010c84, /* 0x010c84 */
+	0x010c85, /* 0x010c85 */
+	0x010c86, /* 0x010c86 */
+	0x010c87, /* 0x010c87 */
+	0x010c88, /* 0x010c88 */
+	0x010c89, /* 0x010c89 */
+	0x010c8a, /* 0x010c8a */
+	0x010c8b, /* 0x010c8b */
+	0x010c8c, /* 0x010c8c */
+	0x010c8d, /* 0x010c8d */
+	0x010c8e, /* 0x010c8e */
+	0x010c8f, /* 0x010c8f */
+	0x010c90, /* 0x010c90 */
+	0x010c91, /* 0x010c91 */
+	0x010c92, /* 0x010c92 */
+	0x010c93, /* 0x010c93 */
+	0x010c94, /* 0x010c94 */
+	0x010c95, /* 0x010c95 */
+	0x010c96, /* 0x010c96 */
+	0x010c97, /* 0x010c97 */
+	0x010c98, /* 0x010c98 */
+	0x010c99, /* 0x010c99 */
+	0x010c9a, /* 0x010c9a */
+	0x010c9b, /* 0x010c9b */
+	0x010c9c, /* 0x010c9c */
+	0x010c9d, /* 0x010c9d */
+	0x010c9e, /* 0x010c9e */
+	0x010c9f, /* 0x010c9f */
+	0x010ca0, /* 0x010ca0 */
+	0x010ca1, /* 0x010ca1 */
+	0x010ca2, /* 0x010ca2 */
+	0x010ca3, /* 0x010ca3 */
+	0x010ca4, /* 0x010ca4 */
+	0x010ca5, /* 0x010ca5 */
+	0x010ca6, /* 0x010ca6 */
+	0x010ca7, /* 0x010ca7 */
+	0x010ca8, /* 0x010ca8 */
+	0x010ca9, /* 0x010ca9 */
+	0x010caa, /* 0x010caa */
+	0x010cab, /* 0x010cab */
+	0x010cac, /* 0x010cac */
+	0x010cad, /* 0x010cad */
+	0x010cae, /* 0x010cae */
+	0x010caf, /* 0x010caf */
+	0x010cb0, /* 0x010cb0 */
+	0x010cb1, /* 0x010cb1 */
+	0x010cb2, /* 0x010cb2 */
+	0x0118a0, /* 0x0118a0 */
+	0x0118a1, /* 0x0118a1 */
+	0x0118a2, /* 0x0118a2 */
+	0x0118a3, /* 0x0118a3 */
+	0x0118a4, /* 0x0118a4 */
+	0x0118a5, /* 0x0118a5 */
+	0x0118a6, /* 0x0118a6 */
+	0x0118a7, /* 0x0118a7 */
+	0x0118a8, /* 0x0118a8 */
+	0x0118a9, /* 0x0118a9 */
+	0x0118aa, /* 0x0118aa */
+	0x0118ab, /* 0x0118ab */
+	0x0118ac, /* 0x0118ac */
+	0x0118ad, /* 0x0118ad */
+	0x0118ae, /* 0x0118ae */
+	0x0118af, /* 0x0118af */
+	0x0118b0, /* 0x0118b0 */
+	0x0118b1, /* 0x0118b1 */
+	0x0118b2, /* 0x0118b2 */
+	0x0118b3, /* 0x0118b3 */
+	0x0118b4, /* 0x0118b4 */
+	0x0118b5, /* 0x0118b5 */
+	0x0118b6, /* 0x0118b6 */
+	0x0118b7, /* 0x0118b7 */
+	0x0118b8, /* 0x0118b8 */
+	0x0118b9, /* 0x0118b9 */
+	0x0118ba, /* 0x0118ba */
+	0x0118bb, /* 0x0118bb */
+	0x0118bc, /* 0x0118bc */
+	0x0118bd, /* 0x0118bd */
+	0x0118be, /* 0x0118be */
+	0x0118bf, /* 0x0118bf */
+	0x016e40, /* 0x016e40 */
+	0x016e41, /* 0x016e41 */
+	0x016e42, /* 0x016e42 */
+	0x016e43, /* 0x016e43 */
+	0x016e44, /* 0x016e44 */
+	0x016e45, /* 0x016e45 */
+	0x016e46, /* 0x016e46 */
+	0x016e47, /* 0x016e47 */
+	0x016e48, /* 0x016e48 */
+	0x016e49, /* 0x016e49 */
+	0x016e4a, /* 0x016e4a */
+	0x016e4b, /* 0x016e4b */
+	0x016e4c, /* 0x016e4c */
+	0x016e4d, /* 0x016e4d */
+	0x016e4e, /* 0x016e4e */
+	0x016e4f, /* 0x016e4f */
+	0x016e50, /* 0x016e50 */
+	0x016e51, /* 0x016e51 */
+	0x016e52, /* 0x016e52 */
+	0x016e53, /* 0x016e53 */
+	0x016e54, /* 0x016e54 */
+	0x016e55, /* 0x016e55 */
+	0x016e56, /* 0x016e56 */
+	0x016e57, /* 0x016e57 */
+	0x016e58, /* 0x016e58 */
+	0x016e59, /* 0x016e59 */
+	0x016e5a, /* 0x016e5a */
+	0x016e5b, /* 0x016e5b */
+	0x016e5c, /* 0x016e5c */
+	0x016e5d, /* 0x016e5d */
+	0x016e5e, /* 0x016e5e */
+	0x016e5f, /* 0x016e5f */
+	0x01e900, /* 0x01e900 */
+	0x01e901, /* 0x01e901 */
+	0x01e902, /* 0x01e902 */
+	0x01e903, /* 0x01e903 */
+	0x01e904, /* 0x01e904 */
+	0x01e905, /* 0x01e905 */
+	0x01e906, /* 0x01e906 */
+	0x01e907, /* 0x01e907 */
+	0x01e908, /* 0x01e908 */
+	0x01e909, /* 0x01e909 */
+	0x01e90a, /* 0x01e90a */
+	0x01e90b, /* 0x01e90b */
+	0x01e90c, /* 0x01e90c */
+	0x01e90d, /* 0x01e90d */
+	0x01e90e, /* 0x01e90e */
+	0x01e90f, /* 0x01e90f */
+	0x01e910, /* 0x01e910 */
+	0x01e911, /* 0x01e911 */
+	0x01e912, /* 0x01e912 */
+	0x01e913, /* 0x01e913 */
+	0x01e914, /* 0x01e914 */
+	0x01e915, /* 0x01e915 */
+	0x01e916, /* 0x01e916 */
+	0x01e917, /* 0x01e917 */
+	0x01e918, /* 0x01e918 */
+	0x01e919, /* 0x01e919 */
+	0x01e91a, /* 0x01e91a */
+	0x01e91b, /* 0x01e91b */
+	0x01e91c, /* 0x01e91c */
+	0x01e91d, /* 0x01e91d */
+	0x01e91e, /* 0x01e91e */
+	0x01e91f, /* 0x01e91f */
+	0x01e920, /* 0x01e920 */
+	0x01e921, /* 0x01e921 */
+};
+
+/*
+ * Case mapping table for upper.
+ */
+static uint32 case_map_upper[1677] =
+{
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000000 */
+	0x000001, /* 0x000001 */
+	0x000002, /* 0x000002 */
+	0x000003, /* 0x000003 */
+	0x000004, /* 0x000004 */
+	0x000005, /* 0x000005 */
+	0x000006, /* 0x000006 */
+	0x000007, /* 0x000007 */
+	0x000008, /* 0x000008 */
+	0x000009, /* 0x000009 */
+	0x00000a, /* 0x00000a */
+	0x00000b, /* 0x00000b */
+	0x00000c, /* 0x00000c */
+	0x00000d, /* 0x00000d */
+	0x00000e, /* 0x00000e */
+	0x00000f, /* 0x00000f */
+	0x000010, /* 0x000010 */
+	0x000011, /* 0x000011 */
+	0x000012, /* 0x000012 */
+	0x000013, /* 0x000013 */
+	0x000014, /* 0x000014 */
+	0x000015, /* 0x000015 */
+	0x000016, /* 0x000016 */
+	0x000017, /* 0x000017 */
+	0x000018, /* 0x000018 */
+	0x000019, /* 0x000019 */
+	0x00001a, /* 0x00001a */
+	0x00001b, /* 0x00001b */
+	0x00001c, /* 0x00001c */
+	0x00001d, /* 0x00001d */
+	0x00001e, /* 0x00001e */
+	0x00001f, /* 0x00001f */
+	0x000020, /* 0x000020 */
+	0x000021, /* 0x000021 */
+	0x000022, /* 0x000022 */
+	0x000023, /* 0x000023 */
+	0x000024, /* 0x000024 */
+	0x000025, /* 0x000025 */
+	0x000026, /* 0x000026 */
+	0x000027, /* 0x000027 */
+	0x000028, /* 0x000028 */
+	0x000029, /* 0x000029 */
+	0x00002a, /* 0x00002a */
+	0x00002b, /* 0x00002b */
+	0x00002c, /* 0x00002c */
+	0x00002d, /* 0x00002d */
+	0x00002e, /* 0x00002e */
+	0x00002f, /* 0x00002f */
+	0x000030, /* 0x000030 */
+	0x000031, /* 0x000031 */
+	0x000032, /* 0x000032 */
+	0x000033, /* 0x000033 */
+	0x000034, /* 0x000034 */
+	0x000035, /* 0x000035 */
+	0x000036, /* 0x000036 */
+	0x000037, /* 0x000037 */
+	0x000038, /* 0x000038 */
+	0x000039, /* 0x000039 */
+	0x00003a, /* 0x00003a */
+	0x00003b, /* 0x00003b */
+	0x00003c, /* 0x00003c */
+	0x00003d, /* 0x00003d */
+	0x00003e, /* 0x00003e */
+	0x00003f, /* 0x00003f */
+	0x000040, /* 0x000040 */
+	0x000041, /* 0x000041 */
+	0x000042, /* 0x000042 */
+	0x000043, /* 0x000043 */
+	0x000044, /* 0x000044 */
+	0x000045, /* 0x000045 */
+	0x000046, /* 0x000046 */
+	0x000047, /* 0x000047 */
+	0x000048, /* 0x000048 */
+	0x000049, /* 0x000049 */
+	0x00004a, /* 0x00004a */
+	0x00004b, /* 0x00004b */
+	0x00004c, /* 0x00004c */
+	0x00004d, /* 0x00004d */
+	0x00004e, /* 0x00004e */
+	0x00004f, /* 0x00004f */
+	0x000050, /* 0x000050 */
+	0x000051, /* 0x000051 */
+	0x000052, /* 0x000052 */
+	0x000053, /* 0x000053 */
+	0x000054, /* 0x000054 */
+	0x000055, /* 0x000055 */
+	0x000056, /* 0x000056 */
+	0x000057, /* 0x000057 */
+	0x000058, /* 0x000058 */
+	0x000059, /* 0x000059 */
+	0x00005a, /* 0x00005a */
+	0x00005b, /* 0x00005b */
+	0x00005c, /* 0x00005c */
+	0x00005d, /* 0x00005d */
+	0x00005e, /* 0x00005e */
+	0x00005f, /* 0x00005f */
+	0x000060, /* 0x000060 */
+	0x000041, /* 0x000061 */
+	0x000042, /* 0x000062 */
+	0x000043, /* 0x000063 */
+	0x000044, /* 0x000064 */
+	0x000045, /* 0x000065 */
+	0x000046, /* 0x000066 */
+	0x000047, /* 0x000067 */
+	0x000048, /* 0x000068 */
+	0x000049, /* 0x000069 */
+	0x00004a, /* 0x00006a */
+	0x00004b, /* 0x00006b */
+	0x00004c, /* 0x00006c */
+	0x00004d, /* 0x00006d */
+	0x00004e, /* 0x00006e */
+	0x00004f, /* 0x00006f */
+	0x000050, /* 0x000070 */
+	0x000051, /* 0x000071 */
+	0x000052, /* 0x000072 */
+	0x000053, /* 0x000073 */
+	0x000054, /* 0x000074 */
+	0x000055, /* 0x000075 */
+	0x000056, /* 0x000076 */
+	0x000057, /* 0x000077 */
+	0x000058, /* 0x000078 */
+	0x000059, /* 0x000079 */
+	0x00005a, /* 0x00007a */
+	0x00007b, /* 0x00007b */
+	0x00007c, /* 0x00007c */
+	0x00007d, /* 0x00007d */
+	0x00007e, /* 0x00007e */
+	0x00007f, /* 0x00007f */
+	0x00039c, /* 0x0000b5 */
+	0x0000c0, /* 0x0000c0 */
+	0x0000c1, /* 0x0000c1 */
+	0x0000c2, /* 0x0000c2 */
+	0x0000c3, /* 0x0000c3 */
+	0x0000c4, /* 0x0000c4 */
+	0x0000c5, /* 0x0000c5 */
+	0x0000c6, /* 0x0000c6 */
+	0x0000c7, /* 0x0000c7 */
+	0x0000c8, /* 0x0000c8 */
+	0x0000c9, /* 0x0000c9 */
+	0x0000ca, /* 0x0000ca */
+	0x0000cb, /* 0x0000cb */
+	0x0000cc, /* 0x0000cc */
+	0x0000cd, /* 0x0000cd */
+	0x0000ce, /* 0x0000ce */
+	0x0000cf, /* 0x0000cf */
+	0x0000d0, /* 0x0000d0 */
+	0x0000d1, /* 0x0000d1 */
+	0x0000d2, /* 0x0000d2 */
+	0x0000d3, /* 0x0000d3 */
+	0x0000d4, /* 0x0000d4 */
+	0x0000d5, /* 0x0000d5 */
+	0x0000d6, /* 0x0000d6 */
+	0x0000d8, /* 0x0000d8 */
+	0x0000d9, /* 0x0000d9 */
+	0x0000da, /* 0x0000da */
+	0x0000db, /* 0x0000db */
+	0x0000dc, /* 0x0000dc */
+	0x0000dd, /* 0x0000dd */
+	0x0000de, /* 0x0000de */
+	0x0000df, /* 0x0000df */
+	0x000178, /* 0x0000ff */
+	0x000100, /* 0x000100 */
+	0x000102, /* 0x000102 */
+	0x000104, /* 0x000104 */
+	0x000106, /* 0x000106 */
+	0x000108, /* 0x000108 */
+	0x00010a, /* 0x00010a */
+	0x00010c, /* 0x00010c */
+	0x00010e, /* 0x00010e */
+	0x000110, /* 0x000110 */
+	0x000112, /* 0x000112 */
+	0x000114, /* 0x000114 */
+	0x000116, /* 0x000116 */
+	0x000118, /* 0x000118 */
+	0x00011a, /* 0x00011a */
+	0x00011c, /* 0x00011c */
+	0x00011e, /* 0x00011e */
+	0x000120, /* 0x000120 */
+	0x000122, /* 0x000122 */
+	0x000124, /* 0x000124 */
+	0x000126, /* 0x000126 */
+	0x000128, /* 0x000128 */
+	0x00012a, /* 0x00012a */
+	0x00012c, /* 0x00012c */
+	0x00012e, /* 0x00012e */
+	0x000130, /* 0x000130 */
+	0x000049, /* 0x000131 */
+	0x000132, /* 0x000132 */
+	0x000134, /* 0x000134 */
+	0x000136, /* 0x000136 */
+	0x000139, /* 0x000139 */
+	0x00013b, /* 0x00013b */
+	0x00013d, /* 0x00013d */
+	0x00013f, /* 0x00013f */
+	0x000141, /* 0x000141 */
+	0x000143, /* 0x000143 */
+	0x000145, /* 0x000145 */
+	0x000147, /* 0x000147 */
+	0x000149, /* 0x000149 */
+	0x00014a, /* 0x00014a */
+	0x00014c, /* 0x00014c */
+	0x00014e, /* 0x00014e */
+	0x000150, /* 0x000150 */
+	0x000152, /* 0x000152 */
+	0x000154, /* 0x000154 */
+	0x000156, /* 0x000156 */
+	0x000158, /* 0x000158 */
+	0x00015a, /* 0x00015a */
+	0x00015c, /* 0x00015c */
+	0x00015e, /* 0x00015e */
+	0x000160, /* 0x000160 */
+	0x000162, /* 0x000162 */
+	0x000164, /* 0x000164 */
+	0x000166, /* 0x000166 */
+	0x000168, /* 0x000168 */
+	0x00016a, /* 0x00016a */
+	0x00016c, /* 0x00016c */
+	0x00016e, /* 0x00016e */
+	0x000170, /* 0x000170 */
+	0x000172, /* 0x000172 */
+	0x000174, /* 0x000174 */
+	0x000176, /* 0x000176 */
+	0x000179, /* 0x000179 */
+	0x00017b, /* 0x00017b */
+	0x00017d, /* 0x00017d */
+	0x000053, /* 0x00017f */
+	0x000243, /* 0x000180 */
+	0x000181, /* 0x000181 */
+	0x000182, /* 0x000182 */
+	0x000184, /* 0x000184 */
+	0x000186, /* 0x000186 */
+	0x000187, /* 0x000187 */
+	0x000189, /* 0x000189 */
+	0x00018a, /* 0x00018a */
+	0x00018b, /* 0x00018b */
+	0x00018e, /* 0x00018e */
+	0x00018f, /* 0x00018f */
+	0x000190, /* 0x000190 */
+	0x000191, /* 0x000191 */
+	0x000193, /* 0x000193 */
+	0x000194, /* 0x000194 */
+	0x0001f6, /* 0x000195 */
+	0x000196, /* 0x000196 */
+	0x000197, /* 0x000197 */
+	0x000198, /* 0x000198 */
+	0x00023d, /* 0x00019a */
+	0x00019c, /* 0x00019c */
+	0x00019d, /* 0x00019d */
+	0x000220, /* 0x00019e */
+	0x00019f, /* 0x00019f */
+	0x0001a0, /* 0x0001a0 */
+	0x0001a2, /* 0x0001a2 */
+	0x0001a4, /* 0x0001a4 */
+	0x0001a6, /* 0x0001a6 */
+	0x0001a7, /* 0x0001a7 */
+	0x0001a9, /* 0x0001a9 */
+	0x0001ac, /* 0x0001ac */
+	0x0001ae, /* 0x0001ae */
+	0x0001af, /* 0x0001af */
+	0x0001b1, /* 0x0001b1 */
+	0x0001b2, /* 0x0001b2 */
+	0x0001b3, /* 0x0001b3 */
+	0x0001b5, /* 0x0001b5 */
+	0x0001b7, /* 0x0001b7 */
+	0x0001b8, /* 0x0001b8 */
+	0x0001bc, /* 0x0001bc */
+	0x0001f7, /* 0x0001bf */
+	0x0001c4, /* 0x0001c4 */
+	0x0001c7, /* 0x0001c7 */
+	0x0001ca, /* 0x0001ca */
+	0x0001cd, /* 0x0001cd */
+	0x0001cf, /* 0x0001cf */
+	0x0001d1, /* 0x0001d1 */
+	0x0001d3, /* 0x0001d3 */
+	0x0001d5, /* 0x0001d5 */
+	0x0001d7, /* 0x0001d7 */
+	0x0001d9, /* 0x0001d9 */
+	0x0001db, /* 0x0001db */
+	0x0001de, /* 0x0001de */
+	0x0001e0, /* 0x0001e0 */
+	0x0001e2, /* 0x0001e2 */
+	0x0001e4, /* 0x0001e4 */
+	0x0001e6, /* 0x0001e6 */
+	0x0001e8, /* 0x0001e8 */
+	0x0001ea, /* 0x0001ea */
+	0x0001ec, /* 0x0001ec */
+	0x0001ee, /* 0x0001ee */
+	0x0001f0, /* 0x0001f0 */
+	0x0001f1, /* 0x0001f1 */
+	0x0001f4, /* 0x0001f4 */
+	0x0001f8, /* 0x0001f8 */
+	0x0001fa, /* 0x0001fa */
+	0x0001fc, /* 0x0001fc */
+	0x0001fe, /* 0x0001fe */
+	0x000200, /* 0x000200 */
+	0x000202, /* 0x000202 */
+	0x000204, /* 0x000204 */
+	0x000206, /* 0x000206 */
+	0x000208, /* 0x000208 */
+	0x00020a, /* 0x00020a */
+	0x00020c, /* 0x00020c */
+	0x00020e, /* 0x00020e */
+	0x000210, /* 0x000210 */
+	0x000212, /* 0x000212 */
+	0x000214, /* 0x000214 */
+	0x000216, /* 0x000216 */
+	0x000218, /* 0x000218 */
+	0x00021a, /* 0x00021a */
+	0x00021c, /* 0x00021c */
+	0x00021e, /* 0x00021e */
+	0x000222, /* 0x000222 */
+	0x000224, /* 0x000224 */
+	0x000226, /* 0x000226 */
+	0x000228, /* 0x000228 */
+	0x00022a, /* 0x00022a */
+	0x00022c, /* 0x00022c */
+	0x00022e, /* 0x00022e */
+	0x000230, /* 0x000230 */
+	0x000232, /* 0x000232 */
+	0x00023a, /* 0x00023a */
+	0x00023b, /* 0x00023b */
+	0x00023e, /* 0x00023e */
+	0x002c7e, /* 0x00023f */
+	0x002c7f, /* 0x000240 */
+	0x000241, /* 0x000241 */
+	0x000244, /* 0x000244 */
+	0x000245, /* 0x000245 */
+	0x000246, /* 0x000246 */
+	0x000248, /* 0x000248 */
+	0x00024a, /* 0x00024a */
+	0x00024c, /* 0x00024c */
+	0x00024e, /* 0x00024e */
+	0x002c6f, /* 0x000250 */
+	0x002c6d, /* 0x000251 */
+	0x002c70, /* 0x000252 */
+	0x00a7ab, /* 0x00025c */
+	0x00a7ac, /* 0x000261 */
+	0x00a78d, /* 0x000265 */
+	0x00a7aa, /* 0x000266 */
+	0x00a7ae, /* 0x00026a */
+	0x002c62, /* 0x00026b */
+	0x00a7ad, /* 0x00026c */
+	0x002c6e, /* 0x000271 */
+	0x002c64, /* 0x00027d */
+	0x00a7c5, /* 0x000282 */
+	0x00a7b1, /* 0x000287 */
+	0x00a7b2, /* 0x00029d */
+	0x00a7b0, /* 0x00029e */
+	0x000399, /* 0x000345 */
+	0x000370, /* 0x000370 */
+	0x000372, /* 0x000372 */
+	0x000376, /* 0x000376 */
+	0x0003fd, /* 0x00037b */
+	0x0003fe, /* 0x00037c */
+	0x0003ff, /* 0x00037d */
+	0x00037f, /* 0x00037f */
+	0x000386, /* 0x000386 */
+	0x000388, /* 0x000388 */
+	0x000389, /* 0x000389 */
+	0x00038a, /* 0x00038a */
+	0x00038c, /* 0x00038c */
+	0x00038e, /* 0x00038e */
+	0x00038f, /* 0x00038f */
+	0x000390, /* 0x000390 */
+	0x000391, /* 0x000391 */
+	0x000392, /* 0x000392 */
+	0x000393, /* 0x000393 */
+	0x000394, /* 0x000394 */
+	0x000395, /* 0x000395 */
+	0x000396, /* 0x000396 */
+	0x000397, /* 0x000397 */
+	0x000398, /* 0x000398 */
+	0x000399, /* 0x000399 */
+	0x00039a, /* 0x00039a */
+	0x00039b, /* 0x00039b */
+	0x00039c, /* 0x00039c */
+	0x00039d, /* 0x00039d */
+	0x00039e, /* 0x00039e */
+	0x00039f, /* 0x00039f */
+	0x0003a0, /* 0x0003a0 */
+	0x0003a1, /* 0x0003a1 */
+	0x0003a3, /* 0x0003a3 */
+	0x0003a4, /* 0x0003a4 */
+	0x0003a5, /* 0x0003a5 */
+	0x0003a6, /* 0x0003a6 */
+	0x0003a7, /* 0x0003a7 */
+	0x0003a8, /* 0x0003a8 */
+	0x0003a9, /* 0x0003a9 */
+	0x0003aa, /* 0x0003aa */
+	0x0003ab, /* 0x0003ab */
+	0x0003b0, /* 0x0003b0 */
+	0x0003a3, /* 0x0003c2 */
+	0x0003a3, /* 0x0003c3 */
+	0x0003cf, /* 0x0003cf */
+	0x000392, /* 0x0003d0 */
+	0x000398, /* 0x0003d1 */
+	0x0003a6, /* 0x0003d5 */
+	0x0003a0, /* 0x0003d6 */
+	0x0003d8, /* 0x0003d8 */
+	0x0003da, /* 0x0003da */
+	0x0003dc, /* 0x0003dc */
+	0x0003de, /* 0x0003de */
+	0x0003e0, /* 0x0003e0 */
+	0x0003e2, /* 0x0003e2 */
+	0x0003e4, /* 0x0003e4 */
+	0x0003e6, /* 0x0003e6 */
+	0x0003e8, /* 0x0003e8 */
+	0x0003ea, /* 0x0003ea */
+	0x0003ec, /* 0x0003ec */
+	0x0003ee, /* 0x0003ee */
+	0x00039a, /* 0x0003f0 */
+	0x0003a1, /* 0x0003f1 */
+	0x0003f9, /* 0x0003f2 */
+	0x0003f4, /* 0x0003f4 */
+	0x000395, /* 0x0003f5 */
+	0x0003f7, /* 0x0003f7 */
+	0x0003fa, /* 0x0003fa */
+	0x000400, /* 0x000400 */
+	0x000401, /* 0x000401 */
+	0x000402, /* 0x000402 */
+	0x000403, /* 0x000403 */
+	0x000404, /* 0x000404 */
+	0x000405, /* 0x000405 */
+	0x000406, /* 0x000406 */
+	0x000407, /* 0x000407 */
+	0x000408, /* 0x000408 */
+	0x000409, /* 0x000409 */
+	0x00040a, /* 0x00040a */
+	0x00040b, /* 0x00040b */
+	0x00040c, /* 0x00040c */
+	0x00040d, /* 0x00040d */
+	0x00040e, /* 0x00040e */
+	0x00040f, /* 0x00040f */
+	0x000410, /* 0x000410 */
+	0x000411, /* 0x000411 */
+	0x000412, /* 0x000412 */
+	0x000413, /* 0x000413 */
+	0x000414, /* 0x000414 */
+	0x000415, /* 0x000415 */
+	0x000416, /* 0x000416 */
+	0x000417, /* 0x000417 */
+	0x000418, /* 0x000418 */
+	0x000419, /* 0x000419 */
+	0x00041a, /* 0x00041a */
+	0x00041b, /* 0x00041b */
+	0x00041c, /* 0x00041c */
+	0x00041d, /* 0x00041d */
+	0x00041e, /* 0x00041e */
+	0x00041f, /* 0x00041f */
+	0x000420, /* 0x000420 */
+	0x000421, /* 0x000421 */
+	0x000422, /* 0x000422 */
+	0x000423, /* 0x000423 */
+	0x000424, /* 0x000424 */
+	0x000425, /* 0x000425 */
+	0x000426, /* 0x000426 */
+	0x000427, /* 0x000427 */
+	0x000428, /* 0x000428 */
+	0x000429, /* 0x000429 */
+	0x00042a, /* 0x00042a */
+	0x00042b, /* 0x00042b */
+	0x00042c, /* 0x00042c */
+	0x00042d, /* 0x00042d */
+	0x00042e, /* 0x00042e */
+	0x00042f, /* 0x00042f */
+	0x000460, /* 0x000460 */
+	0x000462, /* 0x000462 */
+	0x000464, /* 0x000464 */
+	0x000466, /* 0x000466 */
+	0x000468, /* 0x000468 */
+	0x00046a, /* 0x00046a */
+	0x00046c, /* 0x00046c */
+	0x00046e, /* 0x00046e */
+	0x000470, /* 0x000470 */
+	0x000472, /* 0x000472 */
+	0x000474, /* 0x000474 */
+	0x000476, /* 0x000476 */
+	0x000478, /* 0x000478 */
+	0x00047a, /* 0x00047a */
+	0x00047c, /* 0x00047c */
+	0x00047e, /* 0x00047e */
+	0x000480, /* 0x000480 */
+	0x00048a, /* 0x00048a */
+	0x00048c, /* 0x00048c */
+	0x00048e, /* 0x00048e */
+	0x000490, /* 0x000490 */
+	0x000492, /* 0x000492 */
+	0x000494, /* 0x000494 */
+	0x000496, /* 0x000496 */
+	0x000498, /* 0x000498 */
+	0x00049a, /* 0x00049a */
+	0x00049c, /* 0x00049c */
+	0x00049e, /* 0x00049e */
+	0x0004a0, /* 0x0004a0 */
+	0x0004a2, /* 0x0004a2 */
+	0x0004a4, /* 0x0004a4 */
+	0x0004a6, /* 0x0004a6 */
+	0x0004a8, /* 0x0004a8 */
+	0x0004aa, /* 0x0004aa */
+	0x0004ac, /* 0x0004ac */
+	0x0004ae, /* 0x0004ae */
+	0x0004b0, /* 0x0004b0 */
+	0x0004b2, /* 0x0004b2 */
+	0x0004b4, /* 0x0004b4 */
+	0x0004b6, /* 0x0004b6 */
+	0x0004b8, /* 0x0004b8 */
+	0x0004ba, /* 0x0004ba */
+	0x0004bc, /* 0x0004bc */
+	0x0004be, /* 0x0004be */
+	0x0004c0, /* 0x0004c0 */
+	0x0004c1, /* 0x0004c1 */
+	0x0004c3, /* 0x0004c3 */
+	0x0004c5, /* 0x0004c5 */
+	0x0004c7, /* 0x0004c7 */
+	0x0004c9, /* 0x0004c9 */
+	0x0004cb, /* 0x0004cb */
+	0x0004cd, /* 0x0004cd */
+	0x0004d0, /* 0x0004d0 */
+	0x0004d2, /* 0x0004d2 */
+	0x0004d4, /* 0x0004d4 */
+	0x0004d6, /* 0x0004d6 */
+	0x0004d8, /* 0x0004d8 */
+	0x0004da, /* 0x0004da */
+	0x0004dc, /* 0x0004dc */
+	0x0004de, /* 0x0004de */
+	0x0004e0, /* 0x0004e0 */
+	0x0004e2, /* 0x0004e2 */
+	0x0004e4, /* 0x0004e4 */
+	0x0004e6, /* 0x0004e6 */
+	0x0004e8, /* 0x0004e8 */
+	0x0004ea, /* 0x0004ea */
+	0x0004ec, /* 0x0004ec */
+	0x0004ee, /* 0x0004ee */
+	0x0004f0, /* 0x0004f0 */
+	0x0004f2, /* 0x0004f2 */
+	0x0004f4, /* 0x0004f4 */
+	0x0004f6, /* 0x0004f6 */
+	0x0004f8, /* 0x0004f8 */
+	0x0004fa, /* 0x0004fa */
+	0x0004fc, /* 0x0004fc */
+	0x0004fe, /* 0x0004fe */
+	0x000500, /* 0x000500 */
+	0x000502, /* 0x000502 */
+	0x000504, /* 0x000504 */
+	0x000506, /* 0x000506 */
+	0x000508, /* 0x000508 */
+	0x00050a, /* 0x00050a */
+	0x00050c, /* 0x00050c */
+	0x00050e, /* 0x00050e */
+	0x000510, /* 0x000510 */
+	0x000512, /* 0x000512 */
+	0x000514, /* 0x000514 */
+	0x000516, /* 0x000516 */
+	0x000518, /* 0x000518 */
+	0x00051a, /* 0x00051a */
+	0x00051c, /* 0x00051c */
+	0x00051e, /* 0x00051e */
+	0x000520, /* 0x000520 */
+	0x000522, /* 0x000522 */
+	0x000524, /* 0x000524 */
+	0x000526, /* 0x000526 */
+	0x000528, /* 0x000528 */
+	0x00052a, /* 0x00052a */
+	0x00052c, /* 0x00052c */
+	0x00052e, /* 0x00052e */
+	0x000531, /* 0x000531 */
+	0x000532, /* 0x000532 */
+	0x000533, /* 0x000533 */
+	0x000534, /* 0x000534 */
+	0x000535, /* 0x000535 */
+	0x000536, /* 0x000536 */
+	0x000537, /* 0x000537 */
+	0x000538, /* 0x000538 */
+	0x000539, /* 0x000539 */
+	0x00053a, /* 0x00053a */
+	0x00053b, /* 0x00053b */
+	0x00053c, /* 0x00053c */
+	0x00053d, /* 0x00053d */
+	0x00053e, /* 0x00053e */
+	0x00053f, /* 0x00053f */
+	0x000540, /* 0x000540 */
+	0x000541, /* 0x000541 */
+	0x000542, /* 0x000542 */
+	0x000543, /* 0x000543 */
+	0x000544, /* 0x000544 */
+	0x000545, /* 0x000545 */
+	0x000546, /* 0x000546 */
+	0x000547, /* 0x000547 */
+	0x000548, /* 0x000548 */
+	0x000549, /* 0x000549 */
+	0x00054a, /* 0x00054a */
+	0x00054b, /* 0x00054b */
+	0x00054c, /* 0x00054c */
+	0x00054d, /* 0x00054d */
+	0x00054e, /* 0x00054e */
+	0x00054f, /* 0x00054f */
+	0x000550, /* 0x000550 */
+	0x000551, /* 0x000551 */
+	0x000552, /* 0x000552 */
+	0x000553, /* 0x000553 */
+	0x000554, /* 0x000554 */
+	0x000555, /* 0x000555 */
+	0x000556, /* 0x000556 */
+	0x000587, /* 0x000587 */
+	0x0010a0, /* 0x0010a0 */
+	0x0010a1, /* 0x0010a1 */
+	0x0010a2, /* 0x0010a2 */
+	0x0010a3, /* 0x0010a3 */
+	0x0010a4, /* 0x0010a4 */
+	0x0010a5, /* 0x0010a5 */
+	0x0010a6, /* 0x0010a6 */
+	0x0010a7, /* 0x0010a7 */
+	0x0010a8, /* 0x0010a8 */
+	0x0010a9, /* 0x0010a9 */
+	0x0010aa, /* 0x0010aa */
+	0x0010ab, /* 0x0010ab */
+	0x0010ac, /* 0x0010ac */
+	0x0010ad, /* 0x0010ad */
+	0x0010ae, /* 0x0010ae */
+	0x0010af, /* 0x0010af */
+	0x0010b0, /* 0x0010b0 */
+	0x0010b1, /* 0x0010b1 */
+	0x0010b2, /* 0x0010b2 */
+	0x0010b3, /* 0x0010b3 */
+	0x0010b4, /* 0x0010b4 */
+	0x0010b5, /* 0x0010b5 */
+	0x0010b6, /* 0x0010b6 */
+	0x0010b7, /* 0x0010b7 */
+	0x0010b8, /* 0x0010b8 */
+	0x0010b9, /* 0x0010b9 */
+	0x0010ba, /* 0x0010ba */
+	0x0010bb, /* 0x0010bb */
+	0x0010bc, /* 0x0010bc */
+	0x0010bd, /* 0x0010bd */
+	0x0010be, /* 0x0010be */
+	0x0010bf, /* 0x0010bf */
+	0x0010c0, /* 0x0010c0 */
+	0x0010c1, /* 0x0010c1 */
+	0x0010c2, /* 0x0010c2 */
+	0x0010c3, /* 0x0010c3 */
+	0x0010c4, /* 0x0010c4 */
+	0x0010c5, /* 0x0010c5 */
+	0x0010c7, /* 0x0010c7 */
+	0x0010cd, /* 0x0010cd */
+	0x001c90, /* 0x0010d0 */
+	0x001c91, /* 0x0010d1 */
+	0x001c92, /* 0x0010d2 */
+	0x001c93, /* 0x0010d3 */
+	0x001c94, /* 0x0010d4 */
+	0x001c95, /* 0x0010d5 */
+	0x001c96, /* 0x0010d6 */
+	0x001c97, /* 0x0010d7 */
+	0x001c98, /* 0x0010d8 */
+	0x001c99, /* 0x0010d9 */
+	0x001c9a, /* 0x0010da */
+	0x001c9b, /* 0x0010db */
+	0x001c9c, /* 0x0010dc */
+	0x001c9d, /* 0x0010dd */
+	0x001c9e, /* 0x0010de */
+	0x001c9f, /* 0x0010df */
+	0x001ca0, /* 0x0010e0 */
+	0x001ca1, /* 0x0010e1 */
+	0x001ca2, /* 0x0010e2 */
+	0x001ca3, /* 0x0010e3 */
+	0x001ca4, /* 0x0010e4 */
+	0x001ca5, /* 0x0010e5 */
+	0x001ca6, /* 0x0010e6 */
+	0x001ca7, /* 0x0010e7 */
+	0x001ca8, /* 0x0010e8 */
+	0x001ca9, /* 0x0010e9 */
+	0x001caa, /* 0x0010ea */
+	0x001cab, /* 0x0010eb */
+	0x001cac, /* 0x0010ec */
+	0x001cad, /* 0x0010ed */
+	0x001cae, /* 0x0010ee */
+	0x001caf, /* 0x0010ef */
+	0x001cb0, /* 0x0010f0 */
+	0x001cb1, /* 0x0010f1 */
+	0x001cb2, /* 0x0010f2 */
+	0x001cb3, /* 0x0010f3 */
+	0x001cb4, /* 0x0010f4 */
+	0x001cb5, /* 0x0010f5 */
+	0x001cb6, /* 0x0010f6 */
+	0x001cb7, /* 0x0010f7 */
+	0x001cb8, /* 0x0010f8 */
+	0x001cb9, /* 0x0010f9 */
+	0x001cba, /* 0x0010fa */
+	0x001cbd, /* 0x0010fd */
+	0x001cbe, /* 0x0010fe */
+	0x001cbf, /* 0x0010ff */
+	0x0013a0, /* 0x0013a0 */
+	0x0013a1, /* 0x0013a1 */
+	0x0013a2, /* 0x0013a2 */
+	0x0013a3, /* 0x0013a3 */
+	0x0013a4, /* 0x0013a4 */
+	0x0013a5, /* 0x0013a5 */
+	0x0013a6, /* 0x0013a6 */
+	0x0013a7, /* 0x0013a7 */
+	0x0013a8, /* 0x0013a8 */
+	0x0013a9, /* 0x0013a9 */
+	0x0013aa, /* 0x0013aa */
+	0x0013ab, /* 0x0013ab */
+	0x0013ac, /* 0x0013ac */
+	0x0013ad, /* 0x0013ad */
+	0x0013ae, /* 0x0013ae */
+	0x0013af, /* 0x0013af */
+	0x0013b0, /* 0x0013b0 */
+	0x0013b1, /* 0x0013b1 */
+	0x0013b2, /* 0x0013b2 */
+	0x0013b3, /* 0x0013b3 */
+	0x0013b4, /* 0x0013b4 */
+	0x0013b5, /* 0x0013b5 */
+	0x0013b6, /* 0x0013b6 */
+	0x0013b7, /* 0x0013b7 */
+	0x0013b8, /* 0x0013b8 */
+	0x0013b9, /* 0x0013b9 */
+	0x0013ba, /* 0x0013ba */
+	0x0013bb, /* 0x0013bb */
+	0x0013bc, /* 0x0013bc */
+	0x0013bd, /* 0x0013bd */
+	0x0013be, /* 0x0013be */
+	0x0013bf, /* 0x0013bf */
+	0x0013c0, /* 0x0013c0 */
+	0x0013c1, /* 0x0013c1 */
+	0x0013c2, /* 0x0013c2 */
+	0x0013c3, /* 0x0013c3 */
+	0x0013c4, /* 0x0013c4 */
+	0x0013c5, /* 0x0013c5 */
+	0x0013c6, /* 0x0013c6 */
+	0x0013c7, /* 0x0013c7 */
+	0x0013c8, /* 0x0013c8 */
+	0x0013c9, /* 0x0013c9 */
+	0x0013ca, /* 0x0013ca */
+	0x0013cb, /* 0x0013cb */
+	0x0013cc, /* 0x0013cc */
+	0x0013cd, /* 0x0013cd */
+	0x0013ce, /* 0x0013ce */
+	0x0013cf, /* 0x0013cf */
+	0x0013d0, /* 0x0013d0 */
+	0x0013d1, /* 0x0013d1 */
+	0x0013d2, /* 0x0013d2 */
+	0x0013d3, /* 0x0013d3 */
+	0x0013d4, /* 0x0013d4 */
+	0x0013d5, /* 0x0013d5 */
+	0x0013d6, /* 0x0013d6 */
+	0x0013d7, /* 0x0013d7 */
+	0x0013d8, /* 0x0013d8 */
+	0x0013d9, /* 0x0013d9 */
+	0x0013da, /* 0x0013da */
+	0x0013db, /* 0x0013db */
+	0x0013dc, /* 0x0013dc */
+	0x0013dd, /* 0x0013dd */
+	0x0013de, /* 0x0013de */
+	0x0013df, /* 0x0013df */
+	0x0013e0, /* 0x0013e0 */
+	0x0013e1, /* 0x0013e1 */
+	0x0013e2, /* 0x0013e2 */
+	0x0013e3, /* 0x0013e3 */
+	0x0013e4, /* 0x0013e4 */
+	0x0013e5, /* 0x0013e5 */
+	0x0013e6, /* 0x0013e6 */
+	0x0013e7, /* 0x0013e7 */
+	0x0013e8, /* 0x0013e8 */
+	0x0013e9, /* 0x0013e9 */
+	0x0013ea, /* 0x0013ea */
+	0x0013eb, /* 0x0013eb */
+	0x0013ec, /* 0x0013ec */
+	0x0013ed, /* 0x0013ed */
+	0x0013ee, /* 0x0013ee */
+	0x0013ef, /* 0x0013ef */
+	0x0013f0, /* 0x0013f0 */
+	0x0013f1, /* 0x0013f1 */
+	0x0013f2, /* 0x0013f2 */
+	0x0013f3, /* 0x0013f3 */
+	0x0013f4, /* 0x0013f4 */
+	0x0013f5, /* 0x0013f5 */
+	0x000412, /* 0x001c80 */
+	0x000414, /* 0x001c81 */
+	0x00041e, /* 0x001c82 */
+	0x000421, /* 0x001c83 */
+	0x000422, /* 0x001c84 */
+	0x000422, /* 0x001c85 */
+	0x00042a, /* 0x001c86 */
+	0x000462, /* 0x001c87 */
+	0x00a64a, /* 0x001c88 */
+	0x001c90, /* 0x001c90 */
+	0x001c91, /* 0x001c91 */
+	0x001c92, /* 0x001c92 */
+	0x001c93, /* 0x001c93 */
+	0x001c94, /* 0x001c94 */
+	0x001c95, /* 0x001c95 */
+	0x001c96, /* 0x001c96 */
+	0x001c97, /* 0x001c97 */
+	0x001c98, /* 0x001c98 */
+	0x001c99, /* 0x001c99 */
+	0x001c9a, /* 0x001c9a */
+	0x001c9b, /* 0x001c9b */
+	0x001c9c, /* 0x001c9c */
+	0x001c9d, /* 0x001c9d */
+	0x001c9e, /* 0x001c9e */
+	0x001c9f, /* 0x001c9f */
+	0x001ca0, /* 0x001ca0 */
+	0x001ca1, /* 0x001ca1 */
+	0x001ca2, /* 0x001ca2 */
+	0x001ca3, /* 0x001ca3 */
+	0x001ca4, /* 0x001ca4 */
+	0x001ca5, /* 0x001ca5 */
+	0x001ca6, /* 0x001ca6 */
+	0x001ca7, /* 0x001ca7 */
+	0x001ca8, /* 0x001ca8 */
+	0x001ca9, /* 0x001ca9 */
+	0x001caa, /* 0x001caa */
+	0x001cab, /* 0x001cab */
+	0x001cac, /* 0x001cac */
+	0x001cad, /* 0x001cad */
+	0x001cae, /* 0x001cae */
+	0x001caf, /* 0x001caf */
+	0x001cb0, /* 0x001cb0 */
+	0x001cb1, /* 0x001cb1 */
+	0x001cb2, /* 0x001cb2 */
+	0x001cb3, /* 0x001cb3 */
+	0x001cb4, /* 0x001cb4 */
+	0x001cb5, /* 0x001cb5 */
+	0x001cb6, /* 0x001cb6 */
+	0x001cb7, /* 0x001cb7 */
+	0x001cb8, /* 0x001cb8 */
+	0x001cb9, /* 0x001cb9 */
+	0x001cba, /* 0x001cba */
+	0x001cbd, /* 0x001cbd */
+	0x001cbe, /* 0x001cbe */
+	0x001cbf, /* 0x001cbf */
+	0x00a77d, /* 0x001d79 */
+	0x002c63, /* 0x001d7d */
+	0x00a7c6, /* 0x001d8e */
+	0x001e00, /* 0x001e00 */
+	0x001e02, /* 0x001e02 */
+	0x001e04, /* 0x001e04 */
+	0x001e06, /* 0x001e06 */
+	0x001e08, /* 0x001e08 */
+	0x001e0a, /* 0x001e0a */
+	0x001e0c, /* 0x001e0c */
+	0x001e0e, /* 0x001e0e */
+	0x001e10, /* 0x001e10 */
+	0x001e12, /* 0x001e12 */
+	0x001e14, /* 0x001e14 */
+	0x001e16, /* 0x001e16 */
+	0x001e18, /* 0x001e18 */
+	0x001e1a, /* 0x001e1a */
+	0x001e1c, /* 0x001e1c */
+	0x001e1e, /* 0x001e1e */
+	0x001e20, /* 0x001e20 */
+	0x001e22, /* 0x001e22 */
+	0x001e24, /* 0x001e24 */
+	0x001e26, /* 0x001e26 */
+	0x001e28, /* 0x001e28 */
+	0x001e2a, /* 0x001e2a */
+	0x001e2c, /* 0x001e2c */
+	0x001e2e, /* 0x001e2e */
+	0x001e30, /* 0x001e30 */
+	0x001e32, /* 0x001e32 */
+	0x001e34, /* 0x001e34 */
+	0x001e36, /* 0x001e36 */
+	0x001e38, /* 0x001e38 */
+	0x001e3a, /* 0x001e3a */
+	0x001e3c, /* 0x001e3c */
+	0x001e3e, /* 0x001e3e */
+	0x001e40, /* 0x001e40 */
+	0x001e42, /* 0x001e42 */
+	0x001e44, /* 0x001e44 */
+	0x001e46, /* 0x001e46 */
+	0x001e48, /* 0x001e48 */
+	0x001e4a, /* 0x001e4a */
+	0x001e4c, /* 0x001e4c */
+	0x001e4e, /* 0x001e4e */
+	0x001e50, /* 0x001e50 */
+	0x001e52, /* 0x001e52 */
+	0x001e54, /* 0x001e54 */
+	0x001e56, /* 0x001e56 */
+	0x001e58, /* 0x001e58 */
+	0x001e5a, /* 0x001e5a */
+	0x001e5c, /* 0x001e5c */
+	0x001e5e, /* 0x001e5e */
+	0x001e60, /* 0x001e60 */
+	0x001e62, /* 0x001e62 */
+	0x001e64, /* 0x001e64 */
+	0x001e66, /* 0x001e66 */
+	0x001e68, /* 0x001e68 */
+	0x001e6a, /* 0x001e6a */
+	0x001e6c, /* 0x001e6c */
+	0x001e6e, /* 0x001e6e */
+	0x001e70, /* 0x001e70 */
+	0x001e72, /* 0x001e72 */
+	0x001e74, /* 0x001e74 */
+	0x001e76, /* 0x001e76 */
+	0x001e78, /* 0x001e78 */
+	0x001e7a, /* 0x001e7a */
+	0x001e7c, /* 0x001e7c */
+	0x001e7e, /* 0x001e7e */
+	0x001e80, /* 0x001e80 */
+	0x001e82, /* 0x001e82 */
+	0x001e84, /* 0x001e84 */
+	0x001e86, /* 0x001e86 */
+	0x001e88, /* 0x001e88 */
+	0x001e8a, /* 0x001e8a */
+	0x001e8c, /* 0x001e8c */
+	0x001e8e, /* 0x001e8e */
+	0x001e90, /* 0x001e90 */
+	0x001e92, /* 0x001e92 */
+	0x001e94, /* 0x001e94 */
+	0x001e96, /* 0x001e96 */
+	0x001e97, /* 0x001e97 */
+	0x001e98, /* 0x001e98 */
+	0x001e99, /* 0x001e99 */
+	0x001e9a, /* 0x001e9a */
+	0x001e60, /* 0x001e9b */
+	0x001e9e, /* 0x001e9e */
+	0x001ea0, /* 0x001ea0 */
+	0x001ea2, /* 0x001ea2 */
+	0x001ea4, /* 0x001ea4 */
+	0x001ea6, /* 0x001ea6 */
+	0x001ea8, /* 0x001ea8 */
+	0x001eaa, /* 0x001eaa */
+	0x001eac, /* 0x001eac */
+	0x001eae, /* 0x001eae */
+	0x001eb0, /* 0x001eb0 */
+	0x001eb2, /* 0x001eb2 */
+	0x001eb4, /* 0x001eb4 */
+	0x001eb6, /* 0x001eb6 */
+	0x001eb8, /* 0x001eb8 */
+	0x001eba, /* 0x001eba */
+	0x001ebc, /* 0x001ebc */
+	0x001ebe, /* 0x001ebe */
+	0x001ec0, /* 0x001ec0 */
+	0x001ec2, /* 0x001ec2 */
+	0x001ec4, /* 0x001ec4 */
+	0x001ec6, /* 0x001ec6 */
+	0x001ec8, /* 0x001ec8 */
+	0x001eca, /* 0x001eca */
+	0x001ecc, /* 0x001ecc */
+	0x001ece, /* 0x001ece */
+	0x001ed0, /* 0x001ed0 */
+	0x001ed2, /* 0x001ed2 */
+	0x001ed4, /* 0x001ed4 */
+	0x001ed6, /* 0x001ed6 */
+	0x001ed8, /* 0x001ed8 */
+	0x001eda, /* 0x001eda */
+	0x001edc, /* 0x001edc */
+	0x001ede, /* 0x001ede */
+	0x001ee0, /* 0x001ee0 */
+	0x001ee2, /* 0x001ee2 */
+	0x001ee4, /* 0x001ee4 */
+	0x001ee6, /* 0x001ee6 */
+	0x001ee8, /* 0x001ee8 */
+	0x001eea, /* 0x001eea */
+	0x001eec, /* 0x001eec */
+	0x001eee, /* 0x001eee */
+	0x001ef0, /* 0x001ef0 */
+	0x001ef2, /* 0x001ef2 */
+	0x001ef4, /* 0x001ef4 */
+	0x001ef6, /* 0x001ef6 */
+	0x001ef8, /* 0x001ef8 */
+	0x001efa, /* 0x001efa */
+	0x001efc, /* 0x001efc */
+	0x001efe, /* 0x001efe */
+	0x001f08, /* 0x001f00 */
+	0x001f09, /* 0x001f01 */
+	0x001f0a, /* 0x001f02 */
+	0x001f0b, /* 0x001f03 */
+	0x001f0c, /* 0x001f04 */
+	0x001f0d, /* 0x001f05 */
+	0x001f0e, /* 0x001f06 */
+	0x001f0f, /* 0x001f07 */
+	0x001f18, /* 0x001f10 */
+	0x001f19, /* 0x001f11 */
+	0x001f1a, /* 0x001f12 */
+	0x001f1b, /* 0x001f13 */
+	0x001f1c, /* 0x001f14 */
+	0x001f1d, /* 0x001f15 */
+	0x001f28, /* 0x001f20 */
+	0x001f29, /* 0x001f21 */
+	0x001f2a, /* 0x001f22 */
+	0x001f2b, /* 0x001f23 */
+	0x001f2c, /* 0x001f24 */
+	0x001f2d, /* 0x001f25 */
+	0x001f2e, /* 0x001f26 */
+	0x001f2f, /* 0x001f27 */
+	0x001f38, /* 0x001f30 */
+	0x001f39, /* 0x001f31 */
+	0x001f3a, /* 0x001f32 */
+	0x001f3b, /* 0x001f33 */
+	0x001f3c, /* 0x001f34 */
+	0x001f3d, /* 0x001f35 */
+	0x001f3e, /* 0x001f36 */
+	0x001f3f, /* 0x001f37 */
+	0x001f48, /* 0x001f40 */
+	0x001f49, /* 0x001f41 */
+	0x001f4a, /* 0x001f42 */
+	0x001f4b, /* 0x001f43 */
+	0x001f4c, /* 0x001f44 */
+	0x001f4d, /* 0x001f45 */
+	0x001f50, /* 0x001f50 */
+	0x001f59, /* 0x001f51 */
+	0x001f52, /* 0x001f52 */
+	0x001f5b, /* 0x001f53 */
+	0x001f54, /* 0x001f54 */
+	0x001f5d, /* 0x001f55 */
+	0x001f56, /* 0x001f56 */
+	0x001f5f, /* 0x001f57 */
+	0x001f68, /* 0x001f60 */
+	0x001f69, /* 0x001f61 */
+	0x001f6a, /* 0x001f62 */
+	0x001f6b, /* 0x001f63 */
+	0x001f6c, /* 0x001f64 */
+	0x001f6d, /* 0x001f65 */
+	0x001f6e, /* 0x001f66 */
+	0x001f6f, /* 0x001f67 */
+	0x001fba, /* 0x001f70 */
+	0x001fbb, /* 0x001f71 */
+	0x001fc8, /* 0x001f72 */
+	0x001fc9, /* 0x001f73 */
+	0x001fca, /* 0x001f74 */
+	0x001fcb, /* 0x001f75 */
+	0x001fda, /* 0x001f76 */
+	0x001fdb, /* 0x001f77 */
+	0x001ff8, /* 0x001f78 */
+	0x001ff9, /* 0x001f79 */
+	0x001fea, /* 0x001f7a */
+	0x001feb, /* 0x001f7b */
+	0x001ffa, /* 0x001f7c */
+	0x001ffb, /* 0x001f7d */
+	0x001f88, /* 0x001f80 */
+	0x001f89, /* 0x001f81 */
+	0x001f8a, /* 0x001f82 */
+	0x001f8b, /* 0x001f83 */
+	0x001f8c, /* 0x001f84 */
+	0x001f8d, /* 0x001f85 */
+	0x001f8e, /* 0x001f86 */
+	0x001f8f, /* 0x001f87 */
+	0x001f88, /* 0x001f88 */
+	0x001f89, /* 0x001f89 */
+	0x001f8a, /* 0x001f8a */
+	0x001f8b, /* 0x001f8b */
+	0x001f8c, /* 0x001f8c */
+	0x001f8d, /* 0x001f8d */
+	0x001f8e, /* 0x001f8e */
+	0x001f8f, /* 0x001f8f */
+	0x001f98, /* 0x001f90 */
+	0x001f99, /* 0x001f91 */
+	0x001f9a, /* 0x001f92 */
+	0x001f9b, /* 0x001f93 */
+	0x001f9c, /* 0x001f94 */
+	0x001f9d, /* 0x001f95 */
+	0x001f9e, /* 0x001f96 */
+	0x001f9f, /* 0x001f97 */
+	0x001f98, /* 0x001f98 */
+	0x001f99, /* 0x001f99 */
+	0x001f9a, /* 0x001f9a */
+	0x001f9b, /* 0x001f9b */
+	0x001f9c, /* 0x001f9c */
+	0x001f9d, /* 0x001f9d */
+	0x001f9e, /* 0x001f9e */
+	0x001f9f, /* 0x001f9f */
+	0x001fa8, /* 0x001fa0 */
+	0x001fa9, /* 0x001fa1 */
+	0x001faa, /* 0x001fa2 */
+	0x001fab, /* 0x001fa3 */
+	0x001fac, /* 0x001fa4 */
+	0x001fad, /* 0x001fa5 */
+	0x001fae, /* 0x001fa6 */
+	0x001faf, /* 0x001fa7 */
+	0x001fa8, /* 0x001fa8 */
+	0x001fa9, /* 0x001fa9 */
+	0x001faa, /* 0x001faa */
+	0x001fab, /* 0x001fab */
+	0x001fac, /* 0x001fac */
+	0x001fad, /* 0x001fad */
+	0x001fae, /* 0x001fae */
+	0x001faf, /* 0x001faf */
+	0x001fb8, /* 0x001fb0 */
+	0x001fb9, /* 0x001fb1 */
+	0x001fb2, /* 0x001fb2 */
+	0x001fbc, /* 0x001fb3 */
+	0x001fb4, /* 0x001fb4 */
+	0x001fb6, /* 0x001fb6 */
+	0x001fb7, /* 0x001fb7 */
+	0x001fbc, /* 0x001fbc */
+	0x000399, /* 0x001fbe */
+	0x001fc2, /* 0x001fc2 */
+	0x001fcc, /* 0x001fc3 */
+	0x001fc4, /* 0x001fc4 */
+	0x001fc6, /* 0x001fc6 */
+	0x001fc7, /* 0x001fc7 */
+	0x001fcc, /* 0x001fcc */
+	0x001fd8, /* 0x001fd0 */
+	0x001fd9, /* 0x001fd1 */
+	0x001fd2, /* 0x001fd2 */
+	0x001fd3, /* 0x001fd3 */
+	0x001fd6, /* 0x001fd6 */
+	0x001fd7, /* 0x001fd7 */
+	0x001fe8, /* 0x001fe0 */
+	0x001fe9, /* 0x001fe1 */
+	0x001fe2, /* 0x001fe2 */
+	0x001fe3, /* 0x001fe3 */
+	0x001fe4, /* 0x001fe4 */
+	0x001fec, /* 0x001fe5 */
+	0x001fe6, /* 0x001fe6 */
+	0x001fe7, /* 0x001fe7 */
+	0x001ff2, /* 0x001ff2 */
+	0x001ffc, /* 0x001ff3 */
+	0x001ff4, /* 0x001ff4 */
+	0x001ff6, /* 0x001ff6 */
+	0x001ff7, /* 0x001ff7 */
+	0x001ffc, /* 0x001ffc */
+	0x002126, /* 0x002126 */
+	0x00212a, /* 0x00212a */
+	0x00212b, /* 0x00212b */
+	0x002132, /* 0x002132 */
+	0x002160, /* 0x002160 */
+	0x002161, /* 0x002161 */
+	0x002162, /* 0x002162 */
+	0x002163, /* 0x002163 */
+	0x002164, /* 0x002164 */
+	0x002165, /* 0x002165 */
+	0x002166, /* 0x002166 */
+	0x002167, /* 0x002167 */
+	0x002168, /* 0x002168 */
+	0x002169, /* 0x002169 */
+	0x00216a, /* 0x00216a */
+	0x00216b, /* 0x00216b */
+	0x00216c, /* 0x00216c */
+	0x00216d, /* 0x00216d */
+	0x00216e, /* 0x00216e */
+	0x00216f, /* 0x00216f */
+	0x002183, /* 0x002183 */
+	0x0024b6, /* 0x0024b6 */
+	0x0024b7, /* 0x0024b7 */
+	0x0024b8, /* 0x0024b8 */
+	0x0024b9, /* 0x0024b9 */
+	0x0024ba, /* 0x0024ba */
+	0x0024bb, /* 0x0024bb */
+	0x0024bc, /* 0x0024bc */
+	0x0024bd, /* 0x0024bd */
+	0x0024be, /* 0x0024be */
+	0x0024bf, /* 0x0024bf */
+	0x0024c0, /* 0x0024c0 */
+	0x0024c1, /* 0x0024c1 */
+	0x0024c2, /* 0x0024c2 */
+	0x0024c3, /* 0x0024c3 */
+	0x0024c4, /* 0x0024c4 */
+	0x0024c5, /* 0x0024c5 */
+	0x0024c6, /* 0x0024c6 */
+	0x0024c7, /* 0x0024c7 */
+	0x0024c8, /* 0x0024c8 */
+	0x0024c9, /* 0x0024c9 */
+	0x0024ca, /* 0x0024ca */
+	0x0024cb, /* 0x0024cb */
+	0x0024cc, /* 0x0024cc */
+	0x0024cd, /* 0x0024cd */
+	0x0024ce, /* 0x0024ce */
+	0x0024cf, /* 0x0024cf */
+	0x002c00, /* 0x002c00 */
+	0x002c01, /* 0x002c01 */
+	0x002c02, /* 0x002c02 */
+	0x002c03, /* 0x002c03 */
+	0x002c04, /* 0x002c04 */
+	0x002c05, /* 0x002c05 */
+	0x002c06, /* 0x002c06 */
+	0x002c07, /* 0x002c07 */
+	0x002c08, /* 0x002c08 */
+	0x002c09, /* 0x002c09 */
+	0x002c0a, /* 0x002c0a */
+	0x002c0b, /* 0x002c0b */
+	0x002c0c, /* 0x002c0c */
+	0x002c0d, /* 0x002c0d */
+	0x002c0e, /* 0x002c0e */
+	0x002c0f, /* 0x002c0f */
+	0x002c10, /* 0x002c10 */
+	0x002c11, /* 0x002c11 */
+	0x002c12, /* 0x002c12 */
+	0x002c13, /* 0x002c13 */
+	0x002c14, /* 0x002c14 */
+	0x002c15, /* 0x002c15 */
+	0x002c16, /* 0x002c16 */
+	0x002c17, /* 0x002c17 */
+	0x002c18, /* 0x002c18 */
+	0x002c19, /* 0x002c19 */
+	0x002c1a, /* 0x002c1a */
+	0x002c1b, /* 0x002c1b */
+	0x002c1c, /* 0x002c1c */
+	0x002c1d, /* 0x002c1d */
+	0x002c1e, /* 0x002c1e */
+	0x002c1f, /* 0x002c1f */
+	0x002c20, /* 0x002c20 */
+	0x002c21, /* 0x002c21 */
+	0x002c22, /* 0x002c22 */
+	0x002c23, /* 0x002c23 */
+	0x002c24, /* 0x002c24 */
+	0x002c25, /* 0x002c25 */
+	0x002c26, /* 0x002c26 */
+	0x002c27, /* 0x002c27 */
+	0x002c28, /* 0x002c28 */
+	0x002c29, /* 0x002c29 */
+	0x002c2a, /* 0x002c2a */
+	0x002c2b, /* 0x002c2b */
+	0x002c2c, /* 0x002c2c */
+	0x002c2d, /* 0x002c2d */
+	0x002c2e, /* 0x002c2e */
+	0x002c2f, /* 0x002c2f */
+	0x002c60, /* 0x002c60 */
+	0x002c67, /* 0x002c67 */
+	0x002c69, /* 0x002c69 */
+	0x002c6b, /* 0x002c6b */
+	0x002c72, /* 0x002c72 */
+	0x002c75, /* 0x002c75 */
+	0x002c80, /* 0x002c80 */
+	0x002c82, /* 0x002c82 */
+	0x002c84, /* 0x002c84 */
+	0x002c86, /* 0x002c86 */
+	0x002c88, /* 0x002c88 */
+	0x002c8a, /* 0x002c8a */
+	0x002c8c, /* 0x002c8c */
+	0x002c8e, /* 0x002c8e */
+	0x002c90, /* 0x002c90 */
+	0x002c92, /* 0x002c92 */
+	0x002c94, /* 0x002c94 */
+	0x002c96, /* 0x002c96 */
+	0x002c98, /* 0x002c98 */
+	0x002c9a, /* 0x002c9a */
+	0x002c9c, /* 0x002c9c */
+	0x002c9e, /* 0x002c9e */
+	0x002ca0, /* 0x002ca0 */
+	0x002ca2, /* 0x002ca2 */
+	0x002ca4, /* 0x002ca4 */
+	0x002ca6, /* 0x002ca6 */
+	0x002ca8, /* 0x002ca8 */
+	0x002caa, /* 0x002caa */
+	0x002cac, /* 0x002cac */
+	0x002cae, /* 0x002cae */
+	0x002cb0, /* 0x002cb0 */
+	0x002cb2, /* 0x002cb2 */
+	0x002cb4, /* 0x002cb4 */
+	0x002cb6, /* 0x002cb6 */
+	0x002cb8, /* 0x002cb8 */
+	0x002cba, /* 0x002cba */
+	0x002cbc, /* 0x002cbc */
+	0x002cbe, /* 0x002cbe */
+	0x002cc0, /* 0x002cc0 */
+	0x002cc2, /* 0x002cc2 */
+	0x002cc4, /* 0x002cc4 */
+	0x002cc6, /* 0x002cc6 */
+	0x002cc8, /* 0x002cc8 */
+	0x002cca, /* 0x002cca */
+	0x002ccc, /* 0x002ccc */
+	0x002cce, /* 0x002cce */
+	0x002cd0, /* 0x002cd0 */
+	0x002cd2, /* 0x002cd2 */
+	0x002cd4, /* 0x002cd4 */
+	0x002cd6, /* 0x002cd6 */
+	0x002cd8, /* 0x002cd8 */
+	0x002cda, /* 0x002cda */
+	0x002cdc, /* 0x002cdc */
+	0x002cde, /* 0x002cde */
+	0x002ce0, /* 0x002ce0 */
+	0x002ce2, /* 0x002ce2 */
+	0x002ceb, /* 0x002ceb */
+	0x002ced, /* 0x002ced */
+	0x002cf2, /* 0x002cf2 */
+	0x00a640, /* 0x00a640 */
+	0x00a642, /* 0x00a642 */
+	0x00a644, /* 0x00a644 */
+	0x00a646, /* 0x00a646 */
+	0x00a648, /* 0x00a648 */
+	0x00a64a, /* 0x00a64a */
+	0x00a64c, /* 0x00a64c */
+	0x00a64e, /* 0x00a64e */
+	0x00a650, /* 0x00a650 */
+	0x00a652, /* 0x00a652 */
+	0x00a654, /* 0x00a654 */
+	0x00a656, /* 0x00a656 */
+	0x00a658, /* 0x00a658 */
+	0x00a65a, /* 0x00a65a */
+	0x00a65c, /* 0x00a65c */
+	0x00a65e, /* 0x00a65e */
+	0x00a660, /* 0x00a660 */
+	0x00a662, /* 0x00a662 */
+	0x00a664, /* 0x00a664 */
+	0x00a666, /* 0x00a666 */
+	0x00a668, /* 0x00a668 */
+	0x00a66a, /* 0x00a66a */
+	0x00a66c, /* 0x00a66c */
+	0x00a680, /* 0x00a680 */
+	0x00a682, /* 0x00a682 */
+	0x00a684, /* 0x00a684 */
+	0x00a686, /* 0x00a686 */
+	0x00a688, /* 0x00a688 */
+	0x00a68a, /* 0x00a68a */
+	0x00a68c, /* 0x00a68c */
+	0x00a68e, /* 0x00a68e */
+	0x00a690, /* 0x00a690 */
+	0x00a692, /* 0x00a692 */
+	0x00a694, /* 0x00a694 */
+	0x00a696, /* 0x00a696 */
+	0x00a698, /* 0x00a698 */
+	0x00a69a, /* 0x00a69a */
+	0x00a722, /* 0x00a722 */
+	0x00a724, /* 0x00a724 */
+	0x00a726, /* 0x00a726 */
+	0x00a728, /* 0x00a728 */
+	0x00a72a, /* 0x00a72a */
+	0x00a72c, /* 0x00a72c */
+	0x00a72e, /* 0x00a72e */
+	0x00a732, /* 0x00a732 */
+	0x00a734, /* 0x00a734 */
+	0x00a736, /* 0x00a736 */
+	0x00a738, /* 0x00a738 */
+	0x00a73a, /* 0x00a73a */
+	0x00a73c, /* 0x00a73c */
+	0x00a73e, /* 0x00a73e */
+	0x00a740, /* 0x00a740 */
+	0x00a742, /* 0x00a742 */
+	0x00a744, /* 0x00a744 */
+	0x00a746, /* 0x00a746 */
+	0x00a748, /* 0x00a748 */
+	0x00a74a, /* 0x00a74a */
+	0x00a74c, /* 0x00a74c */
+	0x00a74e, /* 0x00a74e */
+	0x00a750, /* 0x00a750 */
+	0x00a752, /* 0x00a752 */
+	0x00a754, /* 0x00a754 */
+	0x00a756, /* 0x00a756 */
+	0x00a758, /* 0x00a758 */
+	0x00a75a, /* 0x00a75a */
+	0x00a75c, /* 0x00a75c */
+	0x00a75e, /* 0x00a75e */
+	0x00a760, /* 0x00a760 */
+	0x00a762, /* 0x00a762 */
+	0x00a764, /* 0x00a764 */
+	0x00a766, /* 0x00a766 */
+	0x00a768, /* 0x00a768 */
+	0x00a76a, /* 0x00a76a */
+	0x00a76c, /* 0x00a76c */
+	0x00a76e, /* 0x00a76e */
+	0x00a779, /* 0x00a779 */
+	0x00a77b, /* 0x00a77b */
+	0x00a77e, /* 0x00a77e */
+	0x00a780, /* 0x00a780 */
+	0x00a782, /* 0x00a782 */
+	0x00a784, /* 0x00a784 */
+	0x00a786, /* 0x00a786 */
+	0x00a78b, /* 0x00a78b */
+	0x00a790, /* 0x00a790 */
+	0x00a792, /* 0x00a792 */
+	0x00a7c4, /* 0x00a794 */
+	0x00a796, /* 0x00a796 */
+	0x00a798, /* 0x00a798 */
+	0x00a79a, /* 0x00a79a */
+	0x00a79c, /* 0x00a79c */
+	0x00a79e, /* 0x00a79e */
+	0x00a7a0, /* 0x00a7a0 */
+	0x00a7a2, /* 0x00a7a2 */
+	0x00a7a4, /* 0x00a7a4 */
+	0x00a7a6, /* 0x00a7a6 */
+	0x00a7a8, /* 0x00a7a8 */
+	0x00a7b3, /* 0x00a7b3 */
+	0x00a7b4, /* 0x00a7b4 */
+	0x00a7b6, /* 0x00a7b6 */
+	0x00a7b8, /* 0x00a7b8 */
+	0x00a7ba, /* 0x00a7ba */
+	0x00a7bc, /* 0x00a7bc */
+	0x00a7be, /* 0x00a7be */
+	0x00a7c0, /* 0x00a7c0 */
+	0x00a7c2, /* 0x00a7c2 */
+	0x00a7c7, /* 0x00a7c7 */
+	0x00a7c9, /* 0x00a7c9 */
+	0x00a7d0, /* 0x00a7d0 */
+	0x00a7d6, /* 0x00a7d6 */
+	0x00a7d8, /* 0x00a7d8 */
+	0x00a7f5, /* 0x00a7f5 */
+	0x00fb00, /* 0x00fb00 */
+	0x00fb01, /* 0x00fb01 */
+	0x00fb02, /* 0x00fb02 */
+	0x00fb03, /* 0x00fb03 */
+	0x00fb04, /* 0x00fb04 */
+	0x00fb05, /* 0x00fb05 */
+	0x00fb06, /* 0x00fb06 */
+	0x00fb13, /* 0x00fb13 */
+	0x00fb14, /* 0x00fb14 */
+	0x00fb15, /* 0x00fb15 */
+	0x00fb16, /* 0x00fb16 */
+	0x00fb17, /* 0x00fb17 */
+	0x00ff21, /* 0x00ff21 */
+	0x00ff22, /* 0x00ff22 */
+	0x00ff23, /* 0x00ff23 */
+	0x00ff24, /* 0x00ff24 */
+	0x00ff25, /* 0x00ff25 */
+	0x00ff26, /* 0x00ff26 */
+	0x00ff27, /* 0x00ff27 */
+	0x00ff28, /* 0x00ff28 */
+	0x00ff29, /* 0x00ff29 */
+	0x00ff2a, /* 0x00ff2a */
+	0x00ff2b, /* 0x00ff2b */
+	0x00ff2c, /* 0x00ff2c */
+	0x00ff2d, /* 0x00ff2d */
+	0x00ff2e, /* 0x00ff2e */
+	0x00ff2f, /* 0x00ff2f */
+	0x00ff30, /* 0x00ff30 */
+	0x00ff31, /* 0x00ff31 */
+	0x00ff32, /* 0x00ff32 */
+	0x00ff33, /* 0x00ff33 */
+	0x00ff34, /* 0x00ff34 */
+	0x00ff35, /* 0x00ff35 */
+	0x00ff36, /* 0x00ff36 */
+	0x00ff37, /* 0x00ff37 */
+	0x00ff38, /* 0x00ff38 */
+	0x00ff39, /* 0x00ff39 */
+	0x00ff3a, /* 0x00ff3a */
+	0x010400, /* 0x010400 */
+	0x010401, /* 0x010401 */
+	0x010402, /* 0x010402 */
+	0x010403, /* 0x010403 */
+	0x010404, /* 0x010404 */
+	0x010405, /* 0x010405 */
+	0x010406, /* 0x010406 */
+	0x010407, /* 0x010407 */
+	0x010408, /* 0x010408 */
+	0x010409, /* 0x010409 */
+	0x01040a, /* 0x01040a */
+	0x01040b, /* 0x01040b */
+	0x01040c, /* 0x01040c */
+	0x01040d, /* 0x01040d */
+	0x01040e, /* 0x01040e */
+	0x01040f, /* 0x01040f */
+	0x010410, /* 0x010410 */
+	0x010411, /* 0x010411 */
+	0x010412, /* 0x010412 */
+	0x010413, /* 0x010413 */
+	0x010414, /* 0x010414 */
+	0x010415, /* 0x010415 */
+	0x010416, /* 0x010416 */
+	0x010417, /* 0x010417 */
+	0x010418, /* 0x010418 */
+	0x010419, /* 0x010419 */
+	0x01041a, /* 0x01041a */
+	0x01041b, /* 0x01041b */
+	0x01041c, /* 0x01041c */
+	0x01041d, /* 0x01041d */
+	0x01041e, /* 0x01041e */
+	0x01041f, /* 0x01041f */
+	0x010420, /* 0x010420 */
+	0x010421, /* 0x010421 */
+	0x010422, /* 0x010422 */
+	0x010423, /* 0x010423 */
+	0x010424, /* 0x010424 */
+	0x010425, /* 0x010425 */
+	0x010426, /* 0x010426 */
+	0x010427, /* 0x010427 */
+	0x0104b0, /* 0x0104b0 */
+	0x0104b1, /* 0x0104b1 */
+	0x0104b2, /* 0x0104b2 */
+	0x0104b3, /* 0x0104b3 */
+	0x0104b4, /* 0x0104b4 */
+	0x0104b5, /* 0x0104b5 */
+	0x0104b6, /* 0x0104b6 */
+	0x0104b7, /* 0x0104b7 */
+	0x0104b8, /* 0x0104b8 */
+	0x0104b9, /* 0x0104b9 */
+	0x0104ba, /* 0x0104ba */
+	0x0104bb, /* 0x0104bb */
+	0x0104bc, /* 0x0104bc */
+	0x0104bd, /* 0x0104bd */
+	0x0104be, /* 0x0104be */
+	0x0104bf, /* 0x0104bf */
+	0x0104c0, /* 0x0104c0 */
+	0x0104c1, /* 0x0104c1 */
+	0x0104c2, /* 0x0104c2 */
+	0x0104c3, /* 0x0104c3 */
+	0x0104c4, /* 0x0104c4 */
+	0x0104c5, /* 0x0104c5 */
+	0x0104c6, /* 0x0104c6 */
+	0x0104c7, /* 0x0104c7 */
+	0x0104c8, /* 0x0104c8 */
+	0x0104c9, /* 0x0104c9 */
+	0x0104ca, /* 0x0104ca */
+	0x0104cb, /* 0x0104cb */
+	0x0104cc, /* 0x0104cc */
+	0x0104cd, /* 0x0104cd */
+	0x0104ce, /* 0x0104ce */
+	0x0104cf, /* 0x0104cf */
+	0x0104d0, /* 0x0104d0 */
+	0x0104d1, /* 0x0104d1 */
+	0x0104d2, /* 0x0104d2 */
+	0x0104d3, /* 0x0104d3 */
+	0x010570, /* 0x010570 */
+	0x010571, /* 0x010571 */
+	0x010572, /* 0x010572 */
+	0x010573, /* 0x010573 */
+	0x010574, /* 0x010574 */
+	0x010575, /* 0x010575 */
+	0x010576, /* 0x010576 */
+	0x010577, /* 0x010577 */
+	0x010578, /* 0x010578 */
+	0x010579, /* 0x010579 */
+	0x01057a, /* 0x01057a */
+	0x01057c, /* 0x01057c */
+	0x01057d, /* 0x01057d */
+	0x01057e, /* 0x01057e */
+	0x01057f, /* 0x01057f */
+	0x010580, /* 0x010580 */
+	0x010581, /* 0x010581 */
+	0x010582, /* 0x010582 */
+	0x010583, /* 0x010583 */
+	0x010584, /* 0x010584 */
+	0x010585, /* 0x010585 */
+	0x010586, /* 0x010586 */
+	0x010587, /* 0x010587 */
+	0x010588, /* 0x010588 */
+	0x010589, /* 0x010589 */
+	0x01058a, /* 0x01058a */
+	0x01058c, /* 0x01058c */
+	0x01058d, /* 0x01058d */
+	0x01058e, /* 0x01058e */
+	0x01058f, /* 0x01058f */
+	0x010590, /* 0x010590 */
+	0x010591, /* 0x010591 */
+	0x010592, /* 0x010592 */
+	0x010594, /* 0x010594 */
+	0x010595, /* 0x010595 */
+	0x010c80, /* 0x010c80 */
+	0x010c81, /* 0x010c81 */
+	0x010c82, /* 0x010c82 */
+	0x010c83, /* 0x010c83 */
+	0x010c84, /* 0x010c84 */
+	0x010c85, /* 0x010c85 */
+	0x010c86, /* 0x010c86 */
+	0x010c87, /* 0x010c87 */
+	0x010c88, /* 0x010c88 */
+	0x010c89, /* 0x010c89 */
+	0x010c8a, /* 0x010c8a */
+	0x010c8b, /* 0x010c8b */
+	0x010c8c, /* 0x010c8c */
+	0x010c8d, /* 0x010c8d */
+	0x010c8e, /* 0x010c8e */
+	0x010c8f, /* 0x010c8f */
+	0x010c90, /* 0x010c90 */
+	0x010c91, /* 0x010c91 */
+	0x010c92, /* 0x010c92 */
+	0x010c93, /* 0x010c93 */
+	0x010c94, /* 0x010c94 */
+	0x010c95, /* 0x010c95 */
+	0x010c96, /* 0x010c96 */
+	0x010c97, /* 0x010c97 */
+	0x010c98, /* 0x010c98 */
+	0x010c99, /* 0x010c99 */
+	0x010c9a, /* 0x010c9a */
+	0x010c9b, /* 0x010c9b */
+	0x010c9c, /* 0x010c9c */
+	0x010c9d, /* 0x010c9d */
+	0x010c9e, /* 0x010c9e */
+	0x010c9f, /* 0x010c9f */
+	0x010ca0, /* 0x010ca0 */
+	0x010ca1, /* 0x010ca1 */
+	0x010ca2, /* 0x010ca2 */
+	0x010ca3, /* 0x010ca3 */
+	0x010ca4, /* 0x010ca4 */
+	0x010ca5, /* 0x010ca5 */
+	0x010ca6, /* 0x010ca6 */
+	0x010ca7, /* 0x010ca7 */
+	0x010ca8, /* 0x010ca8 */
+	0x010ca9, /* 0x010ca9 */
+	0x010caa, /* 0x010caa */
+	0x010cab, /* 0x010cab */
+	0x010cac, /* 0x010cac */
+	0x010cad, /* 0x010cad */
+	0x010cae, /* 0x010cae */
+	0x010caf, /* 0x010caf */
+	0x010cb0, /* 0x010cb0 */
+	0x010cb1, /* 0x010cb1 */
+	0x010cb2, /* 0x010cb2 */
+	0x0118a0, /* 0x0118a0 */
+	0x0118a1, /* 0x0118a1 */
+	0x0118a2, /* 0x0118a2 */
+	0x0118a3, /* 0x0118a3 */
+	0x0118a4, /* 0x0118a4 */
+	0x0118a5, /* 0x0118a5 */
+	0x0118a6, /* 0x0118a6 */
+	0x0118a7, /* 0x0118a7 */
+	0x0118a8, /* 0x0118a8 */
+	0x0118a9, /* 0x0118a9 */
+	0x0118aa, /* 0x0118aa */
+	0x0118ab, /* 0x0118ab */
+	0x0118ac, /* 0x0118ac */
+	0x0118ad, /* 0x0118ad */
+	0x0118ae, /* 0x0118ae */
+	0x0118af, /* 0x0118af */
+	0x0118b0, /* 0x0118b0 */
+	0x0118b1, /* 0x0118b1 */
+	0x0118b2, /* 0x0118b2 */
+	0x0118b3, /* 0x0118b3 */
+	0x0118b4, /* 0x0118b4 */
+	0x0118b5, /* 0x0118b5 */
+	0x0118b6, /* 0x0118b6 */
+	0x0118b7, /* 0x0118b7 */
+	0x0118b8, /* 0x0118b8 */
+	0x0118b9, /* 0x0118b9 */
+	0x0118ba, /* 0x0118ba */
+	0x0118bb, /* 0x0118bb */
+	0x0118bc, /* 0x0118bc */
+	0x0118bd, /* 0x0118bd */
+	0x0118be, /* 0x0118be */
+	0x0118bf, /* 0x0118bf */
+	0x016e40, /* 0x016e40 */
+	0x016e41, /* 0x016e41 */
+	0x016e42, /* 0x016e42 */
+	0x016e43, /* 0x016e43 */
+	0x016e44, /* 0x016e44 */
+	0x016e45, /* 0x016e45 */
+	0x016e46, /* 0x016e46 */
+	0x016e47, /* 0x016e47 */
+	0x016e48, /* 0x016e48 */
+	0x016e49, /* 0x016e49 */
+	0x016e4a, /* 0x016e4a */
+	0x016e4b, /* 0x016e4b */
+	0x016e4c, /* 0x016e4c */
+	0x016e4d, /* 0x016e4d */
+	0x016e4e, /* 0x016e4e */
+	0x016e4f, /* 0x016e4f */
+	0x016e50, /* 0x016e50 */
+	0x016e51, /* 0x016e51 */
+	0x016e52, /* 0x016e52 */
+	0x016e53, /* 0x016e53 */
+	0x016e54, /* 0x016e54 */
+	0x016e55, /* 0x016e55 */
+	0x016e56, /* 0x016e56 */
+	0x016e57, /* 0x016e57 */
+	0x016e58, /* 0x016e58 */
+	0x016e59, /* 0x016e59 */
+	0x016e5a, /* 0x016e5a */
+	0x016e5b, /* 0x016e5b */
+	0x016e5c, /* 0x016e5c */
+	0x016e5d, /* 0x016e5d */
+	0x016e5e, /* 0x016e5e */
+	0x016e5f, /* 0x016e5f */
+	0x01e900, /* 0x01e900 */
+	0x01e901, /* 0x01e901 */
+	0x01e902, /* 0x01e902 */
+	0x01e903, /* 0x01e903 */
+	0x01e904, /* 0x01e904 */
+	0x01e905, /* 0x01e905 */
+	0x01e906, /* 0x01e906 */
+	0x01e907, /* 0x01e907 */
+	0x01e908, /* 0x01e908 */
+	0x01e909, /* 0x01e909 */
+	0x01e90a, /* 0x01e90a */
+	0x01e90b, /* 0x01e90b */
+	0x01e90c, /* 0x01e90c */
+	0x01e90d, /* 0x01e90d */
+	0x01e90e, /* 0x01e90e */
+	0x01e90f, /* 0x01e90f */
+	0x01e910, /* 0x01e910 */
+	0x01e911, /* 0x01e911 */
+	0x01e912, /* 0x01e912 */
+	0x01e913, /* 0x01e913 */
+	0x01e914, /* 0x01e914 */
+	0x01e915, /* 0x01e915 */
+	0x01e916, /* 0x01e916 */
+	0x01e917, /* 0x01e917 */
+	0x01e918, /* 0x01e918 */
+	0x01e919, /* 0x01e919 */
+	0x01e91a, /* 0x01e91a */
+	0x01e91b, /* 0x01e91b */
+	0x01e91c, /* 0x01e91c */
+	0x01e91d, /* 0x01e91d */
+	0x01e91e, /* 0x01e91e */
+	0x01e91f, /* 0x01e91f */
+	0x01e920, /* 0x01e920 */
+	0x01e921, /* 0x01e921 */
 };
 
 /*
- * Case mapping table. Dense for codepoints < 0x80 (enabling fast lookup),
- * sparse for higher codepoints (requiring scan or binary search).
+ * Case mapping table for fold.
  */
-static const pg_case_map case_map[3003] =
+static uint32 case_map_fold[1677] =
 {
-	/* begin dense entries for codepoints < 0x80 */
-	{0x000000, {[CaseLower] = 0x000000,[CaseTitle] = 0x000000,[CaseUpper] = 0x000000,[CaseFold] = 0x000000}, NULL},
-	{0x000001, {[CaseLower] = 0x000001,[CaseTitle] = 0x000001,[CaseUpper] = 0x000001,[CaseFold] = 0x000001}, NULL},
-	{0x000002, {[CaseLower] = 0x000002,[CaseTitle] = 0x000002,[CaseUpper] = 0x000002,[CaseFold] = 0x000002}, NULL},
-	{0x000003, {[CaseLower] = 0x000003,[CaseTitle] = 0x000003,[CaseUpper] = 0x000003,[CaseFold] = 0x000003}, NULL},
-	{0x000004, {[CaseLower] = 0x000004,[CaseTitle] = 0x000004,[CaseUpper] = 0x000004,[CaseFold] = 0x000004}, NULL},
-	{0x000005, {[CaseLower] = 0x000005,[CaseTitle] = 0x000005,[CaseUpper] = 0x000005,[CaseFold] = 0x000005}, NULL},
-	{0x000006, {[CaseLower] = 0x000006,[CaseTitle] = 0x000006,[CaseUpper] = 0x000006,[CaseFold] = 0x000006}, NULL},
-	{0x000007, {[CaseLower] = 0x000007,[CaseTitle] = 0x000007,[CaseUpper] = 0x000007,[CaseFold] = 0x000007}, NULL},
-	{0x000008, {[CaseLower] = 0x000008,[CaseTitle] = 0x000008,[CaseUpper] = 0x000008,[CaseFold] = 0x000008}, NULL},
-	{0x000009, {[CaseLower] = 0x000009,[CaseTitle] = 0x000009,[CaseUpper] = 0x000009,[CaseFold] = 0x000009}, NULL},
-	{0x00000a, {[CaseLower] = 0x00000a,[CaseTitle] = 0x00000a,[CaseUpper] = 0x00000a,[CaseFold] = 0x00000a}, NULL},
-	{0x00000b, {[CaseLower] = 0x00000b,[CaseTitle] = 0x00000b,[CaseUpper] = 0x00000b,[CaseFold] = 0x00000b}, NULL},
-	{0x00000c, {[CaseLower] = 0x00000c,[CaseTitle] = 0x00000c,[CaseUpper] = 0x00000c,[CaseFold] = 0x00000c}, NULL},
-	{0x00000d, {[CaseLower] = 0x00000d,[CaseTitle] = 0x00000d,[CaseUpper] = 0x00000d,[CaseFold] = 0x00000d}, NULL},
-	{0x00000e, {[CaseLower] = 0x00000e,[CaseTitle] = 0x00000e,[CaseUpper] = 0x00000e,[CaseFold] = 0x00000e}, NULL},
-	{0x00000f, {[CaseLower] = 0x00000f,[CaseTitle] = 0x00000f,[CaseUpper] = 0x00000f,[CaseFold] = 0x00000f}, NULL},
-	{0x000010, {[CaseLower] = 0x000010,[CaseTitle] = 0x000010,[CaseUpper] = 0x000010,[CaseFold] = 0x000010}, NULL},
-	{0x000011, {[CaseLower] = 0x000011,[CaseTitle] = 0x000011,[CaseUpper] = 0x000011,[CaseFold] = 0x000011}, NULL},
-	{0x000012, {[CaseLower] = 0x000012,[CaseTitle] = 0x000012,[CaseUpper] = 0x000012,[CaseFold] = 0x000012}, NULL},
-	{0x000013, {[CaseLower] = 0x000013,[CaseTitle] = 0x000013,[CaseUpper] = 0x000013,[CaseFold] = 0x000013}, NULL},
-	{0x000014, {[CaseLower] = 0x000014,[CaseTitle] = 0x000014,[CaseUpper] = 0x000014,[CaseFold] = 0x000014}, NULL},
-	{0x000015, {[CaseLower] = 0x000015,[CaseTitle] = 0x000015,[CaseUpper] = 0x000015,[CaseFold] = 0x000015}, NULL},
-	{0x000016, {[CaseLower] = 0x000016,[CaseTitle] = 0x000016,[CaseUpper] = 0x000016,[CaseFold] = 0x000016}, NULL},
-	{0x000017, {[CaseLower] = 0x000017,[CaseTitle] = 0x000017,[CaseUpper] = 0x000017,[CaseFold] = 0x000017}, NULL},
-	{0x000018, {[CaseLower] = 0x000018,[CaseTitle] = 0x000018,[CaseUpper] = 0x000018,[CaseFold] = 0x000018}, NULL},
-	{0x000019, {[CaseLower] = 0x000019,[CaseTitle] = 0x000019,[CaseUpper] = 0x000019,[CaseFold] = 0x000019}, NULL},
-	{0x00001a, {[CaseLower] = 0x00001a,[CaseTitle] = 0x00001a,[CaseUpper] = 0x00001a,[CaseFold] = 0x00001a}, NULL},
-	{0x00001b, {[CaseLower] = 0x00001b,[CaseTitle] = 0x00001b,[CaseUpper] = 0x00001b,[CaseFold] = 0x00001b}, NULL},
-	{0x00001c, {[CaseLower] = 0x00001c,[CaseTitle] = 0x00001c,[CaseUpper] = 0x00001c,[CaseFold] = 0x00001c}, NULL},
-	{0x00001d, {[CaseLower] = 0x00001d,[CaseTitle] = 0x00001d,[CaseUpper] = 0x00001d,[CaseFold] = 0x00001d}, NULL},
-	{0x00001e, {[CaseLower] = 0x00001e,[CaseTitle] = 0x00001e,[CaseUpper] = 0x00001e,[CaseFold] = 0x00001e}, NULL},
-	{0x00001f, {[CaseLower] = 0x00001f,[CaseTitle] = 0x00001f,[CaseUpper] = 0x00001f,[CaseFold] = 0x00001f}, NULL},
-	{0x000020, {[CaseLower] = 0x000020,[CaseTitle] = 0x000020,[CaseUpper] = 0x000020,[CaseFold] = 0x000020}, NULL},
-	{0x000021, {[CaseLower] = 0x000021,[CaseTitle] = 0x000021,[CaseUpper] = 0x000021,[CaseFold] = 0x000021}, NULL},
-	{0x000022, {[CaseLower] = 0x000022,[CaseTitle] = 0x000022,[CaseUpper] = 0x000022,[CaseFold] = 0x000022}, NULL},
-	{0x000023, {[CaseLower] = 0x000023,[CaseTitle] = 0x000023,[CaseUpper] = 0x000023,[CaseFold] = 0x000023}, NULL},
-	{0x000024, {[CaseLower] = 0x000024,[CaseTitle] = 0x000024,[CaseUpper] = 0x000024,[CaseFold] = 0x000024}, NULL},
-	{0x000025, {[CaseLower] = 0x000025,[CaseTitle] = 0x000025,[CaseUpper] = 0x000025,[CaseFold] = 0x000025}, NULL},
-	{0x000026, {[CaseLower] = 0x000026,[CaseTitle] = 0x000026,[CaseUpper] = 0x000026,[CaseFold] = 0x000026}, NULL},
-	{0x000027, {[CaseLower] = 0x000027,[CaseTitle] = 0x000027,[CaseUpper] = 0x000027,[CaseFold] = 0x000027}, NULL},
-	{0x000028, {[CaseLower] = 0x000028,[CaseTitle] = 0x000028,[CaseUpper] = 0x000028,[CaseFold] = 0x000028}, NULL},
-	{0x000029, {[CaseLower] = 0x000029,[CaseTitle] = 0x000029,[CaseUpper] = 0x000029,[CaseFold] = 0x000029}, NULL},
-	{0x00002a, {[CaseLower] = 0x00002a,[CaseTitle] = 0x00002a,[CaseUpper] = 0x00002a,[CaseFold] = 0x00002a}, NULL},
-	{0x00002b, {[CaseLower] = 0x00002b,[CaseTitle] = 0x00002b,[CaseUpper] = 0x00002b,[CaseFold] = 0x00002b}, NULL},
-	{0x00002c, {[CaseLower] = 0x00002c,[CaseTitle] = 0x00002c,[CaseUpper] = 0x00002c,[CaseFold] = 0x00002c}, NULL},
-	{0x00002d, {[CaseLower] = 0x00002d,[CaseTitle] = 0x00002d,[CaseUpper] = 0x00002d,[CaseFold] = 0x00002d}, NULL},
-	{0x00002e, {[CaseLower] = 0x00002e,[CaseTitle] = 0x00002e,[CaseUpper] = 0x00002e,[CaseFold] = 0x00002e}, NULL},
-	{0x00002f, {[CaseLower] = 0x00002f,[CaseTitle] = 0x00002f,[CaseUpper] = 0x00002f,[CaseFold] = 0x00002f}, NULL},
-	{0x000030, {[CaseLower] = 0x000030,[CaseTitle] = 0x000030,[CaseUpper] = 0x000030,[CaseFold] = 0x000030}, NULL},
-	{0x000031, {[CaseLower] = 0x000031,[CaseTitle] = 0x000031,[CaseUpper] = 0x000031,[CaseFold] = 0x000031}, NULL},
-	{0x000032, {[CaseLower] = 0x000032,[CaseTitle] = 0x000032,[CaseUpper] = 0x000032,[CaseFold] = 0x000032}, NULL},
-	{0x000033, {[CaseLower] = 0x000033,[CaseTitle] = 0x000033,[CaseUpper] = 0x000033,[CaseFold] = 0x000033}, NULL},
-	{0x000034, {[CaseLower] = 0x000034,[CaseTitle] = 0x000034,[CaseUpper] = 0x000034,[CaseFold] = 0x000034}, NULL},
-	{0x000035, {[CaseLower] = 0x000035,[CaseTitle] = 0x000035,[CaseUpper] = 0x000035,[CaseFold] = 0x000035}, NULL},
-	{0x000036, {[CaseLower] = 0x000036,[CaseTitle] = 0x000036,[CaseUpper] = 0x000036,[CaseFold] = 0x000036}, NULL},
-	{0x000037, {[CaseLower] = 0x000037,[CaseTitle] = 0x000037,[CaseUpper] = 0x000037,[CaseFold] = 0x000037}, NULL},
-	{0x000038, {[CaseLower] = 0x000038,[CaseTitle] = 0x000038,[CaseUpper] = 0x000038,[CaseFold] = 0x000038}, NULL},
-	{0x000039, {[CaseLower] = 0x000039,[CaseTitle] = 0x000039,[CaseUpper] = 0x000039,[CaseFold] = 0x000039}, NULL},
-	{0x00003a, {[CaseLower] = 0x00003a,[CaseTitle] = 0x00003a,[CaseUpper] = 0x00003a,[CaseFold] = 0x00003a}, NULL},
-	{0x00003b, {[CaseLower] = 0x00003b,[CaseTitle] = 0x00003b,[CaseUpper] = 0x00003b,[CaseFold] = 0x00003b}, NULL},
-	{0x00003c, {[CaseLower] = 0x00003c,[CaseTitle] = 0x00003c,[CaseUpper] = 0x00003c,[CaseFold] = 0x00003c}, NULL},
-	{0x00003d, {[CaseLower] = 0x00003d,[CaseTitle] = 0x00003d,[CaseUpper] = 0x00003d,[CaseFold] = 0x00003d}, NULL},
-	{0x00003e, {[CaseLower] = 0x00003e,[CaseTitle] = 0x00003e,[CaseUpper] = 0x00003e,[CaseFold] = 0x00003e}, NULL},
-	{0x00003f, {[CaseLower] = 0x00003f,[CaseTitle] = 0x00003f,[CaseUpper] = 0x00003f,[CaseFold] = 0x00003f}, NULL},
-	{0x000040, {[CaseLower] = 0x000040,[CaseTitle] = 0x000040,[CaseUpper] = 0x000040,[CaseFold] = 0x000040}, NULL},
-	{0x000041, {[CaseLower] = 0x000061,[CaseTitle] = 0x000041,[CaseUpper] = 0x000041,[CaseFold] = 0x000061}, NULL},
-	{0x000042, {[CaseLower] = 0x000062,[CaseTitle] = 0x000042,[CaseUpper] = 0x000042,[CaseFold] = 0x000062}, NULL},
-	{0x000043, {[CaseLower] = 0x000063,[CaseTitle] = 0x000043,[CaseUpper] = 0x000043,[CaseFold] = 0x000063}, NULL},
-	{0x000044, {[CaseLower] = 0x000064,[CaseTitle] = 0x000044,[CaseUpper] = 0x000044,[CaseFold] = 0x000064}, NULL},
-	{0x000045, {[CaseLower] = 0x000065,[CaseTitle] = 0x000045,[CaseUpper] = 0x000045,[CaseFold] = 0x000065}, NULL},
-	{0x000046, {[CaseLower] = 0x000066,[CaseTitle] = 0x000046,[CaseUpper] = 0x000046,[CaseFold] = 0x000066}, NULL},
-	{0x000047, {[CaseLower] = 0x000067,[CaseTitle] = 0x000047,[CaseUpper] = 0x000047,[CaseFold] = 0x000067}, NULL},
-	{0x000048, {[CaseLower] = 0x000068,[CaseTitle] = 0x000048,[CaseUpper] = 0x000048,[CaseFold] = 0x000068}, NULL},
-	{0x000049, {[CaseLower] = 0x000069,[CaseTitle] = 0x000049,[CaseUpper] = 0x000049,[CaseFold] = 0x000069}, NULL},
-	{0x00004a, {[CaseLower] = 0x00006a,[CaseTitle] = 0x00004a,[CaseUpper] = 0x00004a,[CaseFold] = 0x00006a}, NULL},
-	{0x00004b, {[CaseLower] = 0x00006b,[CaseTitle] = 0x00004b,[CaseUpper] = 0x00004b,[CaseFold] = 0x00006b}, NULL},
-	{0x00004c, {[CaseLower] = 0x00006c,[CaseTitle] = 0x00004c,[CaseUpper] = 0x00004c,[CaseFold] = 0x00006c}, NULL},
-	{0x00004d, {[CaseLower] = 0x00006d,[CaseTitle] = 0x00004d,[CaseUpper] = 0x00004d,[CaseFold] = 0x00006d}, NULL},
-	{0x00004e, {[CaseLower] = 0x00006e,[CaseTitle] = 0x00004e,[CaseUpper] = 0x00004e,[CaseFold] = 0x00006e}, NULL},
-	{0x00004f, {[CaseLower] = 0x00006f,[CaseTitle] = 0x00004f,[CaseUpper] = 0x00004f,[CaseFold] = 0x00006f}, NULL},
-	{0x000050, {[CaseLower] = 0x000070,[CaseTitle] = 0x000050,[CaseUpper] = 0x000050,[CaseFold] = 0x000070}, NULL},
-	{0x000051, {[CaseLower] = 0x000071,[CaseTitle] = 0x000051,[CaseUpper] = 0x000051,[CaseFold] = 0x000071}, NULL},
-	{0x000052, {[CaseLower] = 0x000072,[CaseTitle] = 0x000052,[CaseUpper] = 0x000052,[CaseFold] = 0x000072}, NULL},
-	{0x000053, {[CaseLower] = 0x000073,[CaseTitle] = 0x000053,[CaseUpper] = 0x000053,[CaseFold] = 0x000073}, NULL},
-	{0x000054, {[CaseLower] = 0x000074,[CaseTitle] = 0x000054,[CaseUpper] = 0x000054,[CaseFold] = 0x000074}, NULL},
-	{0x000055, {[CaseLower] = 0x000075,[CaseTitle] = 0x000055,[CaseUpper] = 0x000055,[CaseFold] = 0x000075}, NULL},
-	{0x000056, {[CaseLower] = 0x000076,[CaseTitle] = 0x000056,[CaseUpper] = 0x000056,[CaseFold] = 0x000076}, NULL},
-	{0x000057, {[CaseLower] = 0x000077,[CaseTitle] = 0x000057,[CaseUpper] = 0x000057,[CaseFold] = 0x000077}, NULL},
-	{0x000058, {[CaseLower] = 0x000078,[CaseTitle] = 0x000058,[CaseUpper] = 0x000058,[CaseFold] = 0x000078}, NULL},
-	{0x000059, {[CaseLower] = 0x000079,[CaseTitle] = 0x000059,[CaseUpper] = 0x000059,[CaseFold] = 0x000079}, NULL},
-	{0x00005a, {[CaseLower] = 0x00007a,[CaseTitle] = 0x00005a,[CaseUpper] = 0x00005a,[CaseFold] = 0x00007a}, NULL},
-	{0x00005b, {[CaseLower] = 0x00005b,[CaseTitle] = 0x00005b,[CaseUpper] = 0x00005b,[CaseFold] = 0x00005b}, NULL},
-	{0x00005c, {[CaseLower] = 0x00005c,[CaseTitle] = 0x00005c,[CaseUpper] = 0x00005c,[CaseFold] = 0x00005c}, NULL},
-	{0x00005d, {[CaseLower] = 0x00005d,[CaseTitle] = 0x00005d,[CaseUpper] = 0x00005d,[CaseFold] = 0x00005d}, NULL},
-	{0x00005e, {[CaseLower] = 0x00005e,[CaseTitle] = 0x00005e,[CaseUpper] = 0x00005e,[CaseFold] = 0x00005e}, NULL},
-	{0x00005f, {[CaseLower] = 0x00005f,[CaseTitle] = 0x00005f,[CaseUpper] = 0x00005f,[CaseFold] = 0x00005f}, NULL},
-	{0x000060, {[CaseLower] = 0x000060,[CaseTitle] = 0x000060,[CaseUpper] = 0x000060,[CaseFold] = 0x000060}, NULL},
-	{0x000061, {[CaseLower] = 0x000061,[CaseTitle] = 0x000041,[CaseUpper] = 0x000041,[CaseFold] = 0x000061}, NULL},
-	{0x000062, {[CaseLower] = 0x000062,[CaseTitle] = 0x000042,[CaseUpper] = 0x000042,[CaseFold] = 0x000062}, NULL},
-	{0x000063, {[CaseLower] = 0x000063,[CaseTitle] = 0x000043,[CaseUpper] = 0x000043,[CaseFold] = 0x000063}, NULL},
-	{0x000064, {[CaseLower] = 0x000064,[CaseTitle] = 0x000044,[CaseUpper] = 0x000044,[CaseFold] = 0x000064}, NULL},
-	{0x000065, {[CaseLower] = 0x000065,[CaseTitle] = 0x000045,[CaseUpper] = 0x000045,[CaseFold] = 0x000065}, NULL},
-	{0x000066, {[CaseLower] = 0x000066,[CaseTitle] = 0x000046,[CaseUpper] = 0x000046,[CaseFold] = 0x000066}, NULL},
-	{0x000067, {[CaseLower] = 0x000067,[CaseTitle] = 0x000047,[CaseUpper] = 0x000047,[CaseFold] = 0x000067}, NULL},
-	{0x000068, {[CaseLower] = 0x000068,[CaseTitle] = 0x000048,[CaseUpper] = 0x000048,[CaseFold] = 0x000068}, NULL},
-	{0x000069, {[CaseLower] = 0x000069,[CaseTitle] = 0x000049,[CaseUpper] = 0x000049,[CaseFold] = 0x000069}, NULL},
-	{0x00006a, {[CaseLower] = 0x00006a,[CaseTitle] = 0x00004a,[CaseUpper] = 0x00004a,[CaseFold] = 0x00006a}, NULL},
-	{0x00006b, {[CaseLower] = 0x00006b,[CaseTitle] = 0x00004b,[CaseUpper] = 0x00004b,[CaseFold] = 0x00006b}, NULL},
-	{0x00006c, {[CaseLower] = 0x00006c,[CaseTitle] = 0x00004c,[CaseUpper] = 0x00004c,[CaseFold] = 0x00006c}, NULL},
-	{0x00006d, {[CaseLower] = 0x00006d,[CaseTitle] = 0x00004d,[CaseUpper] = 0x00004d,[CaseFold] = 0x00006d}, NULL},
-	{0x00006e, {[CaseLower] = 0x00006e,[CaseTitle] = 0x00004e,[CaseUpper] = 0x00004e,[CaseFold] = 0x00006e}, NULL},
-	{0x00006f, {[CaseLower] = 0x00006f,[CaseTitle] = 0x00004f,[CaseUpper] = 0x00004f,[CaseFold] = 0x00006f}, NULL},
-	{0x000070, {[CaseLower] = 0x000070,[CaseTitle] = 0x000050,[CaseUpper] = 0x000050,[CaseFold] = 0x000070}, NULL},
-	{0x000071, {[CaseLower] = 0x000071,[CaseTitle] = 0x000051,[CaseUpper] = 0x000051,[CaseFold] = 0x000071}, NULL},
-	{0x000072, {[CaseLower] = 0x000072,[CaseTitle] = 0x000052,[CaseUpper] = 0x000052,[CaseFold] = 0x000072}, NULL},
-	{0x000073, {[CaseLower] = 0x000073,[CaseTitle] = 0x000053,[CaseUpper] = 0x000053,[CaseFold] = 0x000073}, NULL},
-	{0x000074, {[CaseLower] = 0x000074,[CaseTitle] = 0x000054,[CaseUpper] = 0x000054,[CaseFold] = 0x000074}, NULL},
-	{0x000075, {[CaseLower] = 0x000075,[CaseTitle] = 0x000055,[CaseUpper] = 0x000055,[CaseFold] = 0x000075}, NULL},
-	{0x000076, {[CaseLower] = 0x000076,[CaseTitle] = 0x000056,[CaseUpper] = 0x000056,[CaseFold] = 0x000076}, NULL},
-	{0x000077, {[CaseLower] = 0x000077,[CaseTitle] = 0x000057,[CaseUpper] = 0x000057,[CaseFold] = 0x000077}, NULL},
-	{0x000078, {[CaseLower] = 0x000078,[CaseTitle] = 0x000058,[CaseUpper] = 0x000058,[CaseFold] = 0x000078}, NULL},
-	{0x000079, {[CaseLower] = 0x000079,[CaseTitle] = 0x000059,[CaseUpper] = 0x000059,[CaseFold] = 0x000079}, NULL},
-	{0x00007a, {[CaseLower] = 0x00007a,[CaseTitle] = 0x00005a,[CaseUpper] = 0x00005a,[CaseFold] = 0x00007a}, NULL},
-	{0x00007b, {[CaseLower] = 0x00007b,[CaseTitle] = 0x00007b,[CaseUpper] = 0x00007b,[CaseFold] = 0x00007b}, NULL},
-	{0x00007c, {[CaseLower] = 0x00007c,[CaseTitle] = 0x00007c,[CaseUpper] = 0x00007c,[CaseFold] = 0x00007c}, NULL},
-	{0x00007d, {[CaseLower] = 0x00007d,[CaseTitle] = 0x00007d,[CaseUpper] = 0x00007d,[CaseFold] = 0x00007d}, NULL},
-	{0x00007e, {[CaseLower] = 0x00007e,[CaseTitle] = 0x00007e,[CaseUpper] = 0x00007e,[CaseFold] = 0x00007e}, NULL},
-	{0x00007f, {[CaseLower] = 0x00007f,[CaseTitle] = 0x00007f,[CaseUpper] = 0x00007f,[CaseFold] = 0x00007f}, NULL},
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000000 */
+	0x000001, /* 0x000001 */
+	0x000002, /* 0x000002 */
+	0x000003, /* 0x000003 */
+	0x000004, /* 0x000004 */
+	0x000005, /* 0x000005 */
+	0x000006, /* 0x000006 */
+	0x000007, /* 0x000007 */
+	0x000008, /* 0x000008 */
+	0x000009, /* 0x000009 */
+	0x00000a, /* 0x00000a */
+	0x00000b, /* 0x00000b */
+	0x00000c, /* 0x00000c */
+	0x00000d, /* 0x00000d */
+	0x00000e, /* 0x00000e */
+	0x00000f, /* 0x00000f */
+	0x000010, /* 0x000010 */
+	0x000011, /* 0x000011 */
+	0x000012, /* 0x000012 */
+	0x000013, /* 0x000013 */
+	0x000014, /* 0x000014 */
+	0x000015, /* 0x000015 */
+	0x000016, /* 0x000016 */
+	0x000017, /* 0x000017 */
+	0x000018, /* 0x000018 */
+	0x000019, /* 0x000019 */
+	0x00001a, /* 0x00001a */
+	0x00001b, /* 0x00001b */
+	0x00001c, /* 0x00001c */
+	0x00001d, /* 0x00001d */
+	0x00001e, /* 0x00001e */
+	0x00001f, /* 0x00001f */
+	0x000020, /* 0x000020 */
+	0x000021, /* 0x000021 */
+	0x000022, /* 0x000022 */
+	0x000023, /* 0x000023 */
+	0x000024, /* 0x000024 */
+	0x000025, /* 0x000025 */
+	0x000026, /* 0x000026 */
+	0x000027, /* 0x000027 */
+	0x000028, /* 0x000028 */
+	0x000029, /* 0x000029 */
+	0x00002a, /* 0x00002a */
+	0x00002b, /* 0x00002b */
+	0x00002c, /* 0x00002c */
+	0x00002d, /* 0x00002d */
+	0x00002e, /* 0x00002e */
+	0x00002f, /* 0x00002f */
+	0x000030, /* 0x000030 */
+	0x000031, /* 0x000031 */
+	0x000032, /* 0x000032 */
+	0x000033, /* 0x000033 */
+	0x000034, /* 0x000034 */
+	0x000035, /* 0x000035 */
+	0x000036, /* 0x000036 */
+	0x000037, /* 0x000037 */
+	0x000038, /* 0x000038 */
+	0x000039, /* 0x000039 */
+	0x00003a, /* 0x00003a */
+	0x00003b, /* 0x00003b */
+	0x00003c, /* 0x00003c */
+	0x00003d, /* 0x00003d */
+	0x00003e, /* 0x00003e */
+	0x00003f, /* 0x00003f */
+	0x000040, /* 0x000040 */
+	0x000061, /* 0x000041 */
+	0x000062, /* 0x000042 */
+	0x000063, /* 0x000043 */
+	0x000064, /* 0x000044 */
+	0x000065, /* 0x000045 */
+	0x000066, /* 0x000046 */
+	0x000067, /* 0x000047 */
+	0x000068, /* 0x000048 */
+	0x000069, /* 0x000049 */
+	0x00006a, /* 0x00004a */
+	0x00006b, /* 0x00004b */
+	0x00006c, /* 0x00004c */
+	0x00006d, /* 0x00004d */
+	0x00006e, /* 0x00004e */
+	0x00006f, /* 0x00004f */
+	0x000070, /* 0x000050 */
+	0x000071, /* 0x000051 */
+	0x000072, /* 0x000052 */
+	0x000073, /* 0x000053 */
+	0x000074, /* 0x000054 */
+	0x000075, /* 0x000055 */
+	0x000076, /* 0x000056 */
+	0x000077, /* 0x000057 */
+	0x000078, /* 0x000058 */
+	0x000079, /* 0x000059 */
+	0x00007a, /* 0x00005a */
+	0x00005b, /* 0x00005b */
+	0x00005c, /* 0x00005c */
+	0x00005d, /* 0x00005d */
+	0x00005e, /* 0x00005e */
+	0x00005f, /* 0x00005f */
+	0x000060, /* 0x000060 */
+	0x000061, /* 0x000061 */
+	0x000062, /* 0x000062 */
+	0x000063, /* 0x000063 */
+	0x000064, /* 0x000064 */
+	0x000065, /* 0x000065 */
+	0x000066, /* 0x000066 */
+	0x000067, /* 0x000067 */
+	0x000068, /* 0x000068 */
+	0x000069, /* 0x000069 */
+	0x00006a, /* 0x00006a */
+	0x00006b, /* 0x00006b */
+	0x00006c, /* 0x00006c */
+	0x00006d, /* 0x00006d */
+	0x00006e, /* 0x00006e */
+	0x00006f, /* 0x00006f */
+	0x000070, /* 0x000070 */
+	0x000071, /* 0x000071 */
+	0x000072, /* 0x000072 */
+	0x000073, /* 0x000073 */
+	0x000074, /* 0x000074 */
+	0x000075, /* 0x000075 */
+	0x000076, /* 0x000076 */
+	0x000077, /* 0x000077 */
+	0x000078, /* 0x000078 */
+	0x000079, /* 0x000079 */
+	0x00007a, /* 0x00007a */
+	0x00007b, /* 0x00007b */
+	0x00007c, /* 0x00007c */
+	0x00007d, /* 0x00007d */
+	0x00007e, /* 0x00007e */
+	0x00007f, /* 0x00007f */
+	0x0003bc, /* 0x0000b5 */
+	0x0000e0, /* 0x0000c0 */
+	0x0000e1, /* 0x0000c1 */
+	0x0000e2, /* 0x0000c2 */
+	0x0000e3, /* 0x0000c3 */
+	0x0000e4, /* 0x0000c4 */
+	0x0000e5, /* 0x0000c5 */
+	0x0000e6, /* 0x0000c6 */
+	0x0000e7, /* 0x0000c7 */
+	0x0000e8, /* 0x0000c8 */
+	0x0000e9, /* 0x0000c9 */
+	0x0000ea, /* 0x0000ca */
+	0x0000eb, /* 0x0000cb */
+	0x0000ec, /* 0x0000cc */
+	0x0000ed, /* 0x0000cd */
+	0x0000ee, /* 0x0000ce */
+	0x0000ef, /* 0x0000cf */
+	0x0000f0, /* 0x0000d0 */
+	0x0000f1, /* 0x0000d1 */
+	0x0000f2, /* 0x0000d2 */
+	0x0000f3, /* 0x0000d3 */
+	0x0000f4, /* 0x0000d4 */
+	0x0000f5, /* 0x0000d5 */
+	0x0000f6, /* 0x0000d6 */
+	0x0000f8, /* 0x0000d8 */
+	0x0000f9, /* 0x0000d9 */
+	0x0000fa, /* 0x0000da */
+	0x0000fb, /* 0x0000db */
+	0x0000fc, /* 0x0000dc */
+	0x0000fd, /* 0x0000dd */
+	0x0000fe, /* 0x0000de */
+	0x0000df, /* 0x0000df */
+	0x0000ff, /* 0x0000ff */
+	0x000101, /* 0x000100 */
+	0x000103, /* 0x000102 */
+	0x000105, /* 0x000104 */
+	0x000107, /* 0x000106 */
+	0x000109, /* 0x000108 */
+	0x00010b, /* 0x00010a */
+	0x00010d, /* 0x00010c */
+	0x00010f, /* 0x00010e */
+	0x000111, /* 0x000110 */
+	0x000113, /* 0x000112 */
+	0x000115, /* 0x000114 */
+	0x000117, /* 0x000116 */
+	0x000119, /* 0x000118 */
+	0x00011b, /* 0x00011a */
+	0x00011d, /* 0x00011c */
+	0x00011f, /* 0x00011e */
+	0x000121, /* 0x000120 */
+	0x000123, /* 0x000122 */
+	0x000125, /* 0x000124 */
+	0x000127, /* 0x000126 */
+	0x000129, /* 0x000128 */
+	0x00012b, /* 0x00012a */
+	0x00012d, /* 0x00012c */
+	0x00012f, /* 0x00012e */
+	0x000130, /* 0x000130 */
+	0x000131, /* 0x000131 */
+	0x000133, /* 0x000132 */
+	0x000135, /* 0x000134 */
+	0x000137, /* 0x000136 */
+	0x00013a, /* 0x000139 */
+	0x00013c, /* 0x00013b */
+	0x00013e, /* 0x00013d */
+	0x000140, /* 0x00013f */
+	0x000142, /* 0x000141 */
+	0x000144, /* 0x000143 */
+	0x000146, /* 0x000145 */
+	0x000148, /* 0x000147 */
+	0x000149, /* 0x000149 */
+	0x00014b, /* 0x00014a */
+	0x00014d, /* 0x00014c */
+	0x00014f, /* 0x00014e */
+	0x000151, /* 0x000150 */
+	0x000153, /* 0x000152 */
+	0x000155, /* 0x000154 */
+	0x000157, /* 0x000156 */
+	0x000159, /* 0x000158 */
+	0x00015b, /* 0x00015a */
+	0x00015d, /* 0x00015c */
+	0x00015f, /* 0x00015e */
+	0x000161, /* 0x000160 */
+	0x000163, /* 0x000162 */
+	0x000165, /* 0x000164 */
+	0x000167, /* 0x000166 */
+	0x000169, /* 0x000168 */
+	0x00016b, /* 0x00016a */
+	0x00016d, /* 0x00016c */
+	0x00016f, /* 0x00016e */
+	0x000171, /* 0x000170 */
+	0x000173, /* 0x000172 */
+	0x000175, /* 0x000174 */
+	0x000177, /* 0x000176 */
+	0x00017a, /* 0x000179 */
+	0x00017c, /* 0x00017b */
+	0x00017e, /* 0x00017d */
+	0x000073, /* 0x00017f */
+	0x000180, /* 0x000180 */
+	0x000253, /* 0x000181 */
+	0x000183, /* 0x000182 */
+	0x000185, /* 0x000184 */
+	0x000254, /* 0x000186 */
+	0x000188, /* 0x000187 */
+	0x000256, /* 0x000189 */
+	0x000257, /* 0x00018a */
+	0x00018c, /* 0x00018b */
+	0x0001dd, /* 0x00018e */
+	0x000259, /* 0x00018f */
+	0x00025b, /* 0x000190 */
+	0x000192, /* 0x000191 */
+	0x000260, /* 0x000193 */
+	0x000263, /* 0x000194 */
+	0x000195, /* 0x000195 */
+	0x000269, /* 0x000196 */
+	0x000268, /* 0x000197 */
+	0x000199, /* 0x000198 */
+	0x00019a, /* 0x00019a */
+	0x00026f, /* 0x00019c */
+	0x000272, /* 0x00019d */
+	0x00019e, /* 0x00019e */
+	0x000275, /* 0x00019f */
+	0x0001a1, /* 0x0001a0 */
+	0x0001a3, /* 0x0001a2 */
+	0x0001a5, /* 0x0001a4 */
+	0x000280, /* 0x0001a6 */
+	0x0001a8, /* 0x0001a7 */
+	0x000283, /* 0x0001a9 */
+	0x0001ad, /* 0x0001ac */
+	0x000288, /* 0x0001ae */
+	0x0001b0, /* 0x0001af */
+	0x00028a, /* 0x0001b1 */
+	0x00028b, /* 0x0001b2 */
+	0x0001b4, /* 0x0001b3 */
+	0x0001b6, /* 0x0001b5 */
+	0x000292, /* 0x0001b7 */
+	0x0001b9, /* 0x0001b8 */
+	0x0001bd, /* 0x0001bc */
+	0x0001bf, /* 0x0001bf */
+	0x0001c6, /* 0x0001c4 */
+	0x0001c9, /* 0x0001c7 */
+	0x0001cc, /* 0x0001ca */
+	0x0001ce, /* 0x0001cd */
+	0x0001d0, /* 0x0001cf */
+	0x0001d2, /* 0x0001d1 */
+	0x0001d4, /* 0x0001d3 */
+	0x0001d6, /* 0x0001d5 */
+	0x0001d8, /* 0x0001d7 */
+	0x0001da, /* 0x0001d9 */
+	0x0001dc, /* 0x0001db */
+	0x0001df, /* 0x0001de */
+	0x0001e1, /* 0x0001e0 */
+	0x0001e3, /* 0x0001e2 */
+	0x0001e5, /* 0x0001e4 */
+	0x0001e7, /* 0x0001e6 */
+	0x0001e9, /* 0x0001e8 */
+	0x0001eb, /* 0x0001ea */
+	0x0001ed, /* 0x0001ec */
+	0x0001ef, /* 0x0001ee */
+	0x0001f0, /* 0x0001f0 */
+	0x0001f3, /* 0x0001f1 */
+	0x0001f5, /* 0x0001f4 */
+	0x0001f9, /* 0x0001f8 */
+	0x0001fb, /* 0x0001fa */
+	0x0001fd, /* 0x0001fc */
+	0x0001ff, /* 0x0001fe */
+	0x000201, /* 0x000200 */
+	0x000203, /* 0x000202 */
+	0x000205, /* 0x000204 */
+	0x000207, /* 0x000206 */
+	0x000209, /* 0x000208 */
+	0x00020b, /* 0x00020a */
+	0x00020d, /* 0x00020c */
+	0x00020f, /* 0x00020e */
+	0x000211, /* 0x000210 */
+	0x000213, /* 0x000212 */
+	0x000215, /* 0x000214 */
+	0x000217, /* 0x000216 */
+	0x000219, /* 0x000218 */
+	0x00021b, /* 0x00021a */
+	0x00021d, /* 0x00021c */
+	0x00021f, /* 0x00021e */
+	0x000223, /* 0x000222 */
+	0x000225, /* 0x000224 */
+	0x000227, /* 0x000226 */
+	0x000229, /* 0x000228 */
+	0x00022b, /* 0x00022a */
+	0x00022d, /* 0x00022c */
+	0x00022f, /* 0x00022e */
+	0x000231, /* 0x000230 */
+	0x000233, /* 0x000232 */
+	0x002c65, /* 0x00023a */
+	0x00023c, /* 0x00023b */
+	0x002c66, /* 0x00023e */
+	0x00023f, /* 0x00023f */
+	0x000240, /* 0x000240 */
+	0x000242, /* 0x000241 */
+	0x000289, /* 0x000244 */
+	0x00028c, /* 0x000245 */
+	0x000247, /* 0x000246 */
+	0x000249, /* 0x000248 */
+	0x00024b, /* 0x00024a */
+	0x00024d, /* 0x00024c */
+	0x00024f, /* 0x00024e */
+	0x000250, /* 0x000250 */
+	0x000251, /* 0x000251 */
+	0x000252, /* 0x000252 */
+	0x00025c, /* 0x00025c */
+	0x000261, /* 0x000261 */
+	0x000265, /* 0x000265 */
+	0x000266, /* 0x000266 */
+	0x00026a, /* 0x00026a */
+	0x00026b, /* 0x00026b */
+	0x00026c, /* 0x00026c */
+	0x000271, /* 0x000271 */
+	0x00027d, /* 0x00027d */
+	0x000282, /* 0x000282 */
+	0x000287, /* 0x000287 */
+	0x00029d, /* 0x00029d */
+	0x00029e, /* 0x00029e */
+	0x0003b9, /* 0x000345 */
+	0x000371, /* 0x000370 */
+	0x000373, /* 0x000372 */
+	0x000377, /* 0x000376 */
+	0x00037b, /* 0x00037b */
+	0x00037c, /* 0x00037c */
+	0x00037d, /* 0x00037d */
+	0x0003f3, /* 0x00037f */
+	0x0003ac, /* 0x000386 */
+	0x0003ad, /* 0x000388 */
+	0x0003ae, /* 0x000389 */
+	0x0003af, /* 0x00038a */
+	0x0003cc, /* 0x00038c */
+	0x0003cd, /* 0x00038e */
+	0x0003ce, /* 0x00038f */
+	0x000390, /* 0x000390 */
+	0x0003b1, /* 0x000391 */
+	0x0003b2, /* 0x000392 */
+	0x0003b3, /* 0x000393 */
+	0x0003b4, /* 0x000394 */
+	0x0003b5, /* 0x000395 */
+	0x0003b6, /* 0x000396 */
+	0x0003b7, /* 0x000397 */
+	0x0003b8, /* 0x000398 */
+	0x0003b9, /* 0x000399 */
+	0x0003ba, /* 0x00039a */
+	0x0003bb, /* 0x00039b */
+	0x0003bc, /* 0x00039c */
+	0x0003bd, /* 0x00039d */
+	0x0003be, /* 0x00039e */
+	0x0003bf, /* 0x00039f */
+	0x0003c0, /* 0x0003a0 */
+	0x0003c1, /* 0x0003a1 */
+	0x0003c3, /* 0x0003a3 */
+	0x0003c4, /* 0x0003a4 */
+	0x0003c5, /* 0x0003a5 */
+	0x0003c6, /* 0x0003a6 */
+	0x0003c7, /* 0x0003a7 */
+	0x0003c8, /* 0x0003a8 */
+	0x0003c9, /* 0x0003a9 */
+	0x0003ca, /* 0x0003aa */
+	0x0003cb, /* 0x0003ab */
+	0x0003b0, /* 0x0003b0 */
+	0x0003c3, /* 0x0003c2 */
+	0x0003c3, /* 0x0003c3 */
+	0x0003d7, /* 0x0003cf */
+	0x0003b2, /* 0x0003d0 */
+	0x0003b8, /* 0x0003d1 */
+	0x0003c6, /* 0x0003d5 */
+	0x0003c0, /* 0x0003d6 */
+	0x0003d9, /* 0x0003d8 */
+	0x0003db, /* 0x0003da */
+	0x0003dd, /* 0x0003dc */
+	0x0003df, /* 0x0003de */
+	0x0003e1, /* 0x0003e0 */
+	0x0003e3, /* 0x0003e2 */
+	0x0003e5, /* 0x0003e4 */
+	0x0003e7, /* 0x0003e6 */
+	0x0003e9, /* 0x0003e8 */
+	0x0003eb, /* 0x0003ea */
+	0x0003ed, /* 0x0003ec */
+	0x0003ef, /* 0x0003ee */
+	0x0003ba, /* 0x0003f0 */
+	0x0003c1, /* 0x0003f1 */
+	0x0003f2, /* 0x0003f2 */
+	0x0003b8, /* 0x0003f4 */
+	0x0003b5, /* 0x0003f5 */
+	0x0003f8, /* 0x0003f7 */
+	0x0003fb, /* 0x0003fa */
+	0x000450, /* 0x000400 */
+	0x000451, /* 0x000401 */
+	0x000452, /* 0x000402 */
+	0x000453, /* 0x000403 */
+	0x000454, /* 0x000404 */
+	0x000455, /* 0x000405 */
+	0x000456, /* 0x000406 */
+	0x000457, /* 0x000407 */
+	0x000458, /* 0x000408 */
+	0x000459, /* 0x000409 */
+	0x00045a, /* 0x00040a */
+	0x00045b, /* 0x00040b */
+	0x00045c, /* 0x00040c */
+	0x00045d, /* 0x00040d */
+	0x00045e, /* 0x00040e */
+	0x00045f, /* 0x00040f */
+	0x000430, /* 0x000410 */
+	0x000431, /* 0x000411 */
+	0x000432, /* 0x000412 */
+	0x000433, /* 0x000413 */
+	0x000434, /* 0x000414 */
+	0x000435, /* 0x000415 */
+	0x000436, /* 0x000416 */
+	0x000437, /* 0x000417 */
+	0x000438, /* 0x000418 */
+	0x000439, /* 0x000419 */
+	0x00043a, /* 0x00041a */
+	0x00043b, /* 0x00041b */
+	0x00043c, /* 0x00041c */
+	0x00043d, /* 0x00041d */
+	0x00043e, /* 0x00041e */
+	0x00043f, /* 0x00041f */
+	0x000440, /* 0x000420 */
+	0x000441, /* 0x000421 */
+	0x000442, /* 0x000422 */
+	0x000443, /* 0x000423 */
+	0x000444, /* 0x000424 */
+	0x000445, /* 0x000425 */
+	0x000446, /* 0x000426 */
+	0x000447, /* 0x000427 */
+	0x000448, /* 0x000428 */
+	0x000449, /* 0x000429 */
+	0x00044a, /* 0x00042a */
+	0x00044b, /* 0x00042b */
+	0x00044c, /* 0x00042c */
+	0x00044d, /* 0x00042d */
+	0x00044e, /* 0x00042e */
+	0x00044f, /* 0x00042f */
+	0x000461, /* 0x000460 */
+	0x000463, /* 0x000462 */
+	0x000465, /* 0x000464 */
+	0x000467, /* 0x000466 */
+	0x000469, /* 0x000468 */
+	0x00046b, /* 0x00046a */
+	0x00046d, /* 0x00046c */
+	0x00046f, /* 0x00046e */
+	0x000471, /* 0x000470 */
+	0x000473, /* 0x000472 */
+	0x000475, /* 0x000474 */
+	0x000477, /* 0x000476 */
+	0x000479, /* 0x000478 */
+	0x00047b, /* 0x00047a */
+	0x00047d, /* 0x00047c */
+	0x00047f, /* 0x00047e */
+	0x000481, /* 0x000480 */
+	0x00048b, /* 0x00048a */
+	0x00048d, /* 0x00048c */
+	0x00048f, /* 0x00048e */
+	0x000491, /* 0x000490 */
+	0x000493, /* 0x000492 */
+	0x000495, /* 0x000494 */
+	0x000497, /* 0x000496 */
+	0x000499, /* 0x000498 */
+	0x00049b, /* 0x00049a */
+	0x00049d, /* 0x00049c */
+	0x00049f, /* 0x00049e */
+	0x0004a1, /* 0x0004a0 */
+	0x0004a3, /* 0x0004a2 */
+	0x0004a5, /* 0x0004a4 */
+	0x0004a7, /* 0x0004a6 */
+	0x0004a9, /* 0x0004a8 */
+	0x0004ab, /* 0x0004aa */
+	0x0004ad, /* 0x0004ac */
+	0x0004af, /* 0x0004ae */
+	0x0004b1, /* 0x0004b0 */
+	0x0004b3, /* 0x0004b2 */
+	0x0004b5, /* 0x0004b4 */
+	0x0004b7, /* 0x0004b6 */
+	0x0004b9, /* 0x0004b8 */
+	0x0004bb, /* 0x0004ba */
+	0x0004bd, /* 0x0004bc */
+	0x0004bf, /* 0x0004be */
+	0x0004cf, /* 0x0004c0 */
+	0x0004c2, /* 0x0004c1 */
+	0x0004c4, /* 0x0004c3 */
+	0x0004c6, /* 0x0004c5 */
+	0x0004c8, /* 0x0004c7 */
+	0x0004ca, /* 0x0004c9 */
+	0x0004cc, /* 0x0004cb */
+	0x0004ce, /* 0x0004cd */
+	0x0004d1, /* 0x0004d0 */
+	0x0004d3, /* 0x0004d2 */
+	0x0004d5, /* 0x0004d4 */
+	0x0004d7, /* 0x0004d6 */
+	0x0004d9, /* 0x0004d8 */
+	0x0004db, /* 0x0004da */
+	0x0004dd, /* 0x0004dc */
+	0x0004df, /* 0x0004de */
+	0x0004e1, /* 0x0004e0 */
+	0x0004e3, /* 0x0004e2 */
+	0x0004e5, /* 0x0004e4 */
+	0x0004e7, /* 0x0004e6 */
+	0x0004e9, /* 0x0004e8 */
+	0x0004eb, /* 0x0004ea */
+	0x0004ed, /* 0x0004ec */
+	0x0004ef, /* 0x0004ee */
+	0x0004f1, /* 0x0004f0 */
+	0x0004f3, /* 0x0004f2 */
+	0x0004f5, /* 0x0004f4 */
+	0x0004f7, /* 0x0004f6 */
+	0x0004f9, /* 0x0004f8 */
+	0x0004fb, /* 0x0004fa */
+	0x0004fd, /* 0x0004fc */
+	0x0004ff, /* 0x0004fe */
+	0x000501, /* 0x000500 */
+	0x000503, /* 0x000502 */
+	0x000505, /* 0x000504 */
+	0x000507, /* 0x000506 */
+	0x000509, /* 0x000508 */
+	0x00050b, /* 0x00050a */
+	0x00050d, /* 0x00050c */
+	0x00050f, /* 0x00050e */
+	0x000511, /* 0x000510 */
+	0x000513, /* 0x000512 */
+	0x000515, /* 0x000514 */
+	0x000517, /* 0x000516 */
+	0x000519, /* 0x000518 */
+	0x00051b, /* 0x00051a */
+	0x00051d, /* 0x00051c */
+	0x00051f, /* 0x00051e */
+	0x000521, /* 0x000520 */
+	0x000523, /* 0x000522 */
+	0x000525, /* 0x000524 */
+	0x000527, /* 0x000526 */
+	0x000529, /* 0x000528 */
+	0x00052b, /* 0x00052a */
+	0x00052d, /* 0x00052c */
+	0x00052f, /* 0x00052e */
+	0x000561, /* 0x000531 */
+	0x000562, /* 0x000532 */
+	0x000563, /* 0x000533 */
+	0x000564, /* 0x000534 */
+	0x000565, /* 0x000535 */
+	0x000566, /* 0x000536 */
+	0x000567, /* 0x000537 */
+	0x000568, /* 0x000538 */
+	0x000569, /* 0x000539 */
+	0x00056a, /* 0x00053a */
+	0x00056b, /* 0x00053b */
+	0x00056c, /* 0x00053c */
+	0x00056d, /* 0x00053d */
+	0x00056e, /* 0x00053e */
+	0x00056f, /* 0x00053f */
+	0x000570, /* 0x000540 */
+	0x000571, /* 0x000541 */
+	0x000572, /* 0x000542 */
+	0x000573, /* 0x000543 */
+	0x000574, /* 0x000544 */
+	0x000575, /* 0x000545 */
+	0x000576, /* 0x000546 */
+	0x000577, /* 0x000547 */
+	0x000578, /* 0x000548 */
+	0x000579, /* 0x000549 */
+	0x00057a, /* 0x00054a */
+	0x00057b, /* 0x00054b */
+	0x00057c, /* 0x00054c */
+	0x00057d, /* 0x00054d */
+	0x00057e, /* 0x00054e */
+	0x00057f, /* 0x00054f */
+	0x000580, /* 0x000550 */
+	0x000581, /* 0x000551 */
+	0x000582, /* 0x000552 */
+	0x000583, /* 0x000553 */
+	0x000584, /* 0x000554 */
+	0x000585, /* 0x000555 */
+	0x000586, /* 0x000556 */
+	0x000587, /* 0x000587 */
+	0x002d00, /* 0x0010a0 */
+	0x002d01, /* 0x0010a1 */
+	0x002d02, /* 0x0010a2 */
+	0x002d03, /* 0x0010a3 */
+	0x002d04, /* 0x0010a4 */
+	0x002d05, /* 0x0010a5 */
+	0x002d06, /* 0x0010a6 */
+	0x002d07, /* 0x0010a7 */
+	0x002d08, /* 0x0010a8 */
+	0x002d09, /* 0x0010a9 */
+	0x002d0a, /* 0x0010aa */
+	0x002d0b, /* 0x0010ab */
+	0x002d0c, /* 0x0010ac */
+	0x002d0d, /* 0x0010ad */
+	0x002d0e, /* 0x0010ae */
+	0x002d0f, /* 0x0010af */
+	0x002d10, /* 0x0010b0 */
+	0x002d11, /* 0x0010b1 */
+	0x002d12, /* 0x0010b2 */
+	0x002d13, /* 0x0010b3 */
+	0x002d14, /* 0x0010b4 */
+	0x002d15, /* 0x0010b5 */
+	0x002d16, /* 0x0010b6 */
+	0x002d17, /* 0x0010b7 */
+	0x002d18, /* 0x0010b8 */
+	0x002d19, /* 0x0010b9 */
+	0x002d1a, /* 0x0010ba */
+	0x002d1b, /* 0x0010bb */
+	0x002d1c, /* 0x0010bc */
+	0x002d1d, /* 0x0010bd */
+	0x002d1e, /* 0x0010be */
+	0x002d1f, /* 0x0010bf */
+	0x002d20, /* 0x0010c0 */
+	0x002d21, /* 0x0010c1 */
+	0x002d22, /* 0x0010c2 */
+	0x002d23, /* 0x0010c3 */
+	0x002d24, /* 0x0010c4 */
+	0x002d25, /* 0x0010c5 */
+	0x002d27, /* 0x0010c7 */
+	0x002d2d, /* 0x0010cd */
+	0x0010d0, /* 0x0010d0 */
+	0x0010d1, /* 0x0010d1 */
+	0x0010d2, /* 0x0010d2 */
+	0x0010d3, /* 0x0010d3 */
+	0x0010d4, /* 0x0010d4 */
+	0x0010d5, /* 0x0010d5 */
+	0x0010d6, /* 0x0010d6 */
+	0x0010d7, /* 0x0010d7 */
+	0x0010d8, /* 0x0010d8 */
+	0x0010d9, /* 0x0010d9 */
+	0x0010da, /* 0x0010da */
+	0x0010db, /* 0x0010db */
+	0x0010dc, /* 0x0010dc */
+	0x0010dd, /* 0x0010dd */
+	0x0010de, /* 0x0010de */
+	0x0010df, /* 0x0010df */
+	0x0010e0, /* 0x0010e0 */
+	0x0010e1, /* 0x0010e1 */
+	0x0010e2, /* 0x0010e2 */
+	0x0010e3, /* 0x0010e3 */
+	0x0010e4, /* 0x0010e4 */
+	0x0010e5, /* 0x0010e5 */
+	0x0010e6, /* 0x0010e6 */
+	0x0010e7, /* 0x0010e7 */
+	0x0010e8, /* 0x0010e8 */
+	0x0010e9, /* 0x0010e9 */
+	0x0010ea, /* 0x0010ea */
+	0x0010eb, /* 0x0010eb */
+	0x0010ec, /* 0x0010ec */
+	0x0010ed, /* 0x0010ed */
+	0x0010ee, /* 0x0010ee */
+	0x0010ef, /* 0x0010ef */
+	0x0010f0, /* 0x0010f0 */
+	0x0010f1, /* 0x0010f1 */
+	0x0010f2, /* 0x0010f2 */
+	0x0010f3, /* 0x0010f3 */
+	0x0010f4, /* 0x0010f4 */
+	0x0010f5, /* 0x0010f5 */
+	0x0010f6, /* 0x0010f6 */
+	0x0010f7, /* 0x0010f7 */
+	0x0010f8, /* 0x0010f8 */
+	0x0010f9, /* 0x0010f9 */
+	0x0010fa, /* 0x0010fa */
+	0x0010fd, /* 0x0010fd */
+	0x0010fe, /* 0x0010fe */
+	0x0010ff, /* 0x0010ff */
+	0x0013a0, /* 0x0013a0 */
+	0x0013a1, /* 0x0013a1 */
+	0x0013a2, /* 0x0013a2 */
+	0x0013a3, /* 0x0013a3 */
+	0x0013a4, /* 0x0013a4 */
+	0x0013a5, /* 0x0013a5 */
+	0x0013a6, /* 0x0013a6 */
+	0x0013a7, /* 0x0013a7 */
+	0x0013a8, /* 0x0013a8 */
+	0x0013a9, /* 0x0013a9 */
+	0x0013aa, /* 0x0013aa */
+	0x0013ab, /* 0x0013ab */
+	0x0013ac, /* 0x0013ac */
+	0x0013ad, /* 0x0013ad */
+	0x0013ae, /* 0x0013ae */
+	0x0013af, /* 0x0013af */
+	0x0013b0, /* 0x0013b0 */
+	0x0013b1, /* 0x0013b1 */
+	0x0013b2, /* 0x0013b2 */
+	0x0013b3, /* 0x0013b3 */
+	0x0013b4, /* 0x0013b4 */
+	0x0013b5, /* 0x0013b5 */
+	0x0013b6, /* 0x0013b6 */
+	0x0013b7, /* 0x0013b7 */
+	0x0013b8, /* 0x0013b8 */
+	0x0013b9, /* 0x0013b9 */
+	0x0013ba, /* 0x0013ba */
+	0x0013bb, /* 0x0013bb */
+	0x0013bc, /* 0x0013bc */
+	0x0013bd, /* 0x0013bd */
+	0x0013be, /* 0x0013be */
+	0x0013bf, /* 0x0013bf */
+	0x0013c0, /* 0x0013c0 */
+	0x0013c1, /* 0x0013c1 */
+	0x0013c2, /* 0x0013c2 */
+	0x0013c3, /* 0x0013c3 */
+	0x0013c4, /* 0x0013c4 */
+	0x0013c5, /* 0x0013c5 */
+	0x0013c6, /* 0x0013c6 */
+	0x0013c7, /* 0x0013c7 */
+	0x0013c8, /* 0x0013c8 */
+	0x0013c9, /* 0x0013c9 */
+	0x0013ca, /* 0x0013ca */
+	0x0013cb, /* 0x0013cb */
+	0x0013cc, /* 0x0013cc */
+	0x0013cd, /* 0x0013cd */
+	0x0013ce, /* 0x0013ce */
+	0x0013cf, /* 0x0013cf */
+	0x0013d0, /* 0x0013d0 */
+	0x0013d1, /* 0x0013d1 */
+	0x0013d2, /* 0x0013d2 */
+	0x0013d3, /* 0x0013d3 */
+	0x0013d4, /* 0x0013d4 */
+	0x0013d5, /* 0x0013d5 */
+	0x0013d6, /* 0x0013d6 */
+	0x0013d7, /* 0x0013d7 */
+	0x0013d8, /* 0x0013d8 */
+	0x0013d9, /* 0x0013d9 */
+	0x0013da, /* 0x0013da */
+	0x0013db, /* 0x0013db */
+	0x0013dc, /* 0x0013dc */
+	0x0013dd, /* 0x0013dd */
+	0x0013de, /* 0x0013de */
+	0x0013df, /* 0x0013df */
+	0x0013e0, /* 0x0013e0 */
+	0x0013e1, /* 0x0013e1 */
+	0x0013e2, /* 0x0013e2 */
+	0x0013e3, /* 0x0013e3 */
+	0x0013e4, /* 0x0013e4 */
+	0x0013e5, /* 0x0013e5 */
+	0x0013e6, /* 0x0013e6 */
+	0x0013e7, /* 0x0013e7 */
+	0x0013e8, /* 0x0013e8 */
+	0x0013e9, /* 0x0013e9 */
+	0x0013ea, /* 0x0013ea */
+	0x0013eb, /* 0x0013eb */
+	0x0013ec, /* 0x0013ec */
+	0x0013ed, /* 0x0013ed */
+	0x0013ee, /* 0x0013ee */
+	0x0013ef, /* 0x0013ef */
+	0x0013f0, /* 0x0013f0 */
+	0x0013f1, /* 0x0013f1 */
+	0x0013f2, /* 0x0013f2 */
+	0x0013f3, /* 0x0013f3 */
+	0x0013f4, /* 0x0013f4 */
+	0x0013f5, /* 0x0013f5 */
+	0x000432, /* 0x001c80 */
+	0x000434, /* 0x001c81 */
+	0x00043e, /* 0x001c82 */
+	0x000441, /* 0x001c83 */
+	0x000442, /* 0x001c84 */
+	0x000442, /* 0x001c85 */
+	0x00044a, /* 0x001c86 */
+	0x000463, /* 0x001c87 */
+	0x00a64b, /* 0x001c88 */
+	0x0010d0, /* 0x001c90 */
+	0x0010d1, /* 0x001c91 */
+	0x0010d2, /* 0x001c92 */
+	0x0010d3, /* 0x001c93 */
+	0x0010d4, /* 0x001c94 */
+	0x0010d5, /* 0x001c95 */
+	0x0010d6, /* 0x001c96 */
+	0x0010d7, /* 0x001c97 */
+	0x0010d8, /* 0x001c98 */
+	0x0010d9, /* 0x001c99 */
+	0x0010da, /* 0x001c9a */
+	0x0010db, /* 0x001c9b */
+	0x0010dc, /* 0x001c9c */
+	0x0010dd, /* 0x001c9d */
+	0x0010de, /* 0x001c9e */
+	0x0010df, /* 0x001c9f */
+	0x0010e0, /* 0x001ca0 */
+	0x0010e1, /* 0x001ca1 */
+	0x0010e2, /* 0x001ca2 */
+	0x0010e3, /* 0x001ca3 */
+	0x0010e4, /* 0x001ca4 */
+	0x0010e5, /* 0x001ca5 */
+	0x0010e6, /* 0x001ca6 */
+	0x0010e7, /* 0x001ca7 */
+	0x0010e8, /* 0x001ca8 */
+	0x0010e9, /* 0x001ca9 */
+	0x0010ea, /* 0x001caa */
+	0x0010eb, /* 0x001cab */
+	0x0010ec, /* 0x001cac */
+	0x0010ed, /* 0x001cad */
+	0x0010ee, /* 0x001cae */
+	0x0010ef, /* 0x001caf */
+	0x0010f0, /* 0x001cb0 */
+	0x0010f1, /* 0x001cb1 */
+	0x0010f2, /* 0x001cb2 */
+	0x0010f3, /* 0x001cb3 */
+	0x0010f4, /* 0x001cb4 */
+	0x0010f5, /* 0x001cb5 */
+	0x0010f6, /* 0x001cb6 */
+	0x0010f7, /* 0x001cb7 */
+	0x0010f8, /* 0x001cb8 */
+	0x0010f9, /* 0x001cb9 */
+	0x0010fa, /* 0x001cba */
+	0x0010fd, /* 0x001cbd */
+	0x0010fe, /* 0x001cbe */
+	0x0010ff, /* 0x001cbf */
+	0x001d79, /* 0x001d79 */
+	0x001d7d, /* 0x001d7d */
+	0x001d8e, /* 0x001d8e */
+	0x001e01, /* 0x001e00 */
+	0x001e03, /* 0x001e02 */
+	0x001e05, /* 0x001e04 */
+	0x001e07, /* 0x001e06 */
+	0x001e09, /* 0x001e08 */
+	0x001e0b, /* 0x001e0a */
+	0x001e0d, /* 0x001e0c */
+	0x001e0f, /* 0x001e0e */
+	0x001e11, /* 0x001e10 */
+	0x001e13, /* 0x001e12 */
+	0x001e15, /* 0x001e14 */
+	0x001e17, /* 0x001e16 */
+	0x001e19, /* 0x001e18 */
+	0x001e1b, /* 0x001e1a */
+	0x001e1d, /* 0x001e1c */
+	0x001e1f, /* 0x001e1e */
+	0x001e21, /* 0x001e20 */
+	0x001e23, /* 0x001e22 */
+	0x001e25, /* 0x001e24 */
+	0x001e27, /* 0x001e26 */
+	0x001e29, /* 0x001e28 */
+	0x001e2b, /* 0x001e2a */
+	0x001e2d, /* 0x001e2c */
+	0x001e2f, /* 0x001e2e */
+	0x001e31, /* 0x001e30 */
+	0x001e33, /* 0x001e32 */
+	0x001e35, /* 0x001e34 */
+	0x001e37, /* 0x001e36 */
+	0x001e39, /* 0x001e38 */
+	0x001e3b, /* 0x001e3a */
+	0x001e3d, /* 0x001e3c */
+	0x001e3f, /* 0x001e3e */
+	0x001e41, /* 0x001e40 */
+	0x001e43, /* 0x001e42 */
+	0x001e45, /* 0x001e44 */
+	0x001e47, /* 0x001e46 */
+	0x001e49, /* 0x001e48 */
+	0x001e4b, /* 0x001e4a */
+	0x001e4d, /* 0x001e4c */
+	0x001e4f, /* 0x001e4e */
+	0x001e51, /* 0x001e50 */
+	0x001e53, /* 0x001e52 */
+	0x001e55, /* 0x001e54 */
+	0x001e57, /* 0x001e56 */
+	0x001e59, /* 0x001e58 */
+	0x001e5b, /* 0x001e5a */
+	0x001e5d, /* 0x001e5c */
+	0x001e5f, /* 0x001e5e */
+	0x001e61, /* 0x001e60 */
+	0x001e63, /* 0x001e62 */
+	0x001e65, /* 0x001e64 */
+	0x001e67, /* 0x001e66 */
+	0x001e69, /* 0x001e68 */
+	0x001e6b, /* 0x001e6a */
+	0x001e6d, /* 0x001e6c */
+	0x001e6f, /* 0x001e6e */
+	0x001e71, /* 0x001e70 */
+	0x001e73, /* 0x001e72 */
+	0x001e75, /* 0x001e74 */
+	0x001e77, /* 0x001e76 */
+	0x001e79, /* 0x001e78 */
+	0x001e7b, /* 0x001e7a */
+	0x001e7d, /* 0x001e7c */
+	0x001e7f, /* 0x001e7e */
+	0x001e81, /* 0x001e80 */
+	0x001e83, /* 0x001e82 */
+	0x001e85, /* 0x001e84 */
+	0x001e87, /* 0x001e86 */
+	0x001e89, /* 0x001e88 */
+	0x001e8b, /* 0x001e8a */
+	0x001e8d, /* 0x001e8c */
+	0x001e8f, /* 0x001e8e */
+	0x001e91, /* 0x001e90 */
+	0x001e93, /* 0x001e92 */
+	0x001e95, /* 0x001e94 */
+	0x001e96, /* 0x001e96 */
+	0x001e97, /* 0x001e97 */
+	0x001e98, /* 0x001e98 */
+	0x001e99, /* 0x001e99 */
+	0x001e9a, /* 0x001e9a */
+	0x001e61, /* 0x001e9b */
+	0x0000df, /* 0x001e9e */
+	0x001ea1, /* 0x001ea0 */
+	0x001ea3, /* 0x001ea2 */
+	0x001ea5, /* 0x001ea4 */
+	0x001ea7, /* 0x001ea6 */
+	0x001ea9, /* 0x001ea8 */
+	0x001eab, /* 0x001eaa */
+	0x001ead, /* 0x001eac */
+	0x001eaf, /* 0x001eae */
+	0x001eb1, /* 0x001eb0 */
+	0x001eb3, /* 0x001eb2 */
+	0x001eb5, /* 0x001eb4 */
+	0x001eb7, /* 0x001eb6 */
+	0x001eb9, /* 0x001eb8 */
+	0x001ebb, /* 0x001eba */
+	0x001ebd, /* 0x001ebc */
+	0x001ebf, /* 0x001ebe */
+	0x001ec1, /* 0x001ec0 */
+	0x001ec3, /* 0x001ec2 */
+	0x001ec5, /* 0x001ec4 */
+	0x001ec7, /* 0x001ec6 */
+	0x001ec9, /* 0x001ec8 */
+	0x001ecb, /* 0x001eca */
+	0x001ecd, /* 0x001ecc */
+	0x001ecf, /* 0x001ece */
+	0x001ed1, /* 0x001ed0 */
+	0x001ed3, /* 0x001ed2 */
+	0x001ed5, /* 0x001ed4 */
+	0x001ed7, /* 0x001ed6 */
+	0x001ed9, /* 0x001ed8 */
+	0x001edb, /* 0x001eda */
+	0x001edd, /* 0x001edc */
+	0x001edf, /* 0x001ede */
+	0x001ee1, /* 0x001ee0 */
+	0x001ee3, /* 0x001ee2 */
+	0x001ee5, /* 0x001ee4 */
+	0x001ee7, /* 0x001ee6 */
+	0x001ee9, /* 0x001ee8 */
+	0x001eeb, /* 0x001eea */
+	0x001eed, /* 0x001eec */
+	0x001eef, /* 0x001eee */
+	0x001ef1, /* 0x001ef0 */
+	0x001ef3, /* 0x001ef2 */
+	0x001ef5, /* 0x001ef4 */
+	0x001ef7, /* 0x001ef6 */
+	0x001ef9, /* 0x001ef8 */
+	0x001efb, /* 0x001efa */
+	0x001efd, /* 0x001efc */
+	0x001eff, /* 0x001efe */
+	0x001f00, /* 0x001f00 */
+	0x001f01, /* 0x001f01 */
+	0x001f02, /* 0x001f02 */
+	0x001f03, /* 0x001f03 */
+	0x001f04, /* 0x001f04 */
+	0x001f05, /* 0x001f05 */
+	0x001f06, /* 0x001f06 */
+	0x001f07, /* 0x001f07 */
+	0x001f10, /* 0x001f10 */
+	0x001f11, /* 0x001f11 */
+	0x001f12, /* 0x001f12 */
+	0x001f13, /* 0x001f13 */
+	0x001f14, /* 0x001f14 */
+	0x001f15, /* 0x001f15 */
+	0x001f20, /* 0x001f20 */
+	0x001f21, /* 0x001f21 */
+	0x001f22, /* 0x001f22 */
+	0x001f23, /* 0x001f23 */
+	0x001f24, /* 0x001f24 */
+	0x001f25, /* 0x001f25 */
+	0x001f26, /* 0x001f26 */
+	0x001f27, /* 0x001f27 */
+	0x001f30, /* 0x001f30 */
+	0x001f31, /* 0x001f31 */
+	0x001f32, /* 0x001f32 */
+	0x001f33, /* 0x001f33 */
+	0x001f34, /* 0x001f34 */
+	0x001f35, /* 0x001f35 */
+	0x001f36, /* 0x001f36 */
+	0x001f37, /* 0x001f37 */
+	0x001f40, /* 0x001f40 */
+	0x001f41, /* 0x001f41 */
+	0x001f42, /* 0x001f42 */
+	0x001f43, /* 0x001f43 */
+	0x001f44, /* 0x001f44 */
+	0x001f45, /* 0x001f45 */
+	0x001f50, /* 0x001f50 */
+	0x001f51, /* 0x001f51 */
+	0x001f52, /* 0x001f52 */
+	0x001f53, /* 0x001f53 */
+	0x001f54, /* 0x001f54 */
+	0x001f55, /* 0x001f55 */
+	0x001f56, /* 0x001f56 */
+	0x001f57, /* 0x001f57 */
+	0x001f60, /* 0x001f60 */
+	0x001f61, /* 0x001f61 */
+	0x001f62, /* 0x001f62 */
+	0x001f63, /* 0x001f63 */
+	0x001f64, /* 0x001f64 */
+	0x001f65, /* 0x001f65 */
+	0x001f66, /* 0x001f66 */
+	0x001f67, /* 0x001f67 */
+	0x001f70, /* 0x001f70 */
+	0x001f71, /* 0x001f71 */
+	0x001f72, /* 0x001f72 */
+	0x001f73, /* 0x001f73 */
+	0x001f74, /* 0x001f74 */
+	0x001f75, /* 0x001f75 */
+	0x001f76, /* 0x001f76 */
+	0x001f77, /* 0x001f77 */
+	0x001f78, /* 0x001f78 */
+	0x001f79, /* 0x001f79 */
+	0x001f7a, /* 0x001f7a */
+	0x001f7b, /* 0x001f7b */
+	0x001f7c, /* 0x001f7c */
+	0x001f7d, /* 0x001f7d */
+	0x001f80, /* 0x001f80 */
+	0x001f81, /* 0x001f81 */
+	0x001f82, /* 0x001f82 */
+	0x001f83, /* 0x001f83 */
+	0x001f84, /* 0x001f84 */
+	0x001f85, /* 0x001f85 */
+	0x001f86, /* 0x001f86 */
+	0x001f87, /* 0x001f87 */
+	0x001f80, /* 0x001f88 */
+	0x001f81, /* 0x001f89 */
+	0x001f82, /* 0x001f8a */
+	0x001f83, /* 0x001f8b */
+	0x001f84, /* 0x001f8c */
+	0x001f85, /* 0x001f8d */
+	0x001f86, /* 0x001f8e */
+	0x001f87, /* 0x001f8f */
+	0x001f90, /* 0x001f90 */
+	0x001f91, /* 0x001f91 */
+	0x001f92, /* 0x001f92 */
+	0x001f93, /* 0x001f93 */
+	0x001f94, /* 0x001f94 */
+	0x001f95, /* 0x001f95 */
+	0x001f96, /* 0x001f96 */
+	0x001f97, /* 0x001f97 */
+	0x001f90, /* 0x001f98 */
+	0x001f91, /* 0x001f99 */
+	0x001f92, /* 0x001f9a */
+	0x001f93, /* 0x001f9b */
+	0x001f94, /* 0x001f9c */
+	0x001f95, /* 0x001f9d */
+	0x001f96, /* 0x001f9e */
+	0x001f97, /* 0x001f9f */
+	0x001fa0, /* 0x001fa0 */
+	0x001fa1, /* 0x001fa1 */
+	0x001fa2, /* 0x001fa2 */
+	0x001fa3, /* 0x001fa3 */
+	0x001fa4, /* 0x001fa4 */
+	0x001fa5, /* 0x001fa5 */
+	0x001fa6, /* 0x001fa6 */
+	0x001fa7, /* 0x001fa7 */
+	0x001fa0, /* 0x001fa8 */
+	0x001fa1, /* 0x001fa9 */
+	0x001fa2, /* 0x001faa */
+	0x001fa3, /* 0x001fab */
+	0x001fa4, /* 0x001fac */
+	0x001fa5, /* 0x001fad */
+	0x001fa6, /* 0x001fae */
+	0x001fa7, /* 0x001faf */
+	0x001fb0, /* 0x001fb0 */
+	0x001fb1, /* 0x001fb1 */
+	0x001fb2, /* 0x001fb2 */
+	0x001fb3, /* 0x001fb3 */
+	0x001fb4, /* 0x001fb4 */
+	0x001fb6, /* 0x001fb6 */
+	0x001fb7, /* 0x001fb7 */
+	0x001fb3, /* 0x001fbc */
+	0x0003b9, /* 0x001fbe */
+	0x001fc2, /* 0x001fc2 */
+	0x001fc3, /* 0x001fc3 */
+	0x001fc4, /* 0x001fc4 */
+	0x001fc6, /* 0x001fc6 */
+	0x001fc7, /* 0x001fc7 */
+	0x001fc3, /* 0x001fcc */
+	0x001fd0, /* 0x001fd0 */
+	0x001fd1, /* 0x001fd1 */
+	0x001fd2, /* 0x001fd2 */
+	0x000390, /* 0x001fd3 */
+	0x001fd6, /* 0x001fd6 */
+	0x001fd7, /* 0x001fd7 */
+	0x001fe0, /* 0x001fe0 */
+	0x001fe1, /* 0x001fe1 */
+	0x001fe2, /* 0x001fe2 */
+	0x0003b0, /* 0x001fe3 */
+	0x001fe4, /* 0x001fe4 */
+	0x001fe5, /* 0x001fe5 */
+	0x001fe6, /* 0x001fe6 */
+	0x001fe7, /* 0x001fe7 */
+	0x001ff2, /* 0x001ff2 */
+	0x001ff3, /* 0x001ff3 */
+	0x001ff4, /* 0x001ff4 */
+	0x001ff6, /* 0x001ff6 */
+	0x001ff7, /* 0x001ff7 */
+	0x001ff3, /* 0x001ffc */
+	0x0003c9, /* 0x002126 */
+	0x00006b, /* 0x00212a */
+	0x0000e5, /* 0x00212b */
+	0x00214e, /* 0x002132 */
+	0x002170, /* 0x002160 */
+	0x002171, /* 0x002161 */
+	0x002172, /* 0x002162 */
+	0x002173, /* 0x002163 */
+	0x002174, /* 0x002164 */
+	0x002175, /* 0x002165 */
+	0x002176, /* 0x002166 */
+	0x002177, /* 0x002167 */
+	0x002178, /* 0x002168 */
+	0x002179, /* 0x002169 */
+	0x00217a, /* 0x00216a */
+	0x00217b, /* 0x00216b */
+	0x00217c, /* 0x00216c */
+	0x00217d, /* 0x00216d */
+	0x00217e, /* 0x00216e */
+	0x00217f, /* 0x00216f */
+	0x002184, /* 0x002183 */
+	0x0024d0, /* 0x0024b6 */
+	0x0024d1, /* 0x0024b7 */
+	0x0024d2, /* 0x0024b8 */
+	0x0024d3, /* 0x0024b9 */
+	0x0024d4, /* 0x0024ba */
+	0x0024d5, /* 0x0024bb */
+	0x0024d6, /* 0x0024bc */
+	0x0024d7, /* 0x0024bd */
+	0x0024d8, /* 0x0024be */
+	0x0024d9, /* 0x0024bf */
+	0x0024da, /* 0x0024c0 */
+	0x0024db, /* 0x0024c1 */
+	0x0024dc, /* 0x0024c2 */
+	0x0024dd, /* 0x0024c3 */
+	0x0024de, /* 0x0024c4 */
+	0x0024df, /* 0x0024c5 */
+	0x0024e0, /* 0x0024c6 */
+	0x0024e1, /* 0x0024c7 */
+	0x0024e2, /* 0x0024c8 */
+	0x0024e3, /* 0x0024c9 */
+	0x0024e4, /* 0x0024ca */
+	0x0024e5, /* 0x0024cb */
+	0x0024e6, /* 0x0024cc */
+	0x0024e7, /* 0x0024cd */
+	0x0024e8, /* 0x0024ce */
+	0x0024e9, /* 0x0024cf */
+	0x002c30, /* 0x002c00 */
+	0x002c31, /* 0x002c01 */
+	0x002c32, /* 0x002c02 */
+	0x002c33, /* 0x002c03 */
+	0x002c34, /* 0x002c04 */
+	0x002c35, /* 0x002c05 */
+	0x002c36, /* 0x002c06 */
+	0x002c37, /* 0x002c07 */
+	0x002c38, /* 0x002c08 */
+	0x002c39, /* 0x002c09 */
+	0x002c3a, /* 0x002c0a */
+	0x002c3b, /* 0x002c0b */
+	0x002c3c, /* 0x002c0c */
+	0x002c3d, /* 0x002c0d */
+	0x002c3e, /* 0x002c0e */
+	0x002c3f, /* 0x002c0f */
+	0x002c40, /* 0x002c10 */
+	0x002c41, /* 0x002c11 */
+	0x002c42, /* 0x002c12 */
+	0x002c43, /* 0x002c13 */
+	0x002c44, /* 0x002c14 */
+	0x002c45, /* 0x002c15 */
+	0x002c46, /* 0x002c16 */
+	0x002c47, /* 0x002c17 */
+	0x002c48, /* 0x002c18 */
+	0x002c49, /* 0x002c19 */
+	0x002c4a, /* 0x002c1a */
+	0x002c4b, /* 0x002c1b */
+	0x002c4c, /* 0x002c1c */
+	0x002c4d, /* 0x002c1d */
+	0x002c4e, /* 0x002c1e */
+	0x002c4f, /* 0x002c1f */
+	0x002c50, /* 0x002c20 */
+	0x002c51, /* 0x002c21 */
+	0x002c52, /* 0x002c22 */
+	0x002c53, /* 0x002c23 */
+	0x002c54, /* 0x002c24 */
+	0x002c55, /* 0x002c25 */
+	0x002c56, /* 0x002c26 */
+	0x002c57, /* 0x002c27 */
+	0x002c58, /* 0x002c28 */
+	0x002c59, /* 0x002c29 */
+	0x002c5a, /* 0x002c2a */
+	0x002c5b, /* 0x002c2b */
+	0x002c5c, /* 0x002c2c */
+	0x002c5d, /* 0x002c2d */
+	0x002c5e, /* 0x002c2e */
+	0x002c5f, /* 0x002c2f */
+	0x002c61, /* 0x002c60 */
+	0x002c68, /* 0x002c67 */
+	0x002c6a, /* 0x002c69 */
+	0x002c6c, /* 0x002c6b */
+	0x002c73, /* 0x002c72 */
+	0x002c76, /* 0x002c75 */
+	0x002c81, /* 0x002c80 */
+	0x002c83, /* 0x002c82 */
+	0x002c85, /* 0x002c84 */
+	0x002c87, /* 0x002c86 */
+	0x002c89, /* 0x002c88 */
+	0x002c8b, /* 0x002c8a */
+	0x002c8d, /* 0x002c8c */
+	0x002c8f, /* 0x002c8e */
+	0x002c91, /* 0x002c90 */
+	0x002c93, /* 0x002c92 */
+	0x002c95, /* 0x002c94 */
+	0x002c97, /* 0x002c96 */
+	0x002c99, /* 0x002c98 */
+	0x002c9b, /* 0x002c9a */
+	0x002c9d, /* 0x002c9c */
+	0x002c9f, /* 0x002c9e */
+	0x002ca1, /* 0x002ca0 */
+	0x002ca3, /* 0x002ca2 */
+	0x002ca5, /* 0x002ca4 */
+	0x002ca7, /* 0x002ca6 */
+	0x002ca9, /* 0x002ca8 */
+	0x002cab, /* 0x002caa */
+	0x002cad, /* 0x002cac */
+	0x002caf, /* 0x002cae */
+	0x002cb1, /* 0x002cb0 */
+	0x002cb3, /* 0x002cb2 */
+	0x002cb5, /* 0x002cb4 */
+	0x002cb7, /* 0x002cb6 */
+	0x002cb9, /* 0x002cb8 */
+	0x002cbb, /* 0x002cba */
+	0x002cbd, /* 0x002cbc */
+	0x002cbf, /* 0x002cbe */
+	0x002cc1, /* 0x002cc0 */
+	0x002cc3, /* 0x002cc2 */
+	0x002cc5, /* 0x002cc4 */
+	0x002cc7, /* 0x002cc6 */
+	0x002cc9, /* 0x002cc8 */
+	0x002ccb, /* 0x002cca */
+	0x002ccd, /* 0x002ccc */
+	0x002ccf, /* 0x002cce */
+	0x002cd1, /* 0x002cd0 */
+	0x002cd3, /* 0x002cd2 */
+	0x002cd5, /* 0x002cd4 */
+	0x002cd7, /* 0x002cd6 */
+	0x002cd9, /* 0x002cd8 */
+	0x002cdb, /* 0x002cda */
+	0x002cdd, /* 0x002cdc */
+	0x002cdf, /* 0x002cde */
+	0x002ce1, /* 0x002ce0 */
+	0x002ce3, /* 0x002ce2 */
+	0x002cec, /* 0x002ceb */
+	0x002cee, /* 0x002ced */
+	0x002cf3, /* 0x002cf2 */
+	0x00a641, /* 0x00a640 */
+	0x00a643, /* 0x00a642 */
+	0x00a645, /* 0x00a644 */
+	0x00a647, /* 0x00a646 */
+	0x00a649, /* 0x00a648 */
+	0x00a64b, /* 0x00a64a */
+	0x00a64d, /* 0x00a64c */
+	0x00a64f, /* 0x00a64e */
+	0x00a651, /* 0x00a650 */
+	0x00a653, /* 0x00a652 */
+	0x00a655, /* 0x00a654 */
+	0x00a657, /* 0x00a656 */
+	0x00a659, /* 0x00a658 */
+	0x00a65b, /* 0x00a65a */
+	0x00a65d, /* 0x00a65c */
+	0x00a65f, /* 0x00a65e */
+	0x00a661, /* 0x00a660 */
+	0x00a663, /* 0x00a662 */
+	0x00a665, /* 0x00a664 */
+	0x00a667, /* 0x00a666 */
+	0x00a669, /* 0x00a668 */
+	0x00a66b, /* 0x00a66a */
+	0x00a66d, /* 0x00a66c */
+	0x00a681, /* 0x00a680 */
+	0x00a683, /* 0x00a682 */
+	0x00a685, /* 0x00a684 */
+	0x00a687, /* 0x00a686 */
+	0x00a689, /* 0x00a688 */
+	0x00a68b, /* 0x00a68a */
+	0x00a68d, /* 0x00a68c */
+	0x00a68f, /* 0x00a68e */
+	0x00a691, /* 0x00a690 */
+	0x00a693, /* 0x00a692 */
+	0x00a695, /* 0x00a694 */
+	0x00a697, /* 0x00a696 */
+	0x00a699, /* 0x00a698 */
+	0x00a69b, /* 0x00a69a */
+	0x00a723, /* 0x00a722 */
+	0x00a725, /* 0x00a724 */
+	0x00a727, /* 0x00a726 */
+	0x00a729, /* 0x00a728 */
+	0x00a72b, /* 0x00a72a */
+	0x00a72d, /* 0x00a72c */
+	0x00a72f, /* 0x00a72e */
+	0x00a733, /* 0x00a732 */
+	0x00a735, /* 0x00a734 */
+	0x00a737, /* 0x00a736 */
+	0x00a739, /* 0x00a738 */
+	0x00a73b, /* 0x00a73a */
+	0x00a73d, /* 0x00a73c */
+	0x00a73f, /* 0x00a73e */
+	0x00a741, /* 0x00a740 */
+	0x00a743, /* 0x00a742 */
+	0x00a745, /* 0x00a744 */
+	0x00a747, /* 0x00a746 */
+	0x00a749, /* 0x00a748 */
+	0x00a74b, /* 0x00a74a */
+	0x00a74d, /* 0x00a74c */
+	0x00a74f, /* 0x00a74e */
+	0x00a751, /* 0x00a750 */
+	0x00a753, /* 0x00a752 */
+	0x00a755, /* 0x00a754 */
+	0x00a757, /* 0x00a756 */
+	0x00a759, /* 0x00a758 */
+	0x00a75b, /* 0x00a75a */
+	0x00a75d, /* 0x00a75c */
+	0x00a75f, /* 0x00a75e */
+	0x00a761, /* 0x00a760 */
+	0x00a763, /* 0x00a762 */
+	0x00a765, /* 0x00a764 */
+	0x00a767, /* 0x00a766 */
+	0x00a769, /* 0x00a768 */
+	0x00a76b, /* 0x00a76a */
+	0x00a76d, /* 0x00a76c */
+	0x00a76f, /* 0x00a76e */
+	0x00a77a, /* 0x00a779 */
+	0x00a77c, /* 0x00a77b */
+	0x00a77f, /* 0x00a77e */
+	0x00a781, /* 0x00a780 */
+	0x00a783, /* 0x00a782 */
+	0x00a785, /* 0x00a784 */
+	0x00a787, /* 0x00a786 */
+	0x00a78c, /* 0x00a78b */
+	0x00a791, /* 0x00a790 */
+	0x00a793, /* 0x00a792 */
+	0x00a794, /* 0x00a794 */
+	0x00a797, /* 0x00a796 */
+	0x00a799, /* 0x00a798 */
+	0x00a79b, /* 0x00a79a */
+	0x00a79d, /* 0x00a79c */
+	0x00a79f, /* 0x00a79e */
+	0x00a7a1, /* 0x00a7a0 */
+	0x00a7a3, /* 0x00a7a2 */
+	0x00a7a5, /* 0x00a7a4 */
+	0x00a7a7, /* 0x00a7a6 */
+	0x00a7a9, /* 0x00a7a8 */
+	0x00ab53, /* 0x00a7b3 */
+	0x00a7b5, /* 0x00a7b4 */
+	0x00a7b7, /* 0x00a7b6 */
+	0x00a7b9, /* 0x00a7b8 */
+	0x00a7bb, /* 0x00a7ba */
+	0x00a7bd, /* 0x00a7bc */
+	0x00a7bf, /* 0x00a7be */
+	0x00a7c1, /* 0x00a7c0 */
+	0x00a7c3, /* 0x00a7c2 */
+	0x00a7c8, /* 0x00a7c7 */
+	0x00a7ca, /* 0x00a7c9 */
+	0x00a7d1, /* 0x00a7d0 */
+	0x00a7d7, /* 0x00a7d6 */
+	0x00a7d9, /* 0x00a7d8 */
+	0x00a7f6, /* 0x00a7f5 */
+	0x00fb00, /* 0x00fb00 */
+	0x00fb01, /* 0x00fb01 */
+	0x00fb02, /* 0x00fb02 */
+	0x00fb03, /* 0x00fb03 */
+	0x00fb04, /* 0x00fb04 */
+	0x00fb06, /* 0x00fb05 */
+	0x00fb06, /* 0x00fb06 */
+	0x00fb13, /* 0x00fb13 */
+	0x00fb14, /* 0x00fb14 */
+	0x00fb15, /* 0x00fb15 */
+	0x00fb16, /* 0x00fb16 */
+	0x00fb17, /* 0x00fb17 */
+	0x00ff41, /* 0x00ff21 */
+	0x00ff42, /* 0x00ff22 */
+	0x00ff43, /* 0x00ff23 */
+	0x00ff44, /* 0x00ff24 */
+	0x00ff45, /* 0x00ff25 */
+	0x00ff46, /* 0x00ff26 */
+	0x00ff47, /* 0x00ff27 */
+	0x00ff48, /* 0x00ff28 */
+	0x00ff49, /* 0x00ff29 */
+	0x00ff4a, /* 0x00ff2a */
+	0x00ff4b, /* 0x00ff2b */
+	0x00ff4c, /* 0x00ff2c */
+	0x00ff4d, /* 0x00ff2d */
+	0x00ff4e, /* 0x00ff2e */
+	0x00ff4f, /* 0x00ff2f */
+	0x00ff50, /* 0x00ff30 */
+	0x00ff51, /* 0x00ff31 */
+	0x00ff52, /* 0x00ff32 */
+	0x00ff53, /* 0x00ff33 */
+	0x00ff54, /* 0x00ff34 */
+	0x00ff55, /* 0x00ff35 */
+	0x00ff56, /* 0x00ff36 */
+	0x00ff57, /* 0x00ff37 */
+	0x00ff58, /* 0x00ff38 */
+	0x00ff59, /* 0x00ff39 */
+	0x00ff5a, /* 0x00ff3a */
+	0x010428, /* 0x010400 */
+	0x010429, /* 0x010401 */
+	0x01042a, /* 0x010402 */
+	0x01042b, /* 0x010403 */
+	0x01042c, /* 0x010404 */
+	0x01042d, /* 0x010405 */
+	0x01042e, /* 0x010406 */
+	0x01042f, /* 0x010407 */
+	0x010430, /* 0x010408 */
+	0x010431, /* 0x010409 */
+	0x010432, /* 0x01040a */
+	0x010433, /* 0x01040b */
+	0x010434, /* 0x01040c */
+	0x010435, /* 0x01040d */
+	0x010436, /* 0x01040e */
+	0x010437, /* 0x01040f */
+	0x010438, /* 0x010410 */
+	0x010439, /* 0x010411 */
+	0x01043a, /* 0x010412 */
+	0x01043b, /* 0x010413 */
+	0x01043c, /* 0x010414 */
+	0x01043d, /* 0x010415 */
+	0x01043e, /* 0x010416 */
+	0x01043f, /* 0x010417 */
+	0x010440, /* 0x010418 */
+	0x010441, /* 0x010419 */
+	0x010442, /* 0x01041a */
+	0x010443, /* 0x01041b */
+	0x010444, /* 0x01041c */
+	0x010445, /* 0x01041d */
+	0x010446, /* 0x01041e */
+	0x010447, /* 0x01041f */
+	0x010448, /* 0x010420 */
+	0x010449, /* 0x010421 */
+	0x01044a, /* 0x010422 */
+	0x01044b, /* 0x010423 */
+	0x01044c, /* 0x010424 */
+	0x01044d, /* 0x010425 */
+	0x01044e, /* 0x010426 */
+	0x01044f, /* 0x010427 */
+	0x0104d8, /* 0x0104b0 */
+	0x0104d9, /* 0x0104b1 */
+	0x0104da, /* 0x0104b2 */
+	0x0104db, /* 0x0104b3 */
+	0x0104dc, /* 0x0104b4 */
+	0x0104dd, /* 0x0104b5 */
+	0x0104de, /* 0x0104b6 */
+	0x0104df, /* 0x0104b7 */
+	0x0104e0, /* 0x0104b8 */
+	0x0104e1, /* 0x0104b9 */
+	0x0104e2, /* 0x0104ba */
+	0x0104e3, /* 0x0104bb */
+	0x0104e4, /* 0x0104bc */
+	0x0104e5, /* 0x0104bd */
+	0x0104e6, /* 0x0104be */
+	0x0104e7, /* 0x0104bf */
+	0x0104e8, /* 0x0104c0 */
+	0x0104e9, /* 0x0104c1 */
+	0x0104ea, /* 0x0104c2 */
+	0x0104eb, /* 0x0104c3 */
+	0x0104ec, /* 0x0104c4 */
+	0x0104ed, /* 0x0104c5 */
+	0x0104ee, /* 0x0104c6 */
+	0x0104ef, /* 0x0104c7 */
+	0x0104f0, /* 0x0104c8 */
+	0x0104f1, /* 0x0104c9 */
+	0x0104f2, /* 0x0104ca */
+	0x0104f3, /* 0x0104cb */
+	0x0104f4, /* 0x0104cc */
+	0x0104f5, /* 0x0104cd */
+	0x0104f6, /* 0x0104ce */
+	0x0104f7, /* 0x0104cf */
+	0x0104f8, /* 0x0104d0 */
+	0x0104f9, /* 0x0104d1 */
+	0x0104fa, /* 0x0104d2 */
+	0x0104fb, /* 0x0104d3 */
+	0x010597, /* 0x010570 */
+	0x010598, /* 0x010571 */
+	0x010599, /* 0x010572 */
+	0x01059a, /* 0x010573 */
+	0x01059b, /* 0x010574 */
+	0x01059c, /* 0x010575 */
+	0x01059d, /* 0x010576 */
+	0x01059e, /* 0x010577 */
+	0x01059f, /* 0x010578 */
+	0x0105a0, /* 0x010579 */
+	0x0105a1, /* 0x01057a */
+	0x0105a3, /* 0x01057c */
+	0x0105a4, /* 0x01057d */
+	0x0105a5, /* 0x01057e */
+	0x0105a6, /* 0x01057f */
+	0x0105a7, /* 0x010580 */
+	0x0105a8, /* 0x010581 */
+	0x0105a9, /* 0x010582 */
+	0x0105aa, /* 0x010583 */
+	0x0105ab, /* 0x010584 */
+	0x0105ac, /* 0x010585 */
+	0x0105ad, /* 0x010586 */
+	0x0105ae, /* 0x010587 */
+	0x0105af, /* 0x010588 */
+	0x0105b0, /* 0x010589 */
+	0x0105b1, /* 0x01058a */
+	0x0105b3, /* 0x01058c */
+	0x0105b4, /* 0x01058d */
+	0x0105b5, /* 0x01058e */
+	0x0105b6, /* 0x01058f */
+	0x0105b7, /* 0x010590 */
+	0x0105b8, /* 0x010591 */
+	0x0105b9, /* 0x010592 */
+	0x0105bb, /* 0x010594 */
+	0x0105bc, /* 0x010595 */
+	0x010cc0, /* 0x010c80 */
+	0x010cc1, /* 0x010c81 */
+	0x010cc2, /* 0x010c82 */
+	0x010cc3, /* 0x010c83 */
+	0x010cc4, /* 0x010c84 */
+	0x010cc5, /* 0x010c85 */
+	0x010cc6, /* 0x010c86 */
+	0x010cc7, /* 0x010c87 */
+	0x010cc8, /* 0x010c88 */
+	0x010cc9, /* 0x010c89 */
+	0x010cca, /* 0x010c8a */
+	0x010ccb, /* 0x010c8b */
+	0x010ccc, /* 0x010c8c */
+	0x010ccd, /* 0x010c8d */
+	0x010cce, /* 0x010c8e */
+	0x010ccf, /* 0x010c8f */
+	0x010cd0, /* 0x010c90 */
+	0x010cd1, /* 0x010c91 */
+	0x010cd2, /* 0x010c92 */
+	0x010cd3, /* 0x010c93 */
+	0x010cd4, /* 0x010c94 */
+	0x010cd5, /* 0x010c95 */
+	0x010cd6, /* 0x010c96 */
+	0x010cd7, /* 0x010c97 */
+	0x010cd8, /* 0x010c98 */
+	0x010cd9, /* 0x010c99 */
+	0x010cda, /* 0x010c9a */
+	0x010cdb, /* 0x010c9b */
+	0x010cdc, /* 0x010c9c */
+	0x010cdd, /* 0x010c9d */
+	0x010cde, /* 0x010c9e */
+	0x010cdf, /* 0x010c9f */
+	0x010ce0, /* 0x010ca0 */
+	0x010ce1, /* 0x010ca1 */
+	0x010ce2, /* 0x010ca2 */
+	0x010ce3, /* 0x010ca3 */
+	0x010ce4, /* 0x010ca4 */
+	0x010ce5, /* 0x010ca5 */
+	0x010ce6, /* 0x010ca6 */
+	0x010ce7, /* 0x010ca7 */
+	0x010ce8, /* 0x010ca8 */
+	0x010ce9, /* 0x010ca9 */
+	0x010cea, /* 0x010caa */
+	0x010ceb, /* 0x010cab */
+	0x010cec, /* 0x010cac */
+	0x010ced, /* 0x010cad */
+	0x010cee, /* 0x010cae */
+	0x010cef, /* 0x010caf */
+	0x010cf0, /* 0x010cb0 */
+	0x010cf1, /* 0x010cb1 */
+	0x010cf2, /* 0x010cb2 */
+	0x0118c0, /* 0x0118a0 */
+	0x0118c1, /* 0x0118a1 */
+	0x0118c2, /* 0x0118a2 */
+	0x0118c3, /* 0x0118a3 */
+	0x0118c4, /* 0x0118a4 */
+	0x0118c5, /* 0x0118a5 */
+	0x0118c6, /* 0x0118a6 */
+	0x0118c7, /* 0x0118a7 */
+	0x0118c8, /* 0x0118a8 */
+	0x0118c9, /* 0x0118a9 */
+	0x0118ca, /* 0x0118aa */
+	0x0118cb, /* 0x0118ab */
+	0x0118cc, /* 0x0118ac */
+	0x0118cd, /* 0x0118ad */
+	0x0118ce, /* 0x0118ae */
+	0x0118cf, /* 0x0118af */
+	0x0118d0, /* 0x0118b0 */
+	0x0118d1, /* 0x0118b1 */
+	0x0118d2, /* 0x0118b2 */
+	0x0118d3, /* 0x0118b3 */
+	0x0118d4, /* 0x0118b4 */
+	0x0118d5, /* 0x0118b5 */
+	0x0118d6, /* 0x0118b6 */
+	0x0118d7, /* 0x0118b7 */
+	0x0118d8, /* 0x0118b8 */
+	0x0118d9, /* 0x0118b9 */
+	0x0118da, /* 0x0118ba */
+	0x0118db, /* 0x0118bb */
+	0x0118dc, /* 0x0118bc */
+	0x0118dd, /* 0x0118bd */
+	0x0118de, /* 0x0118be */
+	0x0118df, /* 0x0118bf */
+	0x016e60, /* 0x016e40 */
+	0x016e61, /* 0x016e41 */
+	0x016e62, /* 0x016e42 */
+	0x016e63, /* 0x016e43 */
+	0x016e64, /* 0x016e44 */
+	0x016e65, /* 0x016e45 */
+	0x016e66, /* 0x016e46 */
+	0x016e67, /* 0x016e47 */
+	0x016e68, /* 0x016e48 */
+	0x016e69, /* 0x016e49 */
+	0x016e6a, /* 0x016e4a */
+	0x016e6b, /* 0x016e4b */
+	0x016e6c, /* 0x016e4c */
+	0x016e6d, /* 0x016e4d */
+	0x016e6e, /* 0x016e4e */
+	0x016e6f, /* 0x016e4f */
+	0x016e70, /* 0x016e50 */
+	0x016e71, /* 0x016e51 */
+	0x016e72, /* 0x016e52 */
+	0x016e73, /* 0x016e53 */
+	0x016e74, /* 0x016e54 */
+	0x016e75, /* 0x016e55 */
+	0x016e76, /* 0x016e56 */
+	0x016e77, /* 0x016e57 */
+	0x016e78, /* 0x016e58 */
+	0x016e79, /* 0x016e59 */
+	0x016e7a, /* 0x016e5a */
+	0x016e7b, /* 0x016e5b */
+	0x016e7c, /* 0x016e5c */
+	0x016e7d, /* 0x016e5d */
+	0x016e7e, /* 0x016e5e */
+	0x016e7f, /* 0x016e5f */
+	0x01e922, /* 0x01e900 */
+	0x01e923, /* 0x01e901 */
+	0x01e924, /* 0x01e902 */
+	0x01e925, /* 0x01e903 */
+	0x01e926, /* 0x01e904 */
+	0x01e927, /* 0x01e905 */
+	0x01e928, /* 0x01e906 */
+	0x01e929, /* 0x01e907 */
+	0x01e92a, /* 0x01e908 */
+	0x01e92b, /* 0x01e909 */
+	0x01e92c, /* 0x01e90a */
+	0x01e92d, /* 0x01e90b */
+	0x01e92e, /* 0x01e90c */
+	0x01e92f, /* 0x01e90d */
+	0x01e930, /* 0x01e90e */
+	0x01e931, /* 0x01e90f */
+	0x01e932, /* 0x01e910 */
+	0x01e933, /* 0x01e911 */
+	0x01e934, /* 0x01e912 */
+	0x01e935, /* 0x01e913 */
+	0x01e936, /* 0x01e914 */
+	0x01e937, /* 0x01e915 */
+	0x01e938, /* 0x01e916 */
+	0x01e939, /* 0x01e917 */
+	0x01e93a, /* 0x01e918 */
+	0x01e93b, /* 0x01e919 */
+	0x01e93c, /* 0x01e91a */
+	0x01e93d, /* 0x01e91b */
+	0x01e93e, /* 0x01e91c */
+	0x01e93f, /* 0x01e91d */
+	0x01e940, /* 0x01e91e */
+	0x01e941, /* 0x01e91f */
+	0x01e942, /* 0x01e920 */
+	0x01e943, /* 0x01e921 */
+};
 
-	/* begin sparse entries for codepoints >= 0x80 */
-	{0x0000b5, {[CaseLower] = 0x0000b5,[CaseTitle] = 0x00039c,[CaseUpper] = 0x00039c,[CaseFold] = 0x0003bc}, NULL},
-	{0x0000c0, {[CaseLower] = 0x0000e0,[CaseTitle] = 0x0000c0,[CaseUpper] = 0x0000c0,[CaseFold] = 0x0000e0}, NULL},
-	{0x0000c1, {[CaseLower] = 0x0000e1,[CaseTitle] = 0x0000c1,[CaseUpper] = 0x0000c1,[CaseFold] = 0x0000e1}, NULL},
-	{0x0000c2, {[CaseLower] = 0x0000e2,[CaseTitle] = 0x0000c2,[CaseUpper] = 0x0000c2,[CaseFold] = 0x0000e2}, NULL},
-	{0x0000c3, {[CaseLower] = 0x0000e3,[CaseTitle] = 0x0000c3,[CaseUpper] = 0x0000c3,[CaseFold] = 0x0000e3}, NULL},
-	{0x0000c4, {[CaseLower] = 0x0000e4,[CaseTitle] = 0x0000c4,[CaseUpper] = 0x0000c4,[CaseFold] = 0x0000e4}, NULL},
-	{0x0000c5, {[CaseLower] = 0x0000e5,[CaseTitle] = 0x0000c5,[CaseUpper] = 0x0000c5,[CaseFold] = 0x0000e5}, NULL},
-	{0x0000c6, {[CaseLower] = 0x0000e6,[CaseTitle] = 0x0000c6,[CaseUpper] = 0x0000c6,[CaseFold] = 0x0000e6}, NULL},
-	{0x0000c7, {[CaseLower] = 0x0000e7,[CaseTitle] = 0x0000c7,[CaseUpper] = 0x0000c7,[CaseFold] = 0x0000e7}, NULL},
-	{0x0000c8, {[CaseLower] = 0x0000e8,[CaseTitle] = 0x0000c8,[CaseUpper] = 0x0000c8,[CaseFold] = 0x0000e8}, NULL},
-	{0x0000c9, {[CaseLower] = 0x0000e9,[CaseTitle] = 0x0000c9,[CaseUpper] = 0x0000c9,[CaseFold] = 0x0000e9}, NULL},
-	{0x0000ca, {[CaseLower] = 0x0000ea,[CaseTitle] = 0x0000ca,[CaseUpper] = 0x0000ca,[CaseFold] = 0x0000ea}, NULL},
-	{0x0000cb, {[CaseLower] = 0x0000eb,[CaseTitle] = 0x0000cb,[CaseUpper] = 0x0000cb,[CaseFold] = 0x0000eb}, NULL},
-	{0x0000cc, {[CaseLower] = 0x0000ec,[CaseTitle] = 0x0000cc,[CaseUpper] = 0x0000cc,[CaseFold] = 0x0000ec}, NULL},
-	{0x0000cd, {[CaseLower] = 0x0000ed,[CaseTitle] = 0x0000cd,[CaseUpper] = 0x0000cd,[CaseFold] = 0x0000ed}, NULL},
-	{0x0000ce, {[CaseLower] = 0x0000ee,[CaseTitle] = 0x0000ce,[CaseUpper] = 0x0000ce,[CaseFold] = 0x0000ee}, NULL},
-	{0x0000cf, {[CaseLower] = 0x0000ef,[CaseTitle] = 0x0000cf,[CaseUpper] = 0x0000cf,[CaseFold] = 0x0000ef}, NULL},
-	{0x0000d0, {[CaseLower] = 0x0000f0,[CaseTitle] = 0x0000d0,[CaseUpper] = 0x0000d0,[CaseFold] = 0x0000f0}, NULL},
-	{0x0000d1, {[CaseLower] = 0x0000f1,[CaseTitle] = 0x0000d1,[CaseUpper] = 0x0000d1,[CaseFold] = 0x0000f1}, NULL},
-	{0x0000d2, {[CaseLower] = 0x0000f2,[CaseTitle] = 0x0000d2,[CaseUpper] = 0x0000d2,[CaseFold] = 0x0000f2}, NULL},
-	{0x0000d3, {[CaseLower] = 0x0000f3,[CaseTitle] = 0x0000d3,[CaseUpper] = 0x0000d3,[CaseFold] = 0x0000f3}, NULL},
-	{0x0000d4, {[CaseLower] = 0x0000f4,[CaseTitle] = 0x0000d4,[CaseUpper] = 0x0000d4,[CaseFold] = 0x0000f4}, NULL},
-	{0x0000d5, {[CaseLower] = 0x0000f5,[CaseTitle] = 0x0000d5,[CaseUpper] = 0x0000d5,[CaseFold] = 0x0000f5}, NULL},
-	{0x0000d6, {[CaseLower] = 0x0000f6,[CaseTitle] = 0x0000d6,[CaseUpper] = 0x0000d6,[CaseFold] = 0x0000f6}, NULL},
-	{0x0000d8, {[CaseLower] = 0x0000f8,[CaseTitle] = 0x0000d8,[CaseUpper] = 0x0000d8,[CaseFold] = 0x0000f8}, NULL},
-	{0x0000d9, {[CaseLower] = 0x0000f9,[CaseTitle] = 0x0000d9,[CaseUpper] = 0x0000d9,[CaseFold] = 0x0000f9}, NULL},
-	{0x0000da, {[CaseLower] = 0x0000fa,[CaseTitle] = 0x0000da,[CaseUpper] = 0x0000da,[CaseFold] = 0x0000fa}, NULL},
-	{0x0000db, {[CaseLower] = 0x0000fb,[CaseTitle] = 0x0000db,[CaseUpper] = 0x0000db,[CaseFold] = 0x0000fb}, NULL},
-	{0x0000dc, {[CaseLower] = 0x0000fc,[CaseTitle] = 0x0000dc,[CaseUpper] = 0x0000dc,[CaseFold] = 0x0000fc}, NULL},
-	{0x0000dd, {[CaseLower] = 0x0000fd,[CaseTitle] = 0x0000dd,[CaseUpper] = 0x0000dd,[CaseFold] = 0x0000fd}, NULL},
-	{0x0000de, {[CaseLower] = 0x0000fe,[CaseTitle] = 0x0000de,[CaseUpper] = 0x0000de,[CaseFold] = 0x0000fe}, NULL},
-	{0x0000df, {[CaseLower] = 0x0000df,[CaseTitle] = 0x0000df,[CaseUpper] = 0x0000df,[CaseFold] = 0x0000df}, &special_case[0]},
-	{0x0000e0, {[CaseLower] = 0x0000e0,[CaseTitle] = 0x0000c0,[CaseUpper] = 0x0000c0,[CaseFold] = 0x0000e0}, NULL},
-	{0x0000e1, {[CaseLower] = 0x0000e1,[CaseTitle] = 0x0000c1,[CaseUpper] = 0x0000c1,[CaseFold] = 0x0000e1}, NULL},
-	{0x0000e2, {[CaseLower] = 0x0000e2,[CaseTitle] = 0x0000c2,[CaseUpper] = 0x0000c2,[CaseFold] = 0x0000e2}, NULL},
-	{0x0000e3, {[CaseLower] = 0x0000e3,[CaseTitle] = 0x0000c3,[CaseUpper] = 0x0000c3,[CaseFold] = 0x0000e3}, NULL},
-	{0x0000e4, {[CaseLower] = 0x0000e4,[CaseTitle] = 0x0000c4,[CaseUpper] = 0x0000c4,[CaseFold] = 0x0000e4}, NULL},
-	{0x0000e5, {[CaseLower] = 0x0000e5,[CaseTitle] = 0x0000c5,[CaseUpper] = 0x0000c5,[CaseFold] = 0x0000e5}, NULL},
-	{0x0000e6, {[CaseLower] = 0x0000e6,[CaseTitle] = 0x0000c6,[CaseUpper] = 0x0000c6,[CaseFold] = 0x0000e6}, NULL},
-	{0x0000e7, {[CaseLower] = 0x0000e7,[CaseTitle] = 0x0000c7,[CaseUpper] = 0x0000c7,[CaseFold] = 0x0000e7}, NULL},
-	{0x0000e8, {[CaseLower] = 0x0000e8,[CaseTitle] = 0x0000c8,[CaseUpper] = 0x0000c8,[CaseFold] = 0x0000e8}, NULL},
-	{0x0000e9, {[CaseLower] = 0x0000e9,[CaseTitle] = 0x0000c9,[CaseUpper] = 0x0000c9,[CaseFold] = 0x0000e9}, NULL},
-	{0x0000ea, {[CaseLower] = 0x0000ea,[CaseTitle] = 0x0000ca,[CaseUpper] = 0x0000ca,[CaseFold] = 0x0000ea}, NULL},
-	{0x0000eb, {[CaseLower] = 0x0000eb,[CaseTitle] = 0x0000cb,[CaseUpper] = 0x0000cb,[CaseFold] = 0x0000eb}, NULL},
-	{0x0000ec, {[CaseLower] = 0x0000ec,[CaseTitle] = 0x0000cc,[CaseUpper] = 0x0000cc,[CaseFold] = 0x0000ec}, NULL},
-	{0x0000ed, {[CaseLower] = 0x0000ed,[CaseTitle] = 0x0000cd,[CaseUpper] = 0x0000cd,[CaseFold] = 0x0000ed}, NULL},
-	{0x0000ee, {[CaseLower] = 0x0000ee,[CaseTitle] = 0x0000ce,[CaseUpper] = 0x0000ce,[CaseFold] = 0x0000ee}, NULL},
-	{0x0000ef, {[CaseLower] = 0x0000ef,[CaseTitle] = 0x0000cf,[CaseUpper] = 0x0000cf,[CaseFold] = 0x0000ef}, NULL},
-	{0x0000f0, {[CaseLower] = 0x0000f0,[CaseTitle] = 0x0000d0,[CaseUpper] = 0x0000d0,[CaseFold] = 0x0000f0}, NULL},
-	{0x0000f1, {[CaseLower] = 0x0000f1,[CaseTitle] = 0x0000d1,[CaseUpper] = 0x0000d1,[CaseFold] = 0x0000f1}, NULL},
-	{0x0000f2, {[CaseLower] = 0x0000f2,[CaseTitle] = 0x0000d2,[CaseUpper] = 0x0000d2,[CaseFold] = 0x0000f2}, NULL},
-	{0x0000f3, {[CaseLower] = 0x0000f3,[CaseTitle] = 0x0000d3,[CaseUpper] = 0x0000d3,[CaseFold] = 0x0000f3}, NULL},
-	{0x0000f4, {[CaseLower] = 0x0000f4,[CaseTitle] = 0x0000d4,[CaseUpper] = 0x0000d4,[CaseFold] = 0x0000f4}, NULL},
-	{0x0000f5, {[CaseLower] = 0x0000f5,[CaseTitle] = 0x0000d5,[CaseUpper] = 0x0000d5,[CaseFold] = 0x0000f5}, NULL},
-	{0x0000f6, {[CaseLower] = 0x0000f6,[CaseTitle] = 0x0000d6,[CaseUpper] = 0x0000d6,[CaseFold] = 0x0000f6}, NULL},
-	{0x0000f8, {[CaseLower] = 0x0000f8,[CaseTitle] = 0x0000d8,[CaseUpper] = 0x0000d8,[CaseFold] = 0x0000f8}, NULL},
-	{0x0000f9, {[CaseLower] = 0x0000f9,[CaseTitle] = 0x0000d9,[CaseUpper] = 0x0000d9,[CaseFold] = 0x0000f9}, NULL},
-	{0x0000fa, {[CaseLower] = 0x0000fa,[CaseTitle] = 0x0000da,[CaseUpper] = 0x0000da,[CaseFold] = 0x0000fa}, NULL},
-	{0x0000fb, {[CaseLower] = 0x0000fb,[CaseTitle] = 0x0000db,[CaseUpper] = 0x0000db,[CaseFold] = 0x0000fb}, NULL},
-	{0x0000fc, {[CaseLower] = 0x0000fc,[CaseTitle] = 0x0000dc,[CaseUpper] = 0x0000dc,[CaseFold] = 0x0000fc}, NULL},
-	{0x0000fd, {[CaseLower] = 0x0000fd,[CaseTitle] = 0x0000dd,[CaseUpper] = 0x0000dd,[CaseFold] = 0x0000fd}, NULL},
-	{0x0000fe, {[CaseLower] = 0x0000fe,[CaseTitle] = 0x0000de,[CaseUpper] = 0x0000de,[CaseFold] = 0x0000fe}, NULL},
-	{0x0000ff, {[CaseLower] = 0x0000ff,[CaseTitle] = 0x000178,[CaseUpper] = 0x000178,[CaseFold] = 0x0000ff}, NULL},
-	{0x000100, {[CaseLower] = 0x000101,[CaseTitle] = 0x000100,[CaseUpper] = 0x000100,[CaseFold] = 0x000101}, NULL},
-	{0x000101, {[CaseLower] = 0x000101,[CaseTitle] = 0x000100,[CaseUpper] = 0x000100,[CaseFold] = 0x000101}, NULL},
-	{0x000102, {[CaseLower] = 0x000103,[CaseTitle] = 0x000102,[CaseUpper] = 0x000102,[CaseFold] = 0x000103}, NULL},
-	{0x000103, {[CaseLower] = 0x000103,[CaseTitle] = 0x000102,[CaseUpper] = 0x000102,[CaseFold] = 0x000103}, NULL},
-	{0x000104, {[CaseLower] = 0x000105,[CaseTitle] = 0x000104,[CaseUpper] = 0x000104,[CaseFold] = 0x000105}, NULL},
-	{0x000105, {[CaseLower] = 0x000105,[CaseTitle] = 0x000104,[CaseUpper] = 0x000104,[CaseFold] = 0x000105}, NULL},
-	{0x000106, {[CaseLower] = 0x000107,[CaseTitle] = 0x000106,[CaseUpper] = 0x000106,[CaseFold] = 0x000107}, NULL},
-	{0x000107, {[CaseLower] = 0x000107,[CaseTitle] = 0x000106,[CaseUpper] = 0x000106,[CaseFold] = 0x000107}, NULL},
-	{0x000108, {[CaseLower] = 0x000109,[CaseTitle] = 0x000108,[CaseUpper] = 0x000108,[CaseFold] = 0x000109}, NULL},
-	{0x000109, {[CaseLower] = 0x000109,[CaseTitle] = 0x000108,[CaseUpper] = 0x000108,[CaseFold] = 0x000109}, NULL},
-	{0x00010a, {[CaseLower] = 0x00010b,[CaseTitle] = 0x00010a,[CaseUpper] = 0x00010a,[CaseFold] = 0x00010b}, NULL},
-	{0x00010b, {[CaseLower] = 0x00010b,[CaseTitle] = 0x00010a,[CaseUpper] = 0x00010a,[CaseFold] = 0x00010b}, NULL},
-	{0x00010c, {[CaseLower] = 0x00010d,[CaseTitle] = 0x00010c,[CaseUpper] = 0x00010c,[CaseFold] = 0x00010d}, NULL},
-	{0x00010d, {[CaseLower] = 0x00010d,[CaseTitle] = 0x00010c,[CaseUpper] = 0x00010c,[CaseFold] = 0x00010d}, NULL},
-	{0x00010e, {[CaseLower] = 0x00010f,[CaseTitle] = 0x00010e,[CaseUpper] = 0x00010e,[CaseFold] = 0x00010f}, NULL},
-	{0x00010f, {[CaseLower] = 0x00010f,[CaseTitle] = 0x00010e,[CaseUpper] = 0x00010e,[CaseFold] = 0x00010f}, NULL},
-	{0x000110, {[CaseLower] = 0x000111,[CaseTitle] = 0x000110,[CaseUpper] = 0x000110,[CaseFold] = 0x000111}, NULL},
-	{0x000111, {[CaseLower] = 0x000111,[CaseTitle] = 0x000110,[CaseUpper] = 0x000110,[CaseFold] = 0x000111}, NULL},
-	{0x000112, {[CaseLower] = 0x000113,[CaseTitle] = 0x000112,[CaseUpper] = 0x000112,[CaseFold] = 0x000113}, NULL},
-	{0x000113, {[CaseLower] = 0x000113,[CaseTitle] = 0x000112,[CaseUpper] = 0x000112,[CaseFold] = 0x000113}, NULL},
-	{0x000114, {[CaseLower] = 0x000115,[CaseTitle] = 0x000114,[CaseUpper] = 0x000114,[CaseFold] = 0x000115}, NULL},
-	{0x000115, {[CaseLower] = 0x000115,[CaseTitle] = 0x000114,[CaseUpper] = 0x000114,[CaseFold] = 0x000115}, NULL},
-	{0x000116, {[CaseLower] = 0x000117,[CaseTitle] = 0x000116,[CaseUpper] = 0x000116,[CaseFold] = 0x000117}, NULL},
-	{0x000117, {[CaseLower] = 0x000117,[CaseTitle] = 0x000116,[CaseUpper] = 0x000116,[CaseFold] = 0x000117}, NULL},
-	{0x000118, {[CaseLower] = 0x000119,[CaseTitle] = 0x000118,[CaseUpper] = 0x000118,[CaseFold] = 0x000119}, NULL},
-	{0x000119, {[CaseLower] = 0x000119,[CaseTitle] = 0x000118,[CaseUpper] = 0x000118,[CaseFold] = 0x000119}, NULL},
-	{0x00011a, {[CaseLower] = 0x00011b,[CaseTitle] = 0x00011a,[CaseUpper] = 0x00011a,[CaseFold] = 0x00011b}, NULL},
-	{0x00011b, {[CaseLower] = 0x00011b,[CaseTitle] = 0x00011a,[CaseUpper] = 0x00011a,[CaseFold] = 0x00011b}, NULL},
-	{0x00011c, {[CaseLower] = 0x00011d,[CaseTitle] = 0x00011c,[CaseUpper] = 0x00011c,[CaseFold] = 0x00011d}, NULL},
-	{0x00011d, {[CaseLower] = 0x00011d,[CaseTitle] = 0x00011c,[CaseUpper] = 0x00011c,[CaseFold] = 0x00011d}, NULL},
-	{0x00011e, {[CaseLower] = 0x00011f,[CaseTitle] = 0x00011e,[CaseUpper] = 0x00011e,[CaseFold] = 0x00011f}, NULL},
-	{0x00011f, {[CaseLower] = 0x00011f,[CaseTitle] = 0x00011e,[CaseUpper] = 0x00011e,[CaseFold] = 0x00011f}, NULL},
-	{0x000120, {[CaseLower] = 0x000121,[CaseTitle] = 0x000120,[CaseUpper] = 0x000120,[CaseFold] = 0x000121}, NULL},
-	{0x000121, {[CaseLower] = 0x000121,[CaseTitle] = 0x000120,[CaseUpper] = 0x000120,[CaseFold] = 0x000121}, NULL},
-	{0x000122, {[CaseLower] = 0x000123,[CaseTitle] = 0x000122,[CaseUpper] = 0x000122,[CaseFold] = 0x000123}, NULL},
-	{0x000123, {[CaseLower] = 0x000123,[CaseTitle] = 0x000122,[CaseUpper] = 0x000122,[CaseFold] = 0x000123}, NULL},
-	{0x000124, {[CaseLower] = 0x000125,[CaseTitle] = 0x000124,[CaseUpper] = 0x000124,[CaseFold] = 0x000125}, NULL},
-	{0x000125, {[CaseLower] = 0x000125,[CaseTitle] = 0x000124,[CaseUpper] = 0x000124,[CaseFold] = 0x000125}, NULL},
-	{0x000126, {[CaseLower] = 0x000127,[CaseTitle] = 0x000126,[CaseUpper] = 0x000126,[CaseFold] = 0x000127}, NULL},
-	{0x000127, {[CaseLower] = 0x000127,[CaseTitle] = 0x000126,[CaseUpper] = 0x000126,[CaseFold] = 0x000127}, NULL},
-	{0x000128, {[CaseLower] = 0x000129,[CaseTitle] = 0x000128,[CaseUpper] = 0x000128,[CaseFold] = 0x000129}, NULL},
-	{0x000129, {[CaseLower] = 0x000129,[CaseTitle] = 0x000128,[CaseUpper] = 0x000128,[CaseFold] = 0x000129}, NULL},
-	{0x00012a, {[CaseLower] = 0x00012b,[CaseTitle] = 0x00012a,[CaseUpper] = 0x00012a,[CaseFold] = 0x00012b}, NULL},
-	{0x00012b, {[CaseLower] = 0x00012b,[CaseTitle] = 0x00012a,[CaseUpper] = 0x00012a,[CaseFold] = 0x00012b}, NULL},
-	{0x00012c, {[CaseLower] = 0x00012d,[CaseTitle] = 0x00012c,[CaseUpper] = 0x00012c,[CaseFold] = 0x00012d}, NULL},
-	{0x00012d, {[CaseLower] = 0x00012d,[CaseTitle] = 0x00012c,[CaseUpper] = 0x00012c,[CaseFold] = 0x00012d}, NULL},
-	{0x00012e, {[CaseLower] = 0x00012f,[CaseTitle] = 0x00012e,[CaseUpper] = 0x00012e,[CaseFold] = 0x00012f}, NULL},
-	{0x00012f, {[CaseLower] = 0x00012f,[CaseTitle] = 0x00012e,[CaseUpper] = 0x00012e,[CaseFold] = 0x00012f}, NULL},
-	{0x000130, {[CaseLower] = 0x000069,[CaseTitle] = 0x000130,[CaseUpper] = 0x000130,[CaseFold] = 0x000130}, &special_case[1]},
-	{0x000131, {[CaseLower] = 0x000131,[CaseTitle] = 0x000049,[CaseUpper] = 0x000049,[CaseFold] = 0x000131}, NULL},
-	{0x000132, {[CaseLower] = 0x000133,[CaseTitle] = 0x000132,[CaseUpper] = 0x000132,[CaseFold] = 0x000133}, NULL},
-	{0x000133, {[CaseLower] = 0x000133,[CaseTitle] = 0x000132,[CaseUpper] = 0x000132,[CaseFold] = 0x000133}, NULL},
-	{0x000134, {[CaseLower] = 0x000135,[CaseTitle] = 0x000134,[CaseUpper] = 0x000134,[CaseFold] = 0x000135}, NULL},
-	{0x000135, {[CaseLower] = 0x000135,[CaseTitle] = 0x000134,[CaseUpper] = 0x000134,[CaseFold] = 0x000135}, NULL},
-	{0x000136, {[CaseLower] = 0x000137,[CaseTitle] = 0x000136,[CaseUpper] = 0x000136,[CaseFold] = 0x000137}, NULL},
-	{0x000137, {[CaseLower] = 0x000137,[CaseTitle] = 0x000136,[CaseUpper] = 0x000136,[CaseFold] = 0x000137}, NULL},
-	{0x000139, {[CaseLower] = 0x00013a,[CaseTitle] = 0x000139,[CaseUpper] = 0x000139,[CaseFold] = 0x00013a}, NULL},
-	{0x00013a, {[CaseLower] = 0x00013a,[CaseTitle] = 0x000139,[CaseUpper] = 0x000139,[CaseFold] = 0x00013a}, NULL},
-	{0x00013b, {[CaseLower] = 0x00013c,[CaseTitle] = 0x00013b,[CaseUpper] = 0x00013b,[CaseFold] = 0x00013c}, NULL},
-	{0x00013c, {[CaseLower] = 0x00013c,[CaseTitle] = 0x00013b,[CaseUpper] = 0x00013b,[CaseFold] = 0x00013c}, NULL},
-	{0x00013d, {[CaseLower] = 0x00013e,[CaseTitle] = 0x00013d,[CaseUpper] = 0x00013d,[CaseFold] = 0x00013e}, NULL},
-	{0x00013e, {[CaseLower] = 0x00013e,[CaseTitle] = 0x00013d,[CaseUpper] = 0x00013d,[CaseFold] = 0x00013e}, NULL},
-	{0x00013f, {[CaseLower] = 0x000140,[CaseTitle] = 0x00013f,[CaseUpper] = 0x00013f,[CaseFold] = 0x000140}, NULL},
-	{0x000140, {[CaseLower] = 0x000140,[CaseTitle] = 0x00013f,[CaseUpper] = 0x00013f,[CaseFold] = 0x000140}, NULL},
-	{0x000141, {[CaseLower] = 0x000142,[CaseTitle] = 0x000141,[CaseUpper] = 0x000141,[CaseFold] = 0x000142}, NULL},
-	{0x000142, {[CaseLower] = 0x000142,[CaseTitle] = 0x000141,[CaseUpper] = 0x000141,[CaseFold] = 0x000142}, NULL},
-	{0x000143, {[CaseLower] = 0x000144,[CaseTitle] = 0x000143,[CaseUpper] = 0x000143,[CaseFold] = 0x000144}, NULL},
-	{0x000144, {[CaseLower] = 0x000144,[CaseTitle] = 0x000143,[CaseUpper] = 0x000143,[CaseFold] = 0x000144}, NULL},
-	{0x000145, {[CaseLower] = 0x000146,[CaseTitle] = 0x000145,[CaseUpper] = 0x000145,[CaseFold] = 0x000146}, NULL},
-	{0x000146, {[CaseLower] = 0x000146,[CaseTitle] = 0x000145,[CaseUpper] = 0x000145,[CaseFold] = 0x000146}, NULL},
-	{0x000147, {[CaseLower] = 0x000148,[CaseTitle] = 0x000147,[CaseUpper] = 0x000147,[CaseFold] = 0x000148}, NULL},
-	{0x000148, {[CaseLower] = 0x000148,[CaseTitle] = 0x000147,[CaseUpper] = 0x000147,[CaseFold] = 0x000148}, NULL},
-	{0x000149, {[CaseLower] = 0x000149,[CaseTitle] = 0x000149,[CaseUpper] = 0x000149,[CaseFold] = 0x000149}, &special_case[2]},
-	{0x00014a, {[CaseLower] = 0x00014b,[CaseTitle] = 0x00014a,[CaseUpper] = 0x00014a,[CaseFold] = 0x00014b}, NULL},
-	{0x00014b, {[CaseLower] = 0x00014b,[CaseTitle] = 0x00014a,[CaseUpper] = 0x00014a,[CaseFold] = 0x00014b}, NULL},
-	{0x00014c, {[CaseLower] = 0x00014d,[CaseTitle] = 0x00014c,[CaseUpper] = 0x00014c,[CaseFold] = 0x00014d}, NULL},
-	{0x00014d, {[CaseLower] = 0x00014d,[CaseTitle] = 0x00014c,[CaseUpper] = 0x00014c,[CaseFold] = 0x00014d}, NULL},
-	{0x00014e, {[CaseLower] = 0x00014f,[CaseTitle] = 0x00014e,[CaseUpper] = 0x00014e,[CaseFold] = 0x00014f}, NULL},
-	{0x00014f, {[CaseLower] = 0x00014f,[CaseTitle] = 0x00014e,[CaseUpper] = 0x00014e,[CaseFold] = 0x00014f}, NULL},
-	{0x000150, {[CaseLower] = 0x000151,[CaseTitle] = 0x000150,[CaseUpper] = 0x000150,[CaseFold] = 0x000151}, NULL},
-	{0x000151, {[CaseLower] = 0x000151,[CaseTitle] = 0x000150,[CaseUpper] = 0x000150,[CaseFold] = 0x000151}, NULL},
-	{0x000152, {[CaseLower] = 0x000153,[CaseTitle] = 0x000152,[CaseUpper] = 0x000152,[CaseFold] = 0x000153}, NULL},
-	{0x000153, {[CaseLower] = 0x000153,[CaseTitle] = 0x000152,[CaseUpper] = 0x000152,[CaseFold] = 0x000153}, NULL},
-	{0x000154, {[CaseLower] = 0x000155,[CaseTitle] = 0x000154,[CaseUpper] = 0x000154,[CaseFold] = 0x000155}, NULL},
-	{0x000155, {[CaseLower] = 0x000155,[CaseTitle] = 0x000154,[CaseUpper] = 0x000154,[CaseFold] = 0x000155}, NULL},
-	{0x000156, {[CaseLower] = 0x000157,[CaseTitle] = 0x000156,[CaseUpper] = 0x000156,[CaseFold] = 0x000157}, NULL},
-	{0x000157, {[CaseLower] = 0x000157,[CaseTitle] = 0x000156,[CaseUpper] = 0x000156,[CaseFold] = 0x000157}, NULL},
-	{0x000158, {[CaseLower] = 0x000159,[CaseTitle] = 0x000158,[CaseUpper] = 0x000158,[CaseFold] = 0x000159}, NULL},
-	{0x000159, {[CaseLower] = 0x000159,[CaseTitle] = 0x000158,[CaseUpper] = 0x000158,[CaseFold] = 0x000159}, NULL},
-	{0x00015a, {[CaseLower] = 0x00015b,[CaseTitle] = 0x00015a,[CaseUpper] = 0x00015a,[CaseFold] = 0x00015b}, NULL},
-	{0x00015b, {[CaseLower] = 0x00015b,[CaseTitle] = 0x00015a,[CaseUpper] = 0x00015a,[CaseFold] = 0x00015b}, NULL},
-	{0x00015c, {[CaseLower] = 0x00015d,[CaseTitle] = 0x00015c,[CaseUpper] = 0x00015c,[CaseFold] = 0x00015d}, NULL},
-	{0x00015d, {[CaseLower] = 0x00015d,[CaseTitle] = 0x00015c,[CaseUpper] = 0x00015c,[CaseFold] = 0x00015d}, NULL},
-	{0x00015e, {[CaseLower] = 0x00015f,[CaseTitle] = 0x00015e,[CaseUpper] = 0x00015e,[CaseFold] = 0x00015f}, NULL},
-	{0x00015f, {[CaseLower] = 0x00015f,[CaseTitle] = 0x00015e,[CaseUpper] = 0x00015e,[CaseFold] = 0x00015f}, NULL},
-	{0x000160, {[CaseLower] = 0x000161,[CaseTitle] = 0x000160,[CaseUpper] = 0x000160,[CaseFold] = 0x000161}, NULL},
-	{0x000161, {[CaseLower] = 0x000161,[CaseTitle] = 0x000160,[CaseUpper] = 0x000160,[CaseFold] = 0x000161}, NULL},
-	{0x000162, {[CaseLower] = 0x000163,[CaseTitle] = 0x000162,[CaseUpper] = 0x000162,[CaseFold] = 0x000163}, NULL},
-	{0x000163, {[CaseLower] = 0x000163,[CaseTitle] = 0x000162,[CaseUpper] = 0x000162,[CaseFold] = 0x000163}, NULL},
-	{0x000164, {[CaseLower] = 0x000165,[CaseTitle] = 0x000164,[CaseUpper] = 0x000164,[CaseFold] = 0x000165}, NULL},
-	{0x000165, {[CaseLower] = 0x000165,[CaseTitle] = 0x000164,[CaseUpper] = 0x000164,[CaseFold] = 0x000165}, NULL},
-	{0x000166, {[CaseLower] = 0x000167,[CaseTitle] = 0x000166,[CaseUpper] = 0x000166,[CaseFold] = 0x000167}, NULL},
-	{0x000167, {[CaseLower] = 0x000167,[CaseTitle] = 0x000166,[CaseUpper] = 0x000166,[CaseFold] = 0x000167}, NULL},
-	{0x000168, {[CaseLower] = 0x000169,[CaseTitle] = 0x000168,[CaseUpper] = 0x000168,[CaseFold] = 0x000169}, NULL},
-	{0x000169, {[CaseLower] = 0x000169,[CaseTitle] = 0x000168,[CaseUpper] = 0x000168,[CaseFold] = 0x000169}, NULL},
-	{0x00016a, {[CaseLower] = 0x00016b,[CaseTitle] = 0x00016a,[CaseUpper] = 0x00016a,[CaseFold] = 0x00016b}, NULL},
-	{0x00016b, {[CaseLower] = 0x00016b,[CaseTitle] = 0x00016a,[CaseUpper] = 0x00016a,[CaseFold] = 0x00016b}, NULL},
-	{0x00016c, {[CaseLower] = 0x00016d,[CaseTitle] = 0x00016c,[CaseUpper] = 0x00016c,[CaseFold] = 0x00016d}, NULL},
-	{0x00016d, {[CaseLower] = 0x00016d,[CaseTitle] = 0x00016c,[CaseUpper] = 0x00016c,[CaseFold] = 0x00016d}, NULL},
-	{0x00016e, {[CaseLower] = 0x00016f,[CaseTitle] = 0x00016e,[CaseUpper] = 0x00016e,[CaseFold] = 0x00016f}, NULL},
-	{0x00016f, {[CaseLower] = 0x00016f,[CaseTitle] = 0x00016e,[CaseUpper] = 0x00016e,[CaseFold] = 0x00016f}, NULL},
-	{0x000170, {[CaseLower] = 0x000171,[CaseTitle] = 0x000170,[CaseUpper] = 0x000170,[CaseFold] = 0x000171}, NULL},
-	{0x000171, {[CaseLower] = 0x000171,[CaseTitle] = 0x000170,[CaseUpper] = 0x000170,[CaseFold] = 0x000171}, NULL},
-	{0x000172, {[CaseLower] = 0x000173,[CaseTitle] = 0x000172,[CaseUpper] = 0x000172,[CaseFold] = 0x000173}, NULL},
-	{0x000173, {[CaseLower] = 0x000173,[CaseTitle] = 0x000172,[CaseUpper] = 0x000172,[CaseFold] = 0x000173}, NULL},
-	{0x000174, {[CaseLower] = 0x000175,[CaseTitle] = 0x000174,[CaseUpper] = 0x000174,[CaseFold] = 0x000175}, NULL},
-	{0x000175, {[CaseLower] = 0x000175,[CaseTitle] = 0x000174,[CaseUpper] = 0x000174,[CaseFold] = 0x000175}, NULL},
-	{0x000176, {[CaseLower] = 0x000177,[CaseTitle] = 0x000176,[CaseUpper] = 0x000176,[CaseFold] = 0x000177}, NULL},
-	{0x000177, {[CaseLower] = 0x000177,[CaseTitle] = 0x000176,[CaseUpper] = 0x000176,[CaseFold] = 0x000177}, NULL},
-	{0x000178, {[CaseLower] = 0x0000ff,[CaseTitle] = 0x000178,[CaseUpper] = 0x000178,[CaseFold] = 0x0000ff}, NULL},
-	{0x000179, {[CaseLower] = 0x00017a,[CaseTitle] = 0x000179,[CaseUpper] = 0x000179,[CaseFold] = 0x00017a}, NULL},
-	{0x00017a, {[CaseLower] = 0x00017a,[CaseTitle] = 0x000179,[CaseUpper] = 0x000179,[CaseFold] = 0x00017a}, NULL},
-	{0x00017b, {[CaseLower] = 0x00017c,[CaseTitle] = 0x00017b,[CaseUpper] = 0x00017b,[CaseFold] = 0x00017c}, NULL},
-	{0x00017c, {[CaseLower] = 0x00017c,[CaseTitle] = 0x00017b,[CaseUpper] = 0x00017b,[CaseFold] = 0x00017c}, NULL},
-	{0x00017d, {[CaseLower] = 0x00017e,[CaseTitle] = 0x00017d,[CaseUpper] = 0x00017d,[CaseFold] = 0x00017e}, NULL},
-	{0x00017e, {[CaseLower] = 0x00017e,[CaseTitle] = 0x00017d,[CaseUpper] = 0x00017d,[CaseFold] = 0x00017e}, NULL},
-	{0x00017f, {[CaseLower] = 0x00017f,[CaseTitle] = 0x000053,[CaseUpper] = 0x000053,[CaseFold] = 0x000073}, NULL},
-	{0x000180, {[CaseLower] = 0x000180,[CaseTitle] = 0x000243,[CaseUpper] = 0x000243,[CaseFold] = 0x000180}, NULL},
-	{0x000181, {[CaseLower] = 0x000253,[CaseTitle] = 0x000181,[CaseUpper] = 0x000181,[CaseFold] = 0x000253}, NULL},
-	{0x000182, {[CaseLower] = 0x000183,[CaseTitle] = 0x000182,[CaseUpper] = 0x000182,[CaseFold] = 0x000183}, NULL},
-	{0x000183, {[CaseLower] = 0x000183,[CaseTitle] = 0x000182,[CaseUpper] = 0x000182,[CaseFold] = 0x000183}, NULL},
-	{0x000184, {[CaseLower] = 0x000185,[CaseTitle] = 0x000184,[CaseUpper] = 0x000184,[CaseFold] = 0x000185}, NULL},
-	{0x000185, {[CaseLower] = 0x000185,[CaseTitle] = 0x000184,[CaseUpper] = 0x000184,[CaseFold] = 0x000185}, NULL},
-	{0x000186, {[CaseLower] = 0x000254,[CaseTitle] = 0x000186,[CaseUpper] = 0x000186,[CaseFold] = 0x000254}, NULL},
-	{0x000187, {[CaseLower] = 0x000188,[CaseTitle] = 0x000187,[CaseUpper] = 0x000187,[CaseFold] = 0x000188}, NULL},
-	{0x000188, {[CaseLower] = 0x000188,[CaseTitle] = 0x000187,[CaseUpper] = 0x000187,[CaseFold] = 0x000188}, NULL},
-	{0x000189, {[CaseLower] = 0x000256,[CaseTitle] = 0x000189,[CaseUpper] = 0x000189,[CaseFold] = 0x000256}, NULL},
-	{0x00018a, {[CaseLower] = 0x000257,[CaseTitle] = 0x00018a,[CaseUpper] = 0x00018a,[CaseFold] = 0x000257}, NULL},
-	{0x00018b, {[CaseLower] = 0x00018c,[CaseTitle] = 0x00018b,[CaseUpper] = 0x00018b,[CaseFold] = 0x00018c}, NULL},
-	{0x00018c, {[CaseLower] = 0x00018c,[CaseTitle] = 0x00018b,[CaseUpper] = 0x00018b,[CaseFold] = 0x00018c}, NULL},
-	{0x00018e, {[CaseLower] = 0x0001dd,[CaseTitle] = 0x00018e,[CaseUpper] = 0x00018e,[CaseFold] = 0x0001dd}, NULL},
-	{0x00018f, {[CaseLower] = 0x000259,[CaseTitle] = 0x00018f,[CaseUpper] = 0x00018f,[CaseFold] = 0x000259}, NULL},
-	{0x000190, {[CaseLower] = 0x00025b,[CaseTitle] = 0x000190,[CaseUpper] = 0x000190,[CaseFold] = 0x00025b}, NULL},
-	{0x000191, {[CaseLower] = 0x000192,[CaseTitle] = 0x000191,[CaseUpper] = 0x000191,[CaseFold] = 0x000192}, NULL},
-	{0x000192, {[CaseLower] = 0x000192,[CaseTitle] = 0x000191,[CaseUpper] = 0x000191,[CaseFold] = 0x000192}, NULL},
-	{0x000193, {[CaseLower] = 0x000260,[CaseTitle] = 0x000193,[CaseUpper] = 0x000193,[CaseFold] = 0x000260}, NULL},
-	{0x000194, {[CaseLower] = 0x000263,[CaseTitle] = 0x000194,[CaseUpper] = 0x000194,[CaseFold] = 0x000263}, NULL},
-	{0x000195, {[CaseLower] = 0x000195,[CaseTitle] = 0x0001f6,[CaseUpper] = 0x0001f6,[CaseFold] = 0x000195}, NULL},
-	{0x000196, {[CaseLower] = 0x000269,[CaseTitle] = 0x000196,[CaseUpper] = 0x000196,[CaseFold] = 0x000269}, NULL},
-	{0x000197, {[CaseLower] = 0x000268,[CaseTitle] = 0x000197,[CaseUpper] = 0x000197,[CaseFold] = 0x000268}, NULL},
-	{0x000198, {[CaseLower] = 0x000199,[CaseTitle] = 0x000198,[CaseUpper] = 0x000198,[CaseFold] = 0x000199}, NULL},
-	{0x000199, {[CaseLower] = 0x000199,[CaseTitle] = 0x000198,[CaseUpper] = 0x000198,[CaseFold] = 0x000199}, NULL},
-	{0x00019a, {[CaseLower] = 0x00019a,[CaseTitle] = 0x00023d,[CaseUpper] = 0x00023d,[CaseFold] = 0x00019a}, NULL},
-	{0x00019c, {[CaseLower] = 0x00026f,[CaseTitle] = 0x00019c,[CaseUpper] = 0x00019c,[CaseFold] = 0x00026f}, NULL},
-	{0x00019d, {[CaseLower] = 0x000272,[CaseTitle] = 0x00019d,[CaseUpper] = 0x00019d,[CaseFold] = 0x000272}, NULL},
-	{0x00019e, {[CaseLower] = 0x00019e,[CaseTitle] = 0x000220,[CaseUpper] = 0x000220,[CaseFold] = 0x00019e}, NULL},
-	{0x00019f, {[CaseLower] = 0x000275,[CaseTitle] = 0x00019f,[CaseUpper] = 0x00019f,[CaseFold] = 0x000275}, NULL},
-	{0x0001a0, {[CaseLower] = 0x0001a1,[CaseTitle] = 0x0001a0,[CaseUpper] = 0x0001a0,[CaseFold] = 0x0001a1}, NULL},
-	{0x0001a1, {[CaseLower] = 0x0001a1,[CaseTitle] = 0x0001a0,[CaseUpper] = 0x0001a0,[CaseFold] = 0x0001a1}, NULL},
-	{0x0001a2, {[CaseLower] = 0x0001a3,[CaseTitle] = 0x0001a2,[CaseUpper] = 0x0001a2,[CaseFold] = 0x0001a3}, NULL},
-	{0x0001a3, {[CaseLower] = 0x0001a3,[CaseTitle] = 0x0001a2,[CaseUpper] = 0x0001a2,[CaseFold] = 0x0001a3}, NULL},
-	{0x0001a4, {[CaseLower] = 0x0001a5,[CaseTitle] = 0x0001a4,[CaseUpper] = 0x0001a4,[CaseFold] = 0x0001a5}, NULL},
-	{0x0001a5, {[CaseLower] = 0x0001a5,[CaseTitle] = 0x0001a4,[CaseUpper] = 0x0001a4,[CaseFold] = 0x0001a5}, NULL},
-	{0x0001a6, {[CaseLower] = 0x000280,[CaseTitle] = 0x0001a6,[CaseUpper] = 0x0001a6,[CaseFold] = 0x000280}, NULL},
-	{0x0001a7, {[CaseLower] = 0x0001a8,[CaseTitle] = 0x0001a7,[CaseUpper] = 0x0001a7,[CaseFold] = 0x0001a8}, NULL},
-	{0x0001a8, {[CaseLower] = 0x0001a8,[CaseTitle] = 0x0001a7,[CaseUpper] = 0x0001a7,[CaseFold] = 0x0001a8}, NULL},
-	{0x0001a9, {[CaseLower] = 0x000283,[CaseTitle] = 0x0001a9,[CaseUpper] = 0x0001a9,[CaseFold] = 0x000283}, NULL},
-	{0x0001ac, {[CaseLower] = 0x0001ad,[CaseTitle] = 0x0001ac,[CaseUpper] = 0x0001ac,[CaseFold] = 0x0001ad}, NULL},
-	{0x0001ad, {[CaseLower] = 0x0001ad,[CaseTitle] = 0x0001ac,[CaseUpper] = 0x0001ac,[CaseFold] = 0x0001ad}, NULL},
-	{0x0001ae, {[CaseLower] = 0x000288,[CaseTitle] = 0x0001ae,[CaseUpper] = 0x0001ae,[CaseFold] = 0x000288}, NULL},
-	{0x0001af, {[CaseLower] = 0x0001b0,[CaseTitle] = 0x0001af,[CaseUpper] = 0x0001af,[CaseFold] = 0x0001b0}, NULL},
-	{0x0001b0, {[CaseLower] = 0x0001b0,[CaseTitle] = 0x0001af,[CaseUpper] = 0x0001af,[CaseFold] = 0x0001b0}, NULL},
-	{0x0001b1, {[CaseLower] = 0x00028a,[CaseTitle] = 0x0001b1,[CaseUpper] = 0x0001b1,[CaseFold] = 0x00028a}, NULL},
-	{0x0001b2, {[CaseLower] = 0x00028b,[CaseTitle] = 0x0001b2,[CaseUpper] = 0x0001b2,[CaseFold] = 0x00028b}, NULL},
-	{0x0001b3, {[CaseLower] = 0x0001b4,[CaseTitle] = 0x0001b3,[CaseUpper] = 0x0001b3,[CaseFold] = 0x0001b4}, NULL},
-	{0x0001b4, {[CaseLower] = 0x0001b4,[CaseTitle] = 0x0001b3,[CaseUpper] = 0x0001b3,[CaseFold] = 0x0001b4}, NULL},
-	{0x0001b5, {[CaseLower] = 0x0001b6,[CaseTitle] = 0x0001b5,[CaseUpper] = 0x0001b5,[CaseFold] = 0x0001b6}, NULL},
-	{0x0001b6, {[CaseLower] = 0x0001b6,[CaseTitle] = 0x0001b5,[CaseUpper] = 0x0001b5,[CaseFold] = 0x0001b6}, NULL},
-	{0x0001b7, {[CaseLower] = 0x000292,[CaseTitle] = 0x0001b7,[CaseUpper] = 0x0001b7,[CaseFold] = 0x000292}, NULL},
-	{0x0001b8, {[CaseLower] = 0x0001b9,[CaseTitle] = 0x0001b8,[CaseUpper] = 0x0001b8,[CaseFold] = 0x0001b9}, NULL},
-	{0x0001b9, {[CaseLower] = 0x0001b9,[CaseTitle] = 0x0001b8,[CaseUpper] = 0x0001b8,[CaseFold] = 0x0001b9}, NULL},
-	{0x0001bc, {[CaseLower] = 0x0001bd,[CaseTitle] = 0x0001bc,[CaseUpper] = 0x0001bc,[CaseFold] = 0x0001bd}, NULL},
-	{0x0001bd, {[CaseLower] = 0x0001bd,[CaseTitle] = 0x0001bc,[CaseUpper] = 0x0001bc,[CaseFold] = 0x0001bd}, NULL},
-	{0x0001bf, {[CaseLower] = 0x0001bf,[CaseTitle] = 0x0001f7,[CaseUpper] = 0x0001f7,[CaseFold] = 0x0001bf}, NULL},
-	{0x0001c4, {[CaseLower] = 0x0001c6,[CaseTitle] = 0x0001c5,[CaseUpper] = 0x0001c4,[CaseFold] = 0x0001c6}, NULL},
-	{0x0001c5, {[CaseLower] = 0x0001c6,[CaseTitle] = 0x0001c5,[CaseUpper] = 0x0001c4,[CaseFold] = 0x0001c6}, NULL},
-	{0x0001c6, {[CaseLower] = 0x0001c6,[CaseTitle] = 0x0001c5,[CaseUpper] = 0x0001c4,[CaseFold] = 0x0001c6}, NULL},
-	{0x0001c7, {[CaseLower] = 0x0001c9,[CaseTitle] = 0x0001c8,[CaseUpper] = 0x0001c7,[CaseFold] = 0x0001c9}, NULL},
-	{0x0001c8, {[CaseLower] = 0x0001c9,[CaseTitle] = 0x0001c8,[CaseUpper] = 0x0001c7,[CaseFold] = 0x0001c9}, NULL},
-	{0x0001c9, {[CaseLower] = 0x0001c9,[CaseTitle] = 0x0001c8,[CaseUpper] = 0x0001c7,[CaseFold] = 0x0001c9}, NULL},
-	{0x0001ca, {[CaseLower] = 0x0001cc,[CaseTitle] = 0x0001cb,[CaseUpper] = 0x0001ca,[CaseFold] = 0x0001cc}, NULL},
-	{0x0001cb, {[CaseLower] = 0x0001cc,[CaseTitle] = 0x0001cb,[CaseUpper] = 0x0001ca,[CaseFold] = 0x0001cc}, NULL},
-	{0x0001cc, {[CaseLower] = 0x0001cc,[CaseTitle] = 0x0001cb,[CaseUpper] = 0x0001ca,[CaseFold] = 0x0001cc}, NULL},
-	{0x0001cd, {[CaseLower] = 0x0001ce,[CaseTitle] = 0x0001cd,[CaseUpper] = 0x0001cd,[CaseFold] = 0x0001ce}, NULL},
-	{0x0001ce, {[CaseLower] = 0x0001ce,[CaseTitle] = 0x0001cd,[CaseUpper] = 0x0001cd,[CaseFold] = 0x0001ce}, NULL},
-	{0x0001cf, {[CaseLower] = 0x0001d0,[CaseTitle] = 0x0001cf,[CaseUpper] = 0x0001cf,[CaseFold] = 0x0001d0}, NULL},
-	{0x0001d0, {[CaseLower] = 0x0001d0,[CaseTitle] = 0x0001cf,[CaseUpper] = 0x0001cf,[CaseFold] = 0x0001d0}, NULL},
-	{0x0001d1, {[CaseLower] = 0x0001d2,[CaseTitle] = 0x0001d1,[CaseUpper] = 0x0001d1,[CaseFold] = 0x0001d2}, NULL},
-	{0x0001d2, {[CaseLower] = 0x0001d2,[CaseTitle] = 0x0001d1,[CaseUpper] = 0x0001d1,[CaseFold] = 0x0001d2}, NULL},
-	{0x0001d3, {[CaseLower] = 0x0001d4,[CaseTitle] = 0x0001d3,[CaseUpper] = 0x0001d3,[CaseFold] = 0x0001d4}, NULL},
-	{0x0001d4, {[CaseLower] = 0x0001d4,[CaseTitle] = 0x0001d3,[CaseUpper] = 0x0001d3,[CaseFold] = 0x0001d4}, NULL},
-	{0x0001d5, {[CaseLower] = 0x0001d6,[CaseTitle] = 0x0001d5,[CaseUpper] = 0x0001d5,[CaseFold] = 0x0001d6}, NULL},
-	{0x0001d6, {[CaseLower] = 0x0001d6,[CaseTitle] = 0x0001d5,[CaseUpper] = 0x0001d5,[CaseFold] = 0x0001d6}, NULL},
-	{0x0001d7, {[CaseLower] = 0x0001d8,[CaseTitle] = 0x0001d7,[CaseUpper] = 0x0001d7,[CaseFold] = 0x0001d8}, NULL},
-	{0x0001d8, {[CaseLower] = 0x0001d8,[CaseTitle] = 0x0001d7,[CaseUpper] = 0x0001d7,[CaseFold] = 0x0001d8}, NULL},
-	{0x0001d9, {[CaseLower] = 0x0001da,[CaseTitle] = 0x0001d9,[CaseUpper] = 0x0001d9,[CaseFold] = 0x0001da}, NULL},
-	{0x0001da, {[CaseLower] = 0x0001da,[CaseTitle] = 0x0001d9,[CaseUpper] = 0x0001d9,[CaseFold] = 0x0001da}, NULL},
-	{0x0001db, {[CaseLower] = 0x0001dc,[CaseTitle] = 0x0001db,[CaseUpper] = 0x0001db,[CaseFold] = 0x0001dc}, NULL},
-	{0x0001dc, {[CaseLower] = 0x0001dc,[CaseTitle] = 0x0001db,[CaseUpper] = 0x0001db,[CaseFold] = 0x0001dc}, NULL},
-	{0x0001dd, {[CaseLower] = 0x0001dd,[CaseTitle] = 0x00018e,[CaseUpper] = 0x00018e,[CaseFold] = 0x0001dd}, NULL},
-	{0x0001de, {[CaseLower] = 0x0001df,[CaseTitle] = 0x0001de,[CaseUpper] = 0x0001de,[CaseFold] = 0x0001df}, NULL},
-	{0x0001df, {[CaseLower] = 0x0001df,[CaseTitle] = 0x0001de,[CaseUpper] = 0x0001de,[CaseFold] = 0x0001df}, NULL},
-	{0x0001e0, {[CaseLower] = 0x0001e1,[CaseTitle] = 0x0001e0,[CaseUpper] = 0x0001e0,[CaseFold] = 0x0001e1}, NULL},
-	{0x0001e1, {[CaseLower] = 0x0001e1,[CaseTitle] = 0x0001e0,[CaseUpper] = 0x0001e0,[CaseFold] = 0x0001e1}, NULL},
-	{0x0001e2, {[CaseLower] = 0x0001e3,[CaseTitle] = 0x0001e2,[CaseUpper] = 0x0001e2,[CaseFold] = 0x0001e3}, NULL},
-	{0x0001e3, {[CaseLower] = 0x0001e3,[CaseTitle] = 0x0001e2,[CaseUpper] = 0x0001e2,[CaseFold] = 0x0001e3}, NULL},
-	{0x0001e4, {[CaseLower] = 0x0001e5,[CaseTitle] = 0x0001e4,[CaseUpper] = 0x0001e4,[CaseFold] = 0x0001e5}, NULL},
-	{0x0001e5, {[CaseLower] = 0x0001e5,[CaseTitle] = 0x0001e4,[CaseUpper] = 0x0001e4,[CaseFold] = 0x0001e5}, NULL},
-	{0x0001e6, {[CaseLower] = 0x0001e7,[CaseTitle] = 0x0001e6,[CaseUpper] = 0x0001e6,[CaseFold] = 0x0001e7}, NULL},
-	{0x0001e7, {[CaseLower] = 0x0001e7,[CaseTitle] = 0x0001e6,[CaseUpper] = 0x0001e6,[CaseFold] = 0x0001e7}, NULL},
-	{0x0001e8, {[CaseLower] = 0x0001e9,[CaseTitle] = 0x0001e8,[CaseUpper] = 0x0001e8,[CaseFold] = 0x0001e9}, NULL},
-	{0x0001e9, {[CaseLower] = 0x0001e9,[CaseTitle] = 0x0001e8,[CaseUpper] = 0x0001e8,[CaseFold] = 0x0001e9}, NULL},
-	{0x0001ea, {[CaseLower] = 0x0001eb,[CaseTitle] = 0x0001ea,[CaseUpper] = 0x0001ea,[CaseFold] = 0x0001eb}, NULL},
-	{0x0001eb, {[CaseLower] = 0x0001eb,[CaseTitle] = 0x0001ea,[CaseUpper] = 0x0001ea,[CaseFold] = 0x0001eb}, NULL},
-	{0x0001ec, {[CaseLower] = 0x0001ed,[CaseTitle] = 0x0001ec,[CaseUpper] = 0x0001ec,[CaseFold] = 0x0001ed}, NULL},
-	{0x0001ed, {[CaseLower] = 0x0001ed,[CaseTitle] = 0x0001ec,[CaseUpper] = 0x0001ec,[CaseFold] = 0x0001ed}, NULL},
-	{0x0001ee, {[CaseLower] = 0x0001ef,[CaseTitle] = 0x0001ee,[CaseUpper] = 0x0001ee,[CaseFold] = 0x0001ef}, NULL},
-	{0x0001ef, {[CaseLower] = 0x0001ef,[CaseTitle] = 0x0001ee,[CaseUpper] = 0x0001ee,[CaseFold] = 0x0001ef}, NULL},
-	{0x0001f0, {[CaseLower] = 0x0001f0,[CaseTitle] = 0x0001f0,[CaseUpper] = 0x0001f0,[CaseFold] = 0x0001f0}, &special_case[3]},
-	{0x0001f1, {[CaseLower] = 0x0001f3,[CaseTitle] = 0x0001f2,[CaseUpper] = 0x0001f1,[CaseFold] = 0x0001f3}, NULL},
-	{0x0001f2, {[CaseLower] = 0x0001f3,[CaseTitle] = 0x0001f2,[CaseUpper] = 0x0001f1,[CaseFold] = 0x0001f3}, NULL},
-	{0x0001f3, {[CaseLower] = 0x0001f3,[CaseTitle] = 0x0001f2,[CaseUpper] = 0x0001f1,[CaseFold] = 0x0001f3}, NULL},
-	{0x0001f4, {[CaseLower] = 0x0001f5,[CaseTitle] = 0x0001f4,[CaseUpper] = 0x0001f4,[CaseFold] = 0x0001f5}, NULL},
-	{0x0001f5, {[CaseLower] = 0x0001f5,[CaseTitle] = 0x0001f4,[CaseUpper] = 0x0001f4,[CaseFold] = 0x0001f5}, NULL},
-	{0x0001f6, {[CaseLower] = 0x000195,[CaseTitle] = 0x0001f6,[CaseUpper] = 0x0001f6,[CaseFold] = 0x000195}, NULL},
-	{0x0001f7, {[CaseLower] = 0x0001bf,[CaseTitle] = 0x0001f7,[CaseUpper] = 0x0001f7,[CaseFold] = 0x0001bf}, NULL},
-	{0x0001f8, {[CaseLower] = 0x0001f9,[CaseTitle] = 0x0001f8,[CaseUpper] = 0x0001f8,[CaseFold] = 0x0001f9}, NULL},
-	{0x0001f9, {[CaseLower] = 0x0001f9,[CaseTitle] = 0x0001f8,[CaseUpper] = 0x0001f8,[CaseFold] = 0x0001f9}, NULL},
-	{0x0001fa, {[CaseLower] = 0x0001fb,[CaseTitle] = 0x0001fa,[CaseUpper] = 0x0001fa,[CaseFold] = 0x0001fb}, NULL},
-	{0x0001fb, {[CaseLower] = 0x0001fb,[CaseTitle] = 0x0001fa,[CaseUpper] = 0x0001fa,[CaseFold] = 0x0001fb}, NULL},
-	{0x0001fc, {[CaseLower] = 0x0001fd,[CaseTitle] = 0x0001fc,[CaseUpper] = 0x0001fc,[CaseFold] = 0x0001fd}, NULL},
-	{0x0001fd, {[CaseLower] = 0x0001fd,[CaseTitle] = 0x0001fc,[CaseUpper] = 0x0001fc,[CaseFold] = 0x0001fd}, NULL},
-	{0x0001fe, {[CaseLower] = 0x0001ff,[CaseTitle] = 0x0001fe,[CaseUpper] = 0x0001fe,[CaseFold] = 0x0001ff}, NULL},
-	{0x0001ff, {[CaseLower] = 0x0001ff,[CaseTitle] = 0x0001fe,[CaseUpper] = 0x0001fe,[CaseFold] = 0x0001ff}, NULL},
-	{0x000200, {[CaseLower] = 0x000201,[CaseTitle] = 0x000200,[CaseUpper] = 0x000200,[CaseFold] = 0x000201}, NULL},
-	{0x000201, {[CaseLower] = 0x000201,[CaseTitle] = 0x000200,[CaseUpper] = 0x000200,[CaseFold] = 0x000201}, NULL},
-	{0x000202, {[CaseLower] = 0x000203,[CaseTitle] = 0x000202,[CaseUpper] = 0x000202,[CaseFold] = 0x000203}, NULL},
-	{0x000203, {[CaseLower] = 0x000203,[CaseTitle] = 0x000202,[CaseUpper] = 0x000202,[CaseFold] = 0x000203}, NULL},
-	{0x000204, {[CaseLower] = 0x000205,[CaseTitle] = 0x000204,[CaseUpper] = 0x000204,[CaseFold] = 0x000205}, NULL},
-	{0x000205, {[CaseLower] = 0x000205,[CaseTitle] = 0x000204,[CaseUpper] = 0x000204,[CaseFold] = 0x000205}, NULL},
-	{0x000206, {[CaseLower] = 0x000207,[CaseTitle] = 0x000206,[CaseUpper] = 0x000206,[CaseFold] = 0x000207}, NULL},
-	{0x000207, {[CaseLower] = 0x000207,[CaseTitle] = 0x000206,[CaseUpper] = 0x000206,[CaseFold] = 0x000207}, NULL},
-	{0x000208, {[CaseLower] = 0x000209,[CaseTitle] = 0x000208,[CaseUpper] = 0x000208,[CaseFold] = 0x000209}, NULL},
-	{0x000209, {[CaseLower] = 0x000209,[CaseTitle] = 0x000208,[CaseUpper] = 0x000208,[CaseFold] = 0x000209}, NULL},
-	{0x00020a, {[CaseLower] = 0x00020b,[CaseTitle] = 0x00020a,[CaseUpper] = 0x00020a,[CaseFold] = 0x00020b}, NULL},
-	{0x00020b, {[CaseLower] = 0x00020b,[CaseTitle] = 0x00020a,[CaseUpper] = 0x00020a,[CaseFold] = 0x00020b}, NULL},
-	{0x00020c, {[CaseLower] = 0x00020d,[CaseTitle] = 0x00020c,[CaseUpper] = 0x00020c,[CaseFold] = 0x00020d}, NULL},
-	{0x00020d, {[CaseLower] = 0x00020d,[CaseTitle] = 0x00020c,[CaseUpper] = 0x00020c,[CaseFold] = 0x00020d}, NULL},
-	{0x00020e, {[CaseLower] = 0x00020f,[CaseTitle] = 0x00020e,[CaseUpper] = 0x00020e,[CaseFold] = 0x00020f}, NULL},
-	{0x00020f, {[CaseLower] = 0x00020f,[CaseTitle] = 0x00020e,[CaseUpper] = 0x00020e,[CaseFold] = 0x00020f}, NULL},
-	{0x000210, {[CaseLower] = 0x000211,[CaseTitle] = 0x000210,[CaseUpper] = 0x000210,[CaseFold] = 0x000211}, NULL},
-	{0x000211, {[CaseLower] = 0x000211,[CaseTitle] = 0x000210,[CaseUpper] = 0x000210,[CaseFold] = 0x000211}, NULL},
-	{0x000212, {[CaseLower] = 0x000213,[CaseTitle] = 0x000212,[CaseUpper] = 0x000212,[CaseFold] = 0x000213}, NULL},
-	{0x000213, {[CaseLower] = 0x000213,[CaseTitle] = 0x000212,[CaseUpper] = 0x000212,[CaseFold] = 0x000213}, NULL},
-	{0x000214, {[CaseLower] = 0x000215,[CaseTitle] = 0x000214,[CaseUpper] = 0x000214,[CaseFold] = 0x000215}, NULL},
-	{0x000215, {[CaseLower] = 0x000215,[CaseTitle] = 0x000214,[CaseUpper] = 0x000214,[CaseFold] = 0x000215}, NULL},
-	{0x000216, {[CaseLower] = 0x000217,[CaseTitle] = 0x000216,[CaseUpper] = 0x000216,[CaseFold] = 0x000217}, NULL},
-	{0x000217, {[CaseLower] = 0x000217,[CaseTitle] = 0x000216,[CaseUpper] = 0x000216,[CaseFold] = 0x000217}, NULL},
-	{0x000218, {[CaseLower] = 0x000219,[CaseTitle] = 0x000218,[CaseUpper] = 0x000218,[CaseFold] = 0x000219}, NULL},
-	{0x000219, {[CaseLower] = 0x000219,[CaseTitle] = 0x000218,[CaseUpper] = 0x000218,[CaseFold] = 0x000219}, NULL},
-	{0x00021a, {[CaseLower] = 0x00021b,[CaseTitle] = 0x00021a,[CaseUpper] = 0x00021a,[CaseFold] = 0x00021b}, NULL},
-	{0x00021b, {[CaseLower] = 0x00021b,[CaseTitle] = 0x00021a,[CaseUpper] = 0x00021a,[CaseFold] = 0x00021b}, NULL},
-	{0x00021c, {[CaseLower] = 0x00021d,[CaseTitle] = 0x00021c,[CaseUpper] = 0x00021c,[CaseFold] = 0x00021d}, NULL},
-	{0x00021d, {[CaseLower] = 0x00021d,[CaseTitle] = 0x00021c,[CaseUpper] = 0x00021c,[CaseFold] = 0x00021d}, NULL},
-	{0x00021e, {[CaseLower] = 0x00021f,[CaseTitle] = 0x00021e,[CaseUpper] = 0x00021e,[CaseFold] = 0x00021f}, NULL},
-	{0x00021f, {[CaseLower] = 0x00021f,[CaseTitle] = 0x00021e,[CaseUpper] = 0x00021e,[CaseFold] = 0x00021f}, NULL},
-	{0x000220, {[CaseLower] = 0x00019e,[CaseTitle] = 0x000220,[CaseUpper] = 0x000220,[CaseFold] = 0x00019e}, NULL},
-	{0x000222, {[CaseLower] = 0x000223,[CaseTitle] = 0x000222,[CaseUpper] = 0x000222,[CaseFold] = 0x000223}, NULL},
-	{0x000223, {[CaseLower] = 0x000223,[CaseTitle] = 0x000222,[CaseUpper] = 0x000222,[CaseFold] = 0x000223}, NULL},
-	{0x000224, {[CaseLower] = 0x000225,[CaseTitle] = 0x000224,[CaseUpper] = 0x000224,[CaseFold] = 0x000225}, NULL},
-	{0x000225, {[CaseLower] = 0x000225,[CaseTitle] = 0x000224,[CaseUpper] = 0x000224,[CaseFold] = 0x000225}, NULL},
-	{0x000226, {[CaseLower] = 0x000227,[CaseTitle] = 0x000226,[CaseUpper] = 0x000226,[CaseFold] = 0x000227}, NULL},
-	{0x000227, {[CaseLower] = 0x000227,[CaseTitle] = 0x000226,[CaseUpper] = 0x000226,[CaseFold] = 0x000227}, NULL},
-	{0x000228, {[CaseLower] = 0x000229,[CaseTitle] = 0x000228,[CaseUpper] = 0x000228,[CaseFold] = 0x000229}, NULL},
-	{0x000229, {[CaseLower] = 0x000229,[CaseTitle] = 0x000228,[CaseUpper] = 0x000228,[CaseFold] = 0x000229}, NULL},
-	{0x00022a, {[CaseLower] = 0x00022b,[CaseTitle] = 0x00022a,[CaseUpper] = 0x00022a,[CaseFold] = 0x00022b}, NULL},
-	{0x00022b, {[CaseLower] = 0x00022b,[CaseTitle] = 0x00022a,[CaseUpper] = 0x00022a,[CaseFold] = 0x00022b}, NULL},
-	{0x00022c, {[CaseLower] = 0x00022d,[CaseTitle] = 0x00022c,[CaseUpper] = 0x00022c,[CaseFold] = 0x00022d}, NULL},
-	{0x00022d, {[CaseLower] = 0x00022d,[CaseTitle] = 0x00022c,[CaseUpper] = 0x00022c,[CaseFold] = 0x00022d}, NULL},
-	{0x00022e, {[CaseLower] = 0x00022f,[CaseTitle] = 0x00022e,[CaseUpper] = 0x00022e,[CaseFold] = 0x00022f}, NULL},
-	{0x00022f, {[CaseLower] = 0x00022f,[CaseTitle] = 0x00022e,[CaseUpper] = 0x00022e,[CaseFold] = 0x00022f}, NULL},
-	{0x000230, {[CaseLower] = 0x000231,[CaseTitle] = 0x000230,[CaseUpper] = 0x000230,[CaseFold] = 0x000231}, NULL},
-	{0x000231, {[CaseLower] = 0x000231,[CaseTitle] = 0x000230,[CaseUpper] = 0x000230,[CaseFold] = 0x000231}, NULL},
-	{0x000232, {[CaseLower] = 0x000233,[CaseTitle] = 0x000232,[CaseUpper] = 0x000232,[CaseFold] = 0x000233}, NULL},
-	{0x000233, {[CaseLower] = 0x000233,[CaseTitle] = 0x000232,[CaseUpper] = 0x000232,[CaseFold] = 0x000233}, NULL},
-	{0x00023a, {[CaseLower] = 0x002c65,[CaseTitle] = 0x00023a,[CaseUpper] = 0x00023a,[CaseFold] = 0x002c65}, NULL},
-	{0x00023b, {[CaseLower] = 0x00023c,[CaseTitle] = 0x00023b,[CaseUpper] = 0x00023b,[CaseFold] = 0x00023c}, NULL},
-	{0x00023c, {[CaseLower] = 0x00023c,[CaseTitle] = 0x00023b,[CaseUpper] = 0x00023b,[CaseFold] = 0x00023c}, NULL},
-	{0x00023d, {[CaseLower] = 0x00019a,[CaseTitle] = 0x00023d,[CaseUpper] = 0x00023d,[CaseFold] = 0x00019a}, NULL},
-	{0x00023e, {[CaseLower] = 0x002c66,[CaseTitle] = 0x00023e,[CaseUpper] = 0x00023e,[CaseFold] = 0x002c66}, NULL},
-	{0x00023f, {[CaseLower] = 0x00023f,[CaseTitle] = 0x002c7e,[CaseUpper] = 0x002c7e,[CaseFold] = 0x00023f}, NULL},
-	{0x000240, {[CaseLower] = 0x000240,[CaseTitle] = 0x002c7f,[CaseUpper] = 0x002c7f,[CaseFold] = 0x000240}, NULL},
-	{0x000241, {[CaseLower] = 0x000242,[CaseTitle] = 0x000241,[CaseUpper] = 0x000241,[CaseFold] = 0x000242}, NULL},
-	{0x000242, {[CaseLower] = 0x000242,[CaseTitle] = 0x000241,[CaseUpper] = 0x000241,[CaseFold] = 0x000242}, NULL},
-	{0x000243, {[CaseLower] = 0x000180,[CaseTitle] = 0x000243,[CaseUpper] = 0x000243,[CaseFold] = 0x000180}, NULL},
-	{0x000244, {[CaseLower] = 0x000289,[CaseTitle] = 0x000244,[CaseUpper] = 0x000244,[CaseFold] = 0x000289}, NULL},
-	{0x000245, {[CaseLower] = 0x00028c,[CaseTitle] = 0x000245,[CaseUpper] = 0x000245,[CaseFold] = 0x00028c}, NULL},
-	{0x000246, {[CaseLower] = 0x000247,[CaseTitle] = 0x000246,[CaseUpper] = 0x000246,[CaseFold] = 0x000247}, NULL},
-	{0x000247, {[CaseLower] = 0x000247,[CaseTitle] = 0x000246,[CaseUpper] = 0x000246,[CaseFold] = 0x000247}, NULL},
-	{0x000248, {[CaseLower] = 0x000249,[CaseTitle] = 0x000248,[CaseUpper] = 0x000248,[CaseFold] = 0x000249}, NULL},
-	{0x000249, {[CaseLower] = 0x000249,[CaseTitle] = 0x000248,[CaseUpper] = 0x000248,[CaseFold] = 0x000249}, NULL},
-	{0x00024a, {[CaseLower] = 0x00024b,[CaseTitle] = 0x00024a,[CaseUpper] = 0x00024a,[CaseFold] = 0x00024b}, NULL},
-	{0x00024b, {[CaseLower] = 0x00024b,[CaseTitle] = 0x00024a,[CaseUpper] = 0x00024a,[CaseFold] = 0x00024b}, NULL},
-	{0x00024c, {[CaseLower] = 0x00024d,[CaseTitle] = 0x00024c,[CaseUpper] = 0x00024c,[CaseFold] = 0x00024d}, NULL},
-	{0x00024d, {[CaseLower] = 0x00024d,[CaseTitle] = 0x00024c,[CaseUpper] = 0x00024c,[CaseFold] = 0x00024d}, NULL},
-	{0x00024e, {[CaseLower] = 0x00024f,[CaseTitle] = 0x00024e,[CaseUpper] = 0x00024e,[CaseFold] = 0x00024f}, NULL},
-	{0x00024f, {[CaseLower] = 0x00024f,[CaseTitle] = 0x00024e,[CaseUpper] = 0x00024e,[CaseFold] = 0x00024f}, NULL},
-	{0x000250, {[CaseLower] = 0x000250,[CaseTitle] = 0x002c6f,[CaseUpper] = 0x002c6f,[CaseFold] = 0x000250}, NULL},
-	{0x000251, {[CaseLower] = 0x000251,[CaseTitle] = 0x002c6d,[CaseUpper] = 0x002c6d,[CaseFold] = 0x000251}, NULL},
-	{0x000252, {[CaseLower] = 0x000252,[CaseTitle] = 0x002c70,[CaseUpper] = 0x002c70,[CaseFold] = 0x000252}, NULL},
-	{0x000253, {[CaseLower] = 0x000253,[CaseTitle] = 0x000181,[CaseUpper] = 0x000181,[CaseFold] = 0x000253}, NULL},
-	{0x000254, {[CaseLower] = 0x000254,[CaseTitle] = 0x000186,[CaseUpper] = 0x000186,[CaseFold] = 0x000254}, NULL},
-	{0x000256, {[CaseLower] = 0x000256,[CaseTitle] = 0x000189,[CaseUpper] = 0x000189,[CaseFold] = 0x000256}, NULL},
-	{0x000257, {[CaseLower] = 0x000257,[CaseTitle] = 0x00018a,[CaseUpper] = 0x00018a,[CaseFold] = 0x000257}, NULL},
-	{0x000259, {[CaseLower] = 0x000259,[CaseTitle] = 0x00018f,[CaseUpper] = 0x00018f,[CaseFold] = 0x000259}, NULL},
-	{0x00025b, {[CaseLower] = 0x00025b,[CaseTitle] = 0x000190,[CaseUpper] = 0x000190,[CaseFold] = 0x00025b}, NULL},
-	{0x00025c, {[CaseLower] = 0x00025c,[CaseTitle] = 0x00a7ab,[CaseUpper] = 0x00a7ab,[CaseFold] = 0x00025c}, NULL},
-	{0x000260, {[CaseLower] = 0x000260,[CaseTitle] = 0x000193,[CaseUpper] = 0x000193,[CaseFold] = 0x000260}, NULL},
-	{0x000261, {[CaseLower] = 0x000261,[CaseTitle] = 0x00a7ac,[CaseUpper] = 0x00a7ac,[CaseFold] = 0x000261}, NULL},
-	{0x000263, {[CaseLower] = 0x000263,[CaseTitle] = 0x000194,[CaseUpper] = 0x000194,[CaseFold] = 0x000263}, NULL},
-	{0x000265, {[CaseLower] = 0x000265,[CaseTitle] = 0x00a78d,[CaseUpper] = 0x00a78d,[CaseFold] = 0x000265}, NULL},
-	{0x000266, {[CaseLower] = 0x000266,[CaseTitle] = 0x00a7aa,[CaseUpper] = 0x00a7aa,[CaseFold] = 0x000266}, NULL},
-	{0x000268, {[CaseLower] = 0x000268,[CaseTitle] = 0x000197,[CaseUpper] = 0x000197,[CaseFold] = 0x000268}, NULL},
-	{0x000269, {[CaseLower] = 0x000269,[CaseTitle] = 0x000196,[CaseUpper] = 0x000196,[CaseFold] = 0x000269}, NULL},
-	{0x00026a, {[CaseLower] = 0x00026a,[CaseTitle] = 0x00a7ae,[CaseUpper] = 0x00a7ae,[CaseFold] = 0x00026a}, NULL},
-	{0x00026b, {[CaseLower] = 0x00026b,[CaseTitle] = 0x002c62,[CaseUpper] = 0x002c62,[CaseFold] = 0x00026b}, NULL},
-	{0x00026c, {[CaseLower] = 0x00026c,[CaseTitle] = 0x00a7ad,[CaseUpper] = 0x00a7ad,[CaseFold] = 0x00026c}, NULL},
-	{0x00026f, {[CaseLower] = 0x00026f,[CaseTitle] = 0x00019c,[CaseUpper] = 0x00019c,[CaseFold] = 0x00026f}, NULL},
-	{0x000271, {[CaseLower] = 0x000271,[CaseTitle] = 0x002c6e,[CaseUpper] = 0x002c6e,[CaseFold] = 0x000271}, NULL},
-	{0x000272, {[CaseLower] = 0x000272,[CaseTitle] = 0x00019d,[CaseUpper] = 0x00019d,[CaseFold] = 0x000272}, NULL},
-	{0x000275, {[CaseLower] = 0x000275,[CaseTitle] = 0x00019f,[CaseUpper] = 0x00019f,[CaseFold] = 0x000275}, NULL},
-	{0x00027d, {[CaseLower] = 0x00027d,[CaseTitle] = 0x002c64,[CaseUpper] = 0x002c64,[CaseFold] = 0x00027d}, NULL},
-	{0x000280, {[CaseLower] = 0x000280,[CaseTitle] = 0x0001a6,[CaseUpper] = 0x0001a6,[CaseFold] = 0x000280}, NULL},
-	{0x000282, {[CaseLower] = 0x000282,[CaseTitle] = 0x00a7c5,[CaseUpper] = 0x00a7c5,[CaseFold] = 0x000282}, NULL},
-	{0x000283, {[CaseLower] = 0x000283,[CaseTitle] = 0x0001a9,[CaseUpper] = 0x0001a9,[CaseFold] = 0x000283}, NULL},
-	{0x000287, {[CaseLower] = 0x000287,[CaseTitle] = 0x00a7b1,[CaseUpper] = 0x00a7b1,[CaseFold] = 0x000287}, NULL},
-	{0x000288, {[CaseLower] = 0x000288,[CaseTitle] = 0x0001ae,[CaseUpper] = 0x0001ae,[CaseFold] = 0x000288}, NULL},
-	{0x000289, {[CaseLower] = 0x000289,[CaseTitle] = 0x000244,[CaseUpper] = 0x000244,[CaseFold] = 0x000289}, NULL},
-	{0x00028a, {[CaseLower] = 0x00028a,[CaseTitle] = 0x0001b1,[CaseUpper] = 0x0001b1,[CaseFold] = 0x00028a}, NULL},
-	{0x00028b, {[CaseLower] = 0x00028b,[CaseTitle] = 0x0001b2,[CaseUpper] = 0x0001b2,[CaseFold] = 0x00028b}, NULL},
-	{0x00028c, {[CaseLower] = 0x00028c,[CaseTitle] = 0x000245,[CaseUpper] = 0x000245,[CaseFold] = 0x00028c}, NULL},
-	{0x000292, {[CaseLower] = 0x000292,[CaseTitle] = 0x0001b7,[CaseUpper] = 0x0001b7,[CaseFold] = 0x000292}, NULL},
-	{0x00029d, {[CaseLower] = 0x00029d,[CaseTitle] = 0x00a7b2,[CaseUpper] = 0x00a7b2,[CaseFold] = 0x00029d}, NULL},
-	{0x00029e, {[CaseLower] = 0x00029e,[CaseTitle] = 0x00a7b0,[CaseUpper] = 0x00a7b0,[CaseFold] = 0x00029e}, NULL},
-	{0x000345, {[CaseLower] = 0x000345,[CaseTitle] = 0x000399,[CaseUpper] = 0x000399,[CaseFold] = 0x0003b9}, NULL},
-	{0x000370, {[CaseLower] = 0x000371,[CaseTitle] = 0x000370,[CaseUpper] = 0x000370,[CaseFold] = 0x000371}, NULL},
-	{0x000371, {[CaseLower] = 0x000371,[CaseTitle] = 0x000370,[CaseUpper] = 0x000370,[CaseFold] = 0x000371}, NULL},
-	{0x000372, {[CaseLower] = 0x000373,[CaseTitle] = 0x000372,[CaseUpper] = 0x000372,[CaseFold] = 0x000373}, NULL},
-	{0x000373, {[CaseLower] = 0x000373,[CaseTitle] = 0x000372,[CaseUpper] = 0x000372,[CaseFold] = 0x000373}, NULL},
-	{0x000376, {[CaseLower] = 0x000377,[CaseTitle] = 0x000376,[CaseUpper] = 0x000376,[CaseFold] = 0x000377}, NULL},
-	{0x000377, {[CaseLower] = 0x000377,[CaseTitle] = 0x000376,[CaseUpper] = 0x000376,[CaseFold] = 0x000377}, NULL},
-	{0x00037b, {[CaseLower] = 0x00037b,[CaseTitle] = 0x0003fd,[CaseUpper] = 0x0003fd,[CaseFold] = 0x00037b}, NULL},
-	{0x00037c, {[CaseLower] = 0x00037c,[CaseTitle] = 0x0003fe,[CaseUpper] = 0x0003fe,[CaseFold] = 0x00037c}, NULL},
-	{0x00037d, {[CaseLower] = 0x00037d,[CaseTitle] = 0x0003ff,[CaseUpper] = 0x0003ff,[CaseFold] = 0x00037d}, NULL},
-	{0x00037f, {[CaseLower] = 0x0003f3,[CaseTitle] = 0x00037f,[CaseUpper] = 0x00037f,[CaseFold] = 0x0003f3}, NULL},
-	{0x000386, {[CaseLower] = 0x0003ac,[CaseTitle] = 0x000386,[CaseUpper] = 0x000386,[CaseFold] = 0x0003ac}, NULL},
-	{0x000388, {[CaseLower] = 0x0003ad,[CaseTitle] = 0x000388,[CaseUpper] = 0x000388,[CaseFold] = 0x0003ad}, NULL},
-	{0x000389, {[CaseLower] = 0x0003ae,[CaseTitle] = 0x000389,[CaseUpper] = 0x000389,[CaseFold] = 0x0003ae}, NULL},
-	{0x00038a, {[CaseLower] = 0x0003af,[CaseTitle] = 0x00038a,[CaseUpper] = 0x00038a,[CaseFold] = 0x0003af}, NULL},
-	{0x00038c, {[CaseLower] = 0x0003cc,[CaseTitle] = 0x00038c,[CaseUpper] = 0x00038c,[CaseFold] = 0x0003cc}, NULL},
-	{0x00038e, {[CaseLower] = 0x0003cd,[CaseTitle] = 0x00038e,[CaseUpper] = 0x00038e,[CaseFold] = 0x0003cd}, NULL},
-	{0x00038f, {[CaseLower] = 0x0003ce,[CaseTitle] = 0x00038f,[CaseUpper] = 0x00038f,[CaseFold] = 0x0003ce}, NULL},
-	{0x000390, {[CaseLower] = 0x000390,[CaseTitle] = 0x000390,[CaseUpper] = 0x000390,[CaseFold] = 0x000390}, &special_case[4]},
-	{0x000391, {[CaseLower] = 0x0003b1,[CaseTitle] = 0x000391,[CaseUpper] = 0x000391,[CaseFold] = 0x0003b1}, NULL},
-	{0x000392, {[CaseLower] = 0x0003b2,[CaseTitle] = 0x000392,[CaseUpper] = 0x000392,[CaseFold] = 0x0003b2}, NULL},
-	{0x000393, {[CaseLower] = 0x0003b3,[CaseTitle] = 0x000393,[CaseUpper] = 0x000393,[CaseFold] = 0x0003b3}, NULL},
-	{0x000394, {[CaseLower] = 0x0003b4,[CaseTitle] = 0x000394,[CaseUpper] = 0x000394,[CaseFold] = 0x0003b4}, NULL},
-	{0x000395, {[CaseLower] = 0x0003b5,[CaseTitle] = 0x000395,[CaseUpper] = 0x000395,[CaseFold] = 0x0003b5}, NULL},
-	{0x000396, {[CaseLower] = 0x0003b6,[CaseTitle] = 0x000396,[CaseUpper] = 0x000396,[CaseFold] = 0x0003b6}, NULL},
-	{0x000397, {[CaseLower] = 0x0003b7,[CaseTitle] = 0x000397,[CaseUpper] = 0x000397,[CaseFold] = 0x0003b7}, NULL},
-	{0x000398, {[CaseLower] = 0x0003b8,[CaseTitle] = 0x000398,[CaseUpper] = 0x000398,[CaseFold] = 0x0003b8}, NULL},
-	{0x000399, {[CaseLower] = 0x0003b9,[CaseTitle] = 0x000399,[CaseUpper] = 0x000399,[CaseFold] = 0x0003b9}, NULL},
-	{0x00039a, {[CaseLower] = 0x0003ba,[CaseTitle] = 0x00039a,[CaseUpper] = 0x00039a,[CaseFold] = 0x0003ba}, NULL},
-	{0x00039b, {[CaseLower] = 0x0003bb,[CaseTitle] = 0x00039b,[CaseUpper] = 0x00039b,[CaseFold] = 0x0003bb}, NULL},
-	{0x00039c, {[CaseLower] = 0x0003bc,[CaseTitle] = 0x00039c,[CaseUpper] = 0x00039c,[CaseFold] = 0x0003bc}, NULL},
-	{0x00039d, {[CaseLower] = 0x0003bd,[CaseTitle] = 0x00039d,[CaseUpper] = 0x00039d,[CaseFold] = 0x0003bd}, NULL},
-	{0x00039e, {[CaseLower] = 0x0003be,[CaseTitle] = 0x00039e,[CaseUpper] = 0x00039e,[CaseFold] = 0x0003be}, NULL},
-	{0x00039f, {[CaseLower] = 0x0003bf,[CaseTitle] = 0x00039f,[CaseUpper] = 0x00039f,[CaseFold] = 0x0003bf}, NULL},
-	{0x0003a0, {[CaseLower] = 0x0003c0,[CaseTitle] = 0x0003a0,[CaseUpper] = 0x0003a0,[CaseFold] = 0x0003c0}, NULL},
-	{0x0003a1, {[CaseLower] = 0x0003c1,[CaseTitle] = 0x0003a1,[CaseUpper] = 0x0003a1,[CaseFold] = 0x0003c1}, NULL},
-	{0x0003a3, {[CaseLower] = 0x0003c3,[CaseTitle] = 0x0003a3,[CaseUpper] = 0x0003a3,[CaseFold] = 0x0003c3}, &special_case[5]},
-	{0x0003a4, {[CaseLower] = 0x0003c4,[CaseTitle] = 0x0003a4,[CaseUpper] = 0x0003a4,[CaseFold] = 0x0003c4}, NULL},
-	{0x0003a5, {[CaseLower] = 0x0003c5,[CaseTitle] = 0x0003a5,[CaseUpper] = 0x0003a5,[CaseFold] = 0x0003c5}, NULL},
-	{0x0003a6, {[CaseLower] = 0x0003c6,[CaseTitle] = 0x0003a6,[CaseUpper] = 0x0003a6,[CaseFold] = 0x0003c6}, NULL},
-	{0x0003a7, {[CaseLower] = 0x0003c7,[CaseTitle] = 0x0003a7,[CaseUpper] = 0x0003a7,[CaseFold] = 0x0003c7}, NULL},
-	{0x0003a8, {[CaseLower] = 0x0003c8,[CaseTitle] = 0x0003a8,[CaseUpper] = 0x0003a8,[CaseFold] = 0x0003c8}, NULL},
-	{0x0003a9, {[CaseLower] = 0x0003c9,[CaseTitle] = 0x0003a9,[CaseUpper] = 0x0003a9,[CaseFold] = 0x0003c9}, NULL},
-	{0x0003aa, {[CaseLower] = 0x0003ca,[CaseTitle] = 0x0003aa,[CaseUpper] = 0x0003aa,[CaseFold] = 0x0003ca}, NULL},
-	{0x0003ab, {[CaseLower] = 0x0003cb,[CaseTitle] = 0x0003ab,[CaseUpper] = 0x0003ab,[CaseFold] = 0x0003cb}, NULL},
-	{0x0003ac, {[CaseLower] = 0x0003ac,[CaseTitle] = 0x000386,[CaseUpper] = 0x000386,[CaseFold] = 0x0003ac}, NULL},
-	{0x0003ad, {[CaseLower] = 0x0003ad,[CaseTitle] = 0x000388,[CaseUpper] = 0x000388,[CaseFold] = 0x0003ad}, NULL},
-	{0x0003ae, {[CaseLower] = 0x0003ae,[CaseTitle] = 0x000389,[CaseUpper] = 0x000389,[CaseFold] = 0x0003ae}, NULL},
-	{0x0003af, {[CaseLower] = 0x0003af,[CaseTitle] = 0x00038a,[CaseUpper] = 0x00038a,[CaseFold] = 0x0003af}, NULL},
-	{0x0003b0, {[CaseLower] = 0x0003b0,[CaseTitle] = 0x0003b0,[CaseUpper] = 0x0003b0,[CaseFold] = 0x0003b0}, &special_case[6]},
-	{0x0003b1, {[CaseLower] = 0x0003b1,[CaseTitle] = 0x000391,[CaseUpper] = 0x000391,[CaseFold] = 0x0003b1}, NULL},
-	{0x0003b2, {[CaseLower] = 0x0003b2,[CaseTitle] = 0x000392,[CaseUpper] = 0x000392,[CaseFold] = 0x0003b2}, NULL},
-	{0x0003b3, {[CaseLower] = 0x0003b3,[CaseTitle] = 0x000393,[CaseUpper] = 0x000393,[CaseFold] = 0x0003b3}, NULL},
-	{0x0003b4, {[CaseLower] = 0x0003b4,[CaseTitle] = 0x000394,[CaseUpper] = 0x000394,[CaseFold] = 0x0003b4}, NULL},
-	{0x0003b5, {[CaseLower] = 0x0003b5,[CaseTitle] = 0x000395,[CaseUpper] = 0x000395,[CaseFold] = 0x0003b5}, NULL},
-	{0x0003b6, {[CaseLower] = 0x0003b6,[CaseTitle] = 0x000396,[CaseUpper] = 0x000396,[CaseFold] = 0x0003b6}, NULL},
-	{0x0003b7, {[CaseLower] = 0x0003b7,[CaseTitle] = 0x000397,[CaseUpper] = 0x000397,[CaseFold] = 0x0003b7}, NULL},
-	{0x0003b8, {[CaseLower] = 0x0003b8,[CaseTitle] = 0x000398,[CaseUpper] = 0x000398,[CaseFold] = 0x0003b8}, NULL},
-	{0x0003b9, {[CaseLower] = 0x0003b9,[CaseTitle] = 0x000399,[CaseUpper] = 0x000399,[CaseFold] = 0x0003b9}, NULL},
-	{0x0003ba, {[CaseLower] = 0x0003ba,[CaseTitle] = 0x00039a,[CaseUpper] = 0x00039a,[CaseFold] = 0x0003ba}, NULL},
-	{0x0003bb, {[CaseLower] = 0x0003bb,[CaseTitle] = 0x00039b,[CaseUpper] = 0x00039b,[CaseFold] = 0x0003bb}, NULL},
-	{0x0003bc, {[CaseLower] = 0x0003bc,[CaseTitle] = 0x00039c,[CaseUpper] = 0x00039c,[CaseFold] = 0x0003bc}, NULL},
-	{0x0003bd, {[CaseLower] = 0x0003bd,[CaseTitle] = 0x00039d,[CaseUpper] = 0x00039d,[CaseFold] = 0x0003bd}, NULL},
-	{0x0003be, {[CaseLower] = 0x0003be,[CaseTitle] = 0x00039e,[CaseUpper] = 0x00039e,[CaseFold] = 0x0003be}, NULL},
-	{0x0003bf, {[CaseLower] = 0x0003bf,[CaseTitle] = 0x00039f,[CaseUpper] = 0x00039f,[CaseFold] = 0x0003bf}, NULL},
-	{0x0003c0, {[CaseLower] = 0x0003c0,[CaseTitle] = 0x0003a0,[CaseUpper] = 0x0003a0,[CaseFold] = 0x0003c0}, NULL},
-	{0x0003c1, {[CaseLower] = 0x0003c1,[CaseTitle] = 0x0003a1,[CaseUpper] = 0x0003a1,[CaseFold] = 0x0003c1}, NULL},
-	{0x0003c2, {[CaseLower] = 0x0003c2,[CaseTitle] = 0x0003a3,[CaseUpper] = 0x0003a3,[CaseFold] = 0x0003c3}, NULL},
-	{0x0003c3, {[CaseLower] = 0x0003c3,[CaseTitle] = 0x0003a3,[CaseUpper] = 0x0003a3,[CaseFold] = 0x0003c3}, NULL},
-	{0x0003c4, {[CaseLower] = 0x0003c4,[CaseTitle] = 0x0003a4,[CaseUpper] = 0x0003a4,[CaseFold] = 0x0003c4}, NULL},
-	{0x0003c5, {[CaseLower] = 0x0003c5,[CaseTitle] = 0x0003a5,[CaseUpper] = 0x0003a5,[CaseFold] = 0x0003c5}, NULL},
-	{0x0003c6, {[CaseLower] = 0x0003c6,[CaseTitle] = 0x0003a6,[CaseUpper] = 0x0003a6,[CaseFold] = 0x0003c6}, NULL},
-	{0x0003c7, {[CaseLower] = 0x0003c7,[CaseTitle] = 0x0003a7,[CaseUpper] = 0x0003a7,[CaseFold] = 0x0003c7}, NULL},
-	{0x0003c8, {[CaseLower] = 0x0003c8,[CaseTitle] = 0x0003a8,[CaseUpper] = 0x0003a8,[CaseFold] = 0x0003c8}, NULL},
-	{0x0003c9, {[CaseLower] = 0x0003c9,[CaseTitle] = 0x0003a9,[CaseUpper] = 0x0003a9,[CaseFold] = 0x0003c9}, NULL},
-	{0x0003ca, {[CaseLower] = 0x0003ca,[CaseTitle] = 0x0003aa,[CaseUpper] = 0x0003aa,[CaseFold] = 0x0003ca}, NULL},
-	{0x0003cb, {[CaseLower] = 0x0003cb,[CaseTitle] = 0x0003ab,[CaseUpper] = 0x0003ab,[CaseFold] = 0x0003cb}, NULL},
-	{0x0003cc, {[CaseLower] = 0x0003cc,[CaseTitle] = 0x00038c,[CaseUpper] = 0x00038c,[CaseFold] = 0x0003cc}, NULL},
-	{0x0003cd, {[CaseLower] = 0x0003cd,[CaseTitle] = 0x00038e,[CaseUpper] = 0x00038e,[CaseFold] = 0x0003cd}, NULL},
-	{0x0003ce, {[CaseLower] = 0x0003ce,[CaseTitle] = 0x00038f,[CaseUpper] = 0x00038f,[CaseFold] = 0x0003ce}, NULL},
-	{0x0003cf, {[CaseLower] = 0x0003d7,[CaseTitle] = 0x0003cf,[CaseUpper] = 0x0003cf,[CaseFold] = 0x0003d7}, NULL},
-	{0x0003d0, {[CaseLower] = 0x0003d0,[CaseTitle] = 0x000392,[CaseUpper] = 0x000392,[CaseFold] = 0x0003b2}, NULL},
-	{0x0003d1, {[CaseLower] = 0x0003d1,[CaseTitle] = 0x000398,[CaseUpper] = 0x000398,[CaseFold] = 0x0003b8}, NULL},
-	{0x0003d5, {[CaseLower] = 0x0003d5,[CaseTitle] = 0x0003a6,[CaseUpper] = 0x0003a6,[CaseFold] = 0x0003c6}, NULL},
-	{0x0003d6, {[CaseLower] = 0x0003d6,[CaseTitle] = 0x0003a0,[CaseUpper] = 0x0003a0,[CaseFold] = 0x0003c0}, NULL},
-	{0x0003d7, {[CaseLower] = 0x0003d7,[CaseTitle] = 0x0003cf,[CaseUpper] = 0x0003cf,[CaseFold] = 0x0003d7}, NULL},
-	{0x0003d8, {[CaseLower] = 0x0003d9,[CaseTitle] = 0x0003d8,[CaseUpper] = 0x0003d8,[CaseFold] = 0x0003d9}, NULL},
-	{0x0003d9, {[CaseLower] = 0x0003d9,[CaseTitle] = 0x0003d8,[CaseUpper] = 0x0003d8,[CaseFold] = 0x0003d9}, NULL},
-	{0x0003da, {[CaseLower] = 0x0003db,[CaseTitle] = 0x0003da,[CaseUpper] = 0x0003da,[CaseFold] = 0x0003db}, NULL},
-	{0x0003db, {[CaseLower] = 0x0003db,[CaseTitle] = 0x0003da,[CaseUpper] = 0x0003da,[CaseFold] = 0x0003db}, NULL},
-	{0x0003dc, {[CaseLower] = 0x0003dd,[CaseTitle] = 0x0003dc,[CaseUpper] = 0x0003dc,[CaseFold] = 0x0003dd}, NULL},
-	{0x0003dd, {[CaseLower] = 0x0003dd,[CaseTitle] = 0x0003dc,[CaseUpper] = 0x0003dc,[CaseFold] = 0x0003dd}, NULL},
-	{0x0003de, {[CaseLower] = 0x0003df,[CaseTitle] = 0x0003de,[CaseUpper] = 0x0003de,[CaseFold] = 0x0003df}, NULL},
-	{0x0003df, {[CaseLower] = 0x0003df,[CaseTitle] = 0x0003de,[CaseUpper] = 0x0003de,[CaseFold] = 0x0003df}, NULL},
-	{0x0003e0, {[CaseLower] = 0x0003e1,[CaseTitle] = 0x0003e0,[CaseUpper] = 0x0003e0,[CaseFold] = 0x0003e1}, NULL},
-	{0x0003e1, {[CaseLower] = 0x0003e1,[CaseTitle] = 0x0003e0,[CaseUpper] = 0x0003e0,[CaseFold] = 0x0003e1}, NULL},
-	{0x0003e2, {[CaseLower] = 0x0003e3,[CaseTitle] = 0x0003e2,[CaseUpper] = 0x0003e2,[CaseFold] = 0x0003e3}, NULL},
-	{0x0003e3, {[CaseLower] = 0x0003e3,[CaseTitle] = 0x0003e2,[CaseUpper] = 0x0003e2,[CaseFold] = 0x0003e3}, NULL},
-	{0x0003e4, {[CaseLower] = 0x0003e5,[CaseTitle] = 0x0003e4,[CaseUpper] = 0x0003e4,[CaseFold] = 0x0003e5}, NULL},
-	{0x0003e5, {[CaseLower] = 0x0003e5,[CaseTitle] = 0x0003e4,[CaseUpper] = 0x0003e4,[CaseFold] = 0x0003e5}, NULL},
-	{0x0003e6, {[CaseLower] = 0x0003e7,[CaseTitle] = 0x0003e6,[CaseUpper] = 0x0003e6,[CaseFold] = 0x0003e7}, NULL},
-	{0x0003e7, {[CaseLower] = 0x0003e7,[CaseTitle] = 0x0003e6,[CaseUpper] = 0x0003e6,[CaseFold] = 0x0003e7}, NULL},
-	{0x0003e8, {[CaseLower] = 0x0003e9,[CaseTitle] = 0x0003e8,[CaseUpper] = 0x0003e8,[CaseFold] = 0x0003e9}, NULL},
-	{0x0003e9, {[CaseLower] = 0x0003e9,[CaseTitle] = 0x0003e8,[CaseUpper] = 0x0003e8,[CaseFold] = 0x0003e9}, NULL},
-	{0x0003ea, {[CaseLower] = 0x0003eb,[CaseTitle] = 0x0003ea,[CaseUpper] = 0x0003ea,[CaseFold] = 0x0003eb}, NULL},
-	{0x0003eb, {[CaseLower] = 0x0003eb,[CaseTitle] = 0x0003ea,[CaseUpper] = 0x0003ea,[CaseFold] = 0x0003eb}, NULL},
-	{0x0003ec, {[CaseLower] = 0x0003ed,[CaseTitle] = 0x0003ec,[CaseUpper] = 0x0003ec,[CaseFold] = 0x0003ed}, NULL},
-	{0x0003ed, {[CaseLower] = 0x0003ed,[CaseTitle] = 0x0003ec,[CaseUpper] = 0x0003ec,[CaseFold] = 0x0003ed}, NULL},
-	{0x0003ee, {[CaseLower] = 0x0003ef,[CaseTitle] = 0x0003ee,[CaseUpper] = 0x0003ee,[CaseFold] = 0x0003ef}, NULL},
-	{0x0003ef, {[CaseLower] = 0x0003ef,[CaseTitle] = 0x0003ee,[CaseUpper] = 0x0003ee,[CaseFold] = 0x0003ef}, NULL},
-	{0x0003f0, {[CaseLower] = 0x0003f0,[CaseTitle] = 0x00039a,[CaseUpper] = 0x00039a,[CaseFold] = 0x0003ba}, NULL},
-	{0x0003f1, {[CaseLower] = 0x0003f1,[CaseTitle] = 0x0003a1,[CaseUpper] = 0x0003a1,[CaseFold] = 0x0003c1}, NULL},
-	{0x0003f2, {[CaseLower] = 0x0003f2,[CaseTitle] = 0x0003f9,[CaseUpper] = 0x0003f9,[CaseFold] = 0x0003f2}, NULL},
-	{0x0003f3, {[CaseLower] = 0x0003f3,[CaseTitle] = 0x00037f,[CaseUpper] = 0x00037f,[CaseFold] = 0x0003f3}, NULL},
-	{0x0003f4, {[CaseLower] = 0x0003b8,[CaseTitle] = 0x0003f4,[CaseUpper] = 0x0003f4,[CaseFold] = 0x0003b8}, NULL},
-	{0x0003f5, {[CaseLower] = 0x0003f5,[CaseTitle] = 0x000395,[CaseUpper] = 0x000395,[CaseFold] = 0x0003b5}, NULL},
-	{0x0003f7, {[CaseLower] = 0x0003f8,[CaseTitle] = 0x0003f7,[CaseUpper] = 0x0003f7,[CaseFold] = 0x0003f8}, NULL},
-	{0x0003f8, {[CaseLower] = 0x0003f8,[CaseTitle] = 0x0003f7,[CaseUpper] = 0x0003f7,[CaseFold] = 0x0003f8}, NULL},
-	{0x0003f9, {[CaseLower] = 0x0003f2,[CaseTitle] = 0x0003f9,[CaseUpper] = 0x0003f9,[CaseFold] = 0x0003f2}, NULL},
-	{0x0003fa, {[CaseLower] = 0x0003fb,[CaseTitle] = 0x0003fa,[CaseUpper] = 0x0003fa,[CaseFold] = 0x0003fb}, NULL},
-	{0x0003fb, {[CaseLower] = 0x0003fb,[CaseTitle] = 0x0003fa,[CaseUpper] = 0x0003fa,[CaseFold] = 0x0003fb}, NULL},
-	{0x0003fd, {[CaseLower] = 0x00037b,[CaseTitle] = 0x0003fd,[CaseUpper] = 0x0003fd,[CaseFold] = 0x00037b}, NULL},
-	{0x0003fe, {[CaseLower] = 0x00037c,[CaseTitle] = 0x0003fe,[CaseUpper] = 0x0003fe,[CaseFold] = 0x00037c}, NULL},
-	{0x0003ff, {[CaseLower] = 0x00037d,[CaseTitle] = 0x0003ff,[CaseUpper] = 0x0003ff,[CaseFold] = 0x00037d}, NULL},
-	{0x000400, {[CaseLower] = 0x000450,[CaseTitle] = 0x000400,[CaseUpper] = 0x000400,[CaseFold] = 0x000450}, NULL},
-	{0x000401, {[CaseLower] = 0x000451,[CaseTitle] = 0x000401,[CaseUpper] = 0x000401,[CaseFold] = 0x000451}, NULL},
-	{0x000402, {[CaseLower] = 0x000452,[CaseTitle] = 0x000402,[CaseUpper] = 0x000402,[CaseFold] = 0x000452}, NULL},
-	{0x000403, {[CaseLower] = 0x000453,[CaseTitle] = 0x000403,[CaseUpper] = 0x000403,[CaseFold] = 0x000453}, NULL},
-	{0x000404, {[CaseLower] = 0x000454,[CaseTitle] = 0x000404,[CaseUpper] = 0x000404,[CaseFold] = 0x000454}, NULL},
-	{0x000405, {[CaseLower] = 0x000455,[CaseTitle] = 0x000405,[CaseUpper] = 0x000405,[CaseFold] = 0x000455}, NULL},
-	{0x000406, {[CaseLower] = 0x000456,[CaseTitle] = 0x000406,[CaseUpper] = 0x000406,[CaseFold] = 0x000456}, NULL},
-	{0x000407, {[CaseLower] = 0x000457,[CaseTitle] = 0x000407,[CaseUpper] = 0x000407,[CaseFold] = 0x000457}, NULL},
-	{0x000408, {[CaseLower] = 0x000458,[CaseTitle] = 0x000408,[CaseUpper] = 0x000408,[CaseFold] = 0x000458}, NULL},
-	{0x000409, {[CaseLower] = 0x000459,[CaseTitle] = 0x000409,[CaseUpper] = 0x000409,[CaseFold] = 0x000459}, NULL},
-	{0x00040a, {[CaseLower] = 0x00045a,[CaseTitle] = 0x00040a,[CaseUpper] = 0x00040a,[CaseFold] = 0x00045a}, NULL},
-	{0x00040b, {[CaseLower] = 0x00045b,[CaseTitle] = 0x00040b,[CaseUpper] = 0x00040b,[CaseFold] = 0x00045b}, NULL},
-	{0x00040c, {[CaseLower] = 0x00045c,[CaseTitle] = 0x00040c,[CaseUpper] = 0x00040c,[CaseFold] = 0x00045c}, NULL},
-	{0x00040d, {[CaseLower] = 0x00045d,[CaseTitle] = 0x00040d,[CaseUpper] = 0x00040d,[CaseFold] = 0x00045d}, NULL},
-	{0x00040e, {[CaseLower] = 0x00045e,[CaseTitle] = 0x00040e,[CaseUpper] = 0x00040e,[CaseFold] = 0x00045e}, NULL},
-	{0x00040f, {[CaseLower] = 0x00045f,[CaseTitle] = 0x00040f,[CaseUpper] = 0x00040f,[CaseFold] = 0x00045f}, NULL},
-	{0x000410, {[CaseLower] = 0x000430,[CaseTitle] = 0x000410,[CaseUpper] = 0x000410,[CaseFold] = 0x000430}, NULL},
-	{0x000411, {[CaseLower] = 0x000431,[CaseTitle] = 0x000411,[CaseUpper] = 0x000411,[CaseFold] = 0x000431}, NULL},
-	{0x000412, {[CaseLower] = 0x000432,[CaseTitle] = 0x000412,[CaseUpper] = 0x000412,[CaseFold] = 0x000432}, NULL},
-	{0x000413, {[CaseLower] = 0x000433,[CaseTitle] = 0x000413,[CaseUpper] = 0x000413,[CaseFold] = 0x000433}, NULL},
-	{0x000414, {[CaseLower] = 0x000434,[CaseTitle] = 0x000414,[CaseUpper] = 0x000414,[CaseFold] = 0x000434}, NULL},
-	{0x000415, {[CaseLower] = 0x000435,[CaseTitle] = 0x000415,[CaseUpper] = 0x000415,[CaseFold] = 0x000435}, NULL},
-	{0x000416, {[CaseLower] = 0x000436,[CaseTitle] = 0x000416,[CaseUpper] = 0x000416,[CaseFold] = 0x000436}, NULL},
-	{0x000417, {[CaseLower] = 0x000437,[CaseTitle] = 0x000417,[CaseUpper] = 0x000417,[CaseFold] = 0x000437}, NULL},
-	{0x000418, {[CaseLower] = 0x000438,[CaseTitle] = 0x000418,[CaseUpper] = 0x000418,[CaseFold] = 0x000438}, NULL},
-	{0x000419, {[CaseLower] = 0x000439,[CaseTitle] = 0x000419,[CaseUpper] = 0x000419,[CaseFold] = 0x000439}, NULL},
-	{0x00041a, {[CaseLower] = 0x00043a,[CaseTitle] = 0x00041a,[CaseUpper] = 0x00041a,[CaseFold] = 0x00043a}, NULL},
-	{0x00041b, {[CaseLower] = 0x00043b,[CaseTitle] = 0x00041b,[CaseUpper] = 0x00041b,[CaseFold] = 0x00043b}, NULL},
-	{0x00041c, {[CaseLower] = 0x00043c,[CaseTitle] = 0x00041c,[CaseUpper] = 0x00041c,[CaseFold] = 0x00043c}, NULL},
-	{0x00041d, {[CaseLower] = 0x00043d,[CaseTitle] = 0x00041d,[CaseUpper] = 0x00041d,[CaseFold] = 0x00043d}, NULL},
-	{0x00041e, {[CaseLower] = 0x00043e,[CaseTitle] = 0x00041e,[CaseUpper] = 0x00041e,[CaseFold] = 0x00043e}, NULL},
-	{0x00041f, {[CaseLower] = 0x00043f,[CaseTitle] = 0x00041f,[CaseUpper] = 0x00041f,[CaseFold] = 0x00043f}, NULL},
-	{0x000420, {[CaseLower] = 0x000440,[CaseTitle] = 0x000420,[CaseUpper] = 0x000420,[CaseFold] = 0x000440}, NULL},
-	{0x000421, {[CaseLower] = 0x000441,[CaseTitle] = 0x000421,[CaseUpper] = 0x000421,[CaseFold] = 0x000441}, NULL},
-	{0x000422, {[CaseLower] = 0x000442,[CaseTitle] = 0x000422,[CaseUpper] = 0x000422,[CaseFold] = 0x000442}, NULL},
-	{0x000423, {[CaseLower] = 0x000443,[CaseTitle] = 0x000423,[CaseUpper] = 0x000423,[CaseFold] = 0x000443}, NULL},
-	{0x000424, {[CaseLower] = 0x000444,[CaseTitle] = 0x000424,[CaseUpper] = 0x000424,[CaseFold] = 0x000444}, NULL},
-	{0x000425, {[CaseLower] = 0x000445,[CaseTitle] = 0x000425,[CaseUpper] = 0x000425,[CaseFold] = 0x000445}, NULL},
-	{0x000426, {[CaseLower] = 0x000446,[CaseTitle] = 0x000426,[CaseUpper] = 0x000426,[CaseFold] = 0x000446}, NULL},
-	{0x000427, {[CaseLower] = 0x000447,[CaseTitle] = 0x000427,[CaseUpper] = 0x000427,[CaseFold] = 0x000447}, NULL},
-	{0x000428, {[CaseLower] = 0x000448,[CaseTitle] = 0x000428,[CaseUpper] = 0x000428,[CaseFold] = 0x000448}, NULL},
-	{0x000429, {[CaseLower] = 0x000449,[CaseTitle] = 0x000429,[CaseUpper] = 0x000429,[CaseFold] = 0x000449}, NULL},
-	{0x00042a, {[CaseLower] = 0x00044a,[CaseTitle] = 0x00042a,[CaseUpper] = 0x00042a,[CaseFold] = 0x00044a}, NULL},
-	{0x00042b, {[CaseLower] = 0x00044b,[CaseTitle] = 0x00042b,[CaseUpper] = 0x00042b,[CaseFold] = 0x00044b}, NULL},
-	{0x00042c, {[CaseLower] = 0x00044c,[CaseTitle] = 0x00042c,[CaseUpper] = 0x00042c,[CaseFold] = 0x00044c}, NULL},
-	{0x00042d, {[CaseLower] = 0x00044d,[CaseTitle] = 0x00042d,[CaseUpper] = 0x00042d,[CaseFold] = 0x00044d}, NULL},
-	{0x00042e, {[CaseLower] = 0x00044e,[CaseTitle] = 0x00042e,[CaseUpper] = 0x00042e,[CaseFold] = 0x00044e}, NULL},
-	{0x00042f, {[CaseLower] = 0x00044f,[CaseTitle] = 0x00042f,[CaseUpper] = 0x00042f,[CaseFold] = 0x00044f}, NULL},
-	{0x000430, {[CaseLower] = 0x000430,[CaseTitle] = 0x000410,[CaseUpper] = 0x000410,[CaseFold] = 0x000430}, NULL},
-	{0x000431, {[CaseLower] = 0x000431,[CaseTitle] = 0x000411,[CaseUpper] = 0x000411,[CaseFold] = 0x000431}, NULL},
-	{0x000432, {[CaseLower] = 0x000432,[CaseTitle] = 0x000412,[CaseUpper] = 0x000412,[CaseFold] = 0x000432}, NULL},
-	{0x000433, {[CaseLower] = 0x000433,[CaseTitle] = 0x000413,[CaseUpper] = 0x000413,[CaseFold] = 0x000433}, NULL},
-	{0x000434, {[CaseLower] = 0x000434,[CaseTitle] = 0x000414,[CaseUpper] = 0x000414,[CaseFold] = 0x000434}, NULL},
-	{0x000435, {[CaseLower] = 0x000435,[CaseTitle] = 0x000415,[CaseUpper] = 0x000415,[CaseFold] = 0x000435}, NULL},
-	{0x000436, {[CaseLower] = 0x000436,[CaseTitle] = 0x000416,[CaseUpper] = 0x000416,[CaseFold] = 0x000436}, NULL},
-	{0x000437, {[CaseLower] = 0x000437,[CaseTitle] = 0x000417,[CaseUpper] = 0x000417,[CaseFold] = 0x000437}, NULL},
-	{0x000438, {[CaseLower] = 0x000438,[CaseTitle] = 0x000418,[CaseUpper] = 0x000418,[CaseFold] = 0x000438}, NULL},
-	{0x000439, {[CaseLower] = 0x000439,[CaseTitle] = 0x000419,[CaseUpper] = 0x000419,[CaseFold] = 0x000439}, NULL},
-	{0x00043a, {[CaseLower] = 0x00043a,[CaseTitle] = 0x00041a,[CaseUpper] = 0x00041a,[CaseFold] = 0x00043a}, NULL},
-	{0x00043b, {[CaseLower] = 0x00043b,[CaseTitle] = 0x00041b,[CaseUpper] = 0x00041b,[CaseFold] = 0x00043b}, NULL},
-	{0x00043c, {[CaseLower] = 0x00043c,[CaseTitle] = 0x00041c,[CaseUpper] = 0x00041c,[CaseFold] = 0x00043c}, NULL},
-	{0x00043d, {[CaseLower] = 0x00043d,[CaseTitle] = 0x00041d,[CaseUpper] = 0x00041d,[CaseFold] = 0x00043d}, NULL},
-	{0x00043e, {[CaseLower] = 0x00043e,[CaseTitle] = 0x00041e,[CaseUpper] = 0x00041e,[CaseFold] = 0x00043e}, NULL},
-	{0x00043f, {[CaseLower] = 0x00043f,[CaseTitle] = 0x00041f,[CaseUpper] = 0x00041f,[CaseFold] = 0x00043f}, NULL},
-	{0x000440, {[CaseLower] = 0x000440,[CaseTitle] = 0x000420,[CaseUpper] = 0x000420,[CaseFold] = 0x000440}, NULL},
-	{0x000441, {[CaseLower] = 0x000441,[CaseTitle] = 0x000421,[CaseUpper] = 0x000421,[CaseFold] = 0x000441}, NULL},
-	{0x000442, {[CaseLower] = 0x000442,[CaseTitle] = 0x000422,[CaseUpper] = 0x000422,[CaseFold] = 0x000442}, NULL},
-	{0x000443, {[CaseLower] = 0x000443,[CaseTitle] = 0x000423,[CaseUpper] = 0x000423,[CaseFold] = 0x000443}, NULL},
-	{0x000444, {[CaseLower] = 0x000444,[CaseTitle] = 0x000424,[CaseUpper] = 0x000424,[CaseFold] = 0x000444}, NULL},
-	{0x000445, {[CaseLower] = 0x000445,[CaseTitle] = 0x000425,[CaseUpper] = 0x000425,[CaseFold] = 0x000445}, NULL},
-	{0x000446, {[CaseLower] = 0x000446,[CaseTitle] = 0x000426,[CaseUpper] = 0x000426,[CaseFold] = 0x000446}, NULL},
-	{0x000447, {[CaseLower] = 0x000447,[CaseTitle] = 0x000427,[CaseUpper] = 0x000427,[CaseFold] = 0x000447}, NULL},
-	{0x000448, {[CaseLower] = 0x000448,[CaseTitle] = 0x000428,[CaseUpper] = 0x000428,[CaseFold] = 0x000448}, NULL},
-	{0x000449, {[CaseLower] = 0x000449,[CaseTitle] = 0x000429,[CaseUpper] = 0x000429,[CaseFold] = 0x000449}, NULL},
-	{0x00044a, {[CaseLower] = 0x00044a,[CaseTitle] = 0x00042a,[CaseUpper] = 0x00042a,[CaseFold] = 0x00044a}, NULL},
-	{0x00044b, {[CaseLower] = 0x00044b,[CaseTitle] = 0x00042b,[CaseUpper] = 0x00042b,[CaseFold] = 0x00044b}, NULL},
-	{0x00044c, {[CaseLower] = 0x00044c,[CaseTitle] = 0x00042c,[CaseUpper] = 0x00042c,[CaseFold] = 0x00044c}, NULL},
-	{0x00044d, {[CaseLower] = 0x00044d,[CaseTitle] = 0x00042d,[CaseUpper] = 0x00042d,[CaseFold] = 0x00044d}, NULL},
-	{0x00044e, {[CaseLower] = 0x00044e,[CaseTitle] = 0x00042e,[CaseUpper] = 0x00042e,[CaseFold] = 0x00044e}, NULL},
-	{0x00044f, {[CaseLower] = 0x00044f,[CaseTitle] = 0x00042f,[CaseUpper] = 0x00042f,[CaseFold] = 0x00044f}, NULL},
-	{0x000450, {[CaseLower] = 0x000450,[CaseTitle] = 0x000400,[CaseUpper] = 0x000400,[CaseFold] = 0x000450}, NULL},
-	{0x000451, {[CaseLower] = 0x000451,[CaseTitle] = 0x000401,[CaseUpper] = 0x000401,[CaseFold] = 0x000451}, NULL},
-	{0x000452, {[CaseLower] = 0x000452,[CaseTitle] = 0x000402,[CaseUpper] = 0x000402,[CaseFold] = 0x000452}, NULL},
-	{0x000453, {[CaseLower] = 0x000453,[CaseTitle] = 0x000403,[CaseUpper] = 0x000403,[CaseFold] = 0x000453}, NULL},
-	{0x000454, {[CaseLower] = 0x000454,[CaseTitle] = 0x000404,[CaseUpper] = 0x000404,[CaseFold] = 0x000454}, NULL},
-	{0x000455, {[CaseLower] = 0x000455,[CaseTitle] = 0x000405,[CaseUpper] = 0x000405,[CaseFold] = 0x000455}, NULL},
-	{0x000456, {[CaseLower] = 0x000456,[CaseTitle] = 0x000406,[CaseUpper] = 0x000406,[CaseFold] = 0x000456}, NULL},
-	{0x000457, {[CaseLower] = 0x000457,[CaseTitle] = 0x000407,[CaseUpper] = 0x000407,[CaseFold] = 0x000457}, NULL},
-	{0x000458, {[CaseLower] = 0x000458,[CaseTitle] = 0x000408,[CaseUpper] = 0x000408,[CaseFold] = 0x000458}, NULL},
-	{0x000459, {[CaseLower] = 0x000459,[CaseTitle] = 0x000409,[CaseUpper] = 0x000409,[CaseFold] = 0x000459}, NULL},
-	{0x00045a, {[CaseLower] = 0x00045a,[CaseTitle] = 0x00040a,[CaseUpper] = 0x00040a,[CaseFold] = 0x00045a}, NULL},
-	{0x00045b, {[CaseLower] = 0x00045b,[CaseTitle] = 0x00040b,[CaseUpper] = 0x00040b,[CaseFold] = 0x00045b}, NULL},
-	{0x00045c, {[CaseLower] = 0x00045c,[CaseTitle] = 0x00040c,[CaseUpper] = 0x00040c,[CaseFold] = 0x00045c}, NULL},
-	{0x00045d, {[CaseLower] = 0x00045d,[CaseTitle] = 0x00040d,[CaseUpper] = 0x00040d,[CaseFold] = 0x00045d}, NULL},
-	{0x00045e, {[CaseLower] = 0x00045e,[CaseTitle] = 0x00040e,[CaseUpper] = 0x00040e,[CaseFold] = 0x00045e}, NULL},
-	{0x00045f, {[CaseLower] = 0x00045f,[CaseTitle] = 0x00040f,[CaseUpper] = 0x00040f,[CaseFold] = 0x00045f}, NULL},
-	{0x000460, {[CaseLower] = 0x000461,[CaseTitle] = 0x000460,[CaseUpper] = 0x000460,[CaseFold] = 0x000461}, NULL},
-	{0x000461, {[CaseLower] = 0x000461,[CaseTitle] = 0x000460,[CaseUpper] = 0x000460,[CaseFold] = 0x000461}, NULL},
-	{0x000462, {[CaseLower] = 0x000463,[CaseTitle] = 0x000462,[CaseUpper] = 0x000462,[CaseFold] = 0x000463}, NULL},
-	{0x000463, {[CaseLower] = 0x000463,[CaseTitle] = 0x000462,[CaseUpper] = 0x000462,[CaseFold] = 0x000463}, NULL},
-	{0x000464, {[CaseLower] = 0x000465,[CaseTitle] = 0x000464,[CaseUpper] = 0x000464,[CaseFold] = 0x000465}, NULL},
-	{0x000465, {[CaseLower] = 0x000465,[CaseTitle] = 0x000464,[CaseUpper] = 0x000464,[CaseFold] = 0x000465}, NULL},
-	{0x000466, {[CaseLower] = 0x000467,[CaseTitle] = 0x000466,[CaseUpper] = 0x000466,[CaseFold] = 0x000467}, NULL},
-	{0x000467, {[CaseLower] = 0x000467,[CaseTitle] = 0x000466,[CaseUpper] = 0x000466,[CaseFold] = 0x000467}, NULL},
-	{0x000468, {[CaseLower] = 0x000469,[CaseTitle] = 0x000468,[CaseUpper] = 0x000468,[CaseFold] = 0x000469}, NULL},
-	{0x000469, {[CaseLower] = 0x000469,[CaseTitle] = 0x000468,[CaseUpper] = 0x000468,[CaseFold] = 0x000469}, NULL},
-	{0x00046a, {[CaseLower] = 0x00046b,[CaseTitle] = 0x00046a,[CaseUpper] = 0x00046a,[CaseFold] = 0x00046b}, NULL},
-	{0x00046b, {[CaseLower] = 0x00046b,[CaseTitle] = 0x00046a,[CaseUpper] = 0x00046a,[CaseFold] = 0x00046b}, NULL},
-	{0x00046c, {[CaseLower] = 0x00046d,[CaseTitle] = 0x00046c,[CaseUpper] = 0x00046c,[CaseFold] = 0x00046d}, NULL},
-	{0x00046d, {[CaseLower] = 0x00046d,[CaseTitle] = 0x00046c,[CaseUpper] = 0x00046c,[CaseFold] = 0x00046d}, NULL},
-	{0x00046e, {[CaseLower] = 0x00046f,[CaseTitle] = 0x00046e,[CaseUpper] = 0x00046e,[CaseFold] = 0x00046f}, NULL},
-	{0x00046f, {[CaseLower] = 0x00046f,[CaseTitle] = 0x00046e,[CaseUpper] = 0x00046e,[CaseFold] = 0x00046f}, NULL},
-	{0x000470, {[CaseLower] = 0x000471,[CaseTitle] = 0x000470,[CaseUpper] = 0x000470,[CaseFold] = 0x000471}, NULL},
-	{0x000471, {[CaseLower] = 0x000471,[CaseTitle] = 0x000470,[CaseUpper] = 0x000470,[CaseFold] = 0x000471}, NULL},
-	{0x000472, {[CaseLower] = 0x000473,[CaseTitle] = 0x000472,[CaseUpper] = 0x000472,[CaseFold] = 0x000473}, NULL},
-	{0x000473, {[CaseLower] = 0x000473,[CaseTitle] = 0x000472,[CaseUpper] = 0x000472,[CaseFold] = 0x000473}, NULL},
-	{0x000474, {[CaseLower] = 0x000475,[CaseTitle] = 0x000474,[CaseUpper] = 0x000474,[CaseFold] = 0x000475}, NULL},
-	{0x000475, {[CaseLower] = 0x000475,[CaseTitle] = 0x000474,[CaseUpper] = 0x000474,[CaseFold] = 0x000475}, NULL},
-	{0x000476, {[CaseLower] = 0x000477,[CaseTitle] = 0x000476,[CaseUpper] = 0x000476,[CaseFold] = 0x000477}, NULL},
-	{0x000477, {[CaseLower] = 0x000477,[CaseTitle] = 0x000476,[CaseUpper] = 0x000476,[CaseFold] = 0x000477}, NULL},
-	{0x000478, {[CaseLower] = 0x000479,[CaseTitle] = 0x000478,[CaseUpper] = 0x000478,[CaseFold] = 0x000479}, NULL},
-	{0x000479, {[CaseLower] = 0x000479,[CaseTitle] = 0x000478,[CaseUpper] = 0x000478,[CaseFold] = 0x000479}, NULL},
-	{0x00047a, {[CaseLower] = 0x00047b,[CaseTitle] = 0x00047a,[CaseUpper] = 0x00047a,[CaseFold] = 0x00047b}, NULL},
-	{0x00047b, {[CaseLower] = 0x00047b,[CaseTitle] = 0x00047a,[CaseUpper] = 0x00047a,[CaseFold] = 0x00047b}, NULL},
-	{0x00047c, {[CaseLower] = 0x00047d,[CaseTitle] = 0x00047c,[CaseUpper] = 0x00047c,[CaseFold] = 0x00047d}, NULL},
-	{0x00047d, {[CaseLower] = 0x00047d,[CaseTitle] = 0x00047c,[CaseUpper] = 0x00047c,[CaseFold] = 0x00047d}, NULL},
-	{0x00047e, {[CaseLower] = 0x00047f,[CaseTitle] = 0x00047e,[CaseUpper] = 0x00047e,[CaseFold] = 0x00047f}, NULL},
-	{0x00047f, {[CaseLower] = 0x00047f,[CaseTitle] = 0x00047e,[CaseUpper] = 0x00047e,[CaseFold] = 0x00047f}, NULL},
-	{0x000480, {[CaseLower] = 0x000481,[CaseTitle] = 0x000480,[CaseUpper] = 0x000480,[CaseFold] = 0x000481}, NULL},
-	{0x000481, {[CaseLower] = 0x000481,[CaseTitle] = 0x000480,[CaseUpper] = 0x000480,[CaseFold] = 0x000481}, NULL},
-	{0x00048a, {[CaseLower] = 0x00048b,[CaseTitle] = 0x00048a,[CaseUpper] = 0x00048a,[CaseFold] = 0x00048b}, NULL},
-	{0x00048b, {[CaseLower] = 0x00048b,[CaseTitle] = 0x00048a,[CaseUpper] = 0x00048a,[CaseFold] = 0x00048b}, NULL},
-	{0x00048c, {[CaseLower] = 0x00048d,[CaseTitle] = 0x00048c,[CaseUpper] = 0x00048c,[CaseFold] = 0x00048d}, NULL},
-	{0x00048d, {[CaseLower] = 0x00048d,[CaseTitle] = 0x00048c,[CaseUpper] = 0x00048c,[CaseFold] = 0x00048d}, NULL},
-	{0x00048e, {[CaseLower] = 0x00048f,[CaseTitle] = 0x00048e,[CaseUpper] = 0x00048e,[CaseFold] = 0x00048f}, NULL},
-	{0x00048f, {[CaseLower] = 0x00048f,[CaseTitle] = 0x00048e,[CaseUpper] = 0x00048e,[CaseFold] = 0x00048f}, NULL},
-	{0x000490, {[CaseLower] = 0x000491,[CaseTitle] = 0x000490,[CaseUpper] = 0x000490,[CaseFold] = 0x000491}, NULL},
-	{0x000491, {[CaseLower] = 0x000491,[CaseTitle] = 0x000490,[CaseUpper] = 0x000490,[CaseFold] = 0x000491}, NULL},
-	{0x000492, {[CaseLower] = 0x000493,[CaseTitle] = 0x000492,[CaseUpper] = 0x000492,[CaseFold] = 0x000493}, NULL},
-	{0x000493, {[CaseLower] = 0x000493,[CaseTitle] = 0x000492,[CaseUpper] = 0x000492,[CaseFold] = 0x000493}, NULL},
-	{0x000494, {[CaseLower] = 0x000495,[CaseTitle] = 0x000494,[CaseUpper] = 0x000494,[CaseFold] = 0x000495}, NULL},
-	{0x000495, {[CaseLower] = 0x000495,[CaseTitle] = 0x000494,[CaseUpper] = 0x000494,[CaseFold] = 0x000495}, NULL},
-	{0x000496, {[CaseLower] = 0x000497,[CaseTitle] = 0x000496,[CaseUpper] = 0x000496,[CaseFold] = 0x000497}, NULL},
-	{0x000497, {[CaseLower] = 0x000497,[CaseTitle] = 0x000496,[CaseUpper] = 0x000496,[CaseFold] = 0x000497}, NULL},
-	{0x000498, {[CaseLower] = 0x000499,[CaseTitle] = 0x000498,[CaseUpper] = 0x000498,[CaseFold] = 0x000499}, NULL},
-	{0x000499, {[CaseLower] = 0x000499,[CaseTitle] = 0x000498,[CaseUpper] = 0x000498,[CaseFold] = 0x000499}, NULL},
-	{0x00049a, {[CaseLower] = 0x00049b,[CaseTitle] = 0x00049a,[CaseUpper] = 0x00049a,[CaseFold] = 0x00049b}, NULL},
-	{0x00049b, {[CaseLower] = 0x00049b,[CaseTitle] = 0x00049a,[CaseUpper] = 0x00049a,[CaseFold] = 0x00049b}, NULL},
-	{0x00049c, {[CaseLower] = 0x00049d,[CaseTitle] = 0x00049c,[CaseUpper] = 0x00049c,[CaseFold] = 0x00049d}, NULL},
-	{0x00049d, {[CaseLower] = 0x00049d,[CaseTitle] = 0x00049c,[CaseUpper] = 0x00049c,[CaseFold] = 0x00049d}, NULL},
-	{0x00049e, {[CaseLower] = 0x00049f,[CaseTitle] = 0x00049e,[CaseUpper] = 0x00049e,[CaseFold] = 0x00049f}, NULL},
-	{0x00049f, {[CaseLower] = 0x00049f,[CaseTitle] = 0x00049e,[CaseUpper] = 0x00049e,[CaseFold] = 0x00049f}, NULL},
-	{0x0004a0, {[CaseLower] = 0x0004a1,[CaseTitle] = 0x0004a0,[CaseUpper] = 0x0004a0,[CaseFold] = 0x0004a1}, NULL},
-	{0x0004a1, {[CaseLower] = 0x0004a1,[CaseTitle] = 0x0004a0,[CaseUpper] = 0x0004a0,[CaseFold] = 0x0004a1}, NULL},
-	{0x0004a2, {[CaseLower] = 0x0004a3,[CaseTitle] = 0x0004a2,[CaseUpper] = 0x0004a2,[CaseFold] = 0x0004a3}, NULL},
-	{0x0004a3, {[CaseLower] = 0x0004a3,[CaseTitle] = 0x0004a2,[CaseUpper] = 0x0004a2,[CaseFold] = 0x0004a3}, NULL},
-	{0x0004a4, {[CaseLower] = 0x0004a5,[CaseTitle] = 0x0004a4,[CaseUpper] = 0x0004a4,[CaseFold] = 0x0004a5}, NULL},
-	{0x0004a5, {[CaseLower] = 0x0004a5,[CaseTitle] = 0x0004a4,[CaseUpper] = 0x0004a4,[CaseFold] = 0x0004a5}, NULL},
-	{0x0004a6, {[CaseLower] = 0x0004a7,[CaseTitle] = 0x0004a6,[CaseUpper] = 0x0004a6,[CaseFold] = 0x0004a7}, NULL},
-	{0x0004a7, {[CaseLower] = 0x0004a7,[CaseTitle] = 0x0004a6,[CaseUpper] = 0x0004a6,[CaseFold] = 0x0004a7}, NULL},
-	{0x0004a8, {[CaseLower] = 0x0004a9,[CaseTitle] = 0x0004a8,[CaseUpper] = 0x0004a8,[CaseFold] = 0x0004a9}, NULL},
-	{0x0004a9, {[CaseLower] = 0x0004a9,[CaseTitle] = 0x0004a8,[CaseUpper] = 0x0004a8,[CaseFold] = 0x0004a9}, NULL},
-	{0x0004aa, {[CaseLower] = 0x0004ab,[CaseTitle] = 0x0004aa,[CaseUpper] = 0x0004aa,[CaseFold] = 0x0004ab}, NULL},
-	{0x0004ab, {[CaseLower] = 0x0004ab,[CaseTitle] = 0x0004aa,[CaseUpper] = 0x0004aa,[CaseFold] = 0x0004ab}, NULL},
-	{0x0004ac, {[CaseLower] = 0x0004ad,[CaseTitle] = 0x0004ac,[CaseUpper] = 0x0004ac,[CaseFold] = 0x0004ad}, NULL},
-	{0x0004ad, {[CaseLower] = 0x0004ad,[CaseTitle] = 0x0004ac,[CaseUpper] = 0x0004ac,[CaseFold] = 0x0004ad}, NULL},
-	{0x0004ae, {[CaseLower] = 0x0004af,[CaseTitle] = 0x0004ae,[CaseUpper] = 0x0004ae,[CaseFold] = 0x0004af}, NULL},
-	{0x0004af, {[CaseLower] = 0x0004af,[CaseTitle] = 0x0004ae,[CaseUpper] = 0x0004ae,[CaseFold] = 0x0004af}, NULL},
-	{0x0004b0, {[CaseLower] = 0x0004b1,[CaseTitle] = 0x0004b0,[CaseUpper] = 0x0004b0,[CaseFold] = 0x0004b1}, NULL},
-	{0x0004b1, {[CaseLower] = 0x0004b1,[CaseTitle] = 0x0004b0,[CaseUpper] = 0x0004b0,[CaseFold] = 0x0004b1}, NULL},
-	{0x0004b2, {[CaseLower] = 0x0004b3,[CaseTitle] = 0x0004b2,[CaseUpper] = 0x0004b2,[CaseFold] = 0x0004b3}, NULL},
-	{0x0004b3, {[CaseLower] = 0x0004b3,[CaseTitle] = 0x0004b2,[CaseUpper] = 0x0004b2,[CaseFold] = 0x0004b3}, NULL},
-	{0x0004b4, {[CaseLower] = 0x0004b5,[CaseTitle] = 0x0004b4,[CaseUpper] = 0x0004b4,[CaseFold] = 0x0004b5}, NULL},
-	{0x0004b5, {[CaseLower] = 0x0004b5,[CaseTitle] = 0x0004b4,[CaseUpper] = 0x0004b4,[CaseFold] = 0x0004b5}, NULL},
-	{0x0004b6, {[CaseLower] = 0x0004b7,[CaseTitle] = 0x0004b6,[CaseUpper] = 0x0004b6,[CaseFold] = 0x0004b7}, NULL},
-	{0x0004b7, {[CaseLower] = 0x0004b7,[CaseTitle] = 0x0004b6,[CaseUpper] = 0x0004b6,[CaseFold] = 0x0004b7}, NULL},
-	{0x0004b8, {[CaseLower] = 0x0004b9,[CaseTitle] = 0x0004b8,[CaseUpper] = 0x0004b8,[CaseFold] = 0x0004b9}, NULL},
-	{0x0004b9, {[CaseLower] = 0x0004b9,[CaseTitle] = 0x0004b8,[CaseUpper] = 0x0004b8,[CaseFold] = 0x0004b9}, NULL},
-	{0x0004ba, {[CaseLower] = 0x0004bb,[CaseTitle] = 0x0004ba,[CaseUpper] = 0x0004ba,[CaseFold] = 0x0004bb}, NULL},
-	{0x0004bb, {[CaseLower] = 0x0004bb,[CaseTitle] = 0x0004ba,[CaseUpper] = 0x0004ba,[CaseFold] = 0x0004bb}, NULL},
-	{0x0004bc, {[CaseLower] = 0x0004bd,[CaseTitle] = 0x0004bc,[CaseUpper] = 0x0004bc,[CaseFold] = 0x0004bd}, NULL},
-	{0x0004bd, {[CaseLower] = 0x0004bd,[CaseTitle] = 0x0004bc,[CaseUpper] = 0x0004bc,[CaseFold] = 0x0004bd}, NULL},
-	{0x0004be, {[CaseLower] = 0x0004bf,[CaseTitle] = 0x0004be,[CaseUpper] = 0x0004be,[CaseFold] = 0x0004bf}, NULL},
-	{0x0004bf, {[CaseLower] = 0x0004bf,[CaseTitle] = 0x0004be,[CaseUpper] = 0x0004be,[CaseFold] = 0x0004bf}, NULL},
-	{0x0004c0, {[CaseLower] = 0x0004cf,[CaseTitle] = 0x0004c0,[CaseUpper] = 0x0004c0,[CaseFold] = 0x0004cf}, NULL},
-	{0x0004c1, {[CaseLower] = 0x0004c2,[CaseTitle] = 0x0004c1,[CaseUpper] = 0x0004c1,[CaseFold] = 0x0004c2}, NULL},
-	{0x0004c2, {[CaseLower] = 0x0004c2,[CaseTitle] = 0x0004c1,[CaseUpper] = 0x0004c1,[CaseFold] = 0x0004c2}, NULL},
-	{0x0004c3, {[CaseLower] = 0x0004c4,[CaseTitle] = 0x0004c3,[CaseUpper] = 0x0004c3,[CaseFold] = 0x0004c4}, NULL},
-	{0x0004c4, {[CaseLower] = 0x0004c4,[CaseTitle] = 0x0004c3,[CaseUpper] = 0x0004c3,[CaseFold] = 0x0004c4}, NULL},
-	{0x0004c5, {[CaseLower] = 0x0004c6,[CaseTitle] = 0x0004c5,[CaseUpper] = 0x0004c5,[CaseFold] = 0x0004c6}, NULL},
-	{0x0004c6, {[CaseLower] = 0x0004c6,[CaseTitle] = 0x0004c5,[CaseUpper] = 0x0004c5,[CaseFold] = 0x0004c6}, NULL},
-	{0x0004c7, {[CaseLower] = 0x0004c8,[CaseTitle] = 0x0004c7,[CaseUpper] = 0x0004c7,[CaseFold] = 0x0004c8}, NULL},
-	{0x0004c8, {[CaseLower] = 0x0004c8,[CaseTitle] = 0x0004c7,[CaseUpper] = 0x0004c7,[CaseFold] = 0x0004c8}, NULL},
-	{0x0004c9, {[CaseLower] = 0x0004ca,[CaseTitle] = 0x0004c9,[CaseUpper] = 0x0004c9,[CaseFold] = 0x0004ca}, NULL},
-	{0x0004ca, {[CaseLower] = 0x0004ca,[CaseTitle] = 0x0004c9,[CaseUpper] = 0x0004c9,[CaseFold] = 0x0004ca}, NULL},
-	{0x0004cb, {[CaseLower] = 0x0004cc,[CaseTitle] = 0x0004cb,[CaseUpper] = 0x0004cb,[CaseFold] = 0x0004cc}, NULL},
-	{0x0004cc, {[CaseLower] = 0x0004cc,[CaseTitle] = 0x0004cb,[CaseUpper] = 0x0004cb,[CaseFold] = 0x0004cc}, NULL},
-	{0x0004cd, {[CaseLower] = 0x0004ce,[CaseTitle] = 0x0004cd,[CaseUpper] = 0x0004cd,[CaseFold] = 0x0004ce}, NULL},
-	{0x0004ce, {[CaseLower] = 0x0004ce,[CaseTitle] = 0x0004cd,[CaseUpper] = 0x0004cd,[CaseFold] = 0x0004ce}, NULL},
-	{0x0004cf, {[CaseLower] = 0x0004cf,[CaseTitle] = 0x0004c0,[CaseUpper] = 0x0004c0,[CaseFold] = 0x0004cf}, NULL},
-	{0x0004d0, {[CaseLower] = 0x0004d1,[CaseTitle] = 0x0004d0,[CaseUpper] = 0x0004d0,[CaseFold] = 0x0004d1}, NULL},
-	{0x0004d1, {[CaseLower] = 0x0004d1,[CaseTitle] = 0x0004d0,[CaseUpper] = 0x0004d0,[CaseFold] = 0x0004d1}, NULL},
-	{0x0004d2, {[CaseLower] = 0x0004d3,[CaseTitle] = 0x0004d2,[CaseUpper] = 0x0004d2,[CaseFold] = 0x0004d3}, NULL},
-	{0x0004d3, {[CaseLower] = 0x0004d3,[CaseTitle] = 0x0004d2,[CaseUpper] = 0x0004d2,[CaseFold] = 0x0004d3}, NULL},
-	{0x0004d4, {[CaseLower] = 0x0004d5,[CaseTitle] = 0x0004d4,[CaseUpper] = 0x0004d4,[CaseFold] = 0x0004d5}, NULL},
-	{0x0004d5, {[CaseLower] = 0x0004d5,[CaseTitle] = 0x0004d4,[CaseUpper] = 0x0004d4,[CaseFold] = 0x0004d5}, NULL},
-	{0x0004d6, {[CaseLower] = 0x0004d7,[CaseTitle] = 0x0004d6,[CaseUpper] = 0x0004d6,[CaseFold] = 0x0004d7}, NULL},
-	{0x0004d7, {[CaseLower] = 0x0004d7,[CaseTitle] = 0x0004d6,[CaseUpper] = 0x0004d6,[CaseFold] = 0x0004d7}, NULL},
-	{0x0004d8, {[CaseLower] = 0x0004d9,[CaseTitle] = 0x0004d8,[CaseUpper] = 0x0004d8,[CaseFold] = 0x0004d9}, NULL},
-	{0x0004d9, {[CaseLower] = 0x0004d9,[CaseTitle] = 0x0004d8,[CaseUpper] = 0x0004d8,[CaseFold] = 0x0004d9}, NULL},
-	{0x0004da, {[CaseLower] = 0x0004db,[CaseTitle] = 0x0004da,[CaseUpper] = 0x0004da,[CaseFold] = 0x0004db}, NULL},
-	{0x0004db, {[CaseLower] = 0x0004db,[CaseTitle] = 0x0004da,[CaseUpper] = 0x0004da,[CaseFold] = 0x0004db}, NULL},
-	{0x0004dc, {[CaseLower] = 0x0004dd,[CaseTitle] = 0x0004dc,[CaseUpper] = 0x0004dc,[CaseFold] = 0x0004dd}, NULL},
-	{0x0004dd, {[CaseLower] = 0x0004dd,[CaseTitle] = 0x0004dc,[CaseUpper] = 0x0004dc,[CaseFold] = 0x0004dd}, NULL},
-	{0x0004de, {[CaseLower] = 0x0004df,[CaseTitle] = 0x0004de,[CaseUpper] = 0x0004de,[CaseFold] = 0x0004df}, NULL},
-	{0x0004df, {[CaseLower] = 0x0004df,[CaseTitle] = 0x0004de,[CaseUpper] = 0x0004de,[CaseFold] = 0x0004df}, NULL},
-	{0x0004e0, {[CaseLower] = 0x0004e1,[CaseTitle] = 0x0004e0,[CaseUpper] = 0x0004e0,[CaseFold] = 0x0004e1}, NULL},
-	{0x0004e1, {[CaseLower] = 0x0004e1,[CaseTitle] = 0x0004e0,[CaseUpper] = 0x0004e0,[CaseFold] = 0x0004e1}, NULL},
-	{0x0004e2, {[CaseLower] = 0x0004e3,[CaseTitle] = 0x0004e2,[CaseUpper] = 0x0004e2,[CaseFold] = 0x0004e3}, NULL},
-	{0x0004e3, {[CaseLower] = 0x0004e3,[CaseTitle] = 0x0004e2,[CaseUpper] = 0x0004e2,[CaseFold] = 0x0004e3}, NULL},
-	{0x0004e4, {[CaseLower] = 0x0004e5,[CaseTitle] = 0x0004e4,[CaseUpper] = 0x0004e4,[CaseFold] = 0x0004e5}, NULL},
-	{0x0004e5, {[CaseLower] = 0x0004e5,[CaseTitle] = 0x0004e4,[CaseUpper] = 0x0004e4,[CaseFold] = 0x0004e5}, NULL},
-	{0x0004e6, {[CaseLower] = 0x0004e7,[CaseTitle] = 0x0004e6,[CaseUpper] = 0x0004e6,[CaseFold] = 0x0004e7}, NULL},
-	{0x0004e7, {[CaseLower] = 0x0004e7,[CaseTitle] = 0x0004e6,[CaseUpper] = 0x0004e6,[CaseFold] = 0x0004e7}, NULL},
-	{0x0004e8, {[CaseLower] = 0x0004e9,[CaseTitle] = 0x0004e8,[CaseUpper] = 0x0004e8,[CaseFold] = 0x0004e9}, NULL},
-	{0x0004e9, {[CaseLower] = 0x0004e9,[CaseTitle] = 0x0004e8,[CaseUpper] = 0x0004e8,[CaseFold] = 0x0004e9}, NULL},
-	{0x0004ea, {[CaseLower] = 0x0004eb,[CaseTitle] = 0x0004ea,[CaseUpper] = 0x0004ea,[CaseFold] = 0x0004eb}, NULL},
-	{0x0004eb, {[CaseLower] = 0x0004eb,[CaseTitle] = 0x0004ea,[CaseUpper] = 0x0004ea,[CaseFold] = 0x0004eb}, NULL},
-	{0x0004ec, {[CaseLower] = 0x0004ed,[CaseTitle] = 0x0004ec,[CaseUpper] = 0x0004ec,[CaseFold] = 0x0004ed}, NULL},
-	{0x0004ed, {[CaseLower] = 0x0004ed,[CaseTitle] = 0x0004ec,[CaseUpper] = 0x0004ec,[CaseFold] = 0x0004ed}, NULL},
-	{0x0004ee, {[CaseLower] = 0x0004ef,[CaseTitle] = 0x0004ee,[CaseUpper] = 0x0004ee,[CaseFold] = 0x0004ef}, NULL},
-	{0x0004ef, {[CaseLower] = 0x0004ef,[CaseTitle] = 0x0004ee,[CaseUpper] = 0x0004ee,[CaseFold] = 0x0004ef}, NULL},
-	{0x0004f0, {[CaseLower] = 0x0004f1,[CaseTitle] = 0x0004f0,[CaseUpper] = 0x0004f0,[CaseFold] = 0x0004f1}, NULL},
-	{0x0004f1, {[CaseLower] = 0x0004f1,[CaseTitle] = 0x0004f0,[CaseUpper] = 0x0004f0,[CaseFold] = 0x0004f1}, NULL},
-	{0x0004f2, {[CaseLower] = 0x0004f3,[CaseTitle] = 0x0004f2,[CaseUpper] = 0x0004f2,[CaseFold] = 0x0004f3}, NULL},
-	{0x0004f3, {[CaseLower] = 0x0004f3,[CaseTitle] = 0x0004f2,[CaseUpper] = 0x0004f2,[CaseFold] = 0x0004f3}, NULL},
-	{0x0004f4, {[CaseLower] = 0x0004f5,[CaseTitle] = 0x0004f4,[CaseUpper] = 0x0004f4,[CaseFold] = 0x0004f5}, NULL},
-	{0x0004f5, {[CaseLower] = 0x0004f5,[CaseTitle] = 0x0004f4,[CaseUpper] = 0x0004f4,[CaseFold] = 0x0004f5}, NULL},
-	{0x0004f6, {[CaseLower] = 0x0004f7,[CaseTitle] = 0x0004f6,[CaseUpper] = 0x0004f6,[CaseFold] = 0x0004f7}, NULL},
-	{0x0004f7, {[CaseLower] = 0x0004f7,[CaseTitle] = 0x0004f6,[CaseUpper] = 0x0004f6,[CaseFold] = 0x0004f7}, NULL},
-	{0x0004f8, {[CaseLower] = 0x0004f9,[CaseTitle] = 0x0004f8,[CaseUpper] = 0x0004f8,[CaseFold] = 0x0004f9}, NULL},
-	{0x0004f9, {[CaseLower] = 0x0004f9,[CaseTitle] = 0x0004f8,[CaseUpper] = 0x0004f8,[CaseFold] = 0x0004f9}, NULL},
-	{0x0004fa, {[CaseLower] = 0x0004fb,[CaseTitle] = 0x0004fa,[CaseUpper] = 0x0004fa,[CaseFold] = 0x0004fb}, NULL},
-	{0x0004fb, {[CaseLower] = 0x0004fb,[CaseTitle] = 0x0004fa,[CaseUpper] = 0x0004fa,[CaseFold] = 0x0004fb}, NULL},
-	{0x0004fc, {[CaseLower] = 0x0004fd,[CaseTitle] = 0x0004fc,[CaseUpper] = 0x0004fc,[CaseFold] = 0x0004fd}, NULL},
-	{0x0004fd, {[CaseLower] = 0x0004fd,[CaseTitle] = 0x0004fc,[CaseUpper] = 0x0004fc,[CaseFold] = 0x0004fd}, NULL},
-	{0x0004fe, {[CaseLower] = 0x0004ff,[CaseTitle] = 0x0004fe,[CaseUpper] = 0x0004fe,[CaseFold] = 0x0004ff}, NULL},
-	{0x0004ff, {[CaseLower] = 0x0004ff,[CaseTitle] = 0x0004fe,[CaseUpper] = 0x0004fe,[CaseFold] = 0x0004ff}, NULL},
-	{0x000500, {[CaseLower] = 0x000501,[CaseTitle] = 0x000500,[CaseUpper] = 0x000500,[CaseFold] = 0x000501}, NULL},
-	{0x000501, {[CaseLower] = 0x000501,[CaseTitle] = 0x000500,[CaseUpper] = 0x000500,[CaseFold] = 0x000501}, NULL},
-	{0x000502, {[CaseLower] = 0x000503,[CaseTitle] = 0x000502,[CaseUpper] = 0x000502,[CaseFold] = 0x000503}, NULL},
-	{0x000503, {[CaseLower] = 0x000503,[CaseTitle] = 0x000502,[CaseUpper] = 0x000502,[CaseFold] = 0x000503}, NULL},
-	{0x000504, {[CaseLower] = 0x000505,[CaseTitle] = 0x000504,[CaseUpper] = 0x000504,[CaseFold] = 0x000505}, NULL},
-	{0x000505, {[CaseLower] = 0x000505,[CaseTitle] = 0x000504,[CaseUpper] = 0x000504,[CaseFold] = 0x000505}, NULL},
-	{0x000506, {[CaseLower] = 0x000507,[CaseTitle] = 0x000506,[CaseUpper] = 0x000506,[CaseFold] = 0x000507}, NULL},
-	{0x000507, {[CaseLower] = 0x000507,[CaseTitle] = 0x000506,[CaseUpper] = 0x000506,[CaseFold] = 0x000507}, NULL},
-	{0x000508, {[CaseLower] = 0x000509,[CaseTitle] = 0x000508,[CaseUpper] = 0x000508,[CaseFold] = 0x000509}, NULL},
-	{0x000509, {[CaseLower] = 0x000509,[CaseTitle] = 0x000508,[CaseUpper] = 0x000508,[CaseFold] = 0x000509}, NULL},
-	{0x00050a, {[CaseLower] = 0x00050b,[CaseTitle] = 0x00050a,[CaseUpper] = 0x00050a,[CaseFold] = 0x00050b}, NULL},
-	{0x00050b, {[CaseLower] = 0x00050b,[CaseTitle] = 0x00050a,[CaseUpper] = 0x00050a,[CaseFold] = 0x00050b}, NULL},
-	{0x00050c, {[CaseLower] = 0x00050d,[CaseTitle] = 0x00050c,[CaseUpper] = 0x00050c,[CaseFold] = 0x00050d}, NULL},
-	{0x00050d, {[CaseLower] = 0x00050d,[CaseTitle] = 0x00050c,[CaseUpper] = 0x00050c,[CaseFold] = 0x00050d}, NULL},
-	{0x00050e, {[CaseLower] = 0x00050f,[CaseTitle] = 0x00050e,[CaseUpper] = 0x00050e,[CaseFold] = 0x00050f}, NULL},
-	{0x00050f, {[CaseLower] = 0x00050f,[CaseTitle] = 0x00050e,[CaseUpper] = 0x00050e,[CaseFold] = 0x00050f}, NULL},
-	{0x000510, {[CaseLower] = 0x000511,[CaseTitle] = 0x000510,[CaseUpper] = 0x000510,[CaseFold] = 0x000511}, NULL},
-	{0x000511, {[CaseLower] = 0x000511,[CaseTitle] = 0x000510,[CaseUpper] = 0x000510,[CaseFold] = 0x000511}, NULL},
-	{0x000512, {[CaseLower] = 0x000513,[CaseTitle] = 0x000512,[CaseUpper] = 0x000512,[CaseFold] = 0x000513}, NULL},
-	{0x000513, {[CaseLower] = 0x000513,[CaseTitle] = 0x000512,[CaseUpper] = 0x000512,[CaseFold] = 0x000513}, NULL},
-	{0x000514, {[CaseLower] = 0x000515,[CaseTitle] = 0x000514,[CaseUpper] = 0x000514,[CaseFold] = 0x000515}, NULL},
-	{0x000515, {[CaseLower] = 0x000515,[CaseTitle] = 0x000514,[CaseUpper] = 0x000514,[CaseFold] = 0x000515}, NULL},
-	{0x000516, {[CaseLower] = 0x000517,[CaseTitle] = 0x000516,[CaseUpper] = 0x000516,[CaseFold] = 0x000517}, NULL},
-	{0x000517, {[CaseLower] = 0x000517,[CaseTitle] = 0x000516,[CaseUpper] = 0x000516,[CaseFold] = 0x000517}, NULL},
-	{0x000518, {[CaseLower] = 0x000519,[CaseTitle] = 0x000518,[CaseUpper] = 0x000518,[CaseFold] = 0x000519}, NULL},
-	{0x000519, {[CaseLower] = 0x000519,[CaseTitle] = 0x000518,[CaseUpper] = 0x000518,[CaseFold] = 0x000519}, NULL},
-	{0x00051a, {[CaseLower] = 0x00051b,[CaseTitle] = 0x00051a,[CaseUpper] = 0x00051a,[CaseFold] = 0x00051b}, NULL},
-	{0x00051b, {[CaseLower] = 0x00051b,[CaseTitle] = 0x00051a,[CaseUpper] = 0x00051a,[CaseFold] = 0x00051b}, NULL},
-	{0x00051c, {[CaseLower] = 0x00051d,[CaseTitle] = 0x00051c,[CaseUpper] = 0x00051c,[CaseFold] = 0x00051d}, NULL},
-	{0x00051d, {[CaseLower] = 0x00051d,[CaseTitle] = 0x00051c,[CaseUpper] = 0x00051c,[CaseFold] = 0x00051d}, NULL},
-	{0x00051e, {[CaseLower] = 0x00051f,[CaseTitle] = 0x00051e,[CaseUpper] = 0x00051e,[CaseFold] = 0x00051f}, NULL},
-	{0x00051f, {[CaseLower] = 0x00051f,[CaseTitle] = 0x00051e,[CaseUpper] = 0x00051e,[CaseFold] = 0x00051f}, NULL},
-	{0x000520, {[CaseLower] = 0x000521,[CaseTitle] = 0x000520,[CaseUpper] = 0x000520,[CaseFold] = 0x000521}, NULL},
-	{0x000521, {[CaseLower] = 0x000521,[CaseTitle] = 0x000520,[CaseUpper] = 0x000520,[CaseFold] = 0x000521}, NULL},
-	{0x000522, {[CaseLower] = 0x000523,[CaseTitle] = 0x000522,[CaseUpper] = 0x000522,[CaseFold] = 0x000523}, NULL},
-	{0x000523, {[CaseLower] = 0x000523,[CaseTitle] = 0x000522,[CaseUpper] = 0x000522,[CaseFold] = 0x000523}, NULL},
-	{0x000524, {[CaseLower] = 0x000525,[CaseTitle] = 0x000524,[CaseUpper] = 0x000524,[CaseFold] = 0x000525}, NULL},
-	{0x000525, {[CaseLower] = 0x000525,[CaseTitle] = 0x000524,[CaseUpper] = 0x000524,[CaseFold] = 0x000525}, NULL},
-	{0x000526, {[CaseLower] = 0x000527,[CaseTitle] = 0x000526,[CaseUpper] = 0x000526,[CaseFold] = 0x000527}, NULL},
-	{0x000527, {[CaseLower] = 0x000527,[CaseTitle] = 0x000526,[CaseUpper] = 0x000526,[CaseFold] = 0x000527}, NULL},
-	{0x000528, {[CaseLower] = 0x000529,[CaseTitle] = 0x000528,[CaseUpper] = 0x000528,[CaseFold] = 0x000529}, NULL},
-	{0x000529, {[CaseLower] = 0x000529,[CaseTitle] = 0x000528,[CaseUpper] = 0x000528,[CaseFold] = 0x000529}, NULL},
-	{0x00052a, {[CaseLower] = 0x00052b,[CaseTitle] = 0x00052a,[CaseUpper] = 0x00052a,[CaseFold] = 0x00052b}, NULL},
-	{0x00052b, {[CaseLower] = 0x00052b,[CaseTitle] = 0x00052a,[CaseUpper] = 0x00052a,[CaseFold] = 0x00052b}, NULL},
-	{0x00052c, {[CaseLower] = 0x00052d,[CaseTitle] = 0x00052c,[CaseUpper] = 0x00052c,[CaseFold] = 0x00052d}, NULL},
-	{0x00052d, {[CaseLower] = 0x00052d,[CaseTitle] = 0x00052c,[CaseUpper] = 0x00052c,[CaseFold] = 0x00052d}, NULL},
-	{0x00052e, {[CaseLower] = 0x00052f,[CaseTitle] = 0x00052e,[CaseUpper] = 0x00052e,[CaseFold] = 0x00052f}, NULL},
-	{0x00052f, {[CaseLower] = 0x00052f,[CaseTitle] = 0x00052e,[CaseUpper] = 0x00052e,[CaseFold] = 0x00052f}, NULL},
-	{0x000531, {[CaseLower] = 0x000561,[CaseTitle] = 0x000531,[CaseUpper] = 0x000531,[CaseFold] = 0x000561}, NULL},
-	{0x000532, {[CaseLower] = 0x000562,[CaseTitle] = 0x000532,[CaseUpper] = 0x000532,[CaseFold] = 0x000562}, NULL},
-	{0x000533, {[CaseLower] = 0x000563,[CaseTitle] = 0x000533,[CaseUpper] = 0x000533,[CaseFold] = 0x000563}, NULL},
-	{0x000534, {[CaseLower] = 0x000564,[CaseTitle] = 0x000534,[CaseUpper] = 0x000534,[CaseFold] = 0x000564}, NULL},
-	{0x000535, {[CaseLower] = 0x000565,[CaseTitle] = 0x000535,[CaseUpper] = 0x000535,[CaseFold] = 0x000565}, NULL},
-	{0x000536, {[CaseLower] = 0x000566,[CaseTitle] = 0x000536,[CaseUpper] = 0x000536,[CaseFold] = 0x000566}, NULL},
-	{0x000537, {[CaseLower] = 0x000567,[CaseTitle] = 0x000537,[CaseUpper] = 0x000537,[CaseFold] = 0x000567}, NULL},
-	{0x000538, {[CaseLower] = 0x000568,[CaseTitle] = 0x000538,[CaseUpper] = 0x000538,[CaseFold] = 0x000568}, NULL},
-	{0x000539, {[CaseLower] = 0x000569,[CaseTitle] = 0x000539,[CaseUpper] = 0x000539,[CaseFold] = 0x000569}, NULL},
-	{0x00053a, {[CaseLower] = 0x00056a,[CaseTitle] = 0x00053a,[CaseUpper] = 0x00053a,[CaseFold] = 0x00056a}, NULL},
-	{0x00053b, {[CaseLower] = 0x00056b,[CaseTitle] = 0x00053b,[CaseUpper] = 0x00053b,[CaseFold] = 0x00056b}, NULL},
-	{0x00053c, {[CaseLower] = 0x00056c,[CaseTitle] = 0x00053c,[CaseUpper] = 0x00053c,[CaseFold] = 0x00056c}, NULL},
-	{0x00053d, {[CaseLower] = 0x00056d,[CaseTitle] = 0x00053d,[CaseUpper] = 0x00053d,[CaseFold] = 0x00056d}, NULL},
-	{0x00053e, {[CaseLower] = 0x00056e,[CaseTitle] = 0x00053e,[CaseUpper] = 0x00053e,[CaseFold] = 0x00056e}, NULL},
-	{0x00053f, {[CaseLower] = 0x00056f,[CaseTitle] = 0x00053f,[CaseUpper] = 0x00053f,[CaseFold] = 0x00056f}, NULL},
-	{0x000540, {[CaseLower] = 0x000570,[CaseTitle] = 0x000540,[CaseUpper] = 0x000540,[CaseFold] = 0x000570}, NULL},
-	{0x000541, {[CaseLower] = 0x000571,[CaseTitle] = 0x000541,[CaseUpper] = 0x000541,[CaseFold] = 0x000571}, NULL},
-	{0x000542, {[CaseLower] = 0x000572,[CaseTitle] = 0x000542,[CaseUpper] = 0x000542,[CaseFold] = 0x000572}, NULL},
-	{0x000543, {[CaseLower] = 0x000573,[CaseTitle] = 0x000543,[CaseUpper] = 0x000543,[CaseFold] = 0x000573}, NULL},
-	{0x000544, {[CaseLower] = 0x000574,[CaseTitle] = 0x000544,[CaseUpper] = 0x000544,[CaseFold] = 0x000574}, NULL},
-	{0x000545, {[CaseLower] = 0x000575,[CaseTitle] = 0x000545,[CaseUpper] = 0x000545,[CaseFold] = 0x000575}, NULL},
-	{0x000546, {[CaseLower] = 0x000576,[CaseTitle] = 0x000546,[CaseUpper] = 0x000546,[CaseFold] = 0x000576}, NULL},
-	{0x000547, {[CaseLower] = 0x000577,[CaseTitle] = 0x000547,[CaseUpper] = 0x000547,[CaseFold] = 0x000577}, NULL},
-	{0x000548, {[CaseLower] = 0x000578,[CaseTitle] = 0x000548,[CaseUpper] = 0x000548,[CaseFold] = 0x000578}, NULL},
-	{0x000549, {[CaseLower] = 0x000579,[CaseTitle] = 0x000549,[CaseUpper] = 0x000549,[CaseFold] = 0x000579}, NULL},
-	{0x00054a, {[CaseLower] = 0x00057a,[CaseTitle] = 0x00054a,[CaseUpper] = 0x00054a,[CaseFold] = 0x00057a}, NULL},
-	{0x00054b, {[CaseLower] = 0x00057b,[CaseTitle] = 0x00054b,[CaseUpper] = 0x00054b,[CaseFold] = 0x00057b}, NULL},
-	{0x00054c, {[CaseLower] = 0x00057c,[CaseTitle] = 0x00054c,[CaseUpper] = 0x00054c,[CaseFold] = 0x00057c}, NULL},
-	{0x00054d, {[CaseLower] = 0x00057d,[CaseTitle] = 0x00054d,[CaseUpper] = 0x00054d,[CaseFold] = 0x00057d}, NULL},
-	{0x00054e, {[CaseLower] = 0x00057e,[CaseTitle] = 0x00054e,[CaseUpper] = 0x00054e,[CaseFold] = 0x00057e}, NULL},
-	{0x00054f, {[CaseLower] = 0x00057f,[CaseTitle] = 0x00054f,[CaseUpper] = 0x00054f,[CaseFold] = 0x00057f}, NULL},
-	{0x000550, {[CaseLower] = 0x000580,[CaseTitle] = 0x000550,[CaseUpper] = 0x000550,[CaseFold] = 0x000580}, NULL},
-	{0x000551, {[CaseLower] = 0x000581,[CaseTitle] = 0x000551,[CaseUpper] = 0x000551,[CaseFold] = 0x000581}, NULL},
-	{0x000552, {[CaseLower] = 0x000582,[CaseTitle] = 0x000552,[CaseUpper] = 0x000552,[CaseFold] = 0x000582}, NULL},
-	{0x000553, {[CaseLower] = 0x000583,[CaseTitle] = 0x000553,[CaseUpper] = 0x000553,[CaseFold] = 0x000583}, NULL},
-	{0x000554, {[CaseLower] = 0x000584,[CaseTitle] = 0x000554,[CaseUpper] = 0x000554,[CaseFold] = 0x000584}, NULL},
-	{0x000555, {[CaseLower] = 0x000585,[CaseTitle] = 0x000555,[CaseUpper] = 0x000555,[CaseFold] = 0x000585}, NULL},
-	{0x000556, {[CaseLower] = 0x000586,[CaseTitle] = 0x000556,[CaseUpper] = 0x000556,[CaseFold] = 0x000586}, NULL},
-	{0x000561, {[CaseLower] = 0x000561,[CaseTitle] = 0x000531,[CaseUpper] = 0x000531,[CaseFold] = 0x000561}, NULL},
-	{0x000562, {[CaseLower] = 0x000562,[CaseTitle] = 0x000532,[CaseUpper] = 0x000532,[CaseFold] = 0x000562}, NULL},
-	{0x000563, {[CaseLower] = 0x000563,[CaseTitle] = 0x000533,[CaseUpper] = 0x000533,[CaseFold] = 0x000563}, NULL},
-	{0x000564, {[CaseLower] = 0x000564,[CaseTitle] = 0x000534,[CaseUpper] = 0x000534,[CaseFold] = 0x000564}, NULL},
-	{0x000565, {[CaseLower] = 0x000565,[CaseTitle] = 0x000535,[CaseUpper] = 0x000535,[CaseFold] = 0x000565}, NULL},
-	{0x000566, {[CaseLower] = 0x000566,[CaseTitle] = 0x000536,[CaseUpper] = 0x000536,[CaseFold] = 0x000566}, NULL},
-	{0x000567, {[CaseLower] = 0x000567,[CaseTitle] = 0x000537,[CaseUpper] = 0x000537,[CaseFold] = 0x000567}, NULL},
-	{0x000568, {[CaseLower] = 0x000568,[CaseTitle] = 0x000538,[CaseUpper] = 0x000538,[CaseFold] = 0x000568}, NULL},
-	{0x000569, {[CaseLower] = 0x000569,[CaseTitle] = 0x000539,[CaseUpper] = 0x000539,[CaseFold] = 0x000569}, NULL},
-	{0x00056a, {[CaseLower] = 0x00056a,[CaseTitle] = 0x00053a,[CaseUpper] = 0x00053a,[CaseFold] = 0x00056a}, NULL},
-	{0x00056b, {[CaseLower] = 0x00056b,[CaseTitle] = 0x00053b,[CaseUpper] = 0x00053b,[CaseFold] = 0x00056b}, NULL},
-	{0x00056c, {[CaseLower] = 0x00056c,[CaseTitle] = 0x00053c,[CaseUpper] = 0x00053c,[CaseFold] = 0x00056c}, NULL},
-	{0x00056d, {[CaseLower] = 0x00056d,[CaseTitle] = 0x00053d,[CaseUpper] = 0x00053d,[CaseFold] = 0x00056d}, NULL},
-	{0x00056e, {[CaseLower] = 0x00056e,[CaseTitle] = 0x00053e,[CaseUpper] = 0x00053e,[CaseFold] = 0x00056e}, NULL},
-	{0x00056f, {[CaseLower] = 0x00056f,[CaseTitle] = 0x00053f,[CaseUpper] = 0x00053f,[CaseFold] = 0x00056f}, NULL},
-	{0x000570, {[CaseLower] = 0x000570,[CaseTitle] = 0x000540,[CaseUpper] = 0x000540,[CaseFold] = 0x000570}, NULL},
-	{0x000571, {[CaseLower] = 0x000571,[CaseTitle] = 0x000541,[CaseUpper] = 0x000541,[CaseFold] = 0x000571}, NULL},
-	{0x000572, {[CaseLower] = 0x000572,[CaseTitle] = 0x000542,[CaseUpper] = 0x000542,[CaseFold] = 0x000572}, NULL},
-	{0x000573, {[CaseLower] = 0x000573,[CaseTitle] = 0x000543,[CaseUpper] = 0x000543,[CaseFold] = 0x000573}, NULL},
-	{0x000574, {[CaseLower] = 0x000574,[CaseTitle] = 0x000544,[CaseUpper] = 0x000544,[CaseFold] = 0x000574}, NULL},
-	{0x000575, {[CaseLower] = 0x000575,[CaseTitle] = 0x000545,[CaseUpper] = 0x000545,[CaseFold] = 0x000575}, NULL},
-	{0x000576, {[CaseLower] = 0x000576,[CaseTitle] = 0x000546,[CaseUpper] = 0x000546,[CaseFold] = 0x000576}, NULL},
-	{0x000577, {[CaseLower] = 0x000577,[CaseTitle] = 0x000547,[CaseUpper] = 0x000547,[CaseFold] = 0x000577}, NULL},
-	{0x000578, {[CaseLower] = 0x000578,[CaseTitle] = 0x000548,[CaseUpper] = 0x000548,[CaseFold] = 0x000578}, NULL},
-	{0x000579, {[CaseLower] = 0x000579,[CaseTitle] = 0x000549,[CaseUpper] = 0x000549,[CaseFold] = 0x000579}, NULL},
-	{0x00057a, {[CaseLower] = 0x00057a,[CaseTitle] = 0x00054a,[CaseUpper] = 0x00054a,[CaseFold] = 0x00057a}, NULL},
-	{0x00057b, {[CaseLower] = 0x00057b,[CaseTitle] = 0x00054b,[CaseUpper] = 0x00054b,[CaseFold] = 0x00057b}, NULL},
-	{0x00057c, {[CaseLower] = 0x00057c,[CaseTitle] = 0x00054c,[CaseUpper] = 0x00054c,[CaseFold] = 0x00057c}, NULL},
-	{0x00057d, {[CaseLower] = 0x00057d,[CaseTitle] = 0x00054d,[CaseUpper] = 0x00054d,[CaseFold] = 0x00057d}, NULL},
-	{0x00057e, {[CaseLower] = 0x00057e,[CaseTitle] = 0x00054e,[CaseUpper] = 0x00054e,[CaseFold] = 0x00057e}, NULL},
-	{0x00057f, {[CaseLower] = 0x00057f,[CaseTitle] = 0x00054f,[CaseUpper] = 0x00054f,[CaseFold] = 0x00057f}, NULL},
-	{0x000580, {[CaseLower] = 0x000580,[CaseTitle] = 0x000550,[CaseUpper] = 0x000550,[CaseFold] = 0x000580}, NULL},
-	{0x000581, {[CaseLower] = 0x000581,[CaseTitle] = 0x000551,[CaseUpper] = 0x000551,[CaseFold] = 0x000581}, NULL},
-	{0x000582, {[CaseLower] = 0x000582,[CaseTitle] = 0x000552,[CaseUpper] = 0x000552,[CaseFold] = 0x000582}, NULL},
-	{0x000583, {[CaseLower] = 0x000583,[CaseTitle] = 0x000553,[CaseUpper] = 0x000553,[CaseFold] = 0x000583}, NULL},
-	{0x000584, {[CaseLower] = 0x000584,[CaseTitle] = 0x000554,[CaseUpper] = 0x000554,[CaseFold] = 0x000584}, NULL},
-	{0x000585, {[CaseLower] = 0x000585,[CaseTitle] = 0x000555,[CaseUpper] = 0x000555,[CaseFold] = 0x000585}, NULL},
-	{0x000586, {[CaseLower] = 0x000586,[CaseTitle] = 0x000556,[CaseUpper] = 0x000556,[CaseFold] = 0x000586}, NULL},
-	{0x000587, {[CaseLower] = 0x000587,[CaseTitle] = 0x000587,[CaseUpper] = 0x000587,[CaseFold] = 0x000587}, &special_case[7]},
-	{0x0010a0, {[CaseLower] = 0x002d00,[CaseTitle] = 0x0010a0,[CaseUpper] = 0x0010a0,[CaseFold] = 0x002d00}, NULL},
-	{0x0010a1, {[CaseLower] = 0x002d01,[CaseTitle] = 0x0010a1,[CaseUpper] = 0x0010a1,[CaseFold] = 0x002d01}, NULL},
-	{0x0010a2, {[CaseLower] = 0x002d02,[CaseTitle] = 0x0010a2,[CaseUpper] = 0x0010a2,[CaseFold] = 0x002d02}, NULL},
-	{0x0010a3, {[CaseLower] = 0x002d03,[CaseTitle] = 0x0010a3,[CaseUpper] = 0x0010a3,[CaseFold] = 0x002d03}, NULL},
-	{0x0010a4, {[CaseLower] = 0x002d04,[CaseTitle] = 0x0010a4,[CaseUpper] = 0x0010a4,[CaseFold] = 0x002d04}, NULL},
-	{0x0010a5, {[CaseLower] = 0x002d05,[CaseTitle] = 0x0010a5,[CaseUpper] = 0x0010a5,[CaseFold] = 0x002d05}, NULL},
-	{0x0010a6, {[CaseLower] = 0x002d06,[CaseTitle] = 0x0010a6,[CaseUpper] = 0x0010a6,[CaseFold] = 0x002d06}, NULL},
-	{0x0010a7, {[CaseLower] = 0x002d07,[CaseTitle] = 0x0010a7,[CaseUpper] = 0x0010a7,[CaseFold] = 0x002d07}, NULL},
-	{0x0010a8, {[CaseLower] = 0x002d08,[CaseTitle] = 0x0010a8,[CaseUpper] = 0x0010a8,[CaseFold] = 0x002d08}, NULL},
-	{0x0010a9, {[CaseLower] = 0x002d09,[CaseTitle] = 0x0010a9,[CaseUpper] = 0x0010a9,[CaseFold] = 0x002d09}, NULL},
-	{0x0010aa, {[CaseLower] = 0x002d0a,[CaseTitle] = 0x0010aa,[CaseUpper] = 0x0010aa,[CaseFold] = 0x002d0a}, NULL},
-	{0x0010ab, {[CaseLower] = 0x002d0b,[CaseTitle] = 0x0010ab,[CaseUpper] = 0x0010ab,[CaseFold] = 0x002d0b}, NULL},
-	{0x0010ac, {[CaseLower] = 0x002d0c,[CaseTitle] = 0x0010ac,[CaseUpper] = 0x0010ac,[CaseFold] = 0x002d0c}, NULL},
-	{0x0010ad, {[CaseLower] = 0x002d0d,[CaseTitle] = 0x0010ad,[CaseUpper] = 0x0010ad,[CaseFold] = 0x002d0d}, NULL},
-	{0x0010ae, {[CaseLower] = 0x002d0e,[CaseTitle] = 0x0010ae,[CaseUpper] = 0x0010ae,[CaseFold] = 0x002d0e}, NULL},
-	{0x0010af, {[CaseLower] = 0x002d0f,[CaseTitle] = 0x0010af,[CaseUpper] = 0x0010af,[CaseFold] = 0x002d0f}, NULL},
-	{0x0010b0, {[CaseLower] = 0x002d10,[CaseTitle] = 0x0010b0,[CaseUpper] = 0x0010b0,[CaseFold] = 0x002d10}, NULL},
-	{0x0010b1, {[CaseLower] = 0x002d11,[CaseTitle] = 0x0010b1,[CaseUpper] = 0x0010b1,[CaseFold] = 0x002d11}, NULL},
-	{0x0010b2, {[CaseLower] = 0x002d12,[CaseTitle] = 0x0010b2,[CaseUpper] = 0x0010b2,[CaseFold] = 0x002d12}, NULL},
-	{0x0010b3, {[CaseLower] = 0x002d13,[CaseTitle] = 0x0010b3,[CaseUpper] = 0x0010b3,[CaseFold] = 0x002d13}, NULL},
-	{0x0010b4, {[CaseLower] = 0x002d14,[CaseTitle] = 0x0010b4,[CaseUpper] = 0x0010b4,[CaseFold] = 0x002d14}, NULL},
-	{0x0010b5, {[CaseLower] = 0x002d15,[CaseTitle] = 0x0010b5,[CaseUpper] = 0x0010b5,[CaseFold] = 0x002d15}, NULL},
-	{0x0010b6, {[CaseLower] = 0x002d16,[CaseTitle] = 0x0010b6,[CaseUpper] = 0x0010b6,[CaseFold] = 0x002d16}, NULL},
-	{0x0010b7, {[CaseLower] = 0x002d17,[CaseTitle] = 0x0010b7,[CaseUpper] = 0x0010b7,[CaseFold] = 0x002d17}, NULL},
-	{0x0010b8, {[CaseLower] = 0x002d18,[CaseTitle] = 0x0010b8,[CaseUpper] = 0x0010b8,[CaseFold] = 0x002d18}, NULL},
-	{0x0010b9, {[CaseLower] = 0x002d19,[CaseTitle] = 0x0010b9,[CaseUpper] = 0x0010b9,[CaseFold] = 0x002d19}, NULL},
-	{0x0010ba, {[CaseLower] = 0x002d1a,[CaseTitle] = 0x0010ba,[CaseUpper] = 0x0010ba,[CaseFold] = 0x002d1a}, NULL},
-	{0x0010bb, {[CaseLower] = 0x002d1b,[CaseTitle] = 0x0010bb,[CaseUpper] = 0x0010bb,[CaseFold] = 0x002d1b}, NULL},
-	{0x0010bc, {[CaseLower] = 0x002d1c,[CaseTitle] = 0x0010bc,[CaseUpper] = 0x0010bc,[CaseFold] = 0x002d1c}, NULL},
-	{0x0010bd, {[CaseLower] = 0x002d1d,[CaseTitle] = 0x0010bd,[CaseUpper] = 0x0010bd,[CaseFold] = 0x002d1d}, NULL},
-	{0x0010be, {[CaseLower] = 0x002d1e,[CaseTitle] = 0x0010be,[CaseUpper] = 0x0010be,[CaseFold] = 0x002d1e}, NULL},
-	{0x0010bf, {[CaseLower] = 0x002d1f,[CaseTitle] = 0x0010bf,[CaseUpper] = 0x0010bf,[CaseFold] = 0x002d1f}, NULL},
-	{0x0010c0, {[CaseLower] = 0x002d20,[CaseTitle] = 0x0010c0,[CaseUpper] = 0x0010c0,[CaseFold] = 0x002d20}, NULL},
-	{0x0010c1, {[CaseLower] = 0x002d21,[CaseTitle] = 0x0010c1,[CaseUpper] = 0x0010c1,[CaseFold] = 0x002d21}, NULL},
-	{0x0010c2, {[CaseLower] = 0x002d22,[CaseTitle] = 0x0010c2,[CaseUpper] = 0x0010c2,[CaseFold] = 0x002d22}, NULL},
-	{0x0010c3, {[CaseLower] = 0x002d23,[CaseTitle] = 0x0010c3,[CaseUpper] = 0x0010c3,[CaseFold] = 0x002d23}, NULL},
-	{0x0010c4, {[CaseLower] = 0x002d24,[CaseTitle] = 0x0010c4,[CaseUpper] = 0x0010c4,[CaseFold] = 0x002d24}, NULL},
-	{0x0010c5, {[CaseLower] = 0x002d25,[CaseTitle] = 0x0010c5,[CaseUpper] = 0x0010c5,[CaseFold] = 0x002d25}, NULL},
-	{0x0010c7, {[CaseLower] = 0x002d27,[CaseTitle] = 0x0010c7,[CaseUpper] = 0x0010c7,[CaseFold] = 0x002d27}, NULL},
-	{0x0010cd, {[CaseLower] = 0x002d2d,[CaseTitle] = 0x0010cd,[CaseUpper] = 0x0010cd,[CaseFold] = 0x002d2d}, NULL},
-	{0x0010d0, {[CaseLower] = 0x0010d0,[CaseTitle] = 0x0010d0,[CaseUpper] = 0x001c90,[CaseFold] = 0x0010d0}, NULL},
-	{0x0010d1, {[CaseLower] = 0x0010d1,[CaseTitle] = 0x0010d1,[CaseUpper] = 0x001c91,[CaseFold] = 0x0010d1}, NULL},
-	{0x0010d2, {[CaseLower] = 0x0010d2,[CaseTitle] = 0x0010d2,[CaseUpper] = 0x001c92,[CaseFold] = 0x0010d2}, NULL},
-	{0x0010d3, {[CaseLower] = 0x0010d3,[CaseTitle] = 0x0010d3,[CaseUpper] = 0x001c93,[CaseFold] = 0x0010d3}, NULL},
-	{0x0010d4, {[CaseLower] = 0x0010d4,[CaseTitle] = 0x0010d4,[CaseUpper] = 0x001c94,[CaseFold] = 0x0010d4}, NULL},
-	{0x0010d5, {[CaseLower] = 0x0010d5,[CaseTitle] = 0x0010d5,[CaseUpper] = 0x001c95,[CaseFold] = 0x0010d5}, NULL},
-	{0x0010d6, {[CaseLower] = 0x0010d6,[CaseTitle] = 0x0010d6,[CaseUpper] = 0x001c96,[CaseFold] = 0x0010d6}, NULL},
-	{0x0010d7, {[CaseLower] = 0x0010d7,[CaseTitle] = 0x0010d7,[CaseUpper] = 0x001c97,[CaseFold] = 0x0010d7}, NULL},
-	{0x0010d8, {[CaseLower] = 0x0010d8,[CaseTitle] = 0x0010d8,[CaseUpper] = 0x001c98,[CaseFold] = 0x0010d8}, NULL},
-	{0x0010d9, {[CaseLower] = 0x0010d9,[CaseTitle] = 0x0010d9,[CaseUpper] = 0x001c99,[CaseFold] = 0x0010d9}, NULL},
-	{0x0010da, {[CaseLower] = 0x0010da,[CaseTitle] = 0x0010da,[CaseUpper] = 0x001c9a,[CaseFold] = 0x0010da}, NULL},
-	{0x0010db, {[CaseLower] = 0x0010db,[CaseTitle] = 0x0010db,[CaseUpper] = 0x001c9b,[CaseFold] = 0x0010db}, NULL},
-	{0x0010dc, {[CaseLower] = 0x0010dc,[CaseTitle] = 0x0010dc,[CaseUpper] = 0x001c9c,[CaseFold] = 0x0010dc}, NULL},
-	{0x0010dd, {[CaseLower] = 0x0010dd,[CaseTitle] = 0x0010dd,[CaseUpper] = 0x001c9d,[CaseFold] = 0x0010dd}, NULL},
-	{0x0010de, {[CaseLower] = 0x0010de,[CaseTitle] = 0x0010de,[CaseUpper] = 0x001c9e,[CaseFold] = 0x0010de}, NULL},
-	{0x0010df, {[CaseLower] = 0x0010df,[CaseTitle] = 0x0010df,[CaseUpper] = 0x001c9f,[CaseFold] = 0x0010df}, NULL},
-	{0x0010e0, {[CaseLower] = 0x0010e0,[CaseTitle] = 0x0010e0,[CaseUpper] = 0x001ca0,[CaseFold] = 0x0010e0}, NULL},
-	{0x0010e1, {[CaseLower] = 0x0010e1,[CaseTitle] = 0x0010e1,[CaseUpper] = 0x001ca1,[CaseFold] = 0x0010e1}, NULL},
-	{0x0010e2, {[CaseLower] = 0x0010e2,[CaseTitle] = 0x0010e2,[CaseUpper] = 0x001ca2,[CaseFold] = 0x0010e2}, NULL},
-	{0x0010e3, {[CaseLower] = 0x0010e3,[CaseTitle] = 0x0010e3,[CaseUpper] = 0x001ca3,[CaseFold] = 0x0010e3}, NULL},
-	{0x0010e4, {[CaseLower] = 0x0010e4,[CaseTitle] = 0x0010e4,[CaseUpper] = 0x001ca4,[CaseFold] = 0x0010e4}, NULL},
-	{0x0010e5, {[CaseLower] = 0x0010e5,[CaseTitle] = 0x0010e5,[CaseUpper] = 0x001ca5,[CaseFold] = 0x0010e5}, NULL},
-	{0x0010e6, {[CaseLower] = 0x0010e6,[CaseTitle] = 0x0010e6,[CaseUpper] = 0x001ca6,[CaseFold] = 0x0010e6}, NULL},
-	{0x0010e7, {[CaseLower] = 0x0010e7,[CaseTitle] = 0x0010e7,[CaseUpper] = 0x001ca7,[CaseFold] = 0x0010e7}, NULL},
-	{0x0010e8, {[CaseLower] = 0x0010e8,[CaseTitle] = 0x0010e8,[CaseUpper] = 0x001ca8,[CaseFold] = 0x0010e8}, NULL},
-	{0x0010e9, {[CaseLower] = 0x0010e9,[CaseTitle] = 0x0010e9,[CaseUpper] = 0x001ca9,[CaseFold] = 0x0010e9}, NULL},
-	{0x0010ea, {[CaseLower] = 0x0010ea,[CaseTitle] = 0x0010ea,[CaseUpper] = 0x001caa,[CaseFold] = 0x0010ea}, NULL},
-	{0x0010eb, {[CaseLower] = 0x0010eb,[CaseTitle] = 0x0010eb,[CaseUpper] = 0x001cab,[CaseFold] = 0x0010eb}, NULL},
-	{0x0010ec, {[CaseLower] = 0x0010ec,[CaseTitle] = 0x0010ec,[CaseUpper] = 0x001cac,[CaseFold] = 0x0010ec}, NULL},
-	{0x0010ed, {[CaseLower] = 0x0010ed,[CaseTitle] = 0x0010ed,[CaseUpper] = 0x001cad,[CaseFold] = 0x0010ed}, NULL},
-	{0x0010ee, {[CaseLower] = 0x0010ee,[CaseTitle] = 0x0010ee,[CaseUpper] = 0x001cae,[CaseFold] = 0x0010ee}, NULL},
-	{0x0010ef, {[CaseLower] = 0x0010ef,[CaseTitle] = 0x0010ef,[CaseUpper] = 0x001caf,[CaseFold] = 0x0010ef}, NULL},
-	{0x0010f0, {[CaseLower] = 0x0010f0,[CaseTitle] = 0x0010f0,[CaseUpper] = 0x001cb0,[CaseFold] = 0x0010f0}, NULL},
-	{0x0010f1, {[CaseLower] = 0x0010f1,[CaseTitle] = 0x0010f1,[CaseUpper] = 0x001cb1,[CaseFold] = 0x0010f1}, NULL},
-	{0x0010f2, {[CaseLower] = 0x0010f2,[CaseTitle] = 0x0010f2,[CaseUpper] = 0x001cb2,[CaseFold] = 0x0010f2}, NULL},
-	{0x0010f3, {[CaseLower] = 0x0010f3,[CaseTitle] = 0x0010f3,[CaseUpper] = 0x001cb3,[CaseFold] = 0x0010f3}, NULL},
-	{0x0010f4, {[CaseLower] = 0x0010f4,[CaseTitle] = 0x0010f4,[CaseUpper] = 0x001cb4,[CaseFold] = 0x0010f4}, NULL},
-	{0x0010f5, {[CaseLower] = 0x0010f5,[CaseTitle] = 0x0010f5,[CaseUpper] = 0x001cb5,[CaseFold] = 0x0010f5}, NULL},
-	{0x0010f6, {[CaseLower] = 0x0010f6,[CaseTitle] = 0x0010f6,[CaseUpper] = 0x001cb6,[CaseFold] = 0x0010f6}, NULL},
-	{0x0010f7, {[CaseLower] = 0x0010f7,[CaseTitle] = 0x0010f7,[CaseUpper] = 0x001cb7,[CaseFold] = 0x0010f7}, NULL},
-	{0x0010f8, {[CaseLower] = 0x0010f8,[CaseTitle] = 0x0010f8,[CaseUpper] = 0x001cb8,[CaseFold] = 0x0010f8}, NULL},
-	{0x0010f9, {[CaseLower] = 0x0010f9,[CaseTitle] = 0x0010f9,[CaseUpper] = 0x001cb9,[CaseFold] = 0x0010f9}, NULL},
-	{0x0010fa, {[CaseLower] = 0x0010fa,[CaseTitle] = 0x0010fa,[CaseUpper] = 0x001cba,[CaseFold] = 0x0010fa}, NULL},
-	{0x0010fd, {[CaseLower] = 0x0010fd,[CaseTitle] = 0x0010fd,[CaseUpper] = 0x001cbd,[CaseFold] = 0x0010fd}, NULL},
-	{0x0010fe, {[CaseLower] = 0x0010fe,[CaseTitle] = 0x0010fe,[CaseUpper] = 0x001cbe,[CaseFold] = 0x0010fe}, NULL},
-	{0x0010ff, {[CaseLower] = 0x0010ff,[CaseTitle] = 0x0010ff,[CaseUpper] = 0x001cbf,[CaseFold] = 0x0010ff}, NULL},
-	{0x0013a0, {[CaseLower] = 0x00ab70,[CaseTitle] = 0x0013a0,[CaseUpper] = 0x0013a0,[CaseFold] = 0x0013a0}, NULL},
-	{0x0013a1, {[CaseLower] = 0x00ab71,[CaseTitle] = 0x0013a1,[CaseUpper] = 0x0013a1,[CaseFold] = 0x0013a1}, NULL},
-	{0x0013a2, {[CaseLower] = 0x00ab72,[CaseTitle] = 0x0013a2,[CaseUpper] = 0x0013a2,[CaseFold] = 0x0013a2}, NULL},
-	{0x0013a3, {[CaseLower] = 0x00ab73,[CaseTitle] = 0x0013a3,[CaseUpper] = 0x0013a3,[CaseFold] = 0x0013a3}, NULL},
-	{0x0013a4, {[CaseLower] = 0x00ab74,[CaseTitle] = 0x0013a4,[CaseUpper] = 0x0013a4,[CaseFold] = 0x0013a4}, NULL},
-	{0x0013a5, {[CaseLower] = 0x00ab75,[CaseTitle] = 0x0013a5,[CaseUpper] = 0x0013a5,[CaseFold] = 0x0013a5}, NULL},
-	{0x0013a6, {[CaseLower] = 0x00ab76,[CaseTitle] = 0x0013a6,[CaseUpper] = 0x0013a6,[CaseFold] = 0x0013a6}, NULL},
-	{0x0013a7, {[CaseLower] = 0x00ab77,[CaseTitle] = 0x0013a7,[CaseUpper] = 0x0013a7,[CaseFold] = 0x0013a7}, NULL},
-	{0x0013a8, {[CaseLower] = 0x00ab78,[CaseTitle] = 0x0013a8,[CaseUpper] = 0x0013a8,[CaseFold] = 0x0013a8}, NULL},
-	{0x0013a9, {[CaseLower] = 0x00ab79,[CaseTitle] = 0x0013a9,[CaseUpper] = 0x0013a9,[CaseFold] = 0x0013a9}, NULL},
-	{0x0013aa, {[CaseLower] = 0x00ab7a,[CaseTitle] = 0x0013aa,[CaseUpper] = 0x0013aa,[CaseFold] = 0x0013aa}, NULL},
-	{0x0013ab, {[CaseLower] = 0x00ab7b,[CaseTitle] = 0x0013ab,[CaseUpper] = 0x0013ab,[CaseFold] = 0x0013ab}, NULL},
-	{0x0013ac, {[CaseLower] = 0x00ab7c,[CaseTitle] = 0x0013ac,[CaseUpper] = 0x0013ac,[CaseFold] = 0x0013ac}, NULL},
-	{0x0013ad, {[CaseLower] = 0x00ab7d,[CaseTitle] = 0x0013ad,[CaseUpper] = 0x0013ad,[CaseFold] = 0x0013ad}, NULL},
-	{0x0013ae, {[CaseLower] = 0x00ab7e,[CaseTitle] = 0x0013ae,[CaseUpper] = 0x0013ae,[CaseFold] = 0x0013ae}, NULL},
-	{0x0013af, {[CaseLower] = 0x00ab7f,[CaseTitle] = 0x0013af,[CaseUpper] = 0x0013af,[CaseFold] = 0x0013af}, NULL},
-	{0x0013b0, {[CaseLower] = 0x00ab80,[CaseTitle] = 0x0013b0,[CaseUpper] = 0x0013b0,[CaseFold] = 0x0013b0}, NULL},
-	{0x0013b1, {[CaseLower] = 0x00ab81,[CaseTitle] = 0x0013b1,[CaseUpper] = 0x0013b1,[CaseFold] = 0x0013b1}, NULL},
-	{0x0013b2, {[CaseLower] = 0x00ab82,[CaseTitle] = 0x0013b2,[CaseUpper] = 0x0013b2,[CaseFold] = 0x0013b2}, NULL},
-	{0x0013b3, {[CaseLower] = 0x00ab83,[CaseTitle] = 0x0013b3,[CaseUpper] = 0x0013b3,[CaseFold] = 0x0013b3}, NULL},
-	{0x0013b4, {[CaseLower] = 0x00ab84,[CaseTitle] = 0x0013b4,[CaseUpper] = 0x0013b4,[CaseFold] = 0x0013b4}, NULL},
-	{0x0013b5, {[CaseLower] = 0x00ab85,[CaseTitle] = 0x0013b5,[CaseUpper] = 0x0013b5,[CaseFold] = 0x0013b5}, NULL},
-	{0x0013b6, {[CaseLower] = 0x00ab86,[CaseTitle] = 0x0013b6,[CaseUpper] = 0x0013b6,[CaseFold] = 0x0013b6}, NULL},
-	{0x0013b7, {[CaseLower] = 0x00ab87,[CaseTitle] = 0x0013b7,[CaseUpper] = 0x0013b7,[CaseFold] = 0x0013b7}, NULL},
-	{0x0013b8, {[CaseLower] = 0x00ab88,[CaseTitle] = 0x0013b8,[CaseUpper] = 0x0013b8,[CaseFold] = 0x0013b8}, NULL},
-	{0x0013b9, {[CaseLower] = 0x00ab89,[CaseTitle] = 0x0013b9,[CaseUpper] = 0x0013b9,[CaseFold] = 0x0013b9}, NULL},
-	{0x0013ba, {[CaseLower] = 0x00ab8a,[CaseTitle] = 0x0013ba,[CaseUpper] = 0x0013ba,[CaseFold] = 0x0013ba}, NULL},
-	{0x0013bb, {[CaseLower] = 0x00ab8b,[CaseTitle] = 0x0013bb,[CaseUpper] = 0x0013bb,[CaseFold] = 0x0013bb}, NULL},
-	{0x0013bc, {[CaseLower] = 0x00ab8c,[CaseTitle] = 0x0013bc,[CaseUpper] = 0x0013bc,[CaseFold] = 0x0013bc}, NULL},
-	{0x0013bd, {[CaseLower] = 0x00ab8d,[CaseTitle] = 0x0013bd,[CaseUpper] = 0x0013bd,[CaseFold] = 0x0013bd}, NULL},
-	{0x0013be, {[CaseLower] = 0x00ab8e,[CaseTitle] = 0x0013be,[CaseUpper] = 0x0013be,[CaseFold] = 0x0013be}, NULL},
-	{0x0013bf, {[CaseLower] = 0x00ab8f,[CaseTitle] = 0x0013bf,[CaseUpper] = 0x0013bf,[CaseFold] = 0x0013bf}, NULL},
-	{0x0013c0, {[CaseLower] = 0x00ab90,[CaseTitle] = 0x0013c0,[CaseUpper] = 0x0013c0,[CaseFold] = 0x0013c0}, NULL},
-	{0x0013c1, {[CaseLower] = 0x00ab91,[CaseTitle] = 0x0013c1,[CaseUpper] = 0x0013c1,[CaseFold] = 0x0013c1}, NULL},
-	{0x0013c2, {[CaseLower] = 0x00ab92,[CaseTitle] = 0x0013c2,[CaseUpper] = 0x0013c2,[CaseFold] = 0x0013c2}, NULL},
-	{0x0013c3, {[CaseLower] = 0x00ab93,[CaseTitle] = 0x0013c3,[CaseUpper] = 0x0013c3,[CaseFold] = 0x0013c3}, NULL},
-	{0x0013c4, {[CaseLower] = 0x00ab94,[CaseTitle] = 0x0013c4,[CaseUpper] = 0x0013c4,[CaseFold] = 0x0013c4}, NULL},
-	{0x0013c5, {[CaseLower] = 0x00ab95,[CaseTitle] = 0x0013c5,[CaseUpper] = 0x0013c5,[CaseFold] = 0x0013c5}, NULL},
-	{0x0013c6, {[CaseLower] = 0x00ab96,[CaseTitle] = 0x0013c6,[CaseUpper] = 0x0013c6,[CaseFold] = 0x0013c6}, NULL},
-	{0x0013c7, {[CaseLower] = 0x00ab97,[CaseTitle] = 0x0013c7,[CaseUpper] = 0x0013c7,[CaseFold] = 0x0013c7}, NULL},
-	{0x0013c8, {[CaseLower] = 0x00ab98,[CaseTitle] = 0x0013c8,[CaseUpper] = 0x0013c8,[CaseFold] = 0x0013c8}, NULL},
-	{0x0013c9, {[CaseLower] = 0x00ab99,[CaseTitle] = 0x0013c9,[CaseUpper] = 0x0013c9,[CaseFold] = 0x0013c9}, NULL},
-	{0x0013ca, {[CaseLower] = 0x00ab9a,[CaseTitle] = 0x0013ca,[CaseUpper] = 0x0013ca,[CaseFold] = 0x0013ca}, NULL},
-	{0x0013cb, {[CaseLower] = 0x00ab9b,[CaseTitle] = 0x0013cb,[CaseUpper] = 0x0013cb,[CaseFold] = 0x0013cb}, NULL},
-	{0x0013cc, {[CaseLower] = 0x00ab9c,[CaseTitle] = 0x0013cc,[CaseUpper] = 0x0013cc,[CaseFold] = 0x0013cc}, NULL},
-	{0x0013cd, {[CaseLower] = 0x00ab9d,[CaseTitle] = 0x0013cd,[CaseUpper] = 0x0013cd,[CaseFold] = 0x0013cd}, NULL},
-	{0x0013ce, {[CaseLower] = 0x00ab9e,[CaseTitle] = 0x0013ce,[CaseUpper] = 0x0013ce,[CaseFold] = 0x0013ce}, NULL},
-	{0x0013cf, {[CaseLower] = 0x00ab9f,[CaseTitle] = 0x0013cf,[CaseUpper] = 0x0013cf,[CaseFold] = 0x0013cf}, NULL},
-	{0x0013d0, {[CaseLower] = 0x00aba0,[CaseTitle] = 0x0013d0,[CaseUpper] = 0x0013d0,[CaseFold] = 0x0013d0}, NULL},
-	{0x0013d1, {[CaseLower] = 0x00aba1,[CaseTitle] = 0x0013d1,[CaseUpper] = 0x0013d1,[CaseFold] = 0x0013d1}, NULL},
-	{0x0013d2, {[CaseLower] = 0x00aba2,[CaseTitle] = 0x0013d2,[CaseUpper] = 0x0013d2,[CaseFold] = 0x0013d2}, NULL},
-	{0x0013d3, {[CaseLower] = 0x00aba3,[CaseTitle] = 0x0013d3,[CaseUpper] = 0x0013d3,[CaseFold] = 0x0013d3}, NULL},
-	{0x0013d4, {[CaseLower] = 0x00aba4,[CaseTitle] = 0x0013d4,[CaseUpper] = 0x0013d4,[CaseFold] = 0x0013d4}, NULL},
-	{0x0013d5, {[CaseLower] = 0x00aba5,[CaseTitle] = 0x0013d5,[CaseUpper] = 0x0013d5,[CaseFold] = 0x0013d5}, NULL},
-	{0x0013d6, {[CaseLower] = 0x00aba6,[CaseTitle] = 0x0013d6,[CaseUpper] = 0x0013d6,[CaseFold] = 0x0013d6}, NULL},
-	{0x0013d7, {[CaseLower] = 0x00aba7,[CaseTitle] = 0x0013d7,[CaseUpper] = 0x0013d7,[CaseFold] = 0x0013d7}, NULL},
-	{0x0013d8, {[CaseLower] = 0x00aba8,[CaseTitle] = 0x0013d8,[CaseUpper] = 0x0013d8,[CaseFold] = 0x0013d8}, NULL},
-	{0x0013d9, {[CaseLower] = 0x00aba9,[CaseTitle] = 0x0013d9,[CaseUpper] = 0x0013d9,[CaseFold] = 0x0013d9}, NULL},
-	{0x0013da, {[CaseLower] = 0x00abaa,[CaseTitle] = 0x0013da,[CaseUpper] = 0x0013da,[CaseFold] = 0x0013da}, NULL},
-	{0x0013db, {[CaseLower] = 0x00abab,[CaseTitle] = 0x0013db,[CaseUpper] = 0x0013db,[CaseFold] = 0x0013db}, NULL},
-	{0x0013dc, {[CaseLower] = 0x00abac,[CaseTitle] = 0x0013dc,[CaseUpper] = 0x0013dc,[CaseFold] = 0x0013dc}, NULL},
-	{0x0013dd, {[CaseLower] = 0x00abad,[CaseTitle] = 0x0013dd,[CaseUpper] = 0x0013dd,[CaseFold] = 0x0013dd}, NULL},
-	{0x0013de, {[CaseLower] = 0x00abae,[CaseTitle] = 0x0013de,[CaseUpper] = 0x0013de,[CaseFold] = 0x0013de}, NULL},
-	{0x0013df, {[CaseLower] = 0x00abaf,[CaseTitle] = 0x0013df,[CaseUpper] = 0x0013df,[CaseFold] = 0x0013df}, NULL},
-	{0x0013e0, {[CaseLower] = 0x00abb0,[CaseTitle] = 0x0013e0,[CaseUpper] = 0x0013e0,[CaseFold] = 0x0013e0}, NULL},
-	{0x0013e1, {[CaseLower] = 0x00abb1,[CaseTitle] = 0x0013e1,[CaseUpper] = 0x0013e1,[CaseFold] = 0x0013e1}, NULL},
-	{0x0013e2, {[CaseLower] = 0x00abb2,[CaseTitle] = 0x0013e2,[CaseUpper] = 0x0013e2,[CaseFold] = 0x0013e2}, NULL},
-	{0x0013e3, {[CaseLower] = 0x00abb3,[CaseTitle] = 0x0013e3,[CaseUpper] = 0x0013e3,[CaseFold] = 0x0013e3}, NULL},
-	{0x0013e4, {[CaseLower] = 0x00abb4,[CaseTitle] = 0x0013e4,[CaseUpper] = 0x0013e4,[CaseFold] = 0x0013e4}, NULL},
-	{0x0013e5, {[CaseLower] = 0x00abb5,[CaseTitle] = 0x0013e5,[CaseUpper] = 0x0013e5,[CaseFold] = 0x0013e5}, NULL},
-	{0x0013e6, {[CaseLower] = 0x00abb6,[CaseTitle] = 0x0013e6,[CaseUpper] = 0x0013e6,[CaseFold] = 0x0013e6}, NULL},
-	{0x0013e7, {[CaseLower] = 0x00abb7,[CaseTitle] = 0x0013e7,[CaseUpper] = 0x0013e7,[CaseFold] = 0x0013e7}, NULL},
-	{0x0013e8, {[CaseLower] = 0x00abb8,[CaseTitle] = 0x0013e8,[CaseUpper] = 0x0013e8,[CaseFold] = 0x0013e8}, NULL},
-	{0x0013e9, {[CaseLower] = 0x00abb9,[CaseTitle] = 0x0013e9,[CaseUpper] = 0x0013e9,[CaseFold] = 0x0013e9}, NULL},
-	{0x0013ea, {[CaseLower] = 0x00abba,[CaseTitle] = 0x0013ea,[CaseUpper] = 0x0013ea,[CaseFold] = 0x0013ea}, NULL},
-	{0x0013eb, {[CaseLower] = 0x00abbb,[CaseTitle] = 0x0013eb,[CaseUpper] = 0x0013eb,[CaseFold] = 0x0013eb}, NULL},
-	{0x0013ec, {[CaseLower] = 0x00abbc,[CaseTitle] = 0x0013ec,[CaseUpper] = 0x0013ec,[CaseFold] = 0x0013ec}, NULL},
-	{0x0013ed, {[CaseLower] = 0x00abbd,[CaseTitle] = 0x0013ed,[CaseUpper] = 0x0013ed,[CaseFold] = 0x0013ed}, NULL},
-	{0x0013ee, {[CaseLower] = 0x00abbe,[CaseTitle] = 0x0013ee,[CaseUpper] = 0x0013ee,[CaseFold] = 0x0013ee}, NULL},
-	{0x0013ef, {[CaseLower] = 0x00abbf,[CaseTitle] = 0x0013ef,[CaseUpper] = 0x0013ef,[CaseFold] = 0x0013ef}, NULL},
-	{0x0013f0, {[CaseLower] = 0x0013f8,[CaseTitle] = 0x0013f0,[CaseUpper] = 0x0013f0,[CaseFold] = 0x0013f0}, NULL},
-	{0x0013f1, {[CaseLower] = 0x0013f9,[CaseTitle] = 0x0013f1,[CaseUpper] = 0x0013f1,[CaseFold] = 0x0013f1}, NULL},
-	{0x0013f2, {[CaseLower] = 0x0013fa,[CaseTitle] = 0x0013f2,[CaseUpper] = 0x0013f2,[CaseFold] = 0x0013f2}, NULL},
-	{0x0013f3, {[CaseLower] = 0x0013fb,[CaseTitle] = 0x0013f3,[CaseUpper] = 0x0013f3,[CaseFold] = 0x0013f3}, NULL},
-	{0x0013f4, {[CaseLower] = 0x0013fc,[CaseTitle] = 0x0013f4,[CaseUpper] = 0x0013f4,[CaseFold] = 0x0013f4}, NULL},
-	{0x0013f5, {[CaseLower] = 0x0013fd,[CaseTitle] = 0x0013f5,[CaseUpper] = 0x0013f5,[CaseFold] = 0x0013f5}, NULL},
-	{0x0013f8, {[CaseLower] = 0x0013f8,[CaseTitle] = 0x0013f0,[CaseUpper] = 0x0013f0,[CaseFold] = 0x0013f0}, NULL},
-	{0x0013f9, {[CaseLower] = 0x0013f9,[CaseTitle] = 0x0013f1,[CaseUpper] = 0x0013f1,[CaseFold] = 0x0013f1}, NULL},
-	{0x0013fa, {[CaseLower] = 0x0013fa,[CaseTitle] = 0x0013f2,[CaseUpper] = 0x0013f2,[CaseFold] = 0x0013f2}, NULL},
-	{0x0013fb, {[CaseLower] = 0x0013fb,[CaseTitle] = 0x0013f3,[CaseUpper] = 0x0013f3,[CaseFold] = 0x0013f3}, NULL},
-	{0x0013fc, {[CaseLower] = 0x0013fc,[CaseTitle] = 0x0013f4,[CaseUpper] = 0x0013f4,[CaseFold] = 0x0013f4}, NULL},
-	{0x0013fd, {[CaseLower] = 0x0013fd,[CaseTitle] = 0x0013f5,[CaseUpper] = 0x0013f5,[CaseFold] = 0x0013f5}, NULL},
-	{0x001c80, {[CaseLower] = 0x001c80,[CaseTitle] = 0x000412,[CaseUpper] = 0x000412,[CaseFold] = 0x000432}, NULL},
-	{0x001c81, {[CaseLower] = 0x001c81,[CaseTitle] = 0x000414,[CaseUpper] = 0x000414,[CaseFold] = 0x000434}, NULL},
-	{0x001c82, {[CaseLower] = 0x001c82,[CaseTitle] = 0x00041e,[CaseUpper] = 0x00041e,[CaseFold] = 0x00043e}, NULL},
-	{0x001c83, {[CaseLower] = 0x001c83,[CaseTitle] = 0x000421,[CaseUpper] = 0x000421,[CaseFold] = 0x000441}, NULL},
-	{0x001c84, {[CaseLower] = 0x001c84,[CaseTitle] = 0x000422,[CaseUpper] = 0x000422,[CaseFold] = 0x000442}, NULL},
-	{0x001c85, {[CaseLower] = 0x001c85,[CaseTitle] = 0x000422,[CaseUpper] = 0x000422,[CaseFold] = 0x000442}, NULL},
-	{0x001c86, {[CaseLower] = 0x001c86,[CaseTitle] = 0x00042a,[CaseUpper] = 0x00042a,[CaseFold] = 0x00044a}, NULL},
-	{0x001c87, {[CaseLower] = 0x001c87,[CaseTitle] = 0x000462,[CaseUpper] = 0x000462,[CaseFold] = 0x000463}, NULL},
-	{0x001c88, {[CaseLower] = 0x001c88,[CaseTitle] = 0x00a64a,[CaseUpper] = 0x00a64a,[CaseFold] = 0x00a64b}, NULL},
-	{0x001c90, {[CaseLower] = 0x0010d0,[CaseTitle] = 0x001c90,[CaseUpper] = 0x001c90,[CaseFold] = 0x0010d0}, NULL},
-	{0x001c91, {[CaseLower] = 0x0010d1,[CaseTitle] = 0x001c91,[CaseUpper] = 0x001c91,[CaseFold] = 0x0010d1}, NULL},
-	{0x001c92, {[CaseLower] = 0x0010d2,[CaseTitle] = 0x001c92,[CaseUpper] = 0x001c92,[CaseFold] = 0x0010d2}, NULL},
-	{0x001c93, {[CaseLower] = 0x0010d3,[CaseTitle] = 0x001c93,[CaseUpper] = 0x001c93,[CaseFold] = 0x0010d3}, NULL},
-	{0x001c94, {[CaseLower] = 0x0010d4,[CaseTitle] = 0x001c94,[CaseUpper] = 0x001c94,[CaseFold] = 0x0010d4}, NULL},
-	{0x001c95, {[CaseLower] = 0x0010d5,[CaseTitle] = 0x001c95,[CaseUpper] = 0x001c95,[CaseFold] = 0x0010d5}, NULL},
-	{0x001c96, {[CaseLower] = 0x0010d6,[CaseTitle] = 0x001c96,[CaseUpper] = 0x001c96,[CaseFold] = 0x0010d6}, NULL},
-	{0x001c97, {[CaseLower] = 0x0010d7,[CaseTitle] = 0x001c97,[CaseUpper] = 0x001c97,[CaseFold] = 0x0010d7}, NULL},
-	{0x001c98, {[CaseLower] = 0x0010d8,[CaseTitle] = 0x001c98,[CaseUpper] = 0x001c98,[CaseFold] = 0x0010d8}, NULL},
-	{0x001c99, {[CaseLower] = 0x0010d9,[CaseTitle] = 0x001c99,[CaseUpper] = 0x001c99,[CaseFold] = 0x0010d9}, NULL},
-	{0x001c9a, {[CaseLower] = 0x0010da,[CaseTitle] = 0x001c9a,[CaseUpper] = 0x001c9a,[CaseFold] = 0x0010da}, NULL},
-	{0x001c9b, {[CaseLower] = 0x0010db,[CaseTitle] = 0x001c9b,[CaseUpper] = 0x001c9b,[CaseFold] = 0x0010db}, NULL},
-	{0x001c9c, {[CaseLower] = 0x0010dc,[CaseTitle] = 0x001c9c,[CaseUpper] = 0x001c9c,[CaseFold] = 0x0010dc}, NULL},
-	{0x001c9d, {[CaseLower] = 0x0010dd,[CaseTitle] = 0x001c9d,[CaseUpper] = 0x001c9d,[CaseFold] = 0x0010dd}, NULL},
-	{0x001c9e, {[CaseLower] = 0x0010de,[CaseTitle] = 0x001c9e,[CaseUpper] = 0x001c9e,[CaseFold] = 0x0010de}, NULL},
-	{0x001c9f, {[CaseLower] = 0x0010df,[CaseTitle] = 0x001c9f,[CaseUpper] = 0x001c9f,[CaseFold] = 0x0010df}, NULL},
-	{0x001ca0, {[CaseLower] = 0x0010e0,[CaseTitle] = 0x001ca0,[CaseUpper] = 0x001ca0,[CaseFold] = 0x0010e0}, NULL},
-	{0x001ca1, {[CaseLower] = 0x0010e1,[CaseTitle] = 0x001ca1,[CaseUpper] = 0x001ca1,[CaseFold] = 0x0010e1}, NULL},
-	{0x001ca2, {[CaseLower] = 0x0010e2,[CaseTitle] = 0x001ca2,[CaseUpper] = 0x001ca2,[CaseFold] = 0x0010e2}, NULL},
-	{0x001ca3, {[CaseLower] = 0x0010e3,[CaseTitle] = 0x001ca3,[CaseUpper] = 0x001ca3,[CaseFold] = 0x0010e3}, NULL},
-	{0x001ca4, {[CaseLower] = 0x0010e4,[CaseTitle] = 0x001ca4,[CaseUpper] = 0x001ca4,[CaseFold] = 0x0010e4}, NULL},
-	{0x001ca5, {[CaseLower] = 0x0010e5,[CaseTitle] = 0x001ca5,[CaseUpper] = 0x001ca5,[CaseFold] = 0x0010e5}, NULL},
-	{0x001ca6, {[CaseLower] = 0x0010e6,[CaseTitle] = 0x001ca6,[CaseUpper] = 0x001ca6,[CaseFold] = 0x0010e6}, NULL},
-	{0x001ca7, {[CaseLower] = 0x0010e7,[CaseTitle] = 0x001ca7,[CaseUpper] = 0x001ca7,[CaseFold] = 0x0010e7}, NULL},
-	{0x001ca8, {[CaseLower] = 0x0010e8,[CaseTitle] = 0x001ca8,[CaseUpper] = 0x001ca8,[CaseFold] = 0x0010e8}, NULL},
-	{0x001ca9, {[CaseLower] = 0x0010e9,[CaseTitle] = 0x001ca9,[CaseUpper] = 0x001ca9,[CaseFold] = 0x0010e9}, NULL},
-	{0x001caa, {[CaseLower] = 0x0010ea,[CaseTitle] = 0x001caa,[CaseUpper] = 0x001caa,[CaseFold] = 0x0010ea}, NULL},
-	{0x001cab, {[CaseLower] = 0x0010eb,[CaseTitle] = 0x001cab,[CaseUpper] = 0x001cab,[CaseFold] = 0x0010eb}, NULL},
-	{0x001cac, {[CaseLower] = 0x0010ec,[CaseTitle] = 0x001cac,[CaseUpper] = 0x001cac,[CaseFold] = 0x0010ec}, NULL},
-	{0x001cad, {[CaseLower] = 0x0010ed,[CaseTitle] = 0x001cad,[CaseUpper] = 0x001cad,[CaseFold] = 0x0010ed}, NULL},
-	{0x001cae, {[CaseLower] = 0x0010ee,[CaseTitle] = 0x001cae,[CaseUpper] = 0x001cae,[CaseFold] = 0x0010ee}, NULL},
-	{0x001caf, {[CaseLower] = 0x0010ef,[CaseTitle] = 0x001caf,[CaseUpper] = 0x001caf,[CaseFold] = 0x0010ef}, NULL},
-	{0x001cb0, {[CaseLower] = 0x0010f0,[CaseTitle] = 0x001cb0,[CaseUpper] = 0x001cb0,[CaseFold] = 0x0010f0}, NULL},
-	{0x001cb1, {[CaseLower] = 0x0010f1,[CaseTitle] = 0x001cb1,[CaseUpper] = 0x001cb1,[CaseFold] = 0x0010f1}, NULL},
-	{0x001cb2, {[CaseLower] = 0x0010f2,[CaseTitle] = 0x001cb2,[CaseUpper] = 0x001cb2,[CaseFold] = 0x0010f2}, NULL},
-	{0x001cb3, {[CaseLower] = 0x0010f3,[CaseTitle] = 0x001cb3,[CaseUpper] = 0x001cb3,[CaseFold] = 0x0010f3}, NULL},
-	{0x001cb4, {[CaseLower] = 0x0010f4,[CaseTitle] = 0x001cb4,[CaseUpper] = 0x001cb4,[CaseFold] = 0x0010f4}, NULL},
-	{0x001cb5, {[CaseLower] = 0x0010f5,[CaseTitle] = 0x001cb5,[CaseUpper] = 0x001cb5,[CaseFold] = 0x0010f5}, NULL},
-	{0x001cb6, {[CaseLower] = 0x0010f6,[CaseTitle] = 0x001cb6,[CaseUpper] = 0x001cb6,[CaseFold] = 0x0010f6}, NULL},
-	{0x001cb7, {[CaseLower] = 0x0010f7,[CaseTitle] = 0x001cb7,[CaseUpper] = 0x001cb7,[CaseFold] = 0x0010f7}, NULL},
-	{0x001cb8, {[CaseLower] = 0x0010f8,[CaseTitle] = 0x001cb8,[CaseUpper] = 0x001cb8,[CaseFold] = 0x0010f8}, NULL},
-	{0x001cb9, {[CaseLower] = 0x0010f9,[CaseTitle] = 0x001cb9,[CaseUpper] = 0x001cb9,[CaseFold] = 0x0010f9}, NULL},
-	{0x001cba, {[CaseLower] = 0x0010fa,[CaseTitle] = 0x001cba,[CaseUpper] = 0x001cba,[CaseFold] = 0x0010fa}, NULL},
-	{0x001cbd, {[CaseLower] = 0x0010fd,[CaseTitle] = 0x001cbd,[CaseUpper] = 0x001cbd,[CaseFold] = 0x0010fd}, NULL},
-	{0x001cbe, {[CaseLower] = 0x0010fe,[CaseTitle] = 0x001cbe,[CaseUpper] = 0x001cbe,[CaseFold] = 0x0010fe}, NULL},
-	{0x001cbf, {[CaseLower] = 0x0010ff,[CaseTitle] = 0x001cbf,[CaseUpper] = 0x001cbf,[CaseFold] = 0x0010ff}, NULL},
-	{0x001d79, {[CaseLower] = 0x001d79,[CaseTitle] = 0x00a77d,[CaseUpper] = 0x00a77d,[CaseFold] = 0x001d79}, NULL},
-	{0x001d7d, {[CaseLower] = 0x001d7d,[CaseTitle] = 0x002c63,[CaseUpper] = 0x002c63,[CaseFold] = 0x001d7d}, NULL},
-	{0x001d8e, {[CaseLower] = 0x001d8e,[CaseTitle] = 0x00a7c6,[CaseUpper] = 0x00a7c6,[CaseFold] = 0x001d8e}, NULL},
-	{0x001e00, {[CaseLower] = 0x001e01,[CaseTitle] = 0x001e00,[CaseUpper] = 0x001e00,[CaseFold] = 0x001e01}, NULL},
-	{0x001e01, {[CaseLower] = 0x001e01,[CaseTitle] = 0x001e00,[CaseUpper] = 0x001e00,[CaseFold] = 0x001e01}, NULL},
-	{0x001e02, {[CaseLower] = 0x001e03,[CaseTitle] = 0x001e02,[CaseUpper] = 0x001e02,[CaseFold] = 0x001e03}, NULL},
-	{0x001e03, {[CaseLower] = 0x001e03,[CaseTitle] = 0x001e02,[CaseUpper] = 0x001e02,[CaseFold] = 0x001e03}, NULL},
-	{0x001e04, {[CaseLower] = 0x001e05,[CaseTitle] = 0x001e04,[CaseUpper] = 0x001e04,[CaseFold] = 0x001e05}, NULL},
-	{0x001e05, {[CaseLower] = 0x001e05,[CaseTitle] = 0x001e04,[CaseUpper] = 0x001e04,[CaseFold] = 0x001e05}, NULL},
-	{0x001e06, {[CaseLower] = 0x001e07,[CaseTitle] = 0x001e06,[CaseUpper] = 0x001e06,[CaseFold] = 0x001e07}, NULL},
-	{0x001e07, {[CaseLower] = 0x001e07,[CaseTitle] = 0x001e06,[CaseUpper] = 0x001e06,[CaseFold] = 0x001e07}, NULL},
-	{0x001e08, {[CaseLower] = 0x001e09,[CaseTitle] = 0x001e08,[CaseUpper] = 0x001e08,[CaseFold] = 0x001e09}, NULL},
-	{0x001e09, {[CaseLower] = 0x001e09,[CaseTitle] = 0x001e08,[CaseUpper] = 0x001e08,[CaseFold] = 0x001e09}, NULL},
-	{0x001e0a, {[CaseLower] = 0x001e0b,[CaseTitle] = 0x001e0a,[CaseUpper] = 0x001e0a,[CaseFold] = 0x001e0b}, NULL},
-	{0x001e0b, {[CaseLower] = 0x001e0b,[CaseTitle] = 0x001e0a,[CaseUpper] = 0x001e0a,[CaseFold] = 0x001e0b}, NULL},
-	{0x001e0c, {[CaseLower] = 0x001e0d,[CaseTitle] = 0x001e0c,[CaseUpper] = 0x001e0c,[CaseFold] = 0x001e0d}, NULL},
-	{0x001e0d, {[CaseLower] = 0x001e0d,[CaseTitle] = 0x001e0c,[CaseUpper] = 0x001e0c,[CaseFold] = 0x001e0d}, NULL},
-	{0x001e0e, {[CaseLower] = 0x001e0f,[CaseTitle] = 0x001e0e,[CaseUpper] = 0x001e0e,[CaseFold] = 0x001e0f}, NULL},
-	{0x001e0f, {[CaseLower] = 0x001e0f,[CaseTitle] = 0x001e0e,[CaseUpper] = 0x001e0e,[CaseFold] = 0x001e0f}, NULL},
-	{0x001e10, {[CaseLower] = 0x001e11,[CaseTitle] = 0x001e10,[CaseUpper] = 0x001e10,[CaseFold] = 0x001e11}, NULL},
-	{0x001e11, {[CaseLower] = 0x001e11,[CaseTitle] = 0x001e10,[CaseUpper] = 0x001e10,[CaseFold] = 0x001e11}, NULL},
-	{0x001e12, {[CaseLower] = 0x001e13,[CaseTitle] = 0x001e12,[CaseUpper] = 0x001e12,[CaseFold] = 0x001e13}, NULL},
-	{0x001e13, {[CaseLower] = 0x001e13,[CaseTitle] = 0x001e12,[CaseUpper] = 0x001e12,[CaseFold] = 0x001e13}, NULL},
-	{0x001e14, {[CaseLower] = 0x001e15,[CaseTitle] = 0x001e14,[CaseUpper] = 0x001e14,[CaseFold] = 0x001e15}, NULL},
-	{0x001e15, {[CaseLower] = 0x001e15,[CaseTitle] = 0x001e14,[CaseUpper] = 0x001e14,[CaseFold] = 0x001e15}, NULL},
-	{0x001e16, {[CaseLower] = 0x001e17,[CaseTitle] = 0x001e16,[CaseUpper] = 0x001e16,[CaseFold] = 0x001e17}, NULL},
-	{0x001e17, {[CaseLower] = 0x001e17,[CaseTitle] = 0x001e16,[CaseUpper] = 0x001e16,[CaseFold] = 0x001e17}, NULL},
-	{0x001e18, {[CaseLower] = 0x001e19,[CaseTitle] = 0x001e18,[CaseUpper] = 0x001e18,[CaseFold] = 0x001e19}, NULL},
-	{0x001e19, {[CaseLower] = 0x001e19,[CaseTitle] = 0x001e18,[CaseUpper] = 0x001e18,[CaseFold] = 0x001e19}, NULL},
-	{0x001e1a, {[CaseLower] = 0x001e1b,[CaseTitle] = 0x001e1a,[CaseUpper] = 0x001e1a,[CaseFold] = 0x001e1b}, NULL},
-	{0x001e1b, {[CaseLower] = 0x001e1b,[CaseTitle] = 0x001e1a,[CaseUpper] = 0x001e1a,[CaseFold] = 0x001e1b}, NULL},
-	{0x001e1c, {[CaseLower] = 0x001e1d,[CaseTitle] = 0x001e1c,[CaseUpper] = 0x001e1c,[CaseFold] = 0x001e1d}, NULL},
-	{0x001e1d, {[CaseLower] = 0x001e1d,[CaseTitle] = 0x001e1c,[CaseUpper] = 0x001e1c,[CaseFold] = 0x001e1d}, NULL},
-	{0x001e1e, {[CaseLower] = 0x001e1f,[CaseTitle] = 0x001e1e,[CaseUpper] = 0x001e1e,[CaseFold] = 0x001e1f}, NULL},
-	{0x001e1f, {[CaseLower] = 0x001e1f,[CaseTitle] = 0x001e1e,[CaseUpper] = 0x001e1e,[CaseFold] = 0x001e1f}, NULL},
-	{0x001e20, {[CaseLower] = 0x001e21,[CaseTitle] = 0x001e20,[CaseUpper] = 0x001e20,[CaseFold] = 0x001e21}, NULL},
-	{0x001e21, {[CaseLower] = 0x001e21,[CaseTitle] = 0x001e20,[CaseUpper] = 0x001e20,[CaseFold] = 0x001e21}, NULL},
-	{0x001e22, {[CaseLower] = 0x001e23,[CaseTitle] = 0x001e22,[CaseUpper] = 0x001e22,[CaseFold] = 0x001e23}, NULL},
-	{0x001e23, {[CaseLower] = 0x001e23,[CaseTitle] = 0x001e22,[CaseUpper] = 0x001e22,[CaseFold] = 0x001e23}, NULL},
-	{0x001e24, {[CaseLower] = 0x001e25,[CaseTitle] = 0x001e24,[CaseUpper] = 0x001e24,[CaseFold] = 0x001e25}, NULL},
-	{0x001e25, {[CaseLower] = 0x001e25,[CaseTitle] = 0x001e24,[CaseUpper] = 0x001e24,[CaseFold] = 0x001e25}, NULL},
-	{0x001e26, {[CaseLower] = 0x001e27,[CaseTitle] = 0x001e26,[CaseUpper] = 0x001e26,[CaseFold] = 0x001e27}, NULL},
-	{0x001e27, {[CaseLower] = 0x001e27,[CaseTitle] = 0x001e26,[CaseUpper] = 0x001e26,[CaseFold] = 0x001e27}, NULL},
-	{0x001e28, {[CaseLower] = 0x001e29,[CaseTitle] = 0x001e28,[CaseUpper] = 0x001e28,[CaseFold] = 0x001e29}, NULL},
-	{0x001e29, {[CaseLower] = 0x001e29,[CaseTitle] = 0x001e28,[CaseUpper] = 0x001e28,[CaseFold] = 0x001e29}, NULL},
-	{0x001e2a, {[CaseLower] = 0x001e2b,[CaseTitle] = 0x001e2a,[CaseUpper] = 0x001e2a,[CaseFold] = 0x001e2b}, NULL},
-	{0x001e2b, {[CaseLower] = 0x001e2b,[CaseTitle] = 0x001e2a,[CaseUpper] = 0x001e2a,[CaseFold] = 0x001e2b}, NULL},
-	{0x001e2c, {[CaseLower] = 0x001e2d,[CaseTitle] = 0x001e2c,[CaseUpper] = 0x001e2c,[CaseFold] = 0x001e2d}, NULL},
-	{0x001e2d, {[CaseLower] = 0x001e2d,[CaseTitle] = 0x001e2c,[CaseUpper] = 0x001e2c,[CaseFold] = 0x001e2d}, NULL},
-	{0x001e2e, {[CaseLower] = 0x001e2f,[CaseTitle] = 0x001e2e,[CaseUpper] = 0x001e2e,[CaseFold] = 0x001e2f}, NULL},
-	{0x001e2f, {[CaseLower] = 0x001e2f,[CaseTitle] = 0x001e2e,[CaseUpper] = 0x001e2e,[CaseFold] = 0x001e2f}, NULL},
-	{0x001e30, {[CaseLower] = 0x001e31,[CaseTitle] = 0x001e30,[CaseUpper] = 0x001e30,[CaseFold] = 0x001e31}, NULL},
-	{0x001e31, {[CaseLower] = 0x001e31,[CaseTitle] = 0x001e30,[CaseUpper] = 0x001e30,[CaseFold] = 0x001e31}, NULL},
-	{0x001e32, {[CaseLower] = 0x001e33,[CaseTitle] = 0x001e32,[CaseUpper] = 0x001e32,[CaseFold] = 0x001e33}, NULL},
-	{0x001e33, {[CaseLower] = 0x001e33,[CaseTitle] = 0x001e32,[CaseUpper] = 0x001e32,[CaseFold] = 0x001e33}, NULL},
-	{0x001e34, {[CaseLower] = 0x001e35,[CaseTitle] = 0x001e34,[CaseUpper] = 0x001e34,[CaseFold] = 0x001e35}, NULL},
-	{0x001e35, {[CaseLower] = 0x001e35,[CaseTitle] = 0x001e34,[CaseUpper] = 0x001e34,[CaseFold] = 0x001e35}, NULL},
-	{0x001e36, {[CaseLower] = 0x001e37,[CaseTitle] = 0x001e36,[CaseUpper] = 0x001e36,[CaseFold] = 0x001e37}, NULL},
-	{0x001e37, {[CaseLower] = 0x001e37,[CaseTitle] = 0x001e36,[CaseUpper] = 0x001e36,[CaseFold] = 0x001e37}, NULL},
-	{0x001e38, {[CaseLower] = 0x001e39,[CaseTitle] = 0x001e38,[CaseUpper] = 0x001e38,[CaseFold] = 0x001e39}, NULL},
-	{0x001e39, {[CaseLower] = 0x001e39,[CaseTitle] = 0x001e38,[CaseUpper] = 0x001e38,[CaseFold] = 0x001e39}, NULL},
-	{0x001e3a, {[CaseLower] = 0x001e3b,[CaseTitle] = 0x001e3a,[CaseUpper] = 0x001e3a,[CaseFold] = 0x001e3b}, NULL},
-	{0x001e3b, {[CaseLower] = 0x001e3b,[CaseTitle] = 0x001e3a,[CaseUpper] = 0x001e3a,[CaseFold] = 0x001e3b}, NULL},
-	{0x001e3c, {[CaseLower] = 0x001e3d,[CaseTitle] = 0x001e3c,[CaseUpper] = 0x001e3c,[CaseFold] = 0x001e3d}, NULL},
-	{0x001e3d, {[CaseLower] = 0x001e3d,[CaseTitle] = 0x001e3c,[CaseUpper] = 0x001e3c,[CaseFold] = 0x001e3d}, NULL},
-	{0x001e3e, {[CaseLower] = 0x001e3f,[CaseTitle] = 0x001e3e,[CaseUpper] = 0x001e3e,[CaseFold] = 0x001e3f}, NULL},
-	{0x001e3f, {[CaseLower] = 0x001e3f,[CaseTitle] = 0x001e3e,[CaseUpper] = 0x001e3e,[CaseFold] = 0x001e3f}, NULL},
-	{0x001e40, {[CaseLower] = 0x001e41,[CaseTitle] = 0x001e40,[CaseUpper] = 0x001e40,[CaseFold] = 0x001e41}, NULL},
-	{0x001e41, {[CaseLower] = 0x001e41,[CaseTitle] = 0x001e40,[CaseUpper] = 0x001e40,[CaseFold] = 0x001e41}, NULL},
-	{0x001e42, {[CaseLower] = 0x001e43,[CaseTitle] = 0x001e42,[CaseUpper] = 0x001e42,[CaseFold] = 0x001e43}, NULL},
-	{0x001e43, {[CaseLower] = 0x001e43,[CaseTitle] = 0x001e42,[CaseUpper] = 0x001e42,[CaseFold] = 0x001e43}, NULL},
-	{0x001e44, {[CaseLower] = 0x001e45,[CaseTitle] = 0x001e44,[CaseUpper] = 0x001e44,[CaseFold] = 0x001e45}, NULL},
-	{0x001e45, {[CaseLower] = 0x001e45,[CaseTitle] = 0x001e44,[CaseUpper] = 0x001e44,[CaseFold] = 0x001e45}, NULL},
-	{0x001e46, {[CaseLower] = 0x001e47,[CaseTitle] = 0x001e46,[CaseUpper] = 0x001e46,[CaseFold] = 0x001e47}, NULL},
-	{0x001e47, {[CaseLower] = 0x001e47,[CaseTitle] = 0x001e46,[CaseUpper] = 0x001e46,[CaseFold] = 0x001e47}, NULL},
-	{0x001e48, {[CaseLower] = 0x001e49,[CaseTitle] = 0x001e48,[CaseUpper] = 0x001e48,[CaseFold] = 0x001e49}, NULL},
-	{0x001e49, {[CaseLower] = 0x001e49,[CaseTitle] = 0x001e48,[CaseUpper] = 0x001e48,[CaseFold] = 0x001e49}, NULL},
-	{0x001e4a, {[CaseLower] = 0x001e4b,[CaseTitle] = 0x001e4a,[CaseUpper] = 0x001e4a,[CaseFold] = 0x001e4b}, NULL},
-	{0x001e4b, {[CaseLower] = 0x001e4b,[CaseTitle] = 0x001e4a,[CaseUpper] = 0x001e4a,[CaseFold] = 0x001e4b}, NULL},
-	{0x001e4c, {[CaseLower] = 0x001e4d,[CaseTitle] = 0x001e4c,[CaseUpper] = 0x001e4c,[CaseFold] = 0x001e4d}, NULL},
-	{0x001e4d, {[CaseLower] = 0x001e4d,[CaseTitle] = 0x001e4c,[CaseUpper] = 0x001e4c,[CaseFold] = 0x001e4d}, NULL},
-	{0x001e4e, {[CaseLower] = 0x001e4f,[CaseTitle] = 0x001e4e,[CaseUpper] = 0x001e4e,[CaseFold] = 0x001e4f}, NULL},
-	{0x001e4f, {[CaseLower] = 0x001e4f,[CaseTitle] = 0x001e4e,[CaseUpper] = 0x001e4e,[CaseFold] = 0x001e4f}, NULL},
-	{0x001e50, {[CaseLower] = 0x001e51,[CaseTitle] = 0x001e50,[CaseUpper] = 0x001e50,[CaseFold] = 0x001e51}, NULL},
-	{0x001e51, {[CaseLower] = 0x001e51,[CaseTitle] = 0x001e50,[CaseUpper] = 0x001e50,[CaseFold] = 0x001e51}, NULL},
-	{0x001e52, {[CaseLower] = 0x001e53,[CaseTitle] = 0x001e52,[CaseUpper] = 0x001e52,[CaseFold] = 0x001e53}, NULL},
-	{0x001e53, {[CaseLower] = 0x001e53,[CaseTitle] = 0x001e52,[CaseUpper] = 0x001e52,[CaseFold] = 0x001e53}, NULL},
-	{0x001e54, {[CaseLower] = 0x001e55,[CaseTitle] = 0x001e54,[CaseUpper] = 0x001e54,[CaseFold] = 0x001e55}, NULL},
-	{0x001e55, {[CaseLower] = 0x001e55,[CaseTitle] = 0x001e54,[CaseUpper] = 0x001e54,[CaseFold] = 0x001e55}, NULL},
-	{0x001e56, {[CaseLower] = 0x001e57,[CaseTitle] = 0x001e56,[CaseUpper] = 0x001e56,[CaseFold] = 0x001e57}, NULL},
-	{0x001e57, {[CaseLower] = 0x001e57,[CaseTitle] = 0x001e56,[CaseUpper] = 0x001e56,[CaseFold] = 0x001e57}, NULL},
-	{0x001e58, {[CaseLower] = 0x001e59,[CaseTitle] = 0x001e58,[CaseUpper] = 0x001e58,[CaseFold] = 0x001e59}, NULL},
-	{0x001e59, {[CaseLower] = 0x001e59,[CaseTitle] = 0x001e58,[CaseUpper] = 0x001e58,[CaseFold] = 0x001e59}, NULL},
-	{0x001e5a, {[CaseLower] = 0x001e5b,[CaseTitle] = 0x001e5a,[CaseUpper] = 0x001e5a,[CaseFold] = 0x001e5b}, NULL},
-	{0x001e5b, {[CaseLower] = 0x001e5b,[CaseTitle] = 0x001e5a,[CaseUpper] = 0x001e5a,[CaseFold] = 0x001e5b}, NULL},
-	{0x001e5c, {[CaseLower] = 0x001e5d,[CaseTitle] = 0x001e5c,[CaseUpper] = 0x001e5c,[CaseFold] = 0x001e5d}, NULL},
-	{0x001e5d, {[CaseLower] = 0x001e5d,[CaseTitle] = 0x001e5c,[CaseUpper] = 0x001e5c,[CaseFold] = 0x001e5d}, NULL},
-	{0x001e5e, {[CaseLower] = 0x001e5f,[CaseTitle] = 0x001e5e,[CaseUpper] = 0x001e5e,[CaseFold] = 0x001e5f}, NULL},
-	{0x001e5f, {[CaseLower] = 0x001e5f,[CaseTitle] = 0x001e5e,[CaseUpper] = 0x001e5e,[CaseFold] = 0x001e5f}, NULL},
-	{0x001e60, {[CaseLower] = 0x001e61,[CaseTitle] = 0x001e60,[CaseUpper] = 0x001e60,[CaseFold] = 0x001e61}, NULL},
-	{0x001e61, {[CaseLower] = 0x001e61,[CaseTitle] = 0x001e60,[CaseUpper] = 0x001e60,[CaseFold] = 0x001e61}, NULL},
-	{0x001e62, {[CaseLower] = 0x001e63,[CaseTitle] = 0x001e62,[CaseUpper] = 0x001e62,[CaseFold] = 0x001e63}, NULL},
-	{0x001e63, {[CaseLower] = 0x001e63,[CaseTitle] = 0x001e62,[CaseUpper] = 0x001e62,[CaseFold] = 0x001e63}, NULL},
-	{0x001e64, {[CaseLower] = 0x001e65,[CaseTitle] = 0x001e64,[CaseUpper] = 0x001e64,[CaseFold] = 0x001e65}, NULL},
-	{0x001e65, {[CaseLower] = 0x001e65,[CaseTitle] = 0x001e64,[CaseUpper] = 0x001e64,[CaseFold] = 0x001e65}, NULL},
-	{0x001e66, {[CaseLower] = 0x001e67,[CaseTitle] = 0x001e66,[CaseUpper] = 0x001e66,[CaseFold] = 0x001e67}, NULL},
-	{0x001e67, {[CaseLower] = 0x001e67,[CaseTitle] = 0x001e66,[CaseUpper] = 0x001e66,[CaseFold] = 0x001e67}, NULL},
-	{0x001e68, {[CaseLower] = 0x001e69,[CaseTitle] = 0x001e68,[CaseUpper] = 0x001e68,[CaseFold] = 0x001e69}, NULL},
-	{0x001e69, {[CaseLower] = 0x001e69,[CaseTitle] = 0x001e68,[CaseUpper] = 0x001e68,[CaseFold] = 0x001e69}, NULL},
-	{0x001e6a, {[CaseLower] = 0x001e6b,[CaseTitle] = 0x001e6a,[CaseUpper] = 0x001e6a,[CaseFold] = 0x001e6b}, NULL},
-	{0x001e6b, {[CaseLower] = 0x001e6b,[CaseTitle] = 0x001e6a,[CaseUpper] = 0x001e6a,[CaseFold] = 0x001e6b}, NULL},
-	{0x001e6c, {[CaseLower] = 0x001e6d,[CaseTitle] = 0x001e6c,[CaseUpper] = 0x001e6c,[CaseFold] = 0x001e6d}, NULL},
-	{0x001e6d, {[CaseLower] = 0x001e6d,[CaseTitle] = 0x001e6c,[CaseUpper] = 0x001e6c,[CaseFold] = 0x001e6d}, NULL},
-	{0x001e6e, {[CaseLower] = 0x001e6f,[CaseTitle] = 0x001e6e,[CaseUpper] = 0x001e6e,[CaseFold] = 0x001e6f}, NULL},
-	{0x001e6f, {[CaseLower] = 0x001e6f,[CaseTitle] = 0x001e6e,[CaseUpper] = 0x001e6e,[CaseFold] = 0x001e6f}, NULL},
-	{0x001e70, {[CaseLower] = 0x001e71,[CaseTitle] = 0x001e70,[CaseUpper] = 0x001e70,[CaseFold] = 0x001e71}, NULL},
-	{0x001e71, {[CaseLower] = 0x001e71,[CaseTitle] = 0x001e70,[CaseUpper] = 0x001e70,[CaseFold] = 0x001e71}, NULL},
-	{0x001e72, {[CaseLower] = 0x001e73,[CaseTitle] = 0x001e72,[CaseUpper] = 0x001e72,[CaseFold] = 0x001e73}, NULL},
-	{0x001e73, {[CaseLower] = 0x001e73,[CaseTitle] = 0x001e72,[CaseUpper] = 0x001e72,[CaseFold] = 0x001e73}, NULL},
-	{0x001e74, {[CaseLower] = 0x001e75,[CaseTitle] = 0x001e74,[CaseUpper] = 0x001e74,[CaseFold] = 0x001e75}, NULL},
-	{0x001e75, {[CaseLower] = 0x001e75,[CaseTitle] = 0x001e74,[CaseUpper] = 0x001e74,[CaseFold] = 0x001e75}, NULL},
-	{0x001e76, {[CaseLower] = 0x001e77,[CaseTitle] = 0x001e76,[CaseUpper] = 0x001e76,[CaseFold] = 0x001e77}, NULL},
-	{0x001e77, {[CaseLower] = 0x001e77,[CaseTitle] = 0x001e76,[CaseUpper] = 0x001e76,[CaseFold] = 0x001e77}, NULL},
-	{0x001e78, {[CaseLower] = 0x001e79,[CaseTitle] = 0x001e78,[CaseUpper] = 0x001e78,[CaseFold] = 0x001e79}, NULL},
-	{0x001e79, {[CaseLower] = 0x001e79,[CaseTitle] = 0x001e78,[CaseUpper] = 0x001e78,[CaseFold] = 0x001e79}, NULL},
-	{0x001e7a, {[CaseLower] = 0x001e7b,[CaseTitle] = 0x001e7a,[CaseUpper] = 0x001e7a,[CaseFold] = 0x001e7b}, NULL},
-	{0x001e7b, {[CaseLower] = 0x001e7b,[CaseTitle] = 0x001e7a,[CaseUpper] = 0x001e7a,[CaseFold] = 0x001e7b}, NULL},
-	{0x001e7c, {[CaseLower] = 0x001e7d,[CaseTitle] = 0x001e7c,[CaseUpper] = 0x001e7c,[CaseFold] = 0x001e7d}, NULL},
-	{0x001e7d, {[CaseLower] = 0x001e7d,[CaseTitle] = 0x001e7c,[CaseUpper] = 0x001e7c,[CaseFold] = 0x001e7d}, NULL},
-	{0x001e7e, {[CaseLower] = 0x001e7f,[CaseTitle] = 0x001e7e,[CaseUpper] = 0x001e7e,[CaseFold] = 0x001e7f}, NULL},
-	{0x001e7f, {[CaseLower] = 0x001e7f,[CaseTitle] = 0x001e7e,[CaseUpper] = 0x001e7e,[CaseFold] = 0x001e7f}, NULL},
-	{0x001e80, {[CaseLower] = 0x001e81,[CaseTitle] = 0x001e80,[CaseUpper] = 0x001e80,[CaseFold] = 0x001e81}, NULL},
-	{0x001e81, {[CaseLower] = 0x001e81,[CaseTitle] = 0x001e80,[CaseUpper] = 0x001e80,[CaseFold] = 0x001e81}, NULL},
-	{0x001e82, {[CaseLower] = 0x001e83,[CaseTitle] = 0x001e82,[CaseUpper] = 0x001e82,[CaseFold] = 0x001e83}, NULL},
-	{0x001e83, {[CaseLower] = 0x001e83,[CaseTitle] = 0x001e82,[CaseUpper] = 0x001e82,[CaseFold] = 0x001e83}, NULL},
-	{0x001e84, {[CaseLower] = 0x001e85,[CaseTitle] = 0x001e84,[CaseUpper] = 0x001e84,[CaseFold] = 0x001e85}, NULL},
-	{0x001e85, {[CaseLower] = 0x001e85,[CaseTitle] = 0x001e84,[CaseUpper] = 0x001e84,[CaseFold] = 0x001e85}, NULL},
-	{0x001e86, {[CaseLower] = 0x001e87,[CaseTitle] = 0x001e86,[CaseUpper] = 0x001e86,[CaseFold] = 0x001e87}, NULL},
-	{0x001e87, {[CaseLower] = 0x001e87,[CaseTitle] = 0x001e86,[CaseUpper] = 0x001e86,[CaseFold] = 0x001e87}, NULL},
-	{0x001e88, {[CaseLower] = 0x001e89,[CaseTitle] = 0x001e88,[CaseUpper] = 0x001e88,[CaseFold] = 0x001e89}, NULL},
-	{0x001e89, {[CaseLower] = 0x001e89,[CaseTitle] = 0x001e88,[CaseUpper] = 0x001e88,[CaseFold] = 0x001e89}, NULL},
-	{0x001e8a, {[CaseLower] = 0x001e8b,[CaseTitle] = 0x001e8a,[CaseUpper] = 0x001e8a,[CaseFold] = 0x001e8b}, NULL},
-	{0x001e8b, {[CaseLower] = 0x001e8b,[CaseTitle] = 0x001e8a,[CaseUpper] = 0x001e8a,[CaseFold] = 0x001e8b}, NULL},
-	{0x001e8c, {[CaseLower] = 0x001e8d,[CaseTitle] = 0x001e8c,[CaseUpper] = 0x001e8c,[CaseFold] = 0x001e8d}, NULL},
-	{0x001e8d, {[CaseLower] = 0x001e8d,[CaseTitle] = 0x001e8c,[CaseUpper] = 0x001e8c,[CaseFold] = 0x001e8d}, NULL},
-	{0x001e8e, {[CaseLower] = 0x001e8f,[CaseTitle] = 0x001e8e,[CaseUpper] = 0x001e8e,[CaseFold] = 0x001e8f}, NULL},
-	{0x001e8f, {[CaseLower] = 0x001e8f,[CaseTitle] = 0x001e8e,[CaseUpper] = 0x001e8e,[CaseFold] = 0x001e8f}, NULL},
-	{0x001e90, {[CaseLower] = 0x001e91,[CaseTitle] = 0x001e90,[CaseUpper] = 0x001e90,[CaseFold] = 0x001e91}, NULL},
-	{0x001e91, {[CaseLower] = 0x001e91,[CaseTitle] = 0x001e90,[CaseUpper] = 0x001e90,[CaseFold] = 0x001e91}, NULL},
-	{0x001e92, {[CaseLower] = 0x001e93,[CaseTitle] = 0x001e92,[CaseUpper] = 0x001e92,[CaseFold] = 0x001e93}, NULL},
-	{0x001e93, {[CaseLower] = 0x001e93,[CaseTitle] = 0x001e92,[CaseUpper] = 0x001e92,[CaseFold] = 0x001e93}, NULL},
-	{0x001e94, {[CaseLower] = 0x001e95,[CaseTitle] = 0x001e94,[CaseUpper] = 0x001e94,[CaseFold] = 0x001e95}, NULL},
-	{0x001e95, {[CaseLower] = 0x001e95,[CaseTitle] = 0x001e94,[CaseUpper] = 0x001e94,[CaseFold] = 0x001e95}, NULL},
-	{0x001e96, {[CaseLower] = 0x001e96,[CaseTitle] = 0x001e96,[CaseUpper] = 0x001e96,[CaseFold] = 0x001e96}, &special_case[8]},
-	{0x001e97, {[CaseLower] = 0x001e97,[CaseTitle] = 0x001e97,[CaseUpper] = 0x001e97,[CaseFold] = 0x001e97}, &special_case[9]},
-	{0x001e98, {[CaseLower] = 0x001e98,[CaseTitle] = 0x001e98,[CaseUpper] = 0x001e98,[CaseFold] = 0x001e98}, &special_case[10]},
-	{0x001e99, {[CaseLower] = 0x001e99,[CaseTitle] = 0x001e99,[CaseUpper] = 0x001e99,[CaseFold] = 0x001e99}, &special_case[11]},
-	{0x001e9a, {[CaseLower] = 0x001e9a,[CaseTitle] = 0x001e9a,[CaseUpper] = 0x001e9a,[CaseFold] = 0x001e9a}, &special_case[12]},
-	{0x001e9b, {[CaseLower] = 0x001e9b,[CaseTitle] = 0x001e60,[CaseUpper] = 0x001e60,[CaseFold] = 0x001e61}, NULL},
-	{0x001e9e, {[CaseLower] = 0x0000df,[CaseTitle] = 0x001e9e,[CaseUpper] = 0x001e9e,[CaseFold] = 0x0000df}, &special_case[13]},
-	{0x001ea0, {[CaseLower] = 0x001ea1,[CaseTitle] = 0x001ea0,[CaseUpper] = 0x001ea0,[CaseFold] = 0x001ea1}, NULL},
-	{0x001ea1, {[CaseLower] = 0x001ea1,[CaseTitle] = 0x001ea0,[CaseUpper] = 0x001ea0,[CaseFold] = 0x001ea1}, NULL},
-	{0x001ea2, {[CaseLower] = 0x001ea3,[CaseTitle] = 0x001ea2,[CaseUpper] = 0x001ea2,[CaseFold] = 0x001ea3}, NULL},
-	{0x001ea3, {[CaseLower] = 0x001ea3,[CaseTitle] = 0x001ea2,[CaseUpper] = 0x001ea2,[CaseFold] = 0x001ea3}, NULL},
-	{0x001ea4, {[CaseLower] = 0x001ea5,[CaseTitle] = 0x001ea4,[CaseUpper] = 0x001ea4,[CaseFold] = 0x001ea5}, NULL},
-	{0x001ea5, {[CaseLower] = 0x001ea5,[CaseTitle] = 0x001ea4,[CaseUpper] = 0x001ea4,[CaseFold] = 0x001ea5}, NULL},
-	{0x001ea6, {[CaseLower] = 0x001ea7,[CaseTitle] = 0x001ea6,[CaseUpper] = 0x001ea6,[CaseFold] = 0x001ea7}, NULL},
-	{0x001ea7, {[CaseLower] = 0x001ea7,[CaseTitle] = 0x001ea6,[CaseUpper] = 0x001ea6,[CaseFold] = 0x001ea7}, NULL},
-	{0x001ea8, {[CaseLower] = 0x001ea9,[CaseTitle] = 0x001ea8,[CaseUpper] = 0x001ea8,[CaseFold] = 0x001ea9}, NULL},
-	{0x001ea9, {[CaseLower] = 0x001ea9,[CaseTitle] = 0x001ea8,[CaseUpper] = 0x001ea8,[CaseFold] = 0x001ea9}, NULL},
-	{0x001eaa, {[CaseLower] = 0x001eab,[CaseTitle] = 0x001eaa,[CaseUpper] = 0x001eaa,[CaseFold] = 0x001eab}, NULL},
-	{0x001eab, {[CaseLower] = 0x001eab,[CaseTitle] = 0x001eaa,[CaseUpper] = 0x001eaa,[CaseFold] = 0x001eab}, NULL},
-	{0x001eac, {[CaseLower] = 0x001ead,[CaseTitle] = 0x001eac,[CaseUpper] = 0x001eac,[CaseFold] = 0x001ead}, NULL},
-	{0x001ead, {[CaseLower] = 0x001ead,[CaseTitle] = 0x001eac,[CaseUpper] = 0x001eac,[CaseFold] = 0x001ead}, NULL},
-	{0x001eae, {[CaseLower] = 0x001eaf,[CaseTitle] = 0x001eae,[CaseUpper] = 0x001eae,[CaseFold] = 0x001eaf}, NULL},
-	{0x001eaf, {[CaseLower] = 0x001eaf,[CaseTitle] = 0x001eae,[CaseUpper] = 0x001eae,[CaseFold] = 0x001eaf}, NULL},
-	{0x001eb0, {[CaseLower] = 0x001eb1,[CaseTitle] = 0x001eb0,[CaseUpper] = 0x001eb0,[CaseFold] = 0x001eb1}, NULL},
-	{0x001eb1, {[CaseLower] = 0x001eb1,[CaseTitle] = 0x001eb0,[CaseUpper] = 0x001eb0,[CaseFold] = 0x001eb1}, NULL},
-	{0x001eb2, {[CaseLower] = 0x001eb3,[CaseTitle] = 0x001eb2,[CaseUpper] = 0x001eb2,[CaseFold] = 0x001eb3}, NULL},
-	{0x001eb3, {[CaseLower] = 0x001eb3,[CaseTitle] = 0x001eb2,[CaseUpper] = 0x001eb2,[CaseFold] = 0x001eb3}, NULL},
-	{0x001eb4, {[CaseLower] = 0x001eb5,[CaseTitle] = 0x001eb4,[CaseUpper] = 0x001eb4,[CaseFold] = 0x001eb5}, NULL},
-	{0x001eb5, {[CaseLower] = 0x001eb5,[CaseTitle] = 0x001eb4,[CaseUpper] = 0x001eb4,[CaseFold] = 0x001eb5}, NULL},
-	{0x001eb6, {[CaseLower] = 0x001eb7,[CaseTitle] = 0x001eb6,[CaseUpper] = 0x001eb6,[CaseFold] = 0x001eb7}, NULL},
-	{0x001eb7, {[CaseLower] = 0x001eb7,[CaseTitle] = 0x001eb6,[CaseUpper] = 0x001eb6,[CaseFold] = 0x001eb7}, NULL},
-	{0x001eb8, {[CaseLower] = 0x001eb9,[CaseTitle] = 0x001eb8,[CaseUpper] = 0x001eb8,[CaseFold] = 0x001eb9}, NULL},
-	{0x001eb9, {[CaseLower] = 0x001eb9,[CaseTitle] = 0x001eb8,[CaseUpper] = 0x001eb8,[CaseFold] = 0x001eb9}, NULL},
-	{0x001eba, {[CaseLower] = 0x001ebb,[CaseTitle] = 0x001eba,[CaseUpper] = 0x001eba,[CaseFold] = 0x001ebb}, NULL},
-	{0x001ebb, {[CaseLower] = 0x001ebb,[CaseTitle] = 0x001eba,[CaseUpper] = 0x001eba,[CaseFold] = 0x001ebb}, NULL},
-	{0x001ebc, {[CaseLower] = 0x001ebd,[CaseTitle] = 0x001ebc,[CaseUpper] = 0x001ebc,[CaseFold] = 0x001ebd}, NULL},
-	{0x001ebd, {[CaseLower] = 0x001ebd,[CaseTitle] = 0x001ebc,[CaseUpper] = 0x001ebc,[CaseFold] = 0x001ebd}, NULL},
-	{0x001ebe, {[CaseLower] = 0x001ebf,[CaseTitle] = 0x001ebe,[CaseUpper] = 0x001ebe,[CaseFold] = 0x001ebf}, NULL},
-	{0x001ebf, {[CaseLower] = 0x001ebf,[CaseTitle] = 0x001ebe,[CaseUpper] = 0x001ebe,[CaseFold] = 0x001ebf}, NULL},
-	{0x001ec0, {[CaseLower] = 0x001ec1,[CaseTitle] = 0x001ec0,[CaseUpper] = 0x001ec0,[CaseFold] = 0x001ec1}, NULL},
-	{0x001ec1, {[CaseLower] = 0x001ec1,[CaseTitle] = 0x001ec0,[CaseUpper] = 0x001ec0,[CaseFold] = 0x001ec1}, NULL},
-	{0x001ec2, {[CaseLower] = 0x001ec3,[CaseTitle] = 0x001ec2,[CaseUpper] = 0x001ec2,[CaseFold] = 0x001ec3}, NULL},
-	{0x001ec3, {[CaseLower] = 0x001ec3,[CaseTitle] = 0x001ec2,[CaseUpper] = 0x001ec2,[CaseFold] = 0x001ec3}, NULL},
-	{0x001ec4, {[CaseLower] = 0x001ec5,[CaseTitle] = 0x001ec4,[CaseUpper] = 0x001ec4,[CaseFold] = 0x001ec5}, NULL},
-	{0x001ec5, {[CaseLower] = 0x001ec5,[CaseTitle] = 0x001ec4,[CaseUpper] = 0x001ec4,[CaseFold] = 0x001ec5}, NULL},
-	{0x001ec6, {[CaseLower] = 0x001ec7,[CaseTitle] = 0x001ec6,[CaseUpper] = 0x001ec6,[CaseFold] = 0x001ec7}, NULL},
-	{0x001ec7, {[CaseLower] = 0x001ec7,[CaseTitle] = 0x001ec6,[CaseUpper] = 0x001ec6,[CaseFold] = 0x001ec7}, NULL},
-	{0x001ec8, {[CaseLower] = 0x001ec9,[CaseTitle] = 0x001ec8,[CaseUpper] = 0x001ec8,[CaseFold] = 0x001ec9}, NULL},
-	{0x001ec9, {[CaseLower] = 0x001ec9,[CaseTitle] = 0x001ec8,[CaseUpper] = 0x001ec8,[CaseFold] = 0x001ec9}, NULL},
-	{0x001eca, {[CaseLower] = 0x001ecb,[CaseTitle] = 0x001eca,[CaseUpper] = 0x001eca,[CaseFold] = 0x001ecb}, NULL},
-	{0x001ecb, {[CaseLower] = 0x001ecb,[CaseTitle] = 0x001eca,[CaseUpper] = 0x001eca,[CaseFold] = 0x001ecb}, NULL},
-	{0x001ecc, {[CaseLower] = 0x001ecd,[CaseTitle] = 0x001ecc,[CaseUpper] = 0x001ecc,[CaseFold] = 0x001ecd}, NULL},
-	{0x001ecd, {[CaseLower] = 0x001ecd,[CaseTitle] = 0x001ecc,[CaseUpper] = 0x001ecc,[CaseFold] = 0x001ecd}, NULL},
-	{0x001ece, {[CaseLower] = 0x001ecf,[CaseTitle] = 0x001ece,[CaseUpper] = 0x001ece,[CaseFold] = 0x001ecf}, NULL},
-	{0x001ecf, {[CaseLower] = 0x001ecf,[CaseTitle] = 0x001ece,[CaseUpper] = 0x001ece,[CaseFold] = 0x001ecf}, NULL},
-	{0x001ed0, {[CaseLower] = 0x001ed1,[CaseTitle] = 0x001ed0,[CaseUpper] = 0x001ed0,[CaseFold] = 0x001ed1}, NULL},
-	{0x001ed1, {[CaseLower] = 0x001ed1,[CaseTitle] = 0x001ed0,[CaseUpper] = 0x001ed0,[CaseFold] = 0x001ed1}, NULL},
-	{0x001ed2, {[CaseLower] = 0x001ed3,[CaseTitle] = 0x001ed2,[CaseUpper] = 0x001ed2,[CaseFold] = 0x001ed3}, NULL},
-	{0x001ed3, {[CaseLower] = 0x001ed3,[CaseTitle] = 0x001ed2,[CaseUpper] = 0x001ed2,[CaseFold] = 0x001ed3}, NULL},
-	{0x001ed4, {[CaseLower] = 0x001ed5,[CaseTitle] = 0x001ed4,[CaseUpper] = 0x001ed4,[CaseFold] = 0x001ed5}, NULL},
-	{0x001ed5, {[CaseLower] = 0x001ed5,[CaseTitle] = 0x001ed4,[CaseUpper] = 0x001ed4,[CaseFold] = 0x001ed5}, NULL},
-	{0x001ed6, {[CaseLower] = 0x001ed7,[CaseTitle] = 0x001ed6,[CaseUpper] = 0x001ed6,[CaseFold] = 0x001ed7}, NULL},
-	{0x001ed7, {[CaseLower] = 0x001ed7,[CaseTitle] = 0x001ed6,[CaseUpper] = 0x001ed6,[CaseFold] = 0x001ed7}, NULL},
-	{0x001ed8, {[CaseLower] = 0x001ed9,[CaseTitle] = 0x001ed8,[CaseUpper] = 0x001ed8,[CaseFold] = 0x001ed9}, NULL},
-	{0x001ed9, {[CaseLower] = 0x001ed9,[CaseTitle] = 0x001ed8,[CaseUpper] = 0x001ed8,[CaseFold] = 0x001ed9}, NULL},
-	{0x001eda, {[CaseLower] = 0x001edb,[CaseTitle] = 0x001eda,[CaseUpper] = 0x001eda,[CaseFold] = 0x001edb}, NULL},
-	{0x001edb, {[CaseLower] = 0x001edb,[CaseTitle] = 0x001eda,[CaseUpper] = 0x001eda,[CaseFold] = 0x001edb}, NULL},
-	{0x001edc, {[CaseLower] = 0x001edd,[CaseTitle] = 0x001edc,[CaseUpper] = 0x001edc,[CaseFold] = 0x001edd}, NULL},
-	{0x001edd, {[CaseLower] = 0x001edd,[CaseTitle] = 0x001edc,[CaseUpper] = 0x001edc,[CaseFold] = 0x001edd}, NULL},
-	{0x001ede, {[CaseLower] = 0x001edf,[CaseTitle] = 0x001ede,[CaseUpper] = 0x001ede,[CaseFold] = 0x001edf}, NULL},
-	{0x001edf, {[CaseLower] = 0x001edf,[CaseTitle] = 0x001ede,[CaseUpper] = 0x001ede,[CaseFold] = 0x001edf}, NULL},
-	{0x001ee0, {[CaseLower] = 0x001ee1,[CaseTitle] = 0x001ee0,[CaseUpper] = 0x001ee0,[CaseFold] = 0x001ee1}, NULL},
-	{0x001ee1, {[CaseLower] = 0x001ee1,[CaseTitle] = 0x001ee0,[CaseUpper] = 0x001ee0,[CaseFold] = 0x001ee1}, NULL},
-	{0x001ee2, {[CaseLower] = 0x001ee3,[CaseTitle] = 0x001ee2,[CaseUpper] = 0x001ee2,[CaseFold] = 0x001ee3}, NULL},
-	{0x001ee3, {[CaseLower] = 0x001ee3,[CaseTitle] = 0x001ee2,[CaseUpper] = 0x001ee2,[CaseFold] = 0x001ee3}, NULL},
-	{0x001ee4, {[CaseLower] = 0x001ee5,[CaseTitle] = 0x001ee4,[CaseUpper] = 0x001ee4,[CaseFold] = 0x001ee5}, NULL},
-	{0x001ee5, {[CaseLower] = 0x001ee5,[CaseTitle] = 0x001ee4,[CaseUpper] = 0x001ee4,[CaseFold] = 0x001ee5}, NULL},
-	{0x001ee6, {[CaseLower] = 0x001ee7,[CaseTitle] = 0x001ee6,[CaseUpper] = 0x001ee6,[CaseFold] = 0x001ee7}, NULL},
-	{0x001ee7, {[CaseLower] = 0x001ee7,[CaseTitle] = 0x001ee6,[CaseUpper] = 0x001ee6,[CaseFold] = 0x001ee7}, NULL},
-	{0x001ee8, {[CaseLower] = 0x001ee9,[CaseTitle] = 0x001ee8,[CaseUpper] = 0x001ee8,[CaseFold] = 0x001ee9}, NULL},
-	{0x001ee9, {[CaseLower] = 0x001ee9,[CaseTitle] = 0x001ee8,[CaseUpper] = 0x001ee8,[CaseFold] = 0x001ee9}, NULL},
-	{0x001eea, {[CaseLower] = 0x001eeb,[CaseTitle] = 0x001eea,[CaseUpper] = 0x001eea,[CaseFold] = 0x001eeb}, NULL},
-	{0x001eeb, {[CaseLower] = 0x001eeb,[CaseTitle] = 0x001eea,[CaseUpper] = 0x001eea,[CaseFold] = 0x001eeb}, NULL},
-	{0x001eec, {[CaseLower] = 0x001eed,[CaseTitle] = 0x001eec,[CaseUpper] = 0x001eec,[CaseFold] = 0x001eed}, NULL},
-	{0x001eed, {[CaseLower] = 0x001eed,[CaseTitle] = 0x001eec,[CaseUpper] = 0x001eec,[CaseFold] = 0x001eed}, NULL},
-	{0x001eee, {[CaseLower] = 0x001eef,[CaseTitle] = 0x001eee,[CaseUpper] = 0x001eee,[CaseFold] = 0x001eef}, NULL},
-	{0x001eef, {[CaseLower] = 0x001eef,[CaseTitle] = 0x001eee,[CaseUpper] = 0x001eee,[CaseFold] = 0x001eef}, NULL},
-	{0x001ef0, {[CaseLower] = 0x001ef1,[CaseTitle] = 0x001ef0,[CaseUpper] = 0x001ef0,[CaseFold] = 0x001ef1}, NULL},
-	{0x001ef1, {[CaseLower] = 0x001ef1,[CaseTitle] = 0x001ef0,[CaseUpper] = 0x001ef0,[CaseFold] = 0x001ef1}, NULL},
-	{0x001ef2, {[CaseLower] = 0x001ef3,[CaseTitle] = 0x001ef2,[CaseUpper] = 0x001ef2,[CaseFold] = 0x001ef3}, NULL},
-	{0x001ef3, {[CaseLower] = 0x001ef3,[CaseTitle] = 0x001ef2,[CaseUpper] = 0x001ef2,[CaseFold] = 0x001ef3}, NULL},
-	{0x001ef4, {[CaseLower] = 0x001ef5,[CaseTitle] = 0x001ef4,[CaseUpper] = 0x001ef4,[CaseFold] = 0x001ef5}, NULL},
-	{0x001ef5, {[CaseLower] = 0x001ef5,[CaseTitle] = 0x001ef4,[CaseUpper] = 0x001ef4,[CaseFold] = 0x001ef5}, NULL},
-	{0x001ef6, {[CaseLower] = 0x001ef7,[CaseTitle] = 0x001ef6,[CaseUpper] = 0x001ef6,[CaseFold] = 0x001ef7}, NULL},
-	{0x001ef7, {[CaseLower] = 0x001ef7,[CaseTitle] = 0x001ef6,[CaseUpper] = 0x001ef6,[CaseFold] = 0x001ef7}, NULL},
-	{0x001ef8, {[CaseLower] = 0x001ef9,[CaseTitle] = 0x001ef8,[CaseUpper] = 0x001ef8,[CaseFold] = 0x001ef9}, NULL},
-	{0x001ef9, {[CaseLower] = 0x001ef9,[CaseTitle] = 0x001ef8,[CaseUpper] = 0x001ef8,[CaseFold] = 0x001ef9}, NULL},
-	{0x001efa, {[CaseLower] = 0x001efb,[CaseTitle] = 0x001efa,[CaseUpper] = 0x001efa,[CaseFold] = 0x001efb}, NULL},
-	{0x001efb, {[CaseLower] = 0x001efb,[CaseTitle] = 0x001efa,[CaseUpper] = 0x001efa,[CaseFold] = 0x001efb}, NULL},
-	{0x001efc, {[CaseLower] = 0x001efd,[CaseTitle] = 0x001efc,[CaseUpper] = 0x001efc,[CaseFold] = 0x001efd}, NULL},
-	{0x001efd, {[CaseLower] = 0x001efd,[CaseTitle] = 0x001efc,[CaseUpper] = 0x001efc,[CaseFold] = 0x001efd}, NULL},
-	{0x001efe, {[CaseLower] = 0x001eff,[CaseTitle] = 0x001efe,[CaseUpper] = 0x001efe,[CaseFold] = 0x001eff}, NULL},
-	{0x001eff, {[CaseLower] = 0x001eff,[CaseTitle] = 0x001efe,[CaseUpper] = 0x001efe,[CaseFold] = 0x001eff}, NULL},
-	{0x001f00, {[CaseLower] = 0x001f00,[CaseTitle] = 0x001f08,[CaseUpper] = 0x001f08,[CaseFold] = 0x001f00}, NULL},
-	{0x001f01, {[CaseLower] = 0x001f01,[CaseTitle] = 0x001f09,[CaseUpper] = 0x001f09,[CaseFold] = 0x001f01}, NULL},
-	{0x001f02, {[CaseLower] = 0x001f02,[CaseTitle] = 0x001f0a,[CaseUpper] = 0x001f0a,[CaseFold] = 0x001f02}, NULL},
-	{0x001f03, {[CaseLower] = 0x001f03,[CaseTitle] = 0x001f0b,[CaseUpper] = 0x001f0b,[CaseFold] = 0x001f03}, NULL},
-	{0x001f04, {[CaseLower] = 0x001f04,[CaseTitle] = 0x001f0c,[CaseUpper] = 0x001f0c,[CaseFold] = 0x001f04}, NULL},
-	{0x001f05, {[CaseLower] = 0x001f05,[CaseTitle] = 0x001f0d,[CaseUpper] = 0x001f0d,[CaseFold] = 0x001f05}, NULL},
-	{0x001f06, {[CaseLower] = 0x001f06,[CaseTitle] = 0x001f0e,[CaseUpper] = 0x001f0e,[CaseFold] = 0x001f06}, NULL},
-	{0x001f07, {[CaseLower] = 0x001f07,[CaseTitle] = 0x001f0f,[CaseUpper] = 0x001f0f,[CaseFold] = 0x001f07}, NULL},
-	{0x001f08, {[CaseLower] = 0x001f00,[CaseTitle] = 0x001f08,[CaseUpper] = 0x001f08,[CaseFold] = 0x001f00}, NULL},
-	{0x001f09, {[CaseLower] = 0x001f01,[CaseTitle] = 0x001f09,[CaseUpper] = 0x001f09,[CaseFold] = 0x001f01}, NULL},
-	{0x001f0a, {[CaseLower] = 0x001f02,[CaseTitle] = 0x001f0a,[CaseUpper] = 0x001f0a,[CaseFold] = 0x001f02}, NULL},
-	{0x001f0b, {[CaseLower] = 0x001f03,[CaseTitle] = 0x001f0b,[CaseUpper] = 0x001f0b,[CaseFold] = 0x001f03}, NULL},
-	{0x001f0c, {[CaseLower] = 0x001f04,[CaseTitle] = 0x001f0c,[CaseUpper] = 0x001f0c,[CaseFold] = 0x001f04}, NULL},
-	{0x001f0d, {[CaseLower] = 0x001f05,[CaseTitle] = 0x001f0d,[CaseUpper] = 0x001f0d,[CaseFold] = 0x001f05}, NULL},
-	{0x001f0e, {[CaseLower] = 0x001f06,[CaseTitle] = 0x001f0e,[CaseUpper] = 0x001f0e,[CaseFold] = 0x001f06}, NULL},
-	{0x001f0f, {[CaseLower] = 0x001f07,[CaseTitle] = 0x001f0f,[CaseUpper] = 0x001f0f,[CaseFold] = 0x001f07}, NULL},
-	{0x001f10, {[CaseLower] = 0x001f10,[CaseTitle] = 0x001f18,[CaseUpper] = 0x001f18,[CaseFold] = 0x001f10}, NULL},
-	{0x001f11, {[CaseLower] = 0x001f11,[CaseTitle] = 0x001f19,[CaseUpper] = 0x001f19,[CaseFold] = 0x001f11}, NULL},
-	{0x001f12, {[CaseLower] = 0x001f12,[CaseTitle] = 0x001f1a,[CaseUpper] = 0x001f1a,[CaseFold] = 0x001f12}, NULL},
-	{0x001f13, {[CaseLower] = 0x001f13,[CaseTitle] = 0x001f1b,[CaseUpper] = 0x001f1b,[CaseFold] = 0x001f13}, NULL},
-	{0x001f14, {[CaseLower] = 0x001f14,[CaseTitle] = 0x001f1c,[CaseUpper] = 0x001f1c,[CaseFold] = 0x001f14}, NULL},
-	{0x001f15, {[CaseLower] = 0x001f15,[CaseTitle] = 0x001f1d,[CaseUpper] = 0x001f1d,[CaseFold] = 0x001f15}, NULL},
-	{0x001f18, {[CaseLower] = 0x001f10,[CaseTitle] = 0x001f18,[CaseUpper] = 0x001f18,[CaseFold] = 0x001f10}, NULL},
-	{0x001f19, {[CaseLower] = 0x001f11,[CaseTitle] = 0x001f19,[CaseUpper] = 0x001f19,[CaseFold] = 0x001f11}, NULL},
-	{0x001f1a, {[CaseLower] = 0x001f12,[CaseTitle] = 0x001f1a,[CaseUpper] = 0x001f1a,[CaseFold] = 0x001f12}, NULL},
-	{0x001f1b, {[CaseLower] = 0x001f13,[CaseTitle] = 0x001f1b,[CaseUpper] = 0x001f1b,[CaseFold] = 0x001f13}, NULL},
-	{0x001f1c, {[CaseLower] = 0x001f14,[CaseTitle] = 0x001f1c,[CaseUpper] = 0x001f1c,[CaseFold] = 0x001f14}, NULL},
-	{0x001f1d, {[CaseLower] = 0x001f15,[CaseTitle] = 0x001f1d,[CaseUpper] = 0x001f1d,[CaseFold] = 0x001f15}, NULL},
-	{0x001f20, {[CaseLower] = 0x001f20,[CaseTitle] = 0x001f28,[CaseUpper] = 0x001f28,[CaseFold] = 0x001f20}, NULL},
-	{0x001f21, {[CaseLower] = 0x001f21,[CaseTitle] = 0x001f29,[CaseUpper] = 0x001f29,[CaseFold] = 0x001f21}, NULL},
-	{0x001f22, {[CaseLower] = 0x001f22,[CaseTitle] = 0x001f2a,[CaseUpper] = 0x001f2a,[CaseFold] = 0x001f22}, NULL},
-	{0x001f23, {[CaseLower] = 0x001f23,[CaseTitle] = 0x001f2b,[CaseUpper] = 0x001f2b,[CaseFold] = 0x001f23}, NULL},
-	{0x001f24, {[CaseLower] = 0x001f24,[CaseTitle] = 0x001f2c,[CaseUpper] = 0x001f2c,[CaseFold] = 0x001f24}, NULL},
-	{0x001f25, {[CaseLower] = 0x001f25,[CaseTitle] = 0x001f2d,[CaseUpper] = 0x001f2d,[CaseFold] = 0x001f25}, NULL},
-	{0x001f26, {[CaseLower] = 0x001f26,[CaseTitle] = 0x001f2e,[CaseUpper] = 0x001f2e,[CaseFold] = 0x001f26}, NULL},
-	{0x001f27, {[CaseLower] = 0x001f27,[CaseTitle] = 0x001f2f,[CaseUpper] = 0x001f2f,[CaseFold] = 0x001f27}, NULL},
-	{0x001f28, {[CaseLower] = 0x001f20,[CaseTitle] = 0x001f28,[CaseUpper] = 0x001f28,[CaseFold] = 0x001f20}, NULL},
-	{0x001f29, {[CaseLower] = 0x001f21,[CaseTitle] = 0x001f29,[CaseUpper] = 0x001f29,[CaseFold] = 0x001f21}, NULL},
-	{0x001f2a, {[CaseLower] = 0x001f22,[CaseTitle] = 0x001f2a,[CaseUpper] = 0x001f2a,[CaseFold] = 0x001f22}, NULL},
-	{0x001f2b, {[CaseLower] = 0x001f23,[CaseTitle] = 0x001f2b,[CaseUpper] = 0x001f2b,[CaseFold] = 0x001f23}, NULL},
-	{0x001f2c, {[CaseLower] = 0x001f24,[CaseTitle] = 0x001f2c,[CaseUpper] = 0x001f2c,[CaseFold] = 0x001f24}, NULL},
-	{0x001f2d, {[CaseLower] = 0x001f25,[CaseTitle] = 0x001f2d,[CaseUpper] = 0x001f2d,[CaseFold] = 0x001f25}, NULL},
-	{0x001f2e, {[CaseLower] = 0x001f26,[CaseTitle] = 0x001f2e,[CaseUpper] = 0x001f2e,[CaseFold] = 0x001f26}, NULL},
-	{0x001f2f, {[CaseLower] = 0x001f27,[CaseTitle] = 0x001f2f,[CaseUpper] = 0x001f2f,[CaseFold] = 0x001f27}, NULL},
-	{0x001f30, {[CaseLower] = 0x001f30,[CaseTitle] = 0x001f38,[CaseUpper] = 0x001f38,[CaseFold] = 0x001f30}, NULL},
-	{0x001f31, {[CaseLower] = 0x001f31,[CaseTitle] = 0x001f39,[CaseUpper] = 0x001f39,[CaseFold] = 0x001f31}, NULL},
-	{0x001f32, {[CaseLower] = 0x001f32,[CaseTitle] = 0x001f3a,[CaseUpper] = 0x001f3a,[CaseFold] = 0x001f32}, NULL},
-	{0x001f33, {[CaseLower] = 0x001f33,[CaseTitle] = 0x001f3b,[CaseUpper] = 0x001f3b,[CaseFold] = 0x001f33}, NULL},
-	{0x001f34, {[CaseLower] = 0x001f34,[CaseTitle] = 0x001f3c,[CaseUpper] = 0x001f3c,[CaseFold] = 0x001f34}, NULL},
-	{0x001f35, {[CaseLower] = 0x001f35,[CaseTitle] = 0x001f3d,[CaseUpper] = 0x001f3d,[CaseFold] = 0x001f35}, NULL},
-	{0x001f36, {[CaseLower] = 0x001f36,[CaseTitle] = 0x001f3e,[CaseUpper] = 0x001f3e,[CaseFold] = 0x001f36}, NULL},
-	{0x001f37, {[CaseLower] = 0x001f37,[CaseTitle] = 0x001f3f,[CaseUpper] = 0x001f3f,[CaseFold] = 0x001f37}, NULL},
-	{0x001f38, {[CaseLower] = 0x001f30,[CaseTitle] = 0x001f38,[CaseUpper] = 0x001f38,[CaseFold] = 0x001f30}, NULL},
-	{0x001f39, {[CaseLower] = 0x001f31,[CaseTitle] = 0x001f39,[CaseUpper] = 0x001f39,[CaseFold] = 0x001f31}, NULL},
-	{0x001f3a, {[CaseLower] = 0x001f32,[CaseTitle] = 0x001f3a,[CaseUpper] = 0x001f3a,[CaseFold] = 0x001f32}, NULL},
-	{0x001f3b, {[CaseLower] = 0x001f33,[CaseTitle] = 0x001f3b,[CaseUpper] = 0x001f3b,[CaseFold] = 0x001f33}, NULL},
-	{0x001f3c, {[CaseLower] = 0x001f34,[CaseTitle] = 0x001f3c,[CaseUpper] = 0x001f3c,[CaseFold] = 0x001f34}, NULL},
-	{0x001f3d, {[CaseLower] = 0x001f35,[CaseTitle] = 0x001f3d,[CaseUpper] = 0x001f3d,[CaseFold] = 0x001f35}, NULL},
-	{0x001f3e, {[CaseLower] = 0x001f36,[CaseTitle] = 0x001f3e,[CaseUpper] = 0x001f3e,[CaseFold] = 0x001f36}, NULL},
-	{0x001f3f, {[CaseLower] = 0x001f37,[CaseTitle] = 0x001f3f,[CaseUpper] = 0x001f3f,[CaseFold] = 0x001f37}, NULL},
-	{0x001f40, {[CaseLower] = 0x001f40,[CaseTitle] = 0x001f48,[CaseUpper] = 0x001f48,[CaseFold] = 0x001f40}, NULL},
-	{0x001f41, {[CaseLower] = 0x001f41,[CaseTitle] = 0x001f49,[CaseUpper] = 0x001f49,[CaseFold] = 0x001f41}, NULL},
-	{0x001f42, {[CaseLower] = 0x001f42,[CaseTitle] = 0x001f4a,[CaseUpper] = 0x001f4a,[CaseFold] = 0x001f42}, NULL},
-	{0x001f43, {[CaseLower] = 0x001f43,[CaseTitle] = 0x001f4b,[CaseUpper] = 0x001f4b,[CaseFold] = 0x001f43}, NULL},
-	{0x001f44, {[CaseLower] = 0x001f44,[CaseTitle] = 0x001f4c,[CaseUpper] = 0x001f4c,[CaseFold] = 0x001f44}, NULL},
-	{0x001f45, {[CaseLower] = 0x001f45,[CaseTitle] = 0x001f4d,[CaseUpper] = 0x001f4d,[CaseFold] = 0x001f45}, NULL},
-	{0x001f48, {[CaseLower] = 0x001f40,[CaseTitle] = 0x001f48,[CaseUpper] = 0x001f48,[CaseFold] = 0x001f40}, NULL},
-	{0x001f49, {[CaseLower] = 0x001f41,[CaseTitle] = 0x001f49,[CaseUpper] = 0x001f49,[CaseFold] = 0x001f41}, NULL},
-	{0x001f4a, {[CaseLower] = 0x001f42,[CaseTitle] = 0x001f4a,[CaseUpper] = 0x001f4a,[CaseFold] = 0x001f42}, NULL},
-	{0x001f4b, {[CaseLower] = 0x001f43,[CaseTitle] = 0x001f4b,[CaseUpper] = 0x001f4b,[CaseFold] = 0x001f43}, NULL},
-	{0x001f4c, {[CaseLower] = 0x001f44,[CaseTitle] = 0x001f4c,[CaseUpper] = 0x001f4c,[CaseFold] = 0x001f44}, NULL},
-	{0x001f4d, {[CaseLower] = 0x001f45,[CaseTitle] = 0x001f4d,[CaseUpper] = 0x001f4d,[CaseFold] = 0x001f45}, NULL},
-	{0x001f50, {[CaseLower] = 0x001f50,[CaseTitle] = 0x001f50,[CaseUpper] = 0x001f50,[CaseFold] = 0x001f50}, &special_case[14]},
-	{0x001f51, {[CaseLower] = 0x001f51,[CaseTitle] = 0x001f59,[CaseUpper] = 0x001f59,[CaseFold] = 0x001f51}, NULL},
-	{0x001f52, {[CaseLower] = 0x001f52,[CaseTitle] = 0x001f52,[CaseUpper] = 0x001f52,[CaseFold] = 0x001f52}, &special_case[15]},
-	{0x001f53, {[CaseLower] = 0x001f53,[CaseTitle] = 0x001f5b,[CaseUpper] = 0x001f5b,[CaseFold] = 0x001f53}, NULL},
-	{0x001f54, {[CaseLower] = 0x001f54,[CaseTitle] = 0x001f54,[CaseUpper] = 0x001f54,[CaseFold] = 0x001f54}, &special_case[16]},
-	{0x001f55, {[CaseLower] = 0x001f55,[CaseTitle] = 0x001f5d,[CaseUpper] = 0x001f5d,[CaseFold] = 0x001f55}, NULL},
-	{0x001f56, {[CaseLower] = 0x001f56,[CaseTitle] = 0x001f56,[CaseUpper] = 0x001f56,[CaseFold] = 0x001f56}, &special_case[17]},
-	{0x001f57, {[CaseLower] = 0x001f57,[CaseTitle] = 0x001f5f,[CaseUpper] = 0x001f5f,[CaseFold] = 0x001f57}, NULL},
-	{0x001f59, {[CaseLower] = 0x001f51,[CaseTitle] = 0x001f59,[CaseUpper] = 0x001f59,[CaseFold] = 0x001f51}, NULL},
-	{0x001f5b, {[CaseLower] = 0x001f53,[CaseTitle] = 0x001f5b,[CaseUpper] = 0x001f5b,[CaseFold] = 0x001f53}, NULL},
-	{0x001f5d, {[CaseLower] = 0x001f55,[CaseTitle] = 0x001f5d,[CaseUpper] = 0x001f5d,[CaseFold] = 0x001f55}, NULL},
-	{0x001f5f, {[CaseLower] = 0x001f57,[CaseTitle] = 0x001f5f,[CaseUpper] = 0x001f5f,[CaseFold] = 0x001f57}, NULL},
-	{0x001f60, {[CaseLower] = 0x001f60,[CaseTitle] = 0x001f68,[CaseUpper] = 0x001f68,[CaseFold] = 0x001f60}, NULL},
-	{0x001f61, {[CaseLower] = 0x001f61,[CaseTitle] = 0x001f69,[CaseUpper] = 0x001f69,[CaseFold] = 0x001f61}, NULL},
-	{0x001f62, {[CaseLower] = 0x001f62,[CaseTitle] = 0x001f6a,[CaseUpper] = 0x001f6a,[CaseFold] = 0x001f62}, NULL},
-	{0x001f63, {[CaseLower] = 0x001f63,[CaseTitle] = 0x001f6b,[CaseUpper] = 0x001f6b,[CaseFold] = 0x001f63}, NULL},
-	{0x001f64, {[CaseLower] = 0x001f64,[CaseTitle] = 0x001f6c,[CaseUpper] = 0x001f6c,[CaseFold] = 0x001f64}, NULL},
-	{0x001f65, {[CaseLower] = 0x001f65,[CaseTitle] = 0x001f6d,[CaseUpper] = 0x001f6d,[CaseFold] = 0x001f65}, NULL},
-	{0x001f66, {[CaseLower] = 0x001f66,[CaseTitle] = 0x001f6e,[CaseUpper] = 0x001f6e,[CaseFold] = 0x001f66}, NULL},
-	{0x001f67, {[CaseLower] = 0x001f67,[CaseTitle] = 0x001f6f,[CaseUpper] = 0x001f6f,[CaseFold] = 0x001f67}, NULL},
-	{0x001f68, {[CaseLower] = 0x001f60,[CaseTitle] = 0x001f68,[CaseUpper] = 0x001f68,[CaseFold] = 0x001f60}, NULL},
-	{0x001f69, {[CaseLower] = 0x001f61,[CaseTitle] = 0x001f69,[CaseUpper] = 0x001f69,[CaseFold] = 0x001f61}, NULL},
-	{0x001f6a, {[CaseLower] = 0x001f62,[CaseTitle] = 0x001f6a,[CaseUpper] = 0x001f6a,[CaseFold] = 0x001f62}, NULL},
-	{0x001f6b, {[CaseLower] = 0x001f63,[CaseTitle] = 0x001f6b,[CaseUpper] = 0x001f6b,[CaseFold] = 0x001f63}, NULL},
-	{0x001f6c, {[CaseLower] = 0x001f64,[CaseTitle] = 0x001f6c,[CaseUpper] = 0x001f6c,[CaseFold] = 0x001f64}, NULL},
-	{0x001f6d, {[CaseLower] = 0x001f65,[CaseTitle] = 0x001f6d,[CaseUpper] = 0x001f6d,[CaseFold] = 0x001f65}, NULL},
-	{0x001f6e, {[CaseLower] = 0x001f66,[CaseTitle] = 0x001f6e,[CaseUpper] = 0x001f6e,[CaseFold] = 0x001f66}, NULL},
-	{0x001f6f, {[CaseLower] = 0x001f67,[CaseTitle] = 0x001f6f,[CaseUpper] = 0x001f6f,[CaseFold] = 0x001f67}, NULL},
-	{0x001f70, {[CaseLower] = 0x001f70,[CaseTitle] = 0x001fba,[CaseUpper] = 0x001fba,[CaseFold] = 0x001f70}, NULL},
-	{0x001f71, {[CaseLower] = 0x001f71,[CaseTitle] = 0x001fbb,[CaseUpper] = 0x001fbb,[CaseFold] = 0x001f71}, NULL},
-	{0x001f72, {[CaseLower] = 0x001f72,[CaseTitle] = 0x001fc8,[CaseUpper] = 0x001fc8,[CaseFold] = 0x001f72}, NULL},
-	{0x001f73, {[CaseLower] = 0x001f73,[CaseTitle] = 0x001fc9,[CaseUpper] = 0x001fc9,[CaseFold] = 0x001f73}, NULL},
-	{0x001f74, {[CaseLower] = 0x001f74,[CaseTitle] = 0x001fca,[CaseUpper] = 0x001fca,[CaseFold] = 0x001f74}, NULL},
-	{0x001f75, {[CaseLower] = 0x001f75,[CaseTitle] = 0x001fcb,[CaseUpper] = 0x001fcb,[CaseFold] = 0x001f75}, NULL},
-	{0x001f76, {[CaseLower] = 0x001f76,[CaseTitle] = 0x001fda,[CaseUpper] = 0x001fda,[CaseFold] = 0x001f76}, NULL},
-	{0x001f77, {[CaseLower] = 0x001f77,[CaseTitle] = 0x001fdb,[CaseUpper] = 0x001fdb,[CaseFold] = 0x001f77}, NULL},
-	{0x001f78, {[CaseLower] = 0x001f78,[CaseTitle] = 0x001ff8,[CaseUpper] = 0x001ff8,[CaseFold] = 0x001f78}, NULL},
-	{0x001f79, {[CaseLower] = 0x001f79,[CaseTitle] = 0x001ff9,[CaseUpper] = 0x001ff9,[CaseFold] = 0x001f79}, NULL},
-	{0x001f7a, {[CaseLower] = 0x001f7a,[CaseTitle] = 0x001fea,[CaseUpper] = 0x001fea,[CaseFold] = 0x001f7a}, NULL},
-	{0x001f7b, {[CaseLower] = 0x001f7b,[CaseTitle] = 0x001feb,[CaseUpper] = 0x001feb,[CaseFold] = 0x001f7b}, NULL},
-	{0x001f7c, {[CaseLower] = 0x001f7c,[CaseTitle] = 0x001ffa,[CaseUpper] = 0x001ffa,[CaseFold] = 0x001f7c}, NULL},
-	{0x001f7d, {[CaseLower] = 0x001f7d,[CaseTitle] = 0x001ffb,[CaseUpper] = 0x001ffb,[CaseFold] = 0x001f7d}, NULL},
-	{0x001f80, {[CaseLower] = 0x001f80,[CaseTitle] = 0x001f88,[CaseUpper] = 0x001f88,[CaseFold] = 0x001f80}, &special_case[18]},
-	{0x001f81, {[CaseLower] = 0x001f81,[CaseTitle] = 0x001f89,[CaseUpper] = 0x001f89,[CaseFold] = 0x001f81}, &special_case[19]},
-	{0x001f82, {[CaseLower] = 0x001f82,[CaseTitle] = 0x001f8a,[CaseUpper] = 0x001f8a,[CaseFold] = 0x001f82}, &special_case[20]},
-	{0x001f83, {[CaseLower] = 0x001f83,[CaseTitle] = 0x001f8b,[CaseUpper] = 0x001f8b,[CaseFold] = 0x001f83}, &special_case[21]},
-	{0x001f84, {[CaseLower] = 0x001f84,[CaseTitle] = 0x001f8c,[CaseUpper] = 0x001f8c,[CaseFold] = 0x001f84}, &special_case[22]},
-	{0x001f85, {[CaseLower] = 0x001f85,[CaseTitle] = 0x001f8d,[CaseUpper] = 0x001f8d,[CaseFold] = 0x001f85}, &special_case[23]},
-	{0x001f86, {[CaseLower] = 0x001f86,[CaseTitle] = 0x001f8e,[CaseUpper] = 0x001f8e,[CaseFold] = 0x001f86}, &special_case[24]},
-	{0x001f87, {[CaseLower] = 0x001f87,[CaseTitle] = 0x001f8f,[CaseUpper] = 0x001f8f,[CaseFold] = 0x001f87}, &special_case[25]},
-	{0x001f88, {[CaseLower] = 0x001f80,[CaseTitle] = 0x001f88,[CaseUpper] = 0x001f88,[CaseFold] = 0x001f80}, &special_case[26]},
-	{0x001f89, {[CaseLower] = 0x001f81,[CaseTitle] = 0x001f89,[CaseUpper] = 0x001f89,[CaseFold] = 0x001f81}, &special_case[27]},
-	{0x001f8a, {[CaseLower] = 0x001f82,[CaseTitle] = 0x001f8a,[CaseUpper] = 0x001f8a,[CaseFold] = 0x001f82}, &special_case[28]},
-	{0x001f8b, {[CaseLower] = 0x001f83,[CaseTitle] = 0x001f8b,[CaseUpper] = 0x001f8b,[CaseFold] = 0x001f83}, &special_case[29]},
-	{0x001f8c, {[CaseLower] = 0x001f84,[CaseTitle] = 0x001f8c,[CaseUpper] = 0x001f8c,[CaseFold] = 0x001f84}, &special_case[30]},
-	{0x001f8d, {[CaseLower] = 0x001f85,[CaseTitle] = 0x001f8d,[CaseUpper] = 0x001f8d,[CaseFold] = 0x001f85}, &special_case[31]},
-	{0x001f8e, {[CaseLower] = 0x001f86,[CaseTitle] = 0x001f8e,[CaseUpper] = 0x001f8e,[CaseFold] = 0x001f86}, &special_case[32]},
-	{0x001f8f, {[CaseLower] = 0x001f87,[CaseTitle] = 0x001f8f,[CaseUpper] = 0x001f8f,[CaseFold] = 0x001f87}, &special_case[33]},
-	{0x001f90, {[CaseLower] = 0x001f90,[CaseTitle] = 0x001f98,[CaseUpper] = 0x001f98,[CaseFold] = 0x001f90}, &special_case[34]},
-	{0x001f91, {[CaseLower] = 0x001f91,[CaseTitle] = 0x001f99,[CaseUpper] = 0x001f99,[CaseFold] = 0x001f91}, &special_case[35]},
-	{0x001f92, {[CaseLower] = 0x001f92,[CaseTitle] = 0x001f9a,[CaseUpper] = 0x001f9a,[CaseFold] = 0x001f92}, &special_case[36]},
-	{0x001f93, {[CaseLower] = 0x001f93,[CaseTitle] = 0x001f9b,[CaseUpper] = 0x001f9b,[CaseFold] = 0x001f93}, &special_case[37]},
-	{0x001f94, {[CaseLower] = 0x001f94,[CaseTitle] = 0x001f9c,[CaseUpper] = 0x001f9c,[CaseFold] = 0x001f94}, &special_case[38]},
-	{0x001f95, {[CaseLower] = 0x001f95,[CaseTitle] = 0x001f9d,[CaseUpper] = 0x001f9d,[CaseFold] = 0x001f95}, &special_case[39]},
-	{0x001f96, {[CaseLower] = 0x001f96,[CaseTitle] = 0x001f9e,[CaseUpper] = 0x001f9e,[CaseFold] = 0x001f96}, &special_case[40]},
-	{0x001f97, {[CaseLower] = 0x001f97,[CaseTitle] = 0x001f9f,[CaseUpper] = 0x001f9f,[CaseFold] = 0x001f97}, &special_case[41]},
-	{0x001f98, {[CaseLower] = 0x001f90,[CaseTitle] = 0x001f98,[CaseUpper] = 0x001f98,[CaseFold] = 0x001f90}, &special_case[42]},
-	{0x001f99, {[CaseLower] = 0x001f91,[CaseTitle] = 0x001f99,[CaseUpper] = 0x001f99,[CaseFold] = 0x001f91}, &special_case[43]},
-	{0x001f9a, {[CaseLower] = 0x001f92,[CaseTitle] = 0x001f9a,[CaseUpper] = 0x001f9a,[CaseFold] = 0x001f92}, &special_case[44]},
-	{0x001f9b, {[CaseLower] = 0x001f93,[CaseTitle] = 0x001f9b,[CaseUpper] = 0x001f9b,[CaseFold] = 0x001f93}, &special_case[45]},
-	{0x001f9c, {[CaseLower] = 0x001f94,[CaseTitle] = 0x001f9c,[CaseUpper] = 0x001f9c,[CaseFold] = 0x001f94}, &special_case[46]},
-	{0x001f9d, {[CaseLower] = 0x001f95,[CaseTitle] = 0x001f9d,[CaseUpper] = 0x001f9d,[CaseFold] = 0x001f95}, &special_case[47]},
-	{0x001f9e, {[CaseLower] = 0x001f96,[CaseTitle] = 0x001f9e,[CaseUpper] = 0x001f9e,[CaseFold] = 0x001f96}, &special_case[48]},
-	{0x001f9f, {[CaseLower] = 0x001f97,[CaseTitle] = 0x001f9f,[CaseUpper] = 0x001f9f,[CaseFold] = 0x001f97}, &special_case[49]},
-	{0x001fa0, {[CaseLower] = 0x001fa0,[CaseTitle] = 0x001fa8,[CaseUpper] = 0x001fa8,[CaseFold] = 0x001fa0}, &special_case[50]},
-	{0x001fa1, {[CaseLower] = 0x001fa1,[CaseTitle] = 0x001fa9,[CaseUpper] = 0x001fa9,[CaseFold] = 0x001fa1}, &special_case[51]},
-	{0x001fa2, {[CaseLower] = 0x001fa2,[CaseTitle] = 0x001faa,[CaseUpper] = 0x001faa,[CaseFold] = 0x001fa2}, &special_case[52]},
-	{0x001fa3, {[CaseLower] = 0x001fa3,[CaseTitle] = 0x001fab,[CaseUpper] = 0x001fab,[CaseFold] = 0x001fa3}, &special_case[53]},
-	{0x001fa4, {[CaseLower] = 0x001fa4,[CaseTitle] = 0x001fac,[CaseUpper] = 0x001fac,[CaseFold] = 0x001fa4}, &special_case[54]},
-	{0x001fa5, {[CaseLower] = 0x001fa5,[CaseTitle] = 0x001fad,[CaseUpper] = 0x001fad,[CaseFold] = 0x001fa5}, &special_case[55]},
-	{0x001fa6, {[CaseLower] = 0x001fa6,[CaseTitle] = 0x001fae,[CaseUpper] = 0x001fae,[CaseFold] = 0x001fa6}, &special_case[56]},
-	{0x001fa7, {[CaseLower] = 0x001fa7,[CaseTitle] = 0x001faf,[CaseUpper] = 0x001faf,[CaseFold] = 0x001fa7}, &special_case[57]},
-	{0x001fa8, {[CaseLower] = 0x001fa0,[CaseTitle] = 0x001fa8,[CaseUpper] = 0x001fa8,[CaseFold] = 0x001fa0}, &special_case[58]},
-	{0x001fa9, {[CaseLower] = 0x001fa1,[CaseTitle] = 0x001fa9,[CaseUpper] = 0x001fa9,[CaseFold] = 0x001fa1}, &special_case[59]},
-	{0x001faa, {[CaseLower] = 0x001fa2,[CaseTitle] = 0x001faa,[CaseUpper] = 0x001faa,[CaseFold] = 0x001fa2}, &special_case[60]},
-	{0x001fab, {[CaseLower] = 0x001fa3,[CaseTitle] = 0x001fab,[CaseUpper] = 0x001fab,[CaseFold] = 0x001fa3}, &special_case[61]},
-	{0x001fac, {[CaseLower] = 0x001fa4,[CaseTitle] = 0x001fac,[CaseUpper] = 0x001fac,[CaseFold] = 0x001fa4}, &special_case[62]},
-	{0x001fad, {[CaseLower] = 0x001fa5,[CaseTitle] = 0x001fad,[CaseUpper] = 0x001fad,[CaseFold] = 0x001fa5}, &special_case[63]},
-	{0x001fae, {[CaseLower] = 0x001fa6,[CaseTitle] = 0x001fae,[CaseUpper] = 0x001fae,[CaseFold] = 0x001fa6}, &special_case[64]},
-	{0x001faf, {[CaseLower] = 0x001fa7,[CaseTitle] = 0x001faf,[CaseUpper] = 0x001faf,[CaseFold] = 0x001fa7}, &special_case[65]},
-	{0x001fb0, {[CaseLower] = 0x001fb0,[CaseTitle] = 0x001fb8,[CaseUpper] = 0x001fb8,[CaseFold] = 0x001fb0}, NULL},
-	{0x001fb1, {[CaseLower] = 0x001fb1,[CaseTitle] = 0x001fb9,[CaseUpper] = 0x001fb9,[CaseFold] = 0x001fb1}, NULL},
-	{0x001fb2, {[CaseLower] = 0x001fb2,[CaseTitle] = 0x001fb2,[CaseUpper] = 0x001fb2,[CaseFold] = 0x001fb2}, &special_case[66]},
-	{0x001fb3, {[CaseLower] = 0x001fb3,[CaseTitle] = 0x001fbc,[CaseUpper] = 0x001fbc,[CaseFold] = 0x001fb3}, &special_case[67]},
-	{0x001fb4, {[CaseLower] = 0x001fb4,[CaseTitle] = 0x001fb4,[CaseUpper] = 0x001fb4,[CaseFold] = 0x001fb4}, &special_case[68]},
-	{0x001fb6, {[CaseLower] = 0x001fb6,[CaseTitle] = 0x001fb6,[CaseUpper] = 0x001fb6,[CaseFold] = 0x001fb6}, &special_case[69]},
-	{0x001fb7, {[CaseLower] = 0x001fb7,[CaseTitle] = 0x001fb7,[CaseUpper] = 0x001fb7,[CaseFold] = 0x001fb7}, &special_case[70]},
-	{0x001fb8, {[CaseLower] = 0x001fb0,[CaseTitle] = 0x001fb8,[CaseUpper] = 0x001fb8,[CaseFold] = 0x001fb0}, NULL},
-	{0x001fb9, {[CaseLower] = 0x001fb1,[CaseTitle] = 0x001fb9,[CaseUpper] = 0x001fb9,[CaseFold] = 0x001fb1}, NULL},
-	{0x001fba, {[CaseLower] = 0x001f70,[CaseTitle] = 0x001fba,[CaseUpper] = 0x001fba,[CaseFold] = 0x001f70}, NULL},
-	{0x001fbb, {[CaseLower] = 0x001f71,[CaseTitle] = 0x001fbb,[CaseUpper] = 0x001fbb,[CaseFold] = 0x001f71}, NULL},
-	{0x001fbc, {[CaseLower] = 0x001fb3,[CaseTitle] = 0x001fbc,[CaseUpper] = 0x001fbc,[CaseFold] = 0x001fb3}, &special_case[71]},
-	{0x001fbe, {[CaseLower] = 0x001fbe,[CaseTitle] = 0x000399,[CaseUpper] = 0x000399,[CaseFold] = 0x0003b9}, NULL},
-	{0x001fc2, {[CaseLower] = 0x001fc2,[CaseTitle] = 0x001fc2,[CaseUpper] = 0x001fc2,[CaseFold] = 0x001fc2}, &special_case[72]},
-	{0x001fc3, {[CaseLower] = 0x001fc3,[CaseTitle] = 0x001fcc,[CaseUpper] = 0x001fcc,[CaseFold] = 0x001fc3}, &special_case[73]},
-	{0x001fc4, {[CaseLower] = 0x001fc4,[CaseTitle] = 0x001fc4,[CaseUpper] = 0x001fc4,[CaseFold] = 0x001fc4}, &special_case[74]},
-	{0x001fc6, {[CaseLower] = 0x001fc6,[CaseTitle] = 0x001fc6,[CaseUpper] = 0x001fc6,[CaseFold] = 0x001fc6}, &special_case[75]},
-	{0x001fc7, {[CaseLower] = 0x001fc7,[CaseTitle] = 0x001fc7,[CaseUpper] = 0x001fc7,[CaseFold] = 0x001fc7}, &special_case[76]},
-	{0x001fc8, {[CaseLower] = 0x001f72,[CaseTitle] = 0x001fc8,[CaseUpper] = 0x001fc8,[CaseFold] = 0x001f72}, NULL},
-	{0x001fc9, {[CaseLower] = 0x001f73,[CaseTitle] = 0x001fc9,[CaseUpper] = 0x001fc9,[CaseFold] = 0x001f73}, NULL},
-	{0x001fca, {[CaseLower] = 0x001f74,[CaseTitle] = 0x001fca,[CaseUpper] = 0x001fca,[CaseFold] = 0x001f74}, NULL},
-	{0x001fcb, {[CaseLower] = 0x001f75,[CaseTitle] = 0x001fcb,[CaseUpper] = 0x001fcb,[CaseFold] = 0x001f75}, NULL},
-	{0x001fcc, {[CaseLower] = 0x001fc3,[CaseTitle] = 0x001fcc,[CaseUpper] = 0x001fcc,[CaseFold] = 0x001fc3}, &special_case[77]},
-	{0x001fd0, {[CaseLower] = 0x001fd0,[CaseTitle] = 0x001fd8,[CaseUpper] = 0x001fd8,[CaseFold] = 0x001fd0}, NULL},
-	{0x001fd1, {[CaseLower] = 0x001fd1,[CaseTitle] = 0x001fd9,[CaseUpper] = 0x001fd9,[CaseFold] = 0x001fd1}, NULL},
-	{0x001fd2, {[CaseLower] = 0x001fd2,[CaseTitle] = 0x001fd2,[CaseUpper] = 0x001fd2,[CaseFold] = 0x001fd2}, &special_case[78]},
-	{0x001fd3, {[CaseLower] = 0x001fd3,[CaseTitle] = 0x001fd3,[CaseUpper] = 0x001fd3,[CaseFold] = 0x000390}, &special_case[79]},
-	{0x001fd6, {[CaseLower] = 0x001fd6,[CaseTitle] = 0x001fd6,[CaseUpper] = 0x001fd6,[CaseFold] = 0x001fd6}, &special_case[80]},
-	{0x001fd7, {[CaseLower] = 0x001fd7,[CaseTitle] = 0x001fd7,[CaseUpper] = 0x001fd7,[CaseFold] = 0x001fd7}, &special_case[81]},
-	{0x001fd8, {[CaseLower] = 0x001fd0,[CaseTitle] = 0x001fd8,[CaseUpper] = 0x001fd8,[CaseFold] = 0x001fd0}, NULL},
-	{0x001fd9, {[CaseLower] = 0x001fd1,[CaseTitle] = 0x001fd9,[CaseUpper] = 0x001fd9,[CaseFold] = 0x001fd1}, NULL},
-	{0x001fda, {[CaseLower] = 0x001f76,[CaseTitle] = 0x001fda,[CaseUpper] = 0x001fda,[CaseFold] = 0x001f76}, NULL},
-	{0x001fdb, {[CaseLower] = 0x001f77,[CaseTitle] = 0x001fdb,[CaseUpper] = 0x001fdb,[CaseFold] = 0x001f77}, NULL},
-	{0x001fe0, {[CaseLower] = 0x001fe0,[CaseTitle] = 0x001fe8,[CaseUpper] = 0x001fe8,[CaseFold] = 0x001fe0}, NULL},
-	{0x001fe1, {[CaseLower] = 0x001fe1,[CaseTitle] = 0x001fe9,[CaseUpper] = 0x001fe9,[CaseFold] = 0x001fe1}, NULL},
-	{0x001fe2, {[CaseLower] = 0x001fe2,[CaseTitle] = 0x001fe2,[CaseUpper] = 0x001fe2,[CaseFold] = 0x001fe2}, &special_case[82]},
-	{0x001fe3, {[CaseLower] = 0x001fe3,[CaseTitle] = 0x001fe3,[CaseUpper] = 0x001fe3,[CaseFold] = 0x0003b0}, &special_case[83]},
-	{0x001fe4, {[CaseLower] = 0x001fe4,[CaseTitle] = 0x001fe4,[CaseUpper] = 0x001fe4,[CaseFold] = 0x001fe4}, &special_case[84]},
-	{0x001fe5, {[CaseLower] = 0x001fe5,[CaseTitle] = 0x001fec,[CaseUpper] = 0x001fec,[CaseFold] = 0x001fe5}, NULL},
-	{0x001fe6, {[CaseLower] = 0x001fe6,[CaseTitle] = 0x001fe6,[CaseUpper] = 0x001fe6,[CaseFold] = 0x001fe6}, &special_case[85]},
-	{0x001fe7, {[CaseLower] = 0x001fe7,[CaseTitle] = 0x001fe7,[CaseUpper] = 0x001fe7,[CaseFold] = 0x001fe7}, &special_case[86]},
-	{0x001fe8, {[CaseLower] = 0x001fe0,[CaseTitle] = 0x001fe8,[CaseUpper] = 0x001fe8,[CaseFold] = 0x001fe0}, NULL},
-	{0x001fe9, {[CaseLower] = 0x001fe1,[CaseTitle] = 0x001fe9,[CaseUpper] = 0x001fe9,[CaseFold] = 0x001fe1}, NULL},
-	{0x001fea, {[CaseLower] = 0x001f7a,[CaseTitle] = 0x001fea,[CaseUpper] = 0x001fea,[CaseFold] = 0x001f7a}, NULL},
-	{0x001feb, {[CaseLower] = 0x001f7b,[CaseTitle] = 0x001feb,[CaseUpper] = 0x001feb,[CaseFold] = 0x001f7b}, NULL},
-	{0x001fec, {[CaseLower] = 0x001fe5,[CaseTitle] = 0x001fec,[CaseUpper] = 0x001fec,[CaseFold] = 0x001fe5}, NULL},
-	{0x001ff2, {[CaseLower] = 0x001ff2,[CaseTitle] = 0x001ff2,[CaseUpper] = 0x001ff2,[CaseFold] = 0x001ff2}, &special_case[87]},
-	{0x001ff3, {[CaseLower] = 0x001ff3,[CaseTitle] = 0x001ffc,[CaseUpper] = 0x001ffc,[CaseFold] = 0x001ff3}, &special_case[88]},
-	{0x001ff4, {[CaseLower] = 0x001ff4,[CaseTitle] = 0x001ff4,[CaseUpper] = 0x001ff4,[CaseFold] = 0x001ff4}, &special_case[89]},
-	{0x001ff6, {[CaseLower] = 0x001ff6,[CaseTitle] = 0x001ff6,[CaseUpper] = 0x001ff6,[CaseFold] = 0x001ff6}, &special_case[90]},
-	{0x001ff7, {[CaseLower] = 0x001ff7,[CaseTitle] = 0x001ff7,[CaseUpper] = 0x001ff7,[CaseFold] = 0x001ff7}, &special_case[91]},
-	{0x001ff8, {[CaseLower] = 0x001f78,[CaseTitle] = 0x001ff8,[CaseUpper] = 0x001ff8,[CaseFold] = 0x001f78}, NULL},
-	{0x001ff9, {[CaseLower] = 0x001f79,[CaseTitle] = 0x001ff9,[CaseUpper] = 0x001ff9,[CaseFold] = 0x001f79}, NULL},
-	{0x001ffa, {[CaseLower] = 0x001f7c,[CaseTitle] = 0x001ffa,[CaseUpper] = 0x001ffa,[CaseFold] = 0x001f7c}, NULL},
-	{0x001ffb, {[CaseLower] = 0x001f7d,[CaseTitle] = 0x001ffb,[CaseUpper] = 0x001ffb,[CaseFold] = 0x001f7d}, NULL},
-	{0x001ffc, {[CaseLower] = 0x001ff3,[CaseTitle] = 0x001ffc,[CaseUpper] = 0x001ffc,[CaseFold] = 0x001ff3}, &special_case[92]},
-	{0x002126, {[CaseLower] = 0x0003c9,[CaseTitle] = 0x002126,[CaseUpper] = 0x002126,[CaseFold] = 0x0003c9}, NULL},
-	{0x00212a, {[CaseLower] = 0x00006b,[CaseTitle] = 0x00212a,[CaseUpper] = 0x00212a,[CaseFold] = 0x00006b}, NULL},
-	{0x00212b, {[CaseLower] = 0x0000e5,[CaseTitle] = 0x00212b,[CaseUpper] = 0x00212b,[CaseFold] = 0x0000e5}, NULL},
-	{0x002132, {[CaseLower] = 0x00214e,[CaseTitle] = 0x002132,[CaseUpper] = 0x002132,[CaseFold] = 0x00214e}, NULL},
-	{0x00214e, {[CaseLower] = 0x00214e,[CaseTitle] = 0x002132,[CaseUpper] = 0x002132,[CaseFold] = 0x00214e}, NULL},
-	{0x002160, {[CaseLower] = 0x002170,[CaseTitle] = 0x002160,[CaseUpper] = 0x002160,[CaseFold] = 0x002170}, NULL},
-	{0x002161, {[CaseLower] = 0x002171,[CaseTitle] = 0x002161,[CaseUpper] = 0x002161,[CaseFold] = 0x002171}, NULL},
-	{0x002162, {[CaseLower] = 0x002172,[CaseTitle] = 0x002162,[CaseUpper] = 0x002162,[CaseFold] = 0x002172}, NULL},
-	{0x002163, {[CaseLower] = 0x002173,[CaseTitle] = 0x002163,[CaseUpper] = 0x002163,[CaseFold] = 0x002173}, NULL},
-	{0x002164, {[CaseLower] = 0x002174,[CaseTitle] = 0x002164,[CaseUpper] = 0x002164,[CaseFold] = 0x002174}, NULL},
-	{0x002165, {[CaseLower] = 0x002175,[CaseTitle] = 0x002165,[CaseUpper] = 0x002165,[CaseFold] = 0x002175}, NULL},
-	{0x002166, {[CaseLower] = 0x002176,[CaseTitle] = 0x002166,[CaseUpper] = 0x002166,[CaseFold] = 0x002176}, NULL},
-	{0x002167, {[CaseLower] = 0x002177,[CaseTitle] = 0x002167,[CaseUpper] = 0x002167,[CaseFold] = 0x002177}, NULL},
-	{0x002168, {[CaseLower] = 0x002178,[CaseTitle] = 0x002168,[CaseUpper] = 0x002168,[CaseFold] = 0x002178}, NULL},
-	{0x002169, {[CaseLower] = 0x002179,[CaseTitle] = 0x002169,[CaseUpper] = 0x002169,[CaseFold] = 0x002179}, NULL},
-	{0x00216a, {[CaseLower] = 0x00217a,[CaseTitle] = 0x00216a,[CaseUpper] = 0x00216a,[CaseFold] = 0x00217a}, NULL},
-	{0x00216b, {[CaseLower] = 0x00217b,[CaseTitle] = 0x00216b,[CaseUpper] = 0x00216b,[CaseFold] = 0x00217b}, NULL},
-	{0x00216c, {[CaseLower] = 0x00217c,[CaseTitle] = 0x00216c,[CaseUpper] = 0x00216c,[CaseFold] = 0x00217c}, NULL},
-	{0x00216d, {[CaseLower] = 0x00217d,[CaseTitle] = 0x00216d,[CaseUpper] = 0x00216d,[CaseFold] = 0x00217d}, NULL},
-	{0x00216e, {[CaseLower] = 0x00217e,[CaseTitle] = 0x00216e,[CaseUpper] = 0x00216e,[CaseFold] = 0x00217e}, NULL},
-	{0x00216f, {[CaseLower] = 0x00217f,[CaseTitle] = 0x00216f,[CaseUpper] = 0x00216f,[CaseFold] = 0x00217f}, NULL},
-	{0x002170, {[CaseLower] = 0x002170,[CaseTitle] = 0x002160,[CaseUpper] = 0x002160,[CaseFold] = 0x002170}, NULL},
-	{0x002171, {[CaseLower] = 0x002171,[CaseTitle] = 0x002161,[CaseUpper] = 0x002161,[CaseFold] = 0x002171}, NULL},
-	{0x002172, {[CaseLower] = 0x002172,[CaseTitle] = 0x002162,[CaseUpper] = 0x002162,[CaseFold] = 0x002172}, NULL},
-	{0x002173, {[CaseLower] = 0x002173,[CaseTitle] = 0x002163,[CaseUpper] = 0x002163,[CaseFold] = 0x002173}, NULL},
-	{0x002174, {[CaseLower] = 0x002174,[CaseTitle] = 0x002164,[CaseUpper] = 0x002164,[CaseFold] = 0x002174}, NULL},
-	{0x002175, {[CaseLower] = 0x002175,[CaseTitle] = 0x002165,[CaseUpper] = 0x002165,[CaseFold] = 0x002175}, NULL},
-	{0x002176, {[CaseLower] = 0x002176,[CaseTitle] = 0x002166,[CaseUpper] = 0x002166,[CaseFold] = 0x002176}, NULL},
-	{0x002177, {[CaseLower] = 0x002177,[CaseTitle] = 0x002167,[CaseUpper] = 0x002167,[CaseFold] = 0x002177}, NULL},
-	{0x002178, {[CaseLower] = 0x002178,[CaseTitle] = 0x002168,[CaseUpper] = 0x002168,[CaseFold] = 0x002178}, NULL},
-	{0x002179, {[CaseLower] = 0x002179,[CaseTitle] = 0x002169,[CaseUpper] = 0x002169,[CaseFold] = 0x002179}, NULL},
-	{0x00217a, {[CaseLower] = 0x00217a,[CaseTitle] = 0x00216a,[CaseUpper] = 0x00216a,[CaseFold] = 0x00217a}, NULL},
-	{0x00217b, {[CaseLower] = 0x00217b,[CaseTitle] = 0x00216b,[CaseUpper] = 0x00216b,[CaseFold] = 0x00217b}, NULL},
-	{0x00217c, {[CaseLower] = 0x00217c,[CaseTitle] = 0x00216c,[CaseUpper] = 0x00216c,[CaseFold] = 0x00217c}, NULL},
-	{0x00217d, {[CaseLower] = 0x00217d,[CaseTitle] = 0x00216d,[CaseUpper] = 0x00216d,[CaseFold] = 0x00217d}, NULL},
-	{0x00217e, {[CaseLower] = 0x00217e,[CaseTitle] = 0x00216e,[CaseUpper] = 0x00216e,[CaseFold] = 0x00217e}, NULL},
-	{0x00217f, {[CaseLower] = 0x00217f,[CaseTitle] = 0x00216f,[CaseUpper] = 0x00216f,[CaseFold] = 0x00217f}, NULL},
-	{0x002183, {[CaseLower] = 0x002184,[CaseTitle] = 0x002183,[CaseUpper] = 0x002183,[CaseFold] = 0x002184}, NULL},
-	{0x002184, {[CaseLower] = 0x002184,[CaseTitle] = 0x002183,[CaseUpper] = 0x002183,[CaseFold] = 0x002184}, NULL},
-	{0x0024b6, {[CaseLower] = 0x0024d0,[CaseTitle] = 0x0024b6,[CaseUpper] = 0x0024b6,[CaseFold] = 0x0024d0}, NULL},
-	{0x0024b7, {[CaseLower] = 0x0024d1,[CaseTitle] = 0x0024b7,[CaseUpper] = 0x0024b7,[CaseFold] = 0x0024d1}, NULL},
-	{0x0024b8, {[CaseLower] = 0x0024d2,[CaseTitle] = 0x0024b8,[CaseUpper] = 0x0024b8,[CaseFold] = 0x0024d2}, NULL},
-	{0x0024b9, {[CaseLower] = 0x0024d3,[CaseTitle] = 0x0024b9,[CaseUpper] = 0x0024b9,[CaseFold] = 0x0024d3}, NULL},
-	{0x0024ba, {[CaseLower] = 0x0024d4,[CaseTitle] = 0x0024ba,[CaseUpper] = 0x0024ba,[CaseFold] = 0x0024d4}, NULL},
-	{0x0024bb, {[CaseLower] = 0x0024d5,[CaseTitle] = 0x0024bb,[CaseUpper] = 0x0024bb,[CaseFold] = 0x0024d5}, NULL},
-	{0x0024bc, {[CaseLower] = 0x0024d6,[CaseTitle] = 0x0024bc,[CaseUpper] = 0x0024bc,[CaseFold] = 0x0024d6}, NULL},
-	{0x0024bd, {[CaseLower] = 0x0024d7,[CaseTitle] = 0x0024bd,[CaseUpper] = 0x0024bd,[CaseFold] = 0x0024d7}, NULL},
-	{0x0024be, {[CaseLower] = 0x0024d8,[CaseTitle] = 0x0024be,[CaseUpper] = 0x0024be,[CaseFold] = 0x0024d8}, NULL},
-	{0x0024bf, {[CaseLower] = 0x0024d9,[CaseTitle] = 0x0024bf,[CaseUpper] = 0x0024bf,[CaseFold] = 0x0024d9}, NULL},
-	{0x0024c0, {[CaseLower] = 0x0024da,[CaseTitle] = 0x0024c0,[CaseUpper] = 0x0024c0,[CaseFold] = 0x0024da}, NULL},
-	{0x0024c1, {[CaseLower] = 0x0024db,[CaseTitle] = 0x0024c1,[CaseUpper] = 0x0024c1,[CaseFold] = 0x0024db}, NULL},
-	{0x0024c2, {[CaseLower] = 0x0024dc,[CaseTitle] = 0x0024c2,[CaseUpper] = 0x0024c2,[CaseFold] = 0x0024dc}, NULL},
-	{0x0024c3, {[CaseLower] = 0x0024dd,[CaseTitle] = 0x0024c3,[CaseUpper] = 0x0024c3,[CaseFold] = 0x0024dd}, NULL},
-	{0x0024c4, {[CaseLower] = 0x0024de,[CaseTitle] = 0x0024c4,[CaseUpper] = 0x0024c4,[CaseFold] = 0x0024de}, NULL},
-	{0x0024c5, {[CaseLower] = 0x0024df,[CaseTitle] = 0x0024c5,[CaseUpper] = 0x0024c5,[CaseFold] = 0x0024df}, NULL},
-	{0x0024c6, {[CaseLower] = 0x0024e0,[CaseTitle] = 0x0024c6,[CaseUpper] = 0x0024c6,[CaseFold] = 0x0024e0}, NULL},
-	{0x0024c7, {[CaseLower] = 0x0024e1,[CaseTitle] = 0x0024c7,[CaseUpper] = 0x0024c7,[CaseFold] = 0x0024e1}, NULL},
-	{0x0024c8, {[CaseLower] = 0x0024e2,[CaseTitle] = 0x0024c8,[CaseUpper] = 0x0024c8,[CaseFold] = 0x0024e2}, NULL},
-	{0x0024c9, {[CaseLower] = 0x0024e3,[CaseTitle] = 0x0024c9,[CaseUpper] = 0x0024c9,[CaseFold] = 0x0024e3}, NULL},
-	{0x0024ca, {[CaseLower] = 0x0024e4,[CaseTitle] = 0x0024ca,[CaseUpper] = 0x0024ca,[CaseFold] = 0x0024e4}, NULL},
-	{0x0024cb, {[CaseLower] = 0x0024e5,[CaseTitle] = 0x0024cb,[CaseUpper] = 0x0024cb,[CaseFold] = 0x0024e5}, NULL},
-	{0x0024cc, {[CaseLower] = 0x0024e6,[CaseTitle] = 0x0024cc,[CaseUpper] = 0x0024cc,[CaseFold] = 0x0024e6}, NULL},
-	{0x0024cd, {[CaseLower] = 0x0024e7,[CaseTitle] = 0x0024cd,[CaseUpper] = 0x0024cd,[CaseFold] = 0x0024e7}, NULL},
-	{0x0024ce, {[CaseLower] = 0x0024e8,[CaseTitle] = 0x0024ce,[CaseUpper] = 0x0024ce,[CaseFold] = 0x0024e8}, NULL},
-	{0x0024cf, {[CaseLower] = 0x0024e9,[CaseTitle] = 0x0024cf,[CaseUpper] = 0x0024cf,[CaseFold] = 0x0024e9}, NULL},
-	{0x0024d0, {[CaseLower] = 0x0024d0,[CaseTitle] = 0x0024b6,[CaseUpper] = 0x0024b6,[CaseFold] = 0x0024d0}, NULL},
-	{0x0024d1, {[CaseLower] = 0x0024d1,[CaseTitle] = 0x0024b7,[CaseUpper] = 0x0024b7,[CaseFold] = 0x0024d1}, NULL},
-	{0x0024d2, {[CaseLower] = 0x0024d2,[CaseTitle] = 0x0024b8,[CaseUpper] = 0x0024b8,[CaseFold] = 0x0024d2}, NULL},
-	{0x0024d3, {[CaseLower] = 0x0024d3,[CaseTitle] = 0x0024b9,[CaseUpper] = 0x0024b9,[CaseFold] = 0x0024d3}, NULL},
-	{0x0024d4, {[CaseLower] = 0x0024d4,[CaseTitle] = 0x0024ba,[CaseUpper] = 0x0024ba,[CaseFold] = 0x0024d4}, NULL},
-	{0x0024d5, {[CaseLower] = 0x0024d5,[CaseTitle] = 0x0024bb,[CaseUpper] = 0x0024bb,[CaseFold] = 0x0024d5}, NULL},
-	{0x0024d6, {[CaseLower] = 0x0024d6,[CaseTitle] = 0x0024bc,[CaseUpper] = 0x0024bc,[CaseFold] = 0x0024d6}, NULL},
-	{0x0024d7, {[CaseLower] = 0x0024d7,[CaseTitle] = 0x0024bd,[CaseUpper] = 0x0024bd,[CaseFold] = 0x0024d7}, NULL},
-	{0x0024d8, {[CaseLower] = 0x0024d8,[CaseTitle] = 0x0024be,[CaseUpper] = 0x0024be,[CaseFold] = 0x0024d8}, NULL},
-	{0x0024d9, {[CaseLower] = 0x0024d9,[CaseTitle] = 0x0024bf,[CaseUpper] = 0x0024bf,[CaseFold] = 0x0024d9}, NULL},
-	{0x0024da, {[CaseLower] = 0x0024da,[CaseTitle] = 0x0024c0,[CaseUpper] = 0x0024c0,[CaseFold] = 0x0024da}, NULL},
-	{0x0024db, {[CaseLower] = 0x0024db,[CaseTitle] = 0x0024c1,[CaseUpper] = 0x0024c1,[CaseFold] = 0x0024db}, NULL},
-	{0x0024dc, {[CaseLower] = 0x0024dc,[CaseTitle] = 0x0024c2,[CaseUpper] = 0x0024c2,[CaseFold] = 0x0024dc}, NULL},
-	{0x0024dd, {[CaseLower] = 0x0024dd,[CaseTitle] = 0x0024c3,[CaseUpper] = 0x0024c3,[CaseFold] = 0x0024dd}, NULL},
-	{0x0024de, {[CaseLower] = 0x0024de,[CaseTitle] = 0x0024c4,[CaseUpper] = 0x0024c4,[CaseFold] = 0x0024de}, NULL},
-	{0x0024df, {[CaseLower] = 0x0024df,[CaseTitle] = 0x0024c5,[CaseUpper] = 0x0024c5,[CaseFold] = 0x0024df}, NULL},
-	{0x0024e0, {[CaseLower] = 0x0024e0,[CaseTitle] = 0x0024c6,[CaseUpper] = 0x0024c6,[CaseFold] = 0x0024e0}, NULL},
-	{0x0024e1, {[CaseLower] = 0x0024e1,[CaseTitle] = 0x0024c7,[CaseUpper] = 0x0024c7,[CaseFold] = 0x0024e1}, NULL},
-	{0x0024e2, {[CaseLower] = 0x0024e2,[CaseTitle] = 0x0024c8,[CaseUpper] = 0x0024c8,[CaseFold] = 0x0024e2}, NULL},
-	{0x0024e3, {[CaseLower] = 0x0024e3,[CaseTitle] = 0x0024c9,[CaseUpper] = 0x0024c9,[CaseFold] = 0x0024e3}, NULL},
-	{0x0024e4, {[CaseLower] = 0x0024e4,[CaseTitle] = 0x0024ca,[CaseUpper] = 0x0024ca,[CaseFold] = 0x0024e4}, NULL},
-	{0x0024e5, {[CaseLower] = 0x0024e5,[CaseTitle] = 0x0024cb,[CaseUpper] = 0x0024cb,[CaseFold] = 0x0024e5}, NULL},
-	{0x0024e6, {[CaseLower] = 0x0024e6,[CaseTitle] = 0x0024cc,[CaseUpper] = 0x0024cc,[CaseFold] = 0x0024e6}, NULL},
-	{0x0024e7, {[CaseLower] = 0x0024e7,[CaseTitle] = 0x0024cd,[CaseUpper] = 0x0024cd,[CaseFold] = 0x0024e7}, NULL},
-	{0x0024e8, {[CaseLower] = 0x0024e8,[CaseTitle] = 0x0024ce,[CaseUpper] = 0x0024ce,[CaseFold] = 0x0024e8}, NULL},
-	{0x0024e9, {[CaseLower] = 0x0024e9,[CaseTitle] = 0x0024cf,[CaseUpper] = 0x0024cf,[CaseFold] = 0x0024e9}, NULL},
-	{0x002c00, {[CaseLower] = 0x002c30,[CaseTitle] = 0x002c00,[CaseUpper] = 0x002c00,[CaseFold] = 0x002c30}, NULL},
-	{0x002c01, {[CaseLower] = 0x002c31,[CaseTitle] = 0x002c01,[CaseUpper] = 0x002c01,[CaseFold] = 0x002c31}, NULL},
-	{0x002c02, {[CaseLower] = 0x002c32,[CaseTitle] = 0x002c02,[CaseUpper] = 0x002c02,[CaseFold] = 0x002c32}, NULL},
-	{0x002c03, {[CaseLower] = 0x002c33,[CaseTitle] = 0x002c03,[CaseUpper] = 0x002c03,[CaseFold] = 0x002c33}, NULL},
-	{0x002c04, {[CaseLower] = 0x002c34,[CaseTitle] = 0x002c04,[CaseUpper] = 0x002c04,[CaseFold] = 0x002c34}, NULL},
-	{0x002c05, {[CaseLower] = 0x002c35,[CaseTitle] = 0x002c05,[CaseUpper] = 0x002c05,[CaseFold] = 0x002c35}, NULL},
-	{0x002c06, {[CaseLower] = 0x002c36,[CaseTitle] = 0x002c06,[CaseUpper] = 0x002c06,[CaseFold] = 0x002c36}, NULL},
-	{0x002c07, {[CaseLower] = 0x002c37,[CaseTitle] = 0x002c07,[CaseUpper] = 0x002c07,[CaseFold] = 0x002c37}, NULL},
-	{0x002c08, {[CaseLower] = 0x002c38,[CaseTitle] = 0x002c08,[CaseUpper] = 0x002c08,[CaseFold] = 0x002c38}, NULL},
-	{0x002c09, {[CaseLower] = 0x002c39,[CaseTitle] = 0x002c09,[CaseUpper] = 0x002c09,[CaseFold] = 0x002c39}, NULL},
-	{0x002c0a, {[CaseLower] = 0x002c3a,[CaseTitle] = 0x002c0a,[CaseUpper] = 0x002c0a,[CaseFold] = 0x002c3a}, NULL},
-	{0x002c0b, {[CaseLower] = 0x002c3b,[CaseTitle] = 0x002c0b,[CaseUpper] = 0x002c0b,[CaseFold] = 0x002c3b}, NULL},
-	{0x002c0c, {[CaseLower] = 0x002c3c,[CaseTitle] = 0x002c0c,[CaseUpper] = 0x002c0c,[CaseFold] = 0x002c3c}, NULL},
-	{0x002c0d, {[CaseLower] = 0x002c3d,[CaseTitle] = 0x002c0d,[CaseUpper] = 0x002c0d,[CaseFold] = 0x002c3d}, NULL},
-	{0x002c0e, {[CaseLower] = 0x002c3e,[CaseTitle] = 0x002c0e,[CaseUpper] = 0x002c0e,[CaseFold] = 0x002c3e}, NULL},
-	{0x002c0f, {[CaseLower] = 0x002c3f,[CaseTitle] = 0x002c0f,[CaseUpper] = 0x002c0f,[CaseFold] = 0x002c3f}, NULL},
-	{0x002c10, {[CaseLower] = 0x002c40,[CaseTitle] = 0x002c10,[CaseUpper] = 0x002c10,[CaseFold] = 0x002c40}, NULL},
-	{0x002c11, {[CaseLower] = 0x002c41,[CaseTitle] = 0x002c11,[CaseUpper] = 0x002c11,[CaseFold] = 0x002c41}, NULL},
-	{0x002c12, {[CaseLower] = 0x002c42,[CaseTitle] = 0x002c12,[CaseUpper] = 0x002c12,[CaseFold] = 0x002c42}, NULL},
-	{0x002c13, {[CaseLower] = 0x002c43,[CaseTitle] = 0x002c13,[CaseUpper] = 0x002c13,[CaseFold] = 0x002c43}, NULL},
-	{0x002c14, {[CaseLower] = 0x002c44,[CaseTitle] = 0x002c14,[CaseUpper] = 0x002c14,[CaseFold] = 0x002c44}, NULL},
-	{0x002c15, {[CaseLower] = 0x002c45,[CaseTitle] = 0x002c15,[CaseUpper] = 0x002c15,[CaseFold] = 0x002c45}, NULL},
-	{0x002c16, {[CaseLower] = 0x002c46,[CaseTitle] = 0x002c16,[CaseUpper] = 0x002c16,[CaseFold] = 0x002c46}, NULL},
-	{0x002c17, {[CaseLower] = 0x002c47,[CaseTitle] = 0x002c17,[CaseUpper] = 0x002c17,[CaseFold] = 0x002c47}, NULL},
-	{0x002c18, {[CaseLower] = 0x002c48,[CaseTitle] = 0x002c18,[CaseUpper] = 0x002c18,[CaseFold] = 0x002c48}, NULL},
-	{0x002c19, {[CaseLower] = 0x002c49,[CaseTitle] = 0x002c19,[CaseUpper] = 0x002c19,[CaseFold] = 0x002c49}, NULL},
-	{0x002c1a, {[CaseLower] = 0x002c4a,[CaseTitle] = 0x002c1a,[CaseUpper] = 0x002c1a,[CaseFold] = 0x002c4a}, NULL},
-	{0x002c1b, {[CaseLower] = 0x002c4b,[CaseTitle] = 0x002c1b,[CaseUpper] = 0x002c1b,[CaseFold] = 0x002c4b}, NULL},
-	{0x002c1c, {[CaseLower] = 0x002c4c,[CaseTitle] = 0x002c1c,[CaseUpper] = 0x002c1c,[CaseFold] = 0x002c4c}, NULL},
-	{0x002c1d, {[CaseLower] = 0x002c4d,[CaseTitle] = 0x002c1d,[CaseUpper] = 0x002c1d,[CaseFold] = 0x002c4d}, NULL},
-	{0x002c1e, {[CaseLower] = 0x002c4e,[CaseTitle] = 0x002c1e,[CaseUpper] = 0x002c1e,[CaseFold] = 0x002c4e}, NULL},
-	{0x002c1f, {[CaseLower] = 0x002c4f,[CaseTitle] = 0x002c1f,[CaseUpper] = 0x002c1f,[CaseFold] = 0x002c4f}, NULL},
-	{0x002c20, {[CaseLower] = 0x002c50,[CaseTitle] = 0x002c20,[CaseUpper] = 0x002c20,[CaseFold] = 0x002c50}, NULL},
-	{0x002c21, {[CaseLower] = 0x002c51,[CaseTitle] = 0x002c21,[CaseUpper] = 0x002c21,[CaseFold] = 0x002c51}, NULL},
-	{0x002c22, {[CaseLower] = 0x002c52,[CaseTitle] = 0x002c22,[CaseUpper] = 0x002c22,[CaseFold] = 0x002c52}, NULL},
-	{0x002c23, {[CaseLower] = 0x002c53,[CaseTitle] = 0x002c23,[CaseUpper] = 0x002c23,[CaseFold] = 0x002c53}, NULL},
-	{0x002c24, {[CaseLower] = 0x002c54,[CaseTitle] = 0x002c24,[CaseUpper] = 0x002c24,[CaseFold] = 0x002c54}, NULL},
-	{0x002c25, {[CaseLower] = 0x002c55,[CaseTitle] = 0x002c25,[CaseUpper] = 0x002c25,[CaseFold] = 0x002c55}, NULL},
-	{0x002c26, {[CaseLower] = 0x002c56,[CaseTitle] = 0x002c26,[CaseUpper] = 0x002c26,[CaseFold] = 0x002c56}, NULL},
-	{0x002c27, {[CaseLower] = 0x002c57,[CaseTitle] = 0x002c27,[CaseUpper] = 0x002c27,[CaseFold] = 0x002c57}, NULL},
-	{0x002c28, {[CaseLower] = 0x002c58,[CaseTitle] = 0x002c28,[CaseUpper] = 0x002c28,[CaseFold] = 0x002c58}, NULL},
-	{0x002c29, {[CaseLower] = 0x002c59,[CaseTitle] = 0x002c29,[CaseUpper] = 0x002c29,[CaseFold] = 0x002c59}, NULL},
-	{0x002c2a, {[CaseLower] = 0x002c5a,[CaseTitle] = 0x002c2a,[CaseUpper] = 0x002c2a,[CaseFold] = 0x002c5a}, NULL},
-	{0x002c2b, {[CaseLower] = 0x002c5b,[CaseTitle] = 0x002c2b,[CaseUpper] = 0x002c2b,[CaseFold] = 0x002c5b}, NULL},
-	{0x002c2c, {[CaseLower] = 0x002c5c,[CaseTitle] = 0x002c2c,[CaseUpper] = 0x002c2c,[CaseFold] = 0x002c5c}, NULL},
-	{0x002c2d, {[CaseLower] = 0x002c5d,[CaseTitle] = 0x002c2d,[CaseUpper] = 0x002c2d,[CaseFold] = 0x002c5d}, NULL},
-	{0x002c2e, {[CaseLower] = 0x002c5e,[CaseTitle] = 0x002c2e,[CaseUpper] = 0x002c2e,[CaseFold] = 0x002c5e}, NULL},
-	{0x002c2f, {[CaseLower] = 0x002c5f,[CaseTitle] = 0x002c2f,[CaseUpper] = 0x002c2f,[CaseFold] = 0x002c5f}, NULL},
-	{0x002c30, {[CaseLower] = 0x002c30,[CaseTitle] = 0x002c00,[CaseUpper] = 0x002c00,[CaseFold] = 0x002c30}, NULL},
-	{0x002c31, {[CaseLower] = 0x002c31,[CaseTitle] = 0x002c01,[CaseUpper] = 0x002c01,[CaseFold] = 0x002c31}, NULL},
-	{0x002c32, {[CaseLower] = 0x002c32,[CaseTitle] = 0x002c02,[CaseUpper] = 0x002c02,[CaseFold] = 0x002c32}, NULL},
-	{0x002c33, {[CaseLower] = 0x002c33,[CaseTitle] = 0x002c03,[CaseUpper] = 0x002c03,[CaseFold] = 0x002c33}, NULL},
-	{0x002c34, {[CaseLower] = 0x002c34,[CaseTitle] = 0x002c04,[CaseUpper] = 0x002c04,[CaseFold] = 0x002c34}, NULL},
-	{0x002c35, {[CaseLower] = 0x002c35,[CaseTitle] = 0x002c05,[CaseUpper] = 0x002c05,[CaseFold] = 0x002c35}, NULL},
-	{0x002c36, {[CaseLower] = 0x002c36,[CaseTitle] = 0x002c06,[CaseUpper] = 0x002c06,[CaseFold] = 0x002c36}, NULL},
-	{0x002c37, {[CaseLower] = 0x002c37,[CaseTitle] = 0x002c07,[CaseUpper] = 0x002c07,[CaseFold] = 0x002c37}, NULL},
-	{0x002c38, {[CaseLower] = 0x002c38,[CaseTitle] = 0x002c08,[CaseUpper] = 0x002c08,[CaseFold] = 0x002c38}, NULL},
-	{0x002c39, {[CaseLower] = 0x002c39,[CaseTitle] = 0x002c09,[CaseUpper] = 0x002c09,[CaseFold] = 0x002c39}, NULL},
-	{0x002c3a, {[CaseLower] = 0x002c3a,[CaseTitle] = 0x002c0a,[CaseUpper] = 0x002c0a,[CaseFold] = 0x002c3a}, NULL},
-	{0x002c3b, {[CaseLower] = 0x002c3b,[CaseTitle] = 0x002c0b,[CaseUpper] = 0x002c0b,[CaseFold] = 0x002c3b}, NULL},
-	{0x002c3c, {[CaseLower] = 0x002c3c,[CaseTitle] = 0x002c0c,[CaseUpper] = 0x002c0c,[CaseFold] = 0x002c3c}, NULL},
-	{0x002c3d, {[CaseLower] = 0x002c3d,[CaseTitle] = 0x002c0d,[CaseUpper] = 0x002c0d,[CaseFold] = 0x002c3d}, NULL},
-	{0x002c3e, {[CaseLower] = 0x002c3e,[CaseTitle] = 0x002c0e,[CaseUpper] = 0x002c0e,[CaseFold] = 0x002c3e}, NULL},
-	{0x002c3f, {[CaseLower] = 0x002c3f,[CaseTitle] = 0x002c0f,[CaseUpper] = 0x002c0f,[CaseFold] = 0x002c3f}, NULL},
-	{0x002c40, {[CaseLower] = 0x002c40,[CaseTitle] = 0x002c10,[CaseUpper] = 0x002c10,[CaseFold] = 0x002c40}, NULL},
-	{0x002c41, {[CaseLower] = 0x002c41,[CaseTitle] = 0x002c11,[CaseUpper] = 0x002c11,[CaseFold] = 0x002c41}, NULL},
-	{0x002c42, {[CaseLower] = 0x002c42,[CaseTitle] = 0x002c12,[CaseUpper] = 0x002c12,[CaseFold] = 0x002c42}, NULL},
-	{0x002c43, {[CaseLower] = 0x002c43,[CaseTitle] = 0x002c13,[CaseUpper] = 0x002c13,[CaseFold] = 0x002c43}, NULL},
-	{0x002c44, {[CaseLower] = 0x002c44,[CaseTitle] = 0x002c14,[CaseUpper] = 0x002c14,[CaseFold] = 0x002c44}, NULL},
-	{0x002c45, {[CaseLower] = 0x002c45,[CaseTitle] = 0x002c15,[CaseUpper] = 0x002c15,[CaseFold] = 0x002c45}, NULL},
-	{0x002c46, {[CaseLower] = 0x002c46,[CaseTitle] = 0x002c16,[CaseUpper] = 0x002c16,[CaseFold] = 0x002c46}, NULL},
-	{0x002c47, {[CaseLower] = 0x002c47,[CaseTitle] = 0x002c17,[CaseUpper] = 0x002c17,[CaseFold] = 0x002c47}, NULL},
-	{0x002c48, {[CaseLower] = 0x002c48,[CaseTitle] = 0x002c18,[CaseUpper] = 0x002c18,[CaseFold] = 0x002c48}, NULL},
-	{0x002c49, {[CaseLower] = 0x002c49,[CaseTitle] = 0x002c19,[CaseUpper] = 0x002c19,[CaseFold] = 0x002c49}, NULL},
-	{0x002c4a, {[CaseLower] = 0x002c4a,[CaseTitle] = 0x002c1a,[CaseUpper] = 0x002c1a,[CaseFold] = 0x002c4a}, NULL},
-	{0x002c4b, {[CaseLower] = 0x002c4b,[CaseTitle] = 0x002c1b,[CaseUpper] = 0x002c1b,[CaseFold] = 0x002c4b}, NULL},
-	{0x002c4c, {[CaseLower] = 0x002c4c,[CaseTitle] = 0x002c1c,[CaseUpper] = 0x002c1c,[CaseFold] = 0x002c4c}, NULL},
-	{0x002c4d, {[CaseLower] = 0x002c4d,[CaseTitle] = 0x002c1d,[CaseUpper] = 0x002c1d,[CaseFold] = 0x002c4d}, NULL},
-	{0x002c4e, {[CaseLower] = 0x002c4e,[CaseTitle] = 0x002c1e,[CaseUpper] = 0x002c1e,[CaseFold] = 0x002c4e}, NULL},
-	{0x002c4f, {[CaseLower] = 0x002c4f,[CaseTitle] = 0x002c1f,[CaseUpper] = 0x002c1f,[CaseFold] = 0x002c4f}, NULL},
-	{0x002c50, {[CaseLower] = 0x002c50,[CaseTitle] = 0x002c20,[CaseUpper] = 0x002c20,[CaseFold] = 0x002c50}, NULL},
-	{0x002c51, {[CaseLower] = 0x002c51,[CaseTitle] = 0x002c21,[CaseUpper] = 0x002c21,[CaseFold] = 0x002c51}, NULL},
-	{0x002c52, {[CaseLower] = 0x002c52,[CaseTitle] = 0x002c22,[CaseUpper] = 0x002c22,[CaseFold] = 0x002c52}, NULL},
-	{0x002c53, {[CaseLower] = 0x002c53,[CaseTitle] = 0x002c23,[CaseUpper] = 0x002c23,[CaseFold] = 0x002c53}, NULL},
-	{0x002c54, {[CaseLower] = 0x002c54,[CaseTitle] = 0x002c24,[CaseUpper] = 0x002c24,[CaseFold] = 0x002c54}, NULL},
-	{0x002c55, {[CaseLower] = 0x002c55,[CaseTitle] = 0x002c25,[CaseUpper] = 0x002c25,[CaseFold] = 0x002c55}, NULL},
-	{0x002c56, {[CaseLower] = 0x002c56,[CaseTitle] = 0x002c26,[CaseUpper] = 0x002c26,[CaseFold] = 0x002c56}, NULL},
-	{0x002c57, {[CaseLower] = 0x002c57,[CaseTitle] = 0x002c27,[CaseUpper] = 0x002c27,[CaseFold] = 0x002c57}, NULL},
-	{0x002c58, {[CaseLower] = 0x002c58,[CaseTitle] = 0x002c28,[CaseUpper] = 0x002c28,[CaseFold] = 0x002c58}, NULL},
-	{0x002c59, {[CaseLower] = 0x002c59,[CaseTitle] = 0x002c29,[CaseUpper] = 0x002c29,[CaseFold] = 0x002c59}, NULL},
-	{0x002c5a, {[CaseLower] = 0x002c5a,[CaseTitle] = 0x002c2a,[CaseUpper] = 0x002c2a,[CaseFold] = 0x002c5a}, NULL},
-	{0x002c5b, {[CaseLower] = 0x002c5b,[CaseTitle] = 0x002c2b,[CaseUpper] = 0x002c2b,[CaseFold] = 0x002c5b}, NULL},
-	{0x002c5c, {[CaseLower] = 0x002c5c,[CaseTitle] = 0x002c2c,[CaseUpper] = 0x002c2c,[CaseFold] = 0x002c5c}, NULL},
-	{0x002c5d, {[CaseLower] = 0x002c5d,[CaseTitle] = 0x002c2d,[CaseUpper] = 0x002c2d,[CaseFold] = 0x002c5d}, NULL},
-	{0x002c5e, {[CaseLower] = 0x002c5e,[CaseTitle] = 0x002c2e,[CaseUpper] = 0x002c2e,[CaseFold] = 0x002c5e}, NULL},
-	{0x002c5f, {[CaseLower] = 0x002c5f,[CaseTitle] = 0x002c2f,[CaseUpper] = 0x002c2f,[CaseFold] = 0x002c5f}, NULL},
-	{0x002c60, {[CaseLower] = 0x002c61,[CaseTitle] = 0x002c60,[CaseUpper] = 0x002c60,[CaseFold] = 0x002c61}, NULL},
-	{0x002c61, {[CaseLower] = 0x002c61,[CaseTitle] = 0x002c60,[CaseUpper] = 0x002c60,[CaseFold] = 0x002c61}, NULL},
-	{0x002c62, {[CaseLower] = 0x00026b,[CaseTitle] = 0x002c62,[CaseUpper] = 0x002c62,[CaseFold] = 0x00026b}, NULL},
-	{0x002c63, {[CaseLower] = 0x001d7d,[CaseTitle] = 0x002c63,[CaseUpper] = 0x002c63,[CaseFold] = 0x001d7d}, NULL},
-	{0x002c64, {[CaseLower] = 0x00027d,[CaseTitle] = 0x002c64,[CaseUpper] = 0x002c64,[CaseFold] = 0x00027d}, NULL},
-	{0x002c65, {[CaseLower] = 0x002c65,[CaseTitle] = 0x00023a,[CaseUpper] = 0x00023a,[CaseFold] = 0x002c65}, NULL},
-	{0x002c66, {[CaseLower] = 0x002c66,[CaseTitle] = 0x00023e,[CaseUpper] = 0x00023e,[CaseFold] = 0x002c66}, NULL},
-	{0x002c67, {[CaseLower] = 0x002c68,[CaseTitle] = 0x002c67,[CaseUpper] = 0x002c67,[CaseFold] = 0x002c68}, NULL},
-	{0x002c68, {[CaseLower] = 0x002c68,[CaseTitle] = 0x002c67,[CaseUpper] = 0x002c67,[CaseFold] = 0x002c68}, NULL},
-	{0x002c69, {[CaseLower] = 0x002c6a,[CaseTitle] = 0x002c69,[CaseUpper] = 0x002c69,[CaseFold] = 0x002c6a}, NULL},
-	{0x002c6a, {[CaseLower] = 0x002c6a,[CaseTitle] = 0x002c69,[CaseUpper] = 0x002c69,[CaseFold] = 0x002c6a}, NULL},
-	{0x002c6b, {[CaseLower] = 0x002c6c,[CaseTitle] = 0x002c6b,[CaseUpper] = 0x002c6b,[CaseFold] = 0x002c6c}, NULL},
-	{0x002c6c, {[CaseLower] = 0x002c6c,[CaseTitle] = 0x002c6b,[CaseUpper] = 0x002c6b,[CaseFold] = 0x002c6c}, NULL},
-	{0x002c6d, {[CaseLower] = 0x000251,[CaseTitle] = 0x002c6d,[CaseUpper] = 0x002c6d,[CaseFold] = 0x000251}, NULL},
-	{0x002c6e, {[CaseLower] = 0x000271,[CaseTitle] = 0x002c6e,[CaseUpper] = 0x002c6e,[CaseFold] = 0x000271}, NULL},
-	{0x002c6f, {[CaseLower] = 0x000250,[CaseTitle] = 0x002c6f,[CaseUpper] = 0x002c6f,[CaseFold] = 0x000250}, NULL},
-	{0x002c70, {[CaseLower] = 0x000252,[CaseTitle] = 0x002c70,[CaseUpper] = 0x002c70,[CaseFold] = 0x000252}, NULL},
-	{0x002c72, {[CaseLower] = 0x002c73,[CaseTitle] = 0x002c72,[CaseUpper] = 0x002c72,[CaseFold] = 0x002c73}, NULL},
-	{0x002c73, {[CaseLower] = 0x002c73,[CaseTitle] = 0x002c72,[CaseUpper] = 0x002c72,[CaseFold] = 0x002c73}, NULL},
-	{0x002c75, {[CaseLower] = 0x002c76,[CaseTitle] = 0x002c75,[CaseUpper] = 0x002c75,[CaseFold] = 0x002c76}, NULL},
-	{0x002c76, {[CaseLower] = 0x002c76,[CaseTitle] = 0x002c75,[CaseUpper] = 0x002c75,[CaseFold] = 0x002c76}, NULL},
-	{0x002c7e, {[CaseLower] = 0x00023f,[CaseTitle] = 0x002c7e,[CaseUpper] = 0x002c7e,[CaseFold] = 0x00023f}, NULL},
-	{0x002c7f, {[CaseLower] = 0x000240,[CaseTitle] = 0x002c7f,[CaseUpper] = 0x002c7f,[CaseFold] = 0x000240}, NULL},
-	{0x002c80, {[CaseLower] = 0x002c81,[CaseTitle] = 0x002c80,[CaseUpper] = 0x002c80,[CaseFold] = 0x002c81}, NULL},
-	{0x002c81, {[CaseLower] = 0x002c81,[CaseTitle] = 0x002c80,[CaseUpper] = 0x002c80,[CaseFold] = 0x002c81}, NULL},
-	{0x002c82, {[CaseLower] = 0x002c83,[CaseTitle] = 0x002c82,[CaseUpper] = 0x002c82,[CaseFold] = 0x002c83}, NULL},
-	{0x002c83, {[CaseLower] = 0x002c83,[CaseTitle] = 0x002c82,[CaseUpper] = 0x002c82,[CaseFold] = 0x002c83}, NULL},
-	{0x002c84, {[CaseLower] = 0x002c85,[CaseTitle] = 0x002c84,[CaseUpper] = 0x002c84,[CaseFold] = 0x002c85}, NULL},
-	{0x002c85, {[CaseLower] = 0x002c85,[CaseTitle] = 0x002c84,[CaseUpper] = 0x002c84,[CaseFold] = 0x002c85}, NULL},
-	{0x002c86, {[CaseLower] = 0x002c87,[CaseTitle] = 0x002c86,[CaseUpper] = 0x002c86,[CaseFold] = 0x002c87}, NULL},
-	{0x002c87, {[CaseLower] = 0x002c87,[CaseTitle] = 0x002c86,[CaseUpper] = 0x002c86,[CaseFold] = 0x002c87}, NULL},
-	{0x002c88, {[CaseLower] = 0x002c89,[CaseTitle] = 0x002c88,[CaseUpper] = 0x002c88,[CaseFold] = 0x002c89}, NULL},
-	{0x002c89, {[CaseLower] = 0x002c89,[CaseTitle] = 0x002c88,[CaseUpper] = 0x002c88,[CaseFold] = 0x002c89}, NULL},
-	{0x002c8a, {[CaseLower] = 0x002c8b,[CaseTitle] = 0x002c8a,[CaseUpper] = 0x002c8a,[CaseFold] = 0x002c8b}, NULL},
-	{0x002c8b, {[CaseLower] = 0x002c8b,[CaseTitle] = 0x002c8a,[CaseUpper] = 0x002c8a,[CaseFold] = 0x002c8b}, NULL},
-	{0x002c8c, {[CaseLower] = 0x002c8d,[CaseTitle] = 0x002c8c,[CaseUpper] = 0x002c8c,[CaseFold] = 0x002c8d}, NULL},
-	{0x002c8d, {[CaseLower] = 0x002c8d,[CaseTitle] = 0x002c8c,[CaseUpper] = 0x002c8c,[CaseFold] = 0x002c8d}, NULL},
-	{0x002c8e, {[CaseLower] = 0x002c8f,[CaseTitle] = 0x002c8e,[CaseUpper] = 0x002c8e,[CaseFold] = 0x002c8f}, NULL},
-	{0x002c8f, {[CaseLower] = 0x002c8f,[CaseTitle] = 0x002c8e,[CaseUpper] = 0x002c8e,[CaseFold] = 0x002c8f}, NULL},
-	{0x002c90, {[CaseLower] = 0x002c91,[CaseTitle] = 0x002c90,[CaseUpper] = 0x002c90,[CaseFold] = 0x002c91}, NULL},
-	{0x002c91, {[CaseLower] = 0x002c91,[CaseTitle] = 0x002c90,[CaseUpper] = 0x002c90,[CaseFold] = 0x002c91}, NULL},
-	{0x002c92, {[CaseLower] = 0x002c93,[CaseTitle] = 0x002c92,[CaseUpper] = 0x002c92,[CaseFold] = 0x002c93}, NULL},
-	{0x002c93, {[CaseLower] = 0x002c93,[CaseTitle] = 0x002c92,[CaseUpper] = 0x002c92,[CaseFold] = 0x002c93}, NULL},
-	{0x002c94, {[CaseLower] = 0x002c95,[CaseTitle] = 0x002c94,[CaseUpper] = 0x002c94,[CaseFold] = 0x002c95}, NULL},
-	{0x002c95, {[CaseLower] = 0x002c95,[CaseTitle] = 0x002c94,[CaseUpper] = 0x002c94,[CaseFold] = 0x002c95}, NULL},
-	{0x002c96, {[CaseLower] = 0x002c97,[CaseTitle] = 0x002c96,[CaseUpper] = 0x002c96,[CaseFold] = 0x002c97}, NULL},
-	{0x002c97, {[CaseLower] = 0x002c97,[CaseTitle] = 0x002c96,[CaseUpper] = 0x002c96,[CaseFold] = 0x002c97}, NULL},
-	{0x002c98, {[CaseLower] = 0x002c99,[CaseTitle] = 0x002c98,[CaseUpper] = 0x002c98,[CaseFold] = 0x002c99}, NULL},
-	{0x002c99, {[CaseLower] = 0x002c99,[CaseTitle] = 0x002c98,[CaseUpper] = 0x002c98,[CaseFold] = 0x002c99}, NULL},
-	{0x002c9a, {[CaseLower] = 0x002c9b,[CaseTitle] = 0x002c9a,[CaseUpper] = 0x002c9a,[CaseFold] = 0x002c9b}, NULL},
-	{0x002c9b, {[CaseLower] = 0x002c9b,[CaseTitle] = 0x002c9a,[CaseUpper] = 0x002c9a,[CaseFold] = 0x002c9b}, NULL},
-	{0x002c9c, {[CaseLower] = 0x002c9d,[CaseTitle] = 0x002c9c,[CaseUpper] = 0x002c9c,[CaseFold] = 0x002c9d}, NULL},
-	{0x002c9d, {[CaseLower] = 0x002c9d,[CaseTitle] = 0x002c9c,[CaseUpper] = 0x002c9c,[CaseFold] = 0x002c9d}, NULL},
-	{0x002c9e, {[CaseLower] = 0x002c9f,[CaseTitle] = 0x002c9e,[CaseUpper] = 0x002c9e,[CaseFold] = 0x002c9f}, NULL},
-	{0x002c9f, {[CaseLower] = 0x002c9f,[CaseTitle] = 0x002c9e,[CaseUpper] = 0x002c9e,[CaseFold] = 0x002c9f}, NULL},
-	{0x002ca0, {[CaseLower] = 0x002ca1,[CaseTitle] = 0x002ca0,[CaseUpper] = 0x002ca0,[CaseFold] = 0x002ca1}, NULL},
-	{0x002ca1, {[CaseLower] = 0x002ca1,[CaseTitle] = 0x002ca0,[CaseUpper] = 0x002ca0,[CaseFold] = 0x002ca1}, NULL},
-	{0x002ca2, {[CaseLower] = 0x002ca3,[CaseTitle] = 0x002ca2,[CaseUpper] = 0x002ca2,[CaseFold] = 0x002ca3}, NULL},
-	{0x002ca3, {[CaseLower] = 0x002ca3,[CaseTitle] = 0x002ca2,[CaseUpper] = 0x002ca2,[CaseFold] = 0x002ca3}, NULL},
-	{0x002ca4, {[CaseLower] = 0x002ca5,[CaseTitle] = 0x002ca4,[CaseUpper] = 0x002ca4,[CaseFold] = 0x002ca5}, NULL},
-	{0x002ca5, {[CaseLower] = 0x002ca5,[CaseTitle] = 0x002ca4,[CaseUpper] = 0x002ca4,[CaseFold] = 0x002ca5}, NULL},
-	{0x002ca6, {[CaseLower] = 0x002ca7,[CaseTitle] = 0x002ca6,[CaseUpper] = 0x002ca6,[CaseFold] = 0x002ca7}, NULL},
-	{0x002ca7, {[CaseLower] = 0x002ca7,[CaseTitle] = 0x002ca6,[CaseUpper] = 0x002ca6,[CaseFold] = 0x002ca7}, NULL},
-	{0x002ca8, {[CaseLower] = 0x002ca9,[CaseTitle] = 0x002ca8,[CaseUpper] = 0x002ca8,[CaseFold] = 0x002ca9}, NULL},
-	{0x002ca9, {[CaseLower] = 0x002ca9,[CaseTitle] = 0x002ca8,[CaseUpper] = 0x002ca8,[CaseFold] = 0x002ca9}, NULL},
-	{0x002caa, {[CaseLower] = 0x002cab,[CaseTitle] = 0x002caa,[CaseUpper] = 0x002caa,[CaseFold] = 0x002cab}, NULL},
-	{0x002cab, {[CaseLower] = 0x002cab,[CaseTitle] = 0x002caa,[CaseUpper] = 0x002caa,[CaseFold] = 0x002cab}, NULL},
-	{0x002cac, {[CaseLower] = 0x002cad,[CaseTitle] = 0x002cac,[CaseUpper] = 0x002cac,[CaseFold] = 0x002cad}, NULL},
-	{0x002cad, {[CaseLower] = 0x002cad,[CaseTitle] = 0x002cac,[CaseUpper] = 0x002cac,[CaseFold] = 0x002cad}, NULL},
-	{0x002cae, {[CaseLower] = 0x002caf,[CaseTitle] = 0x002cae,[CaseUpper] = 0x002cae,[CaseFold] = 0x002caf}, NULL},
-	{0x002caf, {[CaseLower] = 0x002caf,[CaseTitle] = 0x002cae,[CaseUpper] = 0x002cae,[CaseFold] = 0x002caf}, NULL},
-	{0x002cb0, {[CaseLower] = 0x002cb1,[CaseTitle] = 0x002cb0,[CaseUpper] = 0x002cb0,[CaseFold] = 0x002cb1}, NULL},
-	{0x002cb1, {[CaseLower] = 0x002cb1,[CaseTitle] = 0x002cb0,[CaseUpper] = 0x002cb0,[CaseFold] = 0x002cb1}, NULL},
-	{0x002cb2, {[CaseLower] = 0x002cb3,[CaseTitle] = 0x002cb2,[CaseUpper] = 0x002cb2,[CaseFold] = 0x002cb3}, NULL},
-	{0x002cb3, {[CaseLower] = 0x002cb3,[CaseTitle] = 0x002cb2,[CaseUpper] = 0x002cb2,[CaseFold] = 0x002cb3}, NULL},
-	{0x002cb4, {[CaseLower] = 0x002cb5,[CaseTitle] = 0x002cb4,[CaseUpper] = 0x002cb4,[CaseFold] = 0x002cb5}, NULL},
-	{0x002cb5, {[CaseLower] = 0x002cb5,[CaseTitle] = 0x002cb4,[CaseUpper] = 0x002cb4,[CaseFold] = 0x002cb5}, NULL},
-	{0x002cb6, {[CaseLower] = 0x002cb7,[CaseTitle] = 0x002cb6,[CaseUpper] = 0x002cb6,[CaseFold] = 0x002cb7}, NULL},
-	{0x002cb7, {[CaseLower] = 0x002cb7,[CaseTitle] = 0x002cb6,[CaseUpper] = 0x002cb6,[CaseFold] = 0x002cb7}, NULL},
-	{0x002cb8, {[CaseLower] = 0x002cb9,[CaseTitle] = 0x002cb8,[CaseUpper] = 0x002cb8,[CaseFold] = 0x002cb9}, NULL},
-	{0x002cb9, {[CaseLower] = 0x002cb9,[CaseTitle] = 0x002cb8,[CaseUpper] = 0x002cb8,[CaseFold] = 0x002cb9}, NULL},
-	{0x002cba, {[CaseLower] = 0x002cbb,[CaseTitle] = 0x002cba,[CaseUpper] = 0x002cba,[CaseFold] = 0x002cbb}, NULL},
-	{0x002cbb, {[CaseLower] = 0x002cbb,[CaseTitle] = 0x002cba,[CaseUpper] = 0x002cba,[CaseFold] = 0x002cbb}, NULL},
-	{0x002cbc, {[CaseLower] = 0x002cbd,[CaseTitle] = 0x002cbc,[CaseUpper] = 0x002cbc,[CaseFold] = 0x002cbd}, NULL},
-	{0x002cbd, {[CaseLower] = 0x002cbd,[CaseTitle] = 0x002cbc,[CaseUpper] = 0x002cbc,[CaseFold] = 0x002cbd}, NULL},
-	{0x002cbe, {[CaseLower] = 0x002cbf,[CaseTitle] = 0x002cbe,[CaseUpper] = 0x002cbe,[CaseFold] = 0x002cbf}, NULL},
-	{0x002cbf, {[CaseLower] = 0x002cbf,[CaseTitle] = 0x002cbe,[CaseUpper] = 0x002cbe,[CaseFold] = 0x002cbf}, NULL},
-	{0x002cc0, {[CaseLower] = 0x002cc1,[CaseTitle] = 0x002cc0,[CaseUpper] = 0x002cc0,[CaseFold] = 0x002cc1}, NULL},
-	{0x002cc1, {[CaseLower] = 0x002cc1,[CaseTitle] = 0x002cc0,[CaseUpper] = 0x002cc0,[CaseFold] = 0x002cc1}, NULL},
-	{0x002cc2, {[CaseLower] = 0x002cc3,[CaseTitle] = 0x002cc2,[CaseUpper] = 0x002cc2,[CaseFold] = 0x002cc3}, NULL},
-	{0x002cc3, {[CaseLower] = 0x002cc3,[CaseTitle] = 0x002cc2,[CaseUpper] = 0x002cc2,[CaseFold] = 0x002cc3}, NULL},
-	{0x002cc4, {[CaseLower] = 0x002cc5,[CaseTitle] = 0x002cc4,[CaseUpper] = 0x002cc4,[CaseFold] = 0x002cc5}, NULL},
-	{0x002cc5, {[CaseLower] = 0x002cc5,[CaseTitle] = 0x002cc4,[CaseUpper] = 0x002cc4,[CaseFold] = 0x002cc5}, NULL},
-	{0x002cc6, {[CaseLower] = 0x002cc7,[CaseTitle] = 0x002cc6,[CaseUpper] = 0x002cc6,[CaseFold] = 0x002cc7}, NULL},
-	{0x002cc7, {[CaseLower] = 0x002cc7,[CaseTitle] = 0x002cc6,[CaseUpper] = 0x002cc6,[CaseFold] = 0x002cc7}, NULL},
-	{0x002cc8, {[CaseLower] = 0x002cc9,[CaseTitle] = 0x002cc8,[CaseUpper] = 0x002cc8,[CaseFold] = 0x002cc9}, NULL},
-	{0x002cc9, {[CaseLower] = 0x002cc9,[CaseTitle] = 0x002cc8,[CaseUpper] = 0x002cc8,[CaseFold] = 0x002cc9}, NULL},
-	{0x002cca, {[CaseLower] = 0x002ccb,[CaseTitle] = 0x002cca,[CaseUpper] = 0x002cca,[CaseFold] = 0x002ccb}, NULL},
-	{0x002ccb, {[CaseLower] = 0x002ccb,[CaseTitle] = 0x002cca,[CaseUpper] = 0x002cca,[CaseFold] = 0x002ccb}, NULL},
-	{0x002ccc, {[CaseLower] = 0x002ccd,[CaseTitle] = 0x002ccc,[CaseUpper] = 0x002ccc,[CaseFold] = 0x002ccd}, NULL},
-	{0x002ccd, {[CaseLower] = 0x002ccd,[CaseTitle] = 0x002ccc,[CaseUpper] = 0x002ccc,[CaseFold] = 0x002ccd}, NULL},
-	{0x002cce, {[CaseLower] = 0x002ccf,[CaseTitle] = 0x002cce,[CaseUpper] = 0x002cce,[CaseFold] = 0x002ccf}, NULL},
-	{0x002ccf, {[CaseLower] = 0x002ccf,[CaseTitle] = 0x002cce,[CaseUpper] = 0x002cce,[CaseFold] = 0x002ccf}, NULL},
-	{0x002cd0, {[CaseLower] = 0x002cd1,[CaseTitle] = 0x002cd0,[CaseUpper] = 0x002cd0,[CaseFold] = 0x002cd1}, NULL},
-	{0x002cd1, {[CaseLower] = 0x002cd1,[CaseTitle] = 0x002cd0,[CaseUpper] = 0x002cd0,[CaseFold] = 0x002cd1}, NULL},
-	{0x002cd2, {[CaseLower] = 0x002cd3,[CaseTitle] = 0x002cd2,[CaseUpper] = 0x002cd2,[CaseFold] = 0x002cd3}, NULL},
-	{0x002cd3, {[CaseLower] = 0x002cd3,[CaseTitle] = 0x002cd2,[CaseUpper] = 0x002cd2,[CaseFold] = 0x002cd3}, NULL},
-	{0x002cd4, {[CaseLower] = 0x002cd5,[CaseTitle] = 0x002cd4,[CaseUpper] = 0x002cd4,[CaseFold] = 0x002cd5}, NULL},
-	{0x002cd5, {[CaseLower] = 0x002cd5,[CaseTitle] = 0x002cd4,[CaseUpper] = 0x002cd4,[CaseFold] = 0x002cd5}, NULL},
-	{0x002cd6, {[CaseLower] = 0x002cd7,[CaseTitle] = 0x002cd6,[CaseUpper] = 0x002cd6,[CaseFold] = 0x002cd7}, NULL},
-	{0x002cd7, {[CaseLower] = 0x002cd7,[CaseTitle] = 0x002cd6,[CaseUpper] = 0x002cd6,[CaseFold] = 0x002cd7}, NULL},
-	{0x002cd8, {[CaseLower] = 0x002cd9,[CaseTitle] = 0x002cd8,[CaseUpper] = 0x002cd8,[CaseFold] = 0x002cd9}, NULL},
-	{0x002cd9, {[CaseLower] = 0x002cd9,[CaseTitle] = 0x002cd8,[CaseUpper] = 0x002cd8,[CaseFold] = 0x002cd9}, NULL},
-	{0x002cda, {[CaseLower] = 0x002cdb,[CaseTitle] = 0x002cda,[CaseUpper] = 0x002cda,[CaseFold] = 0x002cdb}, NULL},
-	{0x002cdb, {[CaseLower] = 0x002cdb,[CaseTitle] = 0x002cda,[CaseUpper] = 0x002cda,[CaseFold] = 0x002cdb}, NULL},
-	{0x002cdc, {[CaseLower] = 0x002cdd,[CaseTitle] = 0x002cdc,[CaseUpper] = 0x002cdc,[CaseFold] = 0x002cdd}, NULL},
-	{0x002cdd, {[CaseLower] = 0x002cdd,[CaseTitle] = 0x002cdc,[CaseUpper] = 0x002cdc,[CaseFold] = 0x002cdd}, NULL},
-	{0x002cde, {[CaseLower] = 0x002cdf,[CaseTitle] = 0x002cde,[CaseUpper] = 0x002cde,[CaseFold] = 0x002cdf}, NULL},
-	{0x002cdf, {[CaseLower] = 0x002cdf,[CaseTitle] = 0x002cde,[CaseUpper] = 0x002cde,[CaseFold] = 0x002cdf}, NULL},
-	{0x002ce0, {[CaseLower] = 0x002ce1,[CaseTitle] = 0x002ce0,[CaseUpper] = 0x002ce0,[CaseFold] = 0x002ce1}, NULL},
-	{0x002ce1, {[CaseLower] = 0x002ce1,[CaseTitle] = 0x002ce0,[CaseUpper] = 0x002ce0,[CaseFold] = 0x002ce1}, NULL},
-	{0x002ce2, {[CaseLower] = 0x002ce3,[CaseTitle] = 0x002ce2,[CaseUpper] = 0x002ce2,[CaseFold] = 0x002ce3}, NULL},
-	{0x002ce3, {[CaseLower] = 0x002ce3,[CaseTitle] = 0x002ce2,[CaseUpper] = 0x002ce2,[CaseFold] = 0x002ce3}, NULL},
-	{0x002ceb, {[CaseLower] = 0x002cec,[CaseTitle] = 0x002ceb,[CaseUpper] = 0x002ceb,[CaseFold] = 0x002cec}, NULL},
-	{0x002cec, {[CaseLower] = 0x002cec,[CaseTitle] = 0x002ceb,[CaseUpper] = 0x002ceb,[CaseFold] = 0x002cec}, NULL},
-	{0x002ced, {[CaseLower] = 0x002cee,[CaseTitle] = 0x002ced,[CaseUpper] = 0x002ced,[CaseFold] = 0x002cee}, NULL},
-	{0x002cee, {[CaseLower] = 0x002cee,[CaseTitle] = 0x002ced,[CaseUpper] = 0x002ced,[CaseFold] = 0x002cee}, NULL},
-	{0x002cf2, {[CaseLower] = 0x002cf3,[CaseTitle] = 0x002cf2,[CaseUpper] = 0x002cf2,[CaseFold] = 0x002cf3}, NULL},
-	{0x002cf3, {[CaseLower] = 0x002cf3,[CaseTitle] = 0x002cf2,[CaseUpper] = 0x002cf2,[CaseFold] = 0x002cf3}, NULL},
-	{0x002d00, {[CaseLower] = 0x002d00,[CaseTitle] = 0x0010a0,[CaseUpper] = 0x0010a0,[CaseFold] = 0x002d00}, NULL},
-	{0x002d01, {[CaseLower] = 0x002d01,[CaseTitle] = 0x0010a1,[CaseUpper] = 0x0010a1,[CaseFold] = 0x002d01}, NULL},
-	{0x002d02, {[CaseLower] = 0x002d02,[CaseTitle] = 0x0010a2,[CaseUpper] = 0x0010a2,[CaseFold] = 0x002d02}, NULL},
-	{0x002d03, {[CaseLower] = 0x002d03,[CaseTitle] = 0x0010a3,[CaseUpper] = 0x0010a3,[CaseFold] = 0x002d03}, NULL},
-	{0x002d04, {[CaseLower] = 0x002d04,[CaseTitle] = 0x0010a4,[CaseUpper] = 0x0010a4,[CaseFold] = 0x002d04}, NULL},
-	{0x002d05, {[CaseLower] = 0x002d05,[CaseTitle] = 0x0010a5,[CaseUpper] = 0x0010a5,[CaseFold] = 0x002d05}, NULL},
-	{0x002d06, {[CaseLower] = 0x002d06,[CaseTitle] = 0x0010a6,[CaseUpper] = 0x0010a6,[CaseFold] = 0x002d06}, NULL},
-	{0x002d07, {[CaseLower] = 0x002d07,[CaseTitle] = 0x0010a7,[CaseUpper] = 0x0010a7,[CaseFold] = 0x002d07}, NULL},
-	{0x002d08, {[CaseLower] = 0x002d08,[CaseTitle] = 0x0010a8,[CaseUpper] = 0x0010a8,[CaseFold] = 0x002d08}, NULL},
-	{0x002d09, {[CaseLower] = 0x002d09,[CaseTitle] = 0x0010a9,[CaseUpper] = 0x0010a9,[CaseFold] = 0x002d09}, NULL},
-	{0x002d0a, {[CaseLower] = 0x002d0a,[CaseTitle] = 0x0010aa,[CaseUpper] = 0x0010aa,[CaseFold] = 0x002d0a}, NULL},
-	{0x002d0b, {[CaseLower] = 0x002d0b,[CaseTitle] = 0x0010ab,[CaseUpper] = 0x0010ab,[CaseFold] = 0x002d0b}, NULL},
-	{0x002d0c, {[CaseLower] = 0x002d0c,[CaseTitle] = 0x0010ac,[CaseUpper] = 0x0010ac,[CaseFold] = 0x002d0c}, NULL},
-	{0x002d0d, {[CaseLower] = 0x002d0d,[CaseTitle] = 0x0010ad,[CaseUpper] = 0x0010ad,[CaseFold] = 0x002d0d}, NULL},
-	{0x002d0e, {[CaseLower] = 0x002d0e,[CaseTitle] = 0x0010ae,[CaseUpper] = 0x0010ae,[CaseFold] = 0x002d0e}, NULL},
-	{0x002d0f, {[CaseLower] = 0x002d0f,[CaseTitle] = 0x0010af,[CaseUpper] = 0x0010af,[CaseFold] = 0x002d0f}, NULL},
-	{0x002d10, {[CaseLower] = 0x002d10,[CaseTitle] = 0x0010b0,[CaseUpper] = 0x0010b0,[CaseFold] = 0x002d10}, NULL},
-	{0x002d11, {[CaseLower] = 0x002d11,[CaseTitle] = 0x0010b1,[CaseUpper] = 0x0010b1,[CaseFold] = 0x002d11}, NULL},
-	{0x002d12, {[CaseLower] = 0x002d12,[CaseTitle] = 0x0010b2,[CaseUpper] = 0x0010b2,[CaseFold] = 0x002d12}, NULL},
-	{0x002d13, {[CaseLower] = 0x002d13,[CaseTitle] = 0x0010b3,[CaseUpper] = 0x0010b3,[CaseFold] = 0x002d13}, NULL},
-	{0x002d14, {[CaseLower] = 0x002d14,[CaseTitle] = 0x0010b4,[CaseUpper] = 0x0010b4,[CaseFold] = 0x002d14}, NULL},
-	{0x002d15, {[CaseLower] = 0x002d15,[CaseTitle] = 0x0010b5,[CaseUpper] = 0x0010b5,[CaseFold] = 0x002d15}, NULL},
-	{0x002d16, {[CaseLower] = 0x002d16,[CaseTitle] = 0x0010b6,[CaseUpper] = 0x0010b6,[CaseFold] = 0x002d16}, NULL},
-	{0x002d17, {[CaseLower] = 0x002d17,[CaseTitle] = 0x0010b7,[CaseUpper] = 0x0010b7,[CaseFold] = 0x002d17}, NULL},
-	{0x002d18, {[CaseLower] = 0x002d18,[CaseTitle] = 0x0010b8,[CaseUpper] = 0x0010b8,[CaseFold] = 0x002d18}, NULL},
-	{0x002d19, {[CaseLower] = 0x002d19,[CaseTitle] = 0x0010b9,[CaseUpper] = 0x0010b9,[CaseFold] = 0x002d19}, NULL},
-	{0x002d1a, {[CaseLower] = 0x002d1a,[CaseTitle] = 0x0010ba,[CaseUpper] = 0x0010ba,[CaseFold] = 0x002d1a}, NULL},
-	{0x002d1b, {[CaseLower] = 0x002d1b,[CaseTitle] = 0x0010bb,[CaseUpper] = 0x0010bb,[CaseFold] = 0x002d1b}, NULL},
-	{0x002d1c, {[CaseLower] = 0x002d1c,[CaseTitle] = 0x0010bc,[CaseUpper] = 0x0010bc,[CaseFold] = 0x002d1c}, NULL},
-	{0x002d1d, {[CaseLower] = 0x002d1d,[CaseTitle] = 0x0010bd,[CaseUpper] = 0x0010bd,[CaseFold] = 0x002d1d}, NULL},
-	{0x002d1e, {[CaseLower] = 0x002d1e,[CaseTitle] = 0x0010be,[CaseUpper] = 0x0010be,[CaseFold] = 0x002d1e}, NULL},
-	{0x002d1f, {[CaseLower] = 0x002d1f,[CaseTitle] = 0x0010bf,[CaseUpper] = 0x0010bf,[CaseFold] = 0x002d1f}, NULL},
-	{0x002d20, {[CaseLower] = 0x002d20,[CaseTitle] = 0x0010c0,[CaseUpper] = 0x0010c0,[CaseFold] = 0x002d20}, NULL},
-	{0x002d21, {[CaseLower] = 0x002d21,[CaseTitle] = 0x0010c1,[CaseUpper] = 0x0010c1,[CaseFold] = 0x002d21}, NULL},
-	{0x002d22, {[CaseLower] = 0x002d22,[CaseTitle] = 0x0010c2,[CaseUpper] = 0x0010c2,[CaseFold] = 0x002d22}, NULL},
-	{0x002d23, {[CaseLower] = 0x002d23,[CaseTitle] = 0x0010c3,[CaseUpper] = 0x0010c3,[CaseFold] = 0x002d23}, NULL},
-	{0x002d24, {[CaseLower] = 0x002d24,[CaseTitle] = 0x0010c4,[CaseUpper] = 0x0010c4,[CaseFold] = 0x002d24}, NULL},
-	{0x002d25, {[CaseLower] = 0x002d25,[CaseTitle] = 0x0010c5,[CaseUpper] = 0x0010c5,[CaseFold] = 0x002d25}, NULL},
-	{0x002d27, {[CaseLower] = 0x002d27,[CaseTitle] = 0x0010c7,[CaseUpper] = 0x0010c7,[CaseFold] = 0x002d27}, NULL},
-	{0x002d2d, {[CaseLower] = 0x002d2d,[CaseTitle] = 0x0010cd,[CaseUpper] = 0x0010cd,[CaseFold] = 0x002d2d}, NULL},
-	{0x00a640, {[CaseLower] = 0x00a641,[CaseTitle] = 0x00a640,[CaseUpper] = 0x00a640,[CaseFold] = 0x00a641}, NULL},
-	{0x00a641, {[CaseLower] = 0x00a641,[CaseTitle] = 0x00a640,[CaseUpper] = 0x00a640,[CaseFold] = 0x00a641}, NULL},
-	{0x00a642, {[CaseLower] = 0x00a643,[CaseTitle] = 0x00a642,[CaseUpper] = 0x00a642,[CaseFold] = 0x00a643}, NULL},
-	{0x00a643, {[CaseLower] = 0x00a643,[CaseTitle] = 0x00a642,[CaseUpper] = 0x00a642,[CaseFold] = 0x00a643}, NULL},
-	{0x00a644, {[CaseLower] = 0x00a645,[CaseTitle] = 0x00a644,[CaseUpper] = 0x00a644,[CaseFold] = 0x00a645}, NULL},
-	{0x00a645, {[CaseLower] = 0x00a645,[CaseTitle] = 0x00a644,[CaseUpper] = 0x00a644,[CaseFold] = 0x00a645}, NULL},
-	{0x00a646, {[CaseLower] = 0x00a647,[CaseTitle] = 0x00a646,[CaseUpper] = 0x00a646,[CaseFold] = 0x00a647}, NULL},
-	{0x00a647, {[CaseLower] = 0x00a647,[CaseTitle] = 0x00a646,[CaseUpper] = 0x00a646,[CaseFold] = 0x00a647}, NULL},
-	{0x00a648, {[CaseLower] = 0x00a649,[CaseTitle] = 0x00a648,[CaseUpper] = 0x00a648,[CaseFold] = 0x00a649}, NULL},
-	{0x00a649, {[CaseLower] = 0x00a649,[CaseTitle] = 0x00a648,[CaseUpper] = 0x00a648,[CaseFold] = 0x00a649}, NULL},
-	{0x00a64a, {[CaseLower] = 0x00a64b,[CaseTitle] = 0x00a64a,[CaseUpper] = 0x00a64a,[CaseFold] = 0x00a64b}, NULL},
-	{0x00a64b, {[CaseLower] = 0x00a64b,[CaseTitle] = 0x00a64a,[CaseUpper] = 0x00a64a,[CaseFold] = 0x00a64b}, NULL},
-	{0x00a64c, {[CaseLower] = 0x00a64d,[CaseTitle] = 0x00a64c,[CaseUpper] = 0x00a64c,[CaseFold] = 0x00a64d}, NULL},
-	{0x00a64d, {[CaseLower] = 0x00a64d,[CaseTitle] = 0x00a64c,[CaseUpper] = 0x00a64c,[CaseFold] = 0x00a64d}, NULL},
-	{0x00a64e, {[CaseLower] = 0x00a64f,[CaseTitle] = 0x00a64e,[CaseUpper] = 0x00a64e,[CaseFold] = 0x00a64f}, NULL},
-	{0x00a64f, {[CaseLower] = 0x00a64f,[CaseTitle] = 0x00a64e,[CaseUpper] = 0x00a64e,[CaseFold] = 0x00a64f}, NULL},
-	{0x00a650, {[CaseLower] = 0x00a651,[CaseTitle] = 0x00a650,[CaseUpper] = 0x00a650,[CaseFold] = 0x00a651}, NULL},
-	{0x00a651, {[CaseLower] = 0x00a651,[CaseTitle] = 0x00a650,[CaseUpper] = 0x00a650,[CaseFold] = 0x00a651}, NULL},
-	{0x00a652, {[CaseLower] = 0x00a653,[CaseTitle] = 0x00a652,[CaseUpper] = 0x00a652,[CaseFold] = 0x00a653}, NULL},
-	{0x00a653, {[CaseLower] = 0x00a653,[CaseTitle] = 0x00a652,[CaseUpper] = 0x00a652,[CaseFold] = 0x00a653}, NULL},
-	{0x00a654, {[CaseLower] = 0x00a655,[CaseTitle] = 0x00a654,[CaseUpper] = 0x00a654,[CaseFold] = 0x00a655}, NULL},
-	{0x00a655, {[CaseLower] = 0x00a655,[CaseTitle] = 0x00a654,[CaseUpper] = 0x00a654,[CaseFold] = 0x00a655}, NULL},
-	{0x00a656, {[CaseLower] = 0x00a657,[CaseTitle] = 0x00a656,[CaseUpper] = 0x00a656,[CaseFold] = 0x00a657}, NULL},
-	{0x00a657, {[CaseLower] = 0x00a657,[CaseTitle] = 0x00a656,[CaseUpper] = 0x00a656,[CaseFold] = 0x00a657}, NULL},
-	{0x00a658, {[CaseLower] = 0x00a659,[CaseTitle] = 0x00a658,[CaseUpper] = 0x00a658,[CaseFold] = 0x00a659}, NULL},
-	{0x00a659, {[CaseLower] = 0x00a659,[CaseTitle] = 0x00a658,[CaseUpper] = 0x00a658,[CaseFold] = 0x00a659}, NULL},
-	{0x00a65a, {[CaseLower] = 0x00a65b,[CaseTitle] = 0x00a65a,[CaseUpper] = 0x00a65a,[CaseFold] = 0x00a65b}, NULL},
-	{0x00a65b, {[CaseLower] = 0x00a65b,[CaseTitle] = 0x00a65a,[CaseUpper] = 0x00a65a,[CaseFold] = 0x00a65b}, NULL},
-	{0x00a65c, {[CaseLower] = 0x00a65d,[CaseTitle] = 0x00a65c,[CaseUpper] = 0x00a65c,[CaseFold] = 0x00a65d}, NULL},
-	{0x00a65d, {[CaseLower] = 0x00a65d,[CaseTitle] = 0x00a65c,[CaseUpper] = 0x00a65c,[CaseFold] = 0x00a65d}, NULL},
-	{0x00a65e, {[CaseLower] = 0x00a65f,[CaseTitle] = 0x00a65e,[CaseUpper] = 0x00a65e,[CaseFold] = 0x00a65f}, NULL},
-	{0x00a65f, {[CaseLower] = 0x00a65f,[CaseTitle] = 0x00a65e,[CaseUpper] = 0x00a65e,[CaseFold] = 0x00a65f}, NULL},
-	{0x00a660, {[CaseLower] = 0x00a661,[CaseTitle] = 0x00a660,[CaseUpper] = 0x00a660,[CaseFold] = 0x00a661}, NULL},
-	{0x00a661, {[CaseLower] = 0x00a661,[CaseTitle] = 0x00a660,[CaseUpper] = 0x00a660,[CaseFold] = 0x00a661}, NULL},
-	{0x00a662, {[CaseLower] = 0x00a663,[CaseTitle] = 0x00a662,[CaseUpper] = 0x00a662,[CaseFold] = 0x00a663}, NULL},
-	{0x00a663, {[CaseLower] = 0x00a663,[CaseTitle] = 0x00a662,[CaseUpper] = 0x00a662,[CaseFold] = 0x00a663}, NULL},
-	{0x00a664, {[CaseLower] = 0x00a665,[CaseTitle] = 0x00a664,[CaseUpper] = 0x00a664,[CaseFold] = 0x00a665}, NULL},
-	{0x00a665, {[CaseLower] = 0x00a665,[CaseTitle] = 0x00a664,[CaseUpper] = 0x00a664,[CaseFold] = 0x00a665}, NULL},
-	{0x00a666, {[CaseLower] = 0x00a667,[CaseTitle] = 0x00a666,[CaseUpper] = 0x00a666,[CaseFold] = 0x00a667}, NULL},
-	{0x00a667, {[CaseLower] = 0x00a667,[CaseTitle] = 0x00a666,[CaseUpper] = 0x00a666,[CaseFold] = 0x00a667}, NULL},
-	{0x00a668, {[CaseLower] = 0x00a669,[CaseTitle] = 0x00a668,[CaseUpper] = 0x00a668,[CaseFold] = 0x00a669}, NULL},
-	{0x00a669, {[CaseLower] = 0x00a669,[CaseTitle] = 0x00a668,[CaseUpper] = 0x00a668,[CaseFold] = 0x00a669}, NULL},
-	{0x00a66a, {[CaseLower] = 0x00a66b,[CaseTitle] = 0x00a66a,[CaseUpper] = 0x00a66a,[CaseFold] = 0x00a66b}, NULL},
-	{0x00a66b, {[CaseLower] = 0x00a66b,[CaseTitle] = 0x00a66a,[CaseUpper] = 0x00a66a,[CaseFold] = 0x00a66b}, NULL},
-	{0x00a66c, {[CaseLower] = 0x00a66d,[CaseTitle] = 0x00a66c,[CaseUpper] = 0x00a66c,[CaseFold] = 0x00a66d}, NULL},
-	{0x00a66d, {[CaseLower] = 0x00a66d,[CaseTitle] = 0x00a66c,[CaseUpper] = 0x00a66c,[CaseFold] = 0x00a66d}, NULL},
-	{0x00a680, {[CaseLower] = 0x00a681,[CaseTitle] = 0x00a680,[CaseUpper] = 0x00a680,[CaseFold] = 0x00a681}, NULL},
-	{0x00a681, {[CaseLower] = 0x00a681,[CaseTitle] = 0x00a680,[CaseUpper] = 0x00a680,[CaseFold] = 0x00a681}, NULL},
-	{0x00a682, {[CaseLower] = 0x00a683,[CaseTitle] = 0x00a682,[CaseUpper] = 0x00a682,[CaseFold] = 0x00a683}, NULL},
-	{0x00a683, {[CaseLower] = 0x00a683,[CaseTitle] = 0x00a682,[CaseUpper] = 0x00a682,[CaseFold] = 0x00a683}, NULL},
-	{0x00a684, {[CaseLower] = 0x00a685,[CaseTitle] = 0x00a684,[CaseUpper] = 0x00a684,[CaseFold] = 0x00a685}, NULL},
-	{0x00a685, {[CaseLower] = 0x00a685,[CaseTitle] = 0x00a684,[CaseUpper] = 0x00a684,[CaseFold] = 0x00a685}, NULL},
-	{0x00a686, {[CaseLower] = 0x00a687,[CaseTitle] = 0x00a686,[CaseUpper] = 0x00a686,[CaseFold] = 0x00a687}, NULL},
-	{0x00a687, {[CaseLower] = 0x00a687,[CaseTitle] = 0x00a686,[CaseUpper] = 0x00a686,[CaseFold] = 0x00a687}, NULL},
-	{0x00a688, {[CaseLower] = 0x00a689,[CaseTitle] = 0x00a688,[CaseUpper] = 0x00a688,[CaseFold] = 0x00a689}, NULL},
-	{0x00a689, {[CaseLower] = 0x00a689,[CaseTitle] = 0x00a688,[CaseUpper] = 0x00a688,[CaseFold] = 0x00a689}, NULL},
-	{0x00a68a, {[CaseLower] = 0x00a68b,[CaseTitle] = 0x00a68a,[CaseUpper] = 0x00a68a,[CaseFold] = 0x00a68b}, NULL},
-	{0x00a68b, {[CaseLower] = 0x00a68b,[CaseTitle] = 0x00a68a,[CaseUpper] = 0x00a68a,[CaseFold] = 0x00a68b}, NULL},
-	{0x00a68c, {[CaseLower] = 0x00a68d,[CaseTitle] = 0x00a68c,[CaseUpper] = 0x00a68c,[CaseFold] = 0x00a68d}, NULL},
-	{0x00a68d, {[CaseLower] = 0x00a68d,[CaseTitle] = 0x00a68c,[CaseUpper] = 0x00a68c,[CaseFold] = 0x00a68d}, NULL},
-	{0x00a68e, {[CaseLower] = 0x00a68f,[CaseTitle] = 0x00a68e,[CaseUpper] = 0x00a68e,[CaseFold] = 0x00a68f}, NULL},
-	{0x00a68f, {[CaseLower] = 0x00a68f,[CaseTitle] = 0x00a68e,[CaseUpper] = 0x00a68e,[CaseFold] = 0x00a68f}, NULL},
-	{0x00a690, {[CaseLower] = 0x00a691,[CaseTitle] = 0x00a690,[CaseUpper] = 0x00a690,[CaseFold] = 0x00a691}, NULL},
-	{0x00a691, {[CaseLower] = 0x00a691,[CaseTitle] = 0x00a690,[CaseUpper] = 0x00a690,[CaseFold] = 0x00a691}, NULL},
-	{0x00a692, {[CaseLower] = 0x00a693,[CaseTitle] = 0x00a692,[CaseUpper] = 0x00a692,[CaseFold] = 0x00a693}, NULL},
-	{0x00a693, {[CaseLower] = 0x00a693,[CaseTitle] = 0x00a692,[CaseUpper] = 0x00a692,[CaseFold] = 0x00a693}, NULL},
-	{0x00a694, {[CaseLower] = 0x00a695,[CaseTitle] = 0x00a694,[CaseUpper] = 0x00a694,[CaseFold] = 0x00a695}, NULL},
-	{0x00a695, {[CaseLower] = 0x00a695,[CaseTitle] = 0x00a694,[CaseUpper] = 0x00a694,[CaseFold] = 0x00a695}, NULL},
-	{0x00a696, {[CaseLower] = 0x00a697,[CaseTitle] = 0x00a696,[CaseUpper] = 0x00a696,[CaseFold] = 0x00a697}, NULL},
-	{0x00a697, {[CaseLower] = 0x00a697,[CaseTitle] = 0x00a696,[CaseUpper] = 0x00a696,[CaseFold] = 0x00a697}, NULL},
-	{0x00a698, {[CaseLower] = 0x00a699,[CaseTitle] = 0x00a698,[CaseUpper] = 0x00a698,[CaseFold] = 0x00a699}, NULL},
-	{0x00a699, {[CaseLower] = 0x00a699,[CaseTitle] = 0x00a698,[CaseUpper] = 0x00a698,[CaseFold] = 0x00a699}, NULL},
-	{0x00a69a, {[CaseLower] = 0x00a69b,[CaseTitle] = 0x00a69a,[CaseUpper] = 0x00a69a,[CaseFold] = 0x00a69b}, NULL},
-	{0x00a69b, {[CaseLower] = 0x00a69b,[CaseTitle] = 0x00a69a,[CaseUpper] = 0x00a69a,[CaseFold] = 0x00a69b}, NULL},
-	{0x00a722, {[CaseLower] = 0x00a723,[CaseTitle] = 0x00a722,[CaseUpper] = 0x00a722,[CaseFold] = 0x00a723}, NULL},
-	{0x00a723, {[CaseLower] = 0x00a723,[CaseTitle] = 0x00a722,[CaseUpper] = 0x00a722,[CaseFold] = 0x00a723}, NULL},
-	{0x00a724, {[CaseLower] = 0x00a725,[CaseTitle] = 0x00a724,[CaseUpper] = 0x00a724,[CaseFold] = 0x00a725}, NULL},
-	{0x00a725, {[CaseLower] = 0x00a725,[CaseTitle] = 0x00a724,[CaseUpper] = 0x00a724,[CaseFold] = 0x00a725}, NULL},
-	{0x00a726, {[CaseLower] = 0x00a727,[CaseTitle] = 0x00a726,[CaseUpper] = 0x00a726,[CaseFold] = 0x00a727}, NULL},
-	{0x00a727, {[CaseLower] = 0x00a727,[CaseTitle] = 0x00a726,[CaseUpper] = 0x00a726,[CaseFold] = 0x00a727}, NULL},
-	{0x00a728, {[CaseLower] = 0x00a729,[CaseTitle] = 0x00a728,[CaseUpper] = 0x00a728,[CaseFold] = 0x00a729}, NULL},
-	{0x00a729, {[CaseLower] = 0x00a729,[CaseTitle] = 0x00a728,[CaseUpper] = 0x00a728,[CaseFold] = 0x00a729}, NULL},
-	{0x00a72a, {[CaseLower] = 0x00a72b,[CaseTitle] = 0x00a72a,[CaseUpper] = 0x00a72a,[CaseFold] = 0x00a72b}, NULL},
-	{0x00a72b, {[CaseLower] = 0x00a72b,[CaseTitle] = 0x00a72a,[CaseUpper] = 0x00a72a,[CaseFold] = 0x00a72b}, NULL},
-	{0x00a72c, {[CaseLower] = 0x00a72d,[CaseTitle] = 0x00a72c,[CaseUpper] = 0x00a72c,[CaseFold] = 0x00a72d}, NULL},
-	{0x00a72d, {[CaseLower] = 0x00a72d,[CaseTitle] = 0x00a72c,[CaseUpper] = 0x00a72c,[CaseFold] = 0x00a72d}, NULL},
-	{0x00a72e, {[CaseLower] = 0x00a72f,[CaseTitle] = 0x00a72e,[CaseUpper] = 0x00a72e,[CaseFold] = 0x00a72f}, NULL},
-	{0x00a72f, {[CaseLower] = 0x00a72f,[CaseTitle] = 0x00a72e,[CaseUpper] = 0x00a72e,[CaseFold] = 0x00a72f}, NULL},
-	{0x00a732, {[CaseLower] = 0x00a733,[CaseTitle] = 0x00a732,[CaseUpper] = 0x00a732,[CaseFold] = 0x00a733}, NULL},
-	{0x00a733, {[CaseLower] = 0x00a733,[CaseTitle] = 0x00a732,[CaseUpper] = 0x00a732,[CaseFold] = 0x00a733}, NULL},
-	{0x00a734, {[CaseLower] = 0x00a735,[CaseTitle] = 0x00a734,[CaseUpper] = 0x00a734,[CaseFold] = 0x00a735}, NULL},
-	{0x00a735, {[CaseLower] = 0x00a735,[CaseTitle] = 0x00a734,[CaseUpper] = 0x00a734,[CaseFold] = 0x00a735}, NULL},
-	{0x00a736, {[CaseLower] = 0x00a737,[CaseTitle] = 0x00a736,[CaseUpper] = 0x00a736,[CaseFold] = 0x00a737}, NULL},
-	{0x00a737, {[CaseLower] = 0x00a737,[CaseTitle] = 0x00a736,[CaseUpper] = 0x00a736,[CaseFold] = 0x00a737}, NULL},
-	{0x00a738, {[CaseLower] = 0x00a739,[CaseTitle] = 0x00a738,[CaseUpper] = 0x00a738,[CaseFold] = 0x00a739}, NULL},
-	{0x00a739, {[CaseLower] = 0x00a739,[CaseTitle] = 0x00a738,[CaseUpper] = 0x00a738,[CaseFold] = 0x00a739}, NULL},
-	{0x00a73a, {[CaseLower] = 0x00a73b,[CaseTitle] = 0x00a73a,[CaseUpper] = 0x00a73a,[CaseFold] = 0x00a73b}, NULL},
-	{0x00a73b, {[CaseLower] = 0x00a73b,[CaseTitle] = 0x00a73a,[CaseUpper] = 0x00a73a,[CaseFold] = 0x00a73b}, NULL},
-	{0x00a73c, {[CaseLower] = 0x00a73d,[CaseTitle] = 0x00a73c,[CaseUpper] = 0x00a73c,[CaseFold] = 0x00a73d}, NULL},
-	{0x00a73d, {[CaseLower] = 0x00a73d,[CaseTitle] = 0x00a73c,[CaseUpper] = 0x00a73c,[CaseFold] = 0x00a73d}, NULL},
-	{0x00a73e, {[CaseLower] = 0x00a73f,[CaseTitle] = 0x00a73e,[CaseUpper] = 0x00a73e,[CaseFold] = 0x00a73f}, NULL},
-	{0x00a73f, {[CaseLower] = 0x00a73f,[CaseTitle] = 0x00a73e,[CaseUpper] = 0x00a73e,[CaseFold] = 0x00a73f}, NULL},
-	{0x00a740, {[CaseLower] = 0x00a741,[CaseTitle] = 0x00a740,[CaseUpper] = 0x00a740,[CaseFold] = 0x00a741}, NULL},
-	{0x00a741, {[CaseLower] = 0x00a741,[CaseTitle] = 0x00a740,[CaseUpper] = 0x00a740,[CaseFold] = 0x00a741}, NULL},
-	{0x00a742, {[CaseLower] = 0x00a743,[CaseTitle] = 0x00a742,[CaseUpper] = 0x00a742,[CaseFold] = 0x00a743}, NULL},
-	{0x00a743, {[CaseLower] = 0x00a743,[CaseTitle] = 0x00a742,[CaseUpper] = 0x00a742,[CaseFold] = 0x00a743}, NULL},
-	{0x00a744, {[CaseLower] = 0x00a745,[CaseTitle] = 0x00a744,[CaseUpper] = 0x00a744,[CaseFold] = 0x00a745}, NULL},
-	{0x00a745, {[CaseLower] = 0x00a745,[CaseTitle] = 0x00a744,[CaseUpper] = 0x00a744,[CaseFold] = 0x00a745}, NULL},
-	{0x00a746, {[CaseLower] = 0x00a747,[CaseTitle] = 0x00a746,[CaseUpper] = 0x00a746,[CaseFold] = 0x00a747}, NULL},
-	{0x00a747, {[CaseLower] = 0x00a747,[CaseTitle] = 0x00a746,[CaseUpper] = 0x00a746,[CaseFold] = 0x00a747}, NULL},
-	{0x00a748, {[CaseLower] = 0x00a749,[CaseTitle] = 0x00a748,[CaseUpper] = 0x00a748,[CaseFold] = 0x00a749}, NULL},
-	{0x00a749, {[CaseLower] = 0x00a749,[CaseTitle] = 0x00a748,[CaseUpper] = 0x00a748,[CaseFold] = 0x00a749}, NULL},
-	{0x00a74a, {[CaseLower] = 0x00a74b,[CaseTitle] = 0x00a74a,[CaseUpper] = 0x00a74a,[CaseFold] = 0x00a74b}, NULL},
-	{0x00a74b, {[CaseLower] = 0x00a74b,[CaseTitle] = 0x00a74a,[CaseUpper] = 0x00a74a,[CaseFold] = 0x00a74b}, NULL},
-	{0x00a74c, {[CaseLower] = 0x00a74d,[CaseTitle] = 0x00a74c,[CaseUpper] = 0x00a74c,[CaseFold] = 0x00a74d}, NULL},
-	{0x00a74d, {[CaseLower] = 0x00a74d,[CaseTitle] = 0x00a74c,[CaseUpper] = 0x00a74c,[CaseFold] = 0x00a74d}, NULL},
-	{0x00a74e, {[CaseLower] = 0x00a74f,[CaseTitle] = 0x00a74e,[CaseUpper] = 0x00a74e,[CaseFold] = 0x00a74f}, NULL},
-	{0x00a74f, {[CaseLower] = 0x00a74f,[CaseTitle] = 0x00a74e,[CaseUpper] = 0x00a74e,[CaseFold] = 0x00a74f}, NULL},
-	{0x00a750, {[CaseLower] = 0x00a751,[CaseTitle] = 0x00a750,[CaseUpper] = 0x00a750,[CaseFold] = 0x00a751}, NULL},
-	{0x00a751, {[CaseLower] = 0x00a751,[CaseTitle] = 0x00a750,[CaseUpper] = 0x00a750,[CaseFold] = 0x00a751}, NULL},
-	{0x00a752, {[CaseLower] = 0x00a753,[CaseTitle] = 0x00a752,[CaseUpper] = 0x00a752,[CaseFold] = 0x00a753}, NULL},
-	{0x00a753, {[CaseLower] = 0x00a753,[CaseTitle] = 0x00a752,[CaseUpper] = 0x00a752,[CaseFold] = 0x00a753}, NULL},
-	{0x00a754, {[CaseLower] = 0x00a755,[CaseTitle] = 0x00a754,[CaseUpper] = 0x00a754,[CaseFold] = 0x00a755}, NULL},
-	{0x00a755, {[CaseLower] = 0x00a755,[CaseTitle] = 0x00a754,[CaseUpper] = 0x00a754,[CaseFold] = 0x00a755}, NULL},
-	{0x00a756, {[CaseLower] = 0x00a757,[CaseTitle] = 0x00a756,[CaseUpper] = 0x00a756,[CaseFold] = 0x00a757}, NULL},
-	{0x00a757, {[CaseLower] = 0x00a757,[CaseTitle] = 0x00a756,[CaseUpper] = 0x00a756,[CaseFold] = 0x00a757}, NULL},
-	{0x00a758, {[CaseLower] = 0x00a759,[CaseTitle] = 0x00a758,[CaseUpper] = 0x00a758,[CaseFold] = 0x00a759}, NULL},
-	{0x00a759, {[CaseLower] = 0x00a759,[CaseTitle] = 0x00a758,[CaseUpper] = 0x00a758,[CaseFold] = 0x00a759}, NULL},
-	{0x00a75a, {[CaseLower] = 0x00a75b,[CaseTitle] = 0x00a75a,[CaseUpper] = 0x00a75a,[CaseFold] = 0x00a75b}, NULL},
-	{0x00a75b, {[CaseLower] = 0x00a75b,[CaseTitle] = 0x00a75a,[CaseUpper] = 0x00a75a,[CaseFold] = 0x00a75b}, NULL},
-	{0x00a75c, {[CaseLower] = 0x00a75d,[CaseTitle] = 0x00a75c,[CaseUpper] = 0x00a75c,[CaseFold] = 0x00a75d}, NULL},
-	{0x00a75d, {[CaseLower] = 0x00a75d,[CaseTitle] = 0x00a75c,[CaseUpper] = 0x00a75c,[CaseFold] = 0x00a75d}, NULL},
-	{0x00a75e, {[CaseLower] = 0x00a75f,[CaseTitle] = 0x00a75e,[CaseUpper] = 0x00a75e,[CaseFold] = 0x00a75f}, NULL},
-	{0x00a75f, {[CaseLower] = 0x00a75f,[CaseTitle] = 0x00a75e,[CaseUpper] = 0x00a75e,[CaseFold] = 0x00a75f}, NULL},
-	{0x00a760, {[CaseLower] = 0x00a761,[CaseTitle] = 0x00a760,[CaseUpper] = 0x00a760,[CaseFold] = 0x00a761}, NULL},
-	{0x00a761, {[CaseLower] = 0x00a761,[CaseTitle] = 0x00a760,[CaseUpper] = 0x00a760,[CaseFold] = 0x00a761}, NULL},
-	{0x00a762, {[CaseLower] = 0x00a763,[CaseTitle] = 0x00a762,[CaseUpper] = 0x00a762,[CaseFold] = 0x00a763}, NULL},
-	{0x00a763, {[CaseLower] = 0x00a763,[CaseTitle] = 0x00a762,[CaseUpper] = 0x00a762,[CaseFold] = 0x00a763}, NULL},
-	{0x00a764, {[CaseLower] = 0x00a765,[CaseTitle] = 0x00a764,[CaseUpper] = 0x00a764,[CaseFold] = 0x00a765}, NULL},
-	{0x00a765, {[CaseLower] = 0x00a765,[CaseTitle] = 0x00a764,[CaseUpper] = 0x00a764,[CaseFold] = 0x00a765}, NULL},
-	{0x00a766, {[CaseLower] = 0x00a767,[CaseTitle] = 0x00a766,[CaseUpper] = 0x00a766,[CaseFold] = 0x00a767}, NULL},
-	{0x00a767, {[CaseLower] = 0x00a767,[CaseTitle] = 0x00a766,[CaseUpper] = 0x00a766,[CaseFold] = 0x00a767}, NULL},
-	{0x00a768, {[CaseLower] = 0x00a769,[CaseTitle] = 0x00a768,[CaseUpper] = 0x00a768,[CaseFold] = 0x00a769}, NULL},
-	{0x00a769, {[CaseLower] = 0x00a769,[CaseTitle] = 0x00a768,[CaseUpper] = 0x00a768,[CaseFold] = 0x00a769}, NULL},
-	{0x00a76a, {[CaseLower] = 0x00a76b,[CaseTitle] = 0x00a76a,[CaseUpper] = 0x00a76a,[CaseFold] = 0x00a76b}, NULL},
-	{0x00a76b, {[CaseLower] = 0x00a76b,[CaseTitle] = 0x00a76a,[CaseUpper] = 0x00a76a,[CaseFold] = 0x00a76b}, NULL},
-	{0x00a76c, {[CaseLower] = 0x00a76d,[CaseTitle] = 0x00a76c,[CaseUpper] = 0x00a76c,[CaseFold] = 0x00a76d}, NULL},
-	{0x00a76d, {[CaseLower] = 0x00a76d,[CaseTitle] = 0x00a76c,[CaseUpper] = 0x00a76c,[CaseFold] = 0x00a76d}, NULL},
-	{0x00a76e, {[CaseLower] = 0x00a76f,[CaseTitle] = 0x00a76e,[CaseUpper] = 0x00a76e,[CaseFold] = 0x00a76f}, NULL},
-	{0x00a76f, {[CaseLower] = 0x00a76f,[CaseTitle] = 0x00a76e,[CaseUpper] = 0x00a76e,[CaseFold] = 0x00a76f}, NULL},
-	{0x00a779, {[CaseLower] = 0x00a77a,[CaseTitle] = 0x00a779,[CaseUpper] = 0x00a779,[CaseFold] = 0x00a77a}, NULL},
-	{0x00a77a, {[CaseLower] = 0x00a77a,[CaseTitle] = 0x00a779,[CaseUpper] = 0x00a779,[CaseFold] = 0x00a77a}, NULL},
-	{0x00a77b, {[CaseLower] = 0x00a77c,[CaseTitle] = 0x00a77b,[CaseUpper] = 0x00a77b,[CaseFold] = 0x00a77c}, NULL},
-	{0x00a77c, {[CaseLower] = 0x00a77c,[CaseTitle] = 0x00a77b,[CaseUpper] = 0x00a77b,[CaseFold] = 0x00a77c}, NULL},
-	{0x00a77d, {[CaseLower] = 0x001d79,[CaseTitle] = 0x00a77d,[CaseUpper] = 0x00a77d,[CaseFold] = 0x001d79}, NULL},
-	{0x00a77e, {[CaseLower] = 0x00a77f,[CaseTitle] = 0x00a77e,[CaseUpper] = 0x00a77e,[CaseFold] = 0x00a77f}, NULL},
-	{0x00a77f, {[CaseLower] = 0x00a77f,[CaseTitle] = 0x00a77e,[CaseUpper] = 0x00a77e,[CaseFold] = 0x00a77f}, NULL},
-	{0x00a780, {[CaseLower] = 0x00a781,[CaseTitle] = 0x00a780,[CaseUpper] = 0x00a780,[CaseFold] = 0x00a781}, NULL},
-	{0x00a781, {[CaseLower] = 0x00a781,[CaseTitle] = 0x00a780,[CaseUpper] = 0x00a780,[CaseFold] = 0x00a781}, NULL},
-	{0x00a782, {[CaseLower] = 0x00a783,[CaseTitle] = 0x00a782,[CaseUpper] = 0x00a782,[CaseFold] = 0x00a783}, NULL},
-	{0x00a783, {[CaseLower] = 0x00a783,[CaseTitle] = 0x00a782,[CaseUpper] = 0x00a782,[CaseFold] = 0x00a783}, NULL},
-	{0x00a784, {[CaseLower] = 0x00a785,[CaseTitle] = 0x00a784,[CaseUpper] = 0x00a784,[CaseFold] = 0x00a785}, NULL},
-	{0x00a785, {[CaseLower] = 0x00a785,[CaseTitle] = 0x00a784,[CaseUpper] = 0x00a784,[CaseFold] = 0x00a785}, NULL},
-	{0x00a786, {[CaseLower] = 0x00a787,[CaseTitle] = 0x00a786,[CaseUpper] = 0x00a786,[CaseFold] = 0x00a787}, NULL},
-	{0x00a787, {[CaseLower] = 0x00a787,[CaseTitle] = 0x00a786,[CaseUpper] = 0x00a786,[CaseFold] = 0x00a787}, NULL},
-	{0x00a78b, {[CaseLower] = 0x00a78c,[CaseTitle] = 0x00a78b,[CaseUpper] = 0x00a78b,[CaseFold] = 0x00a78c}, NULL},
-	{0x00a78c, {[CaseLower] = 0x00a78c,[CaseTitle] = 0x00a78b,[CaseUpper] = 0x00a78b,[CaseFold] = 0x00a78c}, NULL},
-	{0x00a78d, {[CaseLower] = 0x000265,[CaseTitle] = 0x00a78d,[CaseUpper] = 0x00a78d,[CaseFold] = 0x000265}, NULL},
-	{0x00a790, {[CaseLower] = 0x00a791,[CaseTitle] = 0x00a790,[CaseUpper] = 0x00a790,[CaseFold] = 0x00a791}, NULL},
-	{0x00a791, {[CaseLower] = 0x00a791,[CaseTitle] = 0x00a790,[CaseUpper] = 0x00a790,[CaseFold] = 0x00a791}, NULL},
-	{0x00a792, {[CaseLower] = 0x00a793,[CaseTitle] = 0x00a792,[CaseUpper] = 0x00a792,[CaseFold] = 0x00a793}, NULL},
-	{0x00a793, {[CaseLower] = 0x00a793,[CaseTitle] = 0x00a792,[CaseUpper] = 0x00a792,[CaseFold] = 0x00a793}, NULL},
-	{0x00a794, {[CaseLower] = 0x00a794,[CaseTitle] = 0x00a7c4,[CaseUpper] = 0x00a7c4,[CaseFold] = 0x00a794}, NULL},
-	{0x00a796, {[CaseLower] = 0x00a797,[CaseTitle] = 0x00a796,[CaseUpper] = 0x00a796,[CaseFold] = 0x00a797}, NULL},
-	{0x00a797, {[CaseLower] = 0x00a797,[CaseTitle] = 0x00a796,[CaseUpper] = 0x00a796,[CaseFold] = 0x00a797}, NULL},
-	{0x00a798, {[CaseLower] = 0x00a799,[CaseTitle] = 0x00a798,[CaseUpper] = 0x00a798,[CaseFold] = 0x00a799}, NULL},
-	{0x00a799, {[CaseLower] = 0x00a799,[CaseTitle] = 0x00a798,[CaseUpper] = 0x00a798,[CaseFold] = 0x00a799}, NULL},
-	{0x00a79a, {[CaseLower] = 0x00a79b,[CaseTitle] = 0x00a79a,[CaseUpper] = 0x00a79a,[CaseFold] = 0x00a79b}, NULL},
-	{0x00a79b, {[CaseLower] = 0x00a79b,[CaseTitle] = 0x00a79a,[CaseUpper] = 0x00a79a,[CaseFold] = 0x00a79b}, NULL},
-	{0x00a79c, {[CaseLower] = 0x00a79d,[CaseTitle] = 0x00a79c,[CaseUpper] = 0x00a79c,[CaseFold] = 0x00a79d}, NULL},
-	{0x00a79d, {[CaseLower] = 0x00a79d,[CaseTitle] = 0x00a79c,[CaseUpper] = 0x00a79c,[CaseFold] = 0x00a79d}, NULL},
-	{0x00a79e, {[CaseLower] = 0x00a79f,[CaseTitle] = 0x00a79e,[CaseUpper] = 0x00a79e,[CaseFold] = 0x00a79f}, NULL},
-	{0x00a79f, {[CaseLower] = 0x00a79f,[CaseTitle] = 0x00a79e,[CaseUpper] = 0x00a79e,[CaseFold] = 0x00a79f}, NULL},
-	{0x00a7a0, {[CaseLower] = 0x00a7a1,[CaseTitle] = 0x00a7a0,[CaseUpper] = 0x00a7a0,[CaseFold] = 0x00a7a1}, NULL},
-	{0x00a7a1, {[CaseLower] = 0x00a7a1,[CaseTitle] = 0x00a7a0,[CaseUpper] = 0x00a7a0,[CaseFold] = 0x00a7a1}, NULL},
-	{0x00a7a2, {[CaseLower] = 0x00a7a3,[CaseTitle] = 0x00a7a2,[CaseUpper] = 0x00a7a2,[CaseFold] = 0x00a7a3}, NULL},
-	{0x00a7a3, {[CaseLower] = 0x00a7a3,[CaseTitle] = 0x00a7a2,[CaseUpper] = 0x00a7a2,[CaseFold] = 0x00a7a3}, NULL},
-	{0x00a7a4, {[CaseLower] = 0x00a7a5,[CaseTitle] = 0x00a7a4,[CaseUpper] = 0x00a7a4,[CaseFold] = 0x00a7a5}, NULL},
-	{0x00a7a5, {[CaseLower] = 0x00a7a5,[CaseTitle] = 0x00a7a4,[CaseUpper] = 0x00a7a4,[CaseFold] = 0x00a7a5}, NULL},
-	{0x00a7a6, {[CaseLower] = 0x00a7a7,[CaseTitle] = 0x00a7a6,[CaseUpper] = 0x00a7a6,[CaseFold] = 0x00a7a7}, NULL},
-	{0x00a7a7, {[CaseLower] = 0x00a7a7,[CaseTitle] = 0x00a7a6,[CaseUpper] = 0x00a7a6,[CaseFold] = 0x00a7a7}, NULL},
-	{0x00a7a8, {[CaseLower] = 0x00a7a9,[CaseTitle] = 0x00a7a8,[CaseUpper] = 0x00a7a8,[CaseFold] = 0x00a7a9}, NULL},
-	{0x00a7a9, {[CaseLower] = 0x00a7a9,[CaseTitle] = 0x00a7a8,[CaseUpper] = 0x00a7a8,[CaseFold] = 0x00a7a9}, NULL},
-	{0x00a7aa, {[CaseLower] = 0x000266,[CaseTitle] = 0x00a7aa,[CaseUpper] = 0x00a7aa,[CaseFold] = 0x000266}, NULL},
-	{0x00a7ab, {[CaseLower] = 0x00025c,[CaseTitle] = 0x00a7ab,[CaseUpper] = 0x00a7ab,[CaseFold] = 0x00025c}, NULL},
-	{0x00a7ac, {[CaseLower] = 0x000261,[CaseTitle] = 0x00a7ac,[CaseUpper] = 0x00a7ac,[CaseFold] = 0x000261}, NULL},
-	{0x00a7ad, {[CaseLower] = 0x00026c,[CaseTitle] = 0x00a7ad,[CaseUpper] = 0x00a7ad,[CaseFold] = 0x00026c}, NULL},
-	{0x00a7ae, {[CaseLower] = 0x00026a,[CaseTitle] = 0x00a7ae,[CaseUpper] = 0x00a7ae,[CaseFold] = 0x00026a}, NULL},
-	{0x00a7b0, {[CaseLower] = 0x00029e,[CaseTitle] = 0x00a7b0,[CaseUpper] = 0x00a7b0,[CaseFold] = 0x00029e}, NULL},
-	{0x00a7b1, {[CaseLower] = 0x000287,[CaseTitle] = 0x00a7b1,[CaseUpper] = 0x00a7b1,[CaseFold] = 0x000287}, NULL},
-	{0x00a7b2, {[CaseLower] = 0x00029d,[CaseTitle] = 0x00a7b2,[CaseUpper] = 0x00a7b2,[CaseFold] = 0x00029d}, NULL},
-	{0x00a7b3, {[CaseLower] = 0x00ab53,[CaseTitle] = 0x00a7b3,[CaseUpper] = 0x00a7b3,[CaseFold] = 0x00ab53}, NULL},
-	{0x00a7b4, {[CaseLower] = 0x00a7b5,[CaseTitle] = 0x00a7b4,[CaseUpper] = 0x00a7b4,[CaseFold] = 0x00a7b5}, NULL},
-	{0x00a7b5, {[CaseLower] = 0x00a7b5,[CaseTitle] = 0x00a7b4,[CaseUpper] = 0x00a7b4,[CaseFold] = 0x00a7b5}, NULL},
-	{0x00a7b6, {[CaseLower] = 0x00a7b7,[CaseTitle] = 0x00a7b6,[CaseUpper] = 0x00a7b6,[CaseFold] = 0x00a7b7}, NULL},
-	{0x00a7b7, {[CaseLower] = 0x00a7b7,[CaseTitle] = 0x00a7b6,[CaseUpper] = 0x00a7b6,[CaseFold] = 0x00a7b7}, NULL},
-	{0x00a7b8, {[CaseLower] = 0x00a7b9,[CaseTitle] = 0x00a7b8,[CaseUpper] = 0x00a7b8,[CaseFold] = 0x00a7b9}, NULL},
-	{0x00a7b9, {[CaseLower] = 0x00a7b9,[CaseTitle] = 0x00a7b8,[CaseUpper] = 0x00a7b8,[CaseFold] = 0x00a7b9}, NULL},
-	{0x00a7ba, {[CaseLower] = 0x00a7bb,[CaseTitle] = 0x00a7ba,[CaseUpper] = 0x00a7ba,[CaseFold] = 0x00a7bb}, NULL},
-	{0x00a7bb, {[CaseLower] = 0x00a7bb,[CaseTitle] = 0x00a7ba,[CaseUpper] = 0x00a7ba,[CaseFold] = 0x00a7bb}, NULL},
-	{0x00a7bc, {[CaseLower] = 0x00a7bd,[CaseTitle] = 0x00a7bc,[CaseUpper] = 0x00a7bc,[CaseFold] = 0x00a7bd}, NULL},
-	{0x00a7bd, {[CaseLower] = 0x00a7bd,[CaseTitle] = 0x00a7bc,[CaseUpper] = 0x00a7bc,[CaseFold] = 0x00a7bd}, NULL},
-	{0x00a7be, {[CaseLower] = 0x00a7bf,[CaseTitle] = 0x00a7be,[CaseUpper] = 0x00a7be,[CaseFold] = 0x00a7bf}, NULL},
-	{0x00a7bf, {[CaseLower] = 0x00a7bf,[CaseTitle] = 0x00a7be,[CaseUpper] = 0x00a7be,[CaseFold] = 0x00a7bf}, NULL},
-	{0x00a7c0, {[CaseLower] = 0x00a7c1,[CaseTitle] = 0x00a7c0,[CaseUpper] = 0x00a7c0,[CaseFold] = 0x00a7c1}, NULL},
-	{0x00a7c1, {[CaseLower] = 0x00a7c1,[CaseTitle] = 0x00a7c0,[CaseUpper] = 0x00a7c0,[CaseFold] = 0x00a7c1}, NULL},
-	{0x00a7c2, {[CaseLower] = 0x00a7c3,[CaseTitle] = 0x00a7c2,[CaseUpper] = 0x00a7c2,[CaseFold] = 0x00a7c3}, NULL},
-	{0x00a7c3, {[CaseLower] = 0x00a7c3,[CaseTitle] = 0x00a7c2,[CaseUpper] = 0x00a7c2,[CaseFold] = 0x00a7c3}, NULL},
-	{0x00a7c4, {[CaseLower] = 0x00a794,[CaseTitle] = 0x00a7c4,[CaseUpper] = 0x00a7c4,[CaseFold] = 0x00a794}, NULL},
-	{0x00a7c5, {[CaseLower] = 0x000282,[CaseTitle] = 0x00a7c5,[CaseUpper] = 0x00a7c5,[CaseFold] = 0x000282}, NULL},
-	{0x00a7c6, {[CaseLower] = 0x001d8e,[CaseTitle] = 0x00a7c6,[CaseUpper] = 0x00a7c6,[CaseFold] = 0x001d8e}, NULL},
-	{0x00a7c7, {[CaseLower] = 0x00a7c8,[CaseTitle] = 0x00a7c7,[CaseUpper] = 0x00a7c7,[CaseFold] = 0x00a7c8}, NULL},
-	{0x00a7c8, {[CaseLower] = 0x00a7c8,[CaseTitle] = 0x00a7c7,[CaseUpper] = 0x00a7c7,[CaseFold] = 0x00a7c8}, NULL},
-	{0x00a7c9, {[CaseLower] = 0x00a7ca,[CaseTitle] = 0x00a7c9,[CaseUpper] = 0x00a7c9,[CaseFold] = 0x00a7ca}, NULL},
-	{0x00a7ca, {[CaseLower] = 0x00a7ca,[CaseTitle] = 0x00a7c9,[CaseUpper] = 0x00a7c9,[CaseFold] = 0x00a7ca}, NULL},
-	{0x00a7d0, {[CaseLower] = 0x00a7d1,[CaseTitle] = 0x00a7d0,[CaseUpper] = 0x00a7d0,[CaseFold] = 0x00a7d1}, NULL},
-	{0x00a7d1, {[CaseLower] = 0x00a7d1,[CaseTitle] = 0x00a7d0,[CaseUpper] = 0x00a7d0,[CaseFold] = 0x00a7d1}, NULL},
-	{0x00a7d6, {[CaseLower] = 0x00a7d7,[CaseTitle] = 0x00a7d6,[CaseUpper] = 0x00a7d6,[CaseFold] = 0x00a7d7}, NULL},
-	{0x00a7d7, {[CaseLower] = 0x00a7d7,[CaseTitle] = 0x00a7d6,[CaseUpper] = 0x00a7d6,[CaseFold] = 0x00a7d7}, NULL},
-	{0x00a7d8, {[CaseLower] = 0x00a7d9,[CaseTitle] = 0x00a7d8,[CaseUpper] = 0x00a7d8,[CaseFold] = 0x00a7d9}, NULL},
-	{0x00a7d9, {[CaseLower] = 0x00a7d9,[CaseTitle] = 0x00a7d8,[CaseUpper] = 0x00a7d8,[CaseFold] = 0x00a7d9}, NULL},
-	{0x00a7f5, {[CaseLower] = 0x00a7f6,[CaseTitle] = 0x00a7f5,[CaseUpper] = 0x00a7f5,[CaseFold] = 0x00a7f6}, NULL},
-	{0x00a7f6, {[CaseLower] = 0x00a7f6,[CaseTitle] = 0x00a7f5,[CaseUpper] = 0x00a7f5,[CaseFold] = 0x00a7f6}, NULL},
-	{0x00ab53, {[CaseLower] = 0x00ab53,[CaseTitle] = 0x00a7b3,[CaseUpper] = 0x00a7b3,[CaseFold] = 0x00ab53}, NULL},
-	{0x00ab70, {[CaseLower] = 0x00ab70,[CaseTitle] = 0x0013a0,[CaseUpper] = 0x0013a0,[CaseFold] = 0x0013a0}, NULL},
-	{0x00ab71, {[CaseLower] = 0x00ab71,[CaseTitle] = 0x0013a1,[CaseUpper] = 0x0013a1,[CaseFold] = 0x0013a1}, NULL},
-	{0x00ab72, {[CaseLower] = 0x00ab72,[CaseTitle] = 0x0013a2,[CaseUpper] = 0x0013a2,[CaseFold] = 0x0013a2}, NULL},
-	{0x00ab73, {[CaseLower] = 0x00ab73,[CaseTitle] = 0x0013a3,[CaseUpper] = 0x0013a3,[CaseFold] = 0x0013a3}, NULL},
-	{0x00ab74, {[CaseLower] = 0x00ab74,[CaseTitle] = 0x0013a4,[CaseUpper] = 0x0013a4,[CaseFold] = 0x0013a4}, NULL},
-	{0x00ab75, {[CaseLower] = 0x00ab75,[CaseTitle] = 0x0013a5,[CaseUpper] = 0x0013a5,[CaseFold] = 0x0013a5}, NULL},
-	{0x00ab76, {[CaseLower] = 0x00ab76,[CaseTitle] = 0x0013a6,[CaseUpper] = 0x0013a6,[CaseFold] = 0x0013a6}, NULL},
-	{0x00ab77, {[CaseLower] = 0x00ab77,[CaseTitle] = 0x0013a7,[CaseUpper] = 0x0013a7,[CaseFold] = 0x0013a7}, NULL},
-	{0x00ab78, {[CaseLower] = 0x00ab78,[CaseTitle] = 0x0013a8,[CaseUpper] = 0x0013a8,[CaseFold] = 0x0013a8}, NULL},
-	{0x00ab79, {[CaseLower] = 0x00ab79,[CaseTitle] = 0x0013a9,[CaseUpper] = 0x0013a9,[CaseFold] = 0x0013a9}, NULL},
-	{0x00ab7a, {[CaseLower] = 0x00ab7a,[CaseTitle] = 0x0013aa,[CaseUpper] = 0x0013aa,[CaseFold] = 0x0013aa}, NULL},
-	{0x00ab7b, {[CaseLower] = 0x00ab7b,[CaseTitle] = 0x0013ab,[CaseUpper] = 0x0013ab,[CaseFold] = 0x0013ab}, NULL},
-	{0x00ab7c, {[CaseLower] = 0x00ab7c,[CaseTitle] = 0x0013ac,[CaseUpper] = 0x0013ac,[CaseFold] = 0x0013ac}, NULL},
-	{0x00ab7d, {[CaseLower] = 0x00ab7d,[CaseTitle] = 0x0013ad,[CaseUpper] = 0x0013ad,[CaseFold] = 0x0013ad}, NULL},
-	{0x00ab7e, {[CaseLower] = 0x00ab7e,[CaseTitle] = 0x0013ae,[CaseUpper] = 0x0013ae,[CaseFold] = 0x0013ae}, NULL},
-	{0x00ab7f, {[CaseLower] = 0x00ab7f,[CaseTitle] = 0x0013af,[CaseUpper] = 0x0013af,[CaseFold] = 0x0013af}, NULL},
-	{0x00ab80, {[CaseLower] = 0x00ab80,[CaseTitle] = 0x0013b0,[CaseUpper] = 0x0013b0,[CaseFold] = 0x0013b0}, NULL},
-	{0x00ab81, {[CaseLower] = 0x00ab81,[CaseTitle] = 0x0013b1,[CaseUpper] = 0x0013b1,[CaseFold] = 0x0013b1}, NULL},
-	{0x00ab82, {[CaseLower] = 0x00ab82,[CaseTitle] = 0x0013b2,[CaseUpper] = 0x0013b2,[CaseFold] = 0x0013b2}, NULL},
-	{0x00ab83, {[CaseLower] = 0x00ab83,[CaseTitle] = 0x0013b3,[CaseUpper] = 0x0013b3,[CaseFold] = 0x0013b3}, NULL},
-	{0x00ab84, {[CaseLower] = 0x00ab84,[CaseTitle] = 0x0013b4,[CaseUpper] = 0x0013b4,[CaseFold] = 0x0013b4}, NULL},
-	{0x00ab85, {[CaseLower] = 0x00ab85,[CaseTitle] = 0x0013b5,[CaseUpper] = 0x0013b5,[CaseFold] = 0x0013b5}, NULL},
-	{0x00ab86, {[CaseLower] = 0x00ab86,[CaseTitle] = 0x0013b6,[CaseUpper] = 0x0013b6,[CaseFold] = 0x0013b6}, NULL},
-	{0x00ab87, {[CaseLower] = 0x00ab87,[CaseTitle] = 0x0013b7,[CaseUpper] = 0x0013b7,[CaseFold] = 0x0013b7}, NULL},
-	{0x00ab88, {[CaseLower] = 0x00ab88,[CaseTitle] = 0x0013b8,[CaseUpper] = 0x0013b8,[CaseFold] = 0x0013b8}, NULL},
-	{0x00ab89, {[CaseLower] = 0x00ab89,[CaseTitle] = 0x0013b9,[CaseUpper] = 0x0013b9,[CaseFold] = 0x0013b9}, NULL},
-	{0x00ab8a, {[CaseLower] = 0x00ab8a,[CaseTitle] = 0x0013ba,[CaseUpper] = 0x0013ba,[CaseFold] = 0x0013ba}, NULL},
-	{0x00ab8b, {[CaseLower] = 0x00ab8b,[CaseTitle] = 0x0013bb,[CaseUpper] = 0x0013bb,[CaseFold] = 0x0013bb}, NULL},
-	{0x00ab8c, {[CaseLower] = 0x00ab8c,[CaseTitle] = 0x0013bc,[CaseUpper] = 0x0013bc,[CaseFold] = 0x0013bc}, NULL},
-	{0x00ab8d, {[CaseLower] = 0x00ab8d,[CaseTitle] = 0x0013bd,[CaseUpper] = 0x0013bd,[CaseFold] = 0x0013bd}, NULL},
-	{0x00ab8e, {[CaseLower] = 0x00ab8e,[CaseTitle] = 0x0013be,[CaseUpper] = 0x0013be,[CaseFold] = 0x0013be}, NULL},
-	{0x00ab8f, {[CaseLower] = 0x00ab8f,[CaseTitle] = 0x0013bf,[CaseUpper] = 0x0013bf,[CaseFold] = 0x0013bf}, NULL},
-	{0x00ab90, {[CaseLower] = 0x00ab90,[CaseTitle] = 0x0013c0,[CaseUpper] = 0x0013c0,[CaseFold] = 0x0013c0}, NULL},
-	{0x00ab91, {[CaseLower] = 0x00ab91,[CaseTitle] = 0x0013c1,[CaseUpper] = 0x0013c1,[CaseFold] = 0x0013c1}, NULL},
-	{0x00ab92, {[CaseLower] = 0x00ab92,[CaseTitle] = 0x0013c2,[CaseUpper] = 0x0013c2,[CaseFold] = 0x0013c2}, NULL},
-	{0x00ab93, {[CaseLower] = 0x00ab93,[CaseTitle] = 0x0013c3,[CaseUpper] = 0x0013c3,[CaseFold] = 0x0013c3}, NULL},
-	{0x00ab94, {[CaseLower] = 0x00ab94,[CaseTitle] = 0x0013c4,[CaseUpper] = 0x0013c4,[CaseFold] = 0x0013c4}, NULL},
-	{0x00ab95, {[CaseLower] = 0x00ab95,[CaseTitle] = 0x0013c5,[CaseUpper] = 0x0013c5,[CaseFold] = 0x0013c5}, NULL},
-	{0x00ab96, {[CaseLower] = 0x00ab96,[CaseTitle] = 0x0013c6,[CaseUpper] = 0x0013c6,[CaseFold] = 0x0013c6}, NULL},
-	{0x00ab97, {[CaseLower] = 0x00ab97,[CaseTitle] = 0x0013c7,[CaseUpper] = 0x0013c7,[CaseFold] = 0x0013c7}, NULL},
-	{0x00ab98, {[CaseLower] = 0x00ab98,[CaseTitle] = 0x0013c8,[CaseUpper] = 0x0013c8,[CaseFold] = 0x0013c8}, NULL},
-	{0x00ab99, {[CaseLower] = 0x00ab99,[CaseTitle] = 0x0013c9,[CaseUpper] = 0x0013c9,[CaseFold] = 0x0013c9}, NULL},
-	{0x00ab9a, {[CaseLower] = 0x00ab9a,[CaseTitle] = 0x0013ca,[CaseUpper] = 0x0013ca,[CaseFold] = 0x0013ca}, NULL},
-	{0x00ab9b, {[CaseLower] = 0x00ab9b,[CaseTitle] = 0x0013cb,[CaseUpper] = 0x0013cb,[CaseFold] = 0x0013cb}, NULL},
-	{0x00ab9c, {[CaseLower] = 0x00ab9c,[CaseTitle] = 0x0013cc,[CaseUpper] = 0x0013cc,[CaseFold] = 0x0013cc}, NULL},
-	{0x00ab9d, {[CaseLower] = 0x00ab9d,[CaseTitle] = 0x0013cd,[CaseUpper] = 0x0013cd,[CaseFold] = 0x0013cd}, NULL},
-	{0x00ab9e, {[CaseLower] = 0x00ab9e,[CaseTitle] = 0x0013ce,[CaseUpper] = 0x0013ce,[CaseFold] = 0x0013ce}, NULL},
-	{0x00ab9f, {[CaseLower] = 0x00ab9f,[CaseTitle] = 0x0013cf,[CaseUpper] = 0x0013cf,[CaseFold] = 0x0013cf}, NULL},
-	{0x00aba0, {[CaseLower] = 0x00aba0,[CaseTitle] = 0x0013d0,[CaseUpper] = 0x0013d0,[CaseFold] = 0x0013d0}, NULL},
-	{0x00aba1, {[CaseLower] = 0x00aba1,[CaseTitle] = 0x0013d1,[CaseUpper] = 0x0013d1,[CaseFold] = 0x0013d1}, NULL},
-	{0x00aba2, {[CaseLower] = 0x00aba2,[CaseTitle] = 0x0013d2,[CaseUpper] = 0x0013d2,[CaseFold] = 0x0013d2}, NULL},
-	{0x00aba3, {[CaseLower] = 0x00aba3,[CaseTitle] = 0x0013d3,[CaseUpper] = 0x0013d3,[CaseFold] = 0x0013d3}, NULL},
-	{0x00aba4, {[CaseLower] = 0x00aba4,[CaseTitle] = 0x0013d4,[CaseUpper] = 0x0013d4,[CaseFold] = 0x0013d4}, NULL},
-	{0x00aba5, {[CaseLower] = 0x00aba5,[CaseTitle] = 0x0013d5,[CaseUpper] = 0x0013d5,[CaseFold] = 0x0013d5}, NULL},
-	{0x00aba6, {[CaseLower] = 0x00aba6,[CaseTitle] = 0x0013d6,[CaseUpper] = 0x0013d6,[CaseFold] = 0x0013d6}, NULL},
-	{0x00aba7, {[CaseLower] = 0x00aba7,[CaseTitle] = 0x0013d7,[CaseUpper] = 0x0013d7,[CaseFold] = 0x0013d7}, NULL},
-	{0x00aba8, {[CaseLower] = 0x00aba8,[CaseTitle] = 0x0013d8,[CaseUpper] = 0x0013d8,[CaseFold] = 0x0013d8}, NULL},
-	{0x00aba9, {[CaseLower] = 0x00aba9,[CaseTitle] = 0x0013d9,[CaseUpper] = 0x0013d9,[CaseFold] = 0x0013d9}, NULL},
-	{0x00abaa, {[CaseLower] = 0x00abaa,[CaseTitle] = 0x0013da,[CaseUpper] = 0x0013da,[CaseFold] = 0x0013da}, NULL},
-	{0x00abab, {[CaseLower] = 0x00abab,[CaseTitle] = 0x0013db,[CaseUpper] = 0x0013db,[CaseFold] = 0x0013db}, NULL},
-	{0x00abac, {[CaseLower] = 0x00abac,[CaseTitle] = 0x0013dc,[CaseUpper] = 0x0013dc,[CaseFold] = 0x0013dc}, NULL},
-	{0x00abad, {[CaseLower] = 0x00abad,[CaseTitle] = 0x0013dd,[CaseUpper] = 0x0013dd,[CaseFold] = 0x0013dd}, NULL},
-	{0x00abae, {[CaseLower] = 0x00abae,[CaseTitle] = 0x0013de,[CaseUpper] = 0x0013de,[CaseFold] = 0x0013de}, NULL},
-	{0x00abaf, {[CaseLower] = 0x00abaf,[CaseTitle] = 0x0013df,[CaseUpper] = 0x0013df,[CaseFold] = 0x0013df}, NULL},
-	{0x00abb0, {[CaseLower] = 0x00abb0,[CaseTitle] = 0x0013e0,[CaseUpper] = 0x0013e0,[CaseFold] = 0x0013e0}, NULL},
-	{0x00abb1, {[CaseLower] = 0x00abb1,[CaseTitle] = 0x0013e1,[CaseUpper] = 0x0013e1,[CaseFold] = 0x0013e1}, NULL},
-	{0x00abb2, {[CaseLower] = 0x00abb2,[CaseTitle] = 0x0013e2,[CaseUpper] = 0x0013e2,[CaseFold] = 0x0013e2}, NULL},
-	{0x00abb3, {[CaseLower] = 0x00abb3,[CaseTitle] = 0x0013e3,[CaseUpper] = 0x0013e3,[CaseFold] = 0x0013e3}, NULL},
-	{0x00abb4, {[CaseLower] = 0x00abb4,[CaseTitle] = 0x0013e4,[CaseUpper] = 0x0013e4,[CaseFold] = 0x0013e4}, NULL},
-	{0x00abb5, {[CaseLower] = 0x00abb5,[CaseTitle] = 0x0013e5,[CaseUpper] = 0x0013e5,[CaseFold] = 0x0013e5}, NULL},
-	{0x00abb6, {[CaseLower] = 0x00abb6,[CaseTitle] = 0x0013e6,[CaseUpper] = 0x0013e6,[CaseFold] = 0x0013e6}, NULL},
-	{0x00abb7, {[CaseLower] = 0x00abb7,[CaseTitle] = 0x0013e7,[CaseUpper] = 0x0013e7,[CaseFold] = 0x0013e7}, NULL},
-	{0x00abb8, {[CaseLower] = 0x00abb8,[CaseTitle] = 0x0013e8,[CaseUpper] = 0x0013e8,[CaseFold] = 0x0013e8}, NULL},
-	{0x00abb9, {[CaseLower] = 0x00abb9,[CaseTitle] = 0x0013e9,[CaseUpper] = 0x0013e9,[CaseFold] = 0x0013e9}, NULL},
-	{0x00abba, {[CaseLower] = 0x00abba,[CaseTitle] = 0x0013ea,[CaseUpper] = 0x0013ea,[CaseFold] = 0x0013ea}, NULL},
-	{0x00abbb, {[CaseLower] = 0x00abbb,[CaseTitle] = 0x0013eb,[CaseUpper] = 0x0013eb,[CaseFold] = 0x0013eb}, NULL},
-	{0x00abbc, {[CaseLower] = 0x00abbc,[CaseTitle] = 0x0013ec,[CaseUpper] = 0x0013ec,[CaseFold] = 0x0013ec}, NULL},
-	{0x00abbd, {[CaseLower] = 0x00abbd,[CaseTitle] = 0x0013ed,[CaseUpper] = 0x0013ed,[CaseFold] = 0x0013ed}, NULL},
-	{0x00abbe, {[CaseLower] = 0x00abbe,[CaseTitle] = 0x0013ee,[CaseUpper] = 0x0013ee,[CaseFold] = 0x0013ee}, NULL},
-	{0x00abbf, {[CaseLower] = 0x00abbf,[CaseTitle] = 0x0013ef,[CaseUpper] = 0x0013ef,[CaseFold] = 0x0013ef}, NULL},
-	{0x00fb00, {[CaseLower] = 0x00fb00,[CaseTitle] = 0x00fb00,[CaseUpper] = 0x00fb00,[CaseFold] = 0x00fb00}, &special_case[93]},
-	{0x00fb01, {[CaseLower] = 0x00fb01,[CaseTitle] = 0x00fb01,[CaseUpper] = 0x00fb01,[CaseFold] = 0x00fb01}, &special_case[94]},
-	{0x00fb02, {[CaseLower] = 0x00fb02,[CaseTitle] = 0x00fb02,[CaseUpper] = 0x00fb02,[CaseFold] = 0x00fb02}, &special_case[95]},
-	{0x00fb03, {[CaseLower] = 0x00fb03,[CaseTitle] = 0x00fb03,[CaseUpper] = 0x00fb03,[CaseFold] = 0x00fb03}, &special_case[96]},
-	{0x00fb04, {[CaseLower] = 0x00fb04,[CaseTitle] = 0x00fb04,[CaseUpper] = 0x00fb04,[CaseFold] = 0x00fb04}, &special_case[97]},
-	{0x00fb05, {[CaseLower] = 0x00fb05,[CaseTitle] = 0x00fb05,[CaseUpper] = 0x00fb05,[CaseFold] = 0x00fb06}, &special_case[98]},
-	{0x00fb06, {[CaseLower] = 0x00fb06,[CaseTitle] = 0x00fb06,[CaseUpper] = 0x00fb06,[CaseFold] = 0x00fb06}, &special_case[99]},
-	{0x00fb13, {[CaseLower] = 0x00fb13,[CaseTitle] = 0x00fb13,[CaseUpper] = 0x00fb13,[CaseFold] = 0x00fb13}, &special_case[100]},
-	{0x00fb14, {[CaseLower] = 0x00fb14,[CaseTitle] = 0x00fb14,[CaseUpper] = 0x00fb14,[CaseFold] = 0x00fb14}, &special_case[101]},
-	{0x00fb15, {[CaseLower] = 0x00fb15,[CaseTitle] = 0x00fb15,[CaseUpper] = 0x00fb15,[CaseFold] = 0x00fb15}, &special_case[102]},
-	{0x00fb16, {[CaseLower] = 0x00fb16,[CaseTitle] = 0x00fb16,[CaseUpper] = 0x00fb16,[CaseFold] = 0x00fb16}, &special_case[103]},
-	{0x00fb17, {[CaseLower] = 0x00fb17,[CaseTitle] = 0x00fb17,[CaseUpper] = 0x00fb17,[CaseFold] = 0x00fb17}, &special_case[104]},
-	{0x00ff21, {[CaseLower] = 0x00ff41,[CaseTitle] = 0x00ff21,[CaseUpper] = 0x00ff21,[CaseFold] = 0x00ff41}, NULL},
-	{0x00ff22, {[CaseLower] = 0x00ff42,[CaseTitle] = 0x00ff22,[CaseUpper] = 0x00ff22,[CaseFold] = 0x00ff42}, NULL},
-	{0x00ff23, {[CaseLower] = 0x00ff43,[CaseTitle] = 0x00ff23,[CaseUpper] = 0x00ff23,[CaseFold] = 0x00ff43}, NULL},
-	{0x00ff24, {[CaseLower] = 0x00ff44,[CaseTitle] = 0x00ff24,[CaseUpper] = 0x00ff24,[CaseFold] = 0x00ff44}, NULL},
-	{0x00ff25, {[CaseLower] = 0x00ff45,[CaseTitle] = 0x00ff25,[CaseUpper] = 0x00ff25,[CaseFold] = 0x00ff45}, NULL},
-	{0x00ff26, {[CaseLower] = 0x00ff46,[CaseTitle] = 0x00ff26,[CaseUpper] = 0x00ff26,[CaseFold] = 0x00ff46}, NULL},
-	{0x00ff27, {[CaseLower] = 0x00ff47,[CaseTitle] = 0x00ff27,[CaseUpper] = 0x00ff27,[CaseFold] = 0x00ff47}, NULL},
-	{0x00ff28, {[CaseLower] = 0x00ff48,[CaseTitle] = 0x00ff28,[CaseUpper] = 0x00ff28,[CaseFold] = 0x00ff48}, NULL},
-	{0x00ff29, {[CaseLower] = 0x00ff49,[CaseTitle] = 0x00ff29,[CaseUpper] = 0x00ff29,[CaseFold] = 0x00ff49}, NULL},
-	{0x00ff2a, {[CaseLower] = 0x00ff4a,[CaseTitle] = 0x00ff2a,[CaseUpper] = 0x00ff2a,[CaseFold] = 0x00ff4a}, NULL},
-	{0x00ff2b, {[CaseLower] = 0x00ff4b,[CaseTitle] = 0x00ff2b,[CaseUpper] = 0x00ff2b,[CaseFold] = 0x00ff4b}, NULL},
-	{0x00ff2c, {[CaseLower] = 0x00ff4c,[CaseTitle] = 0x00ff2c,[CaseUpper] = 0x00ff2c,[CaseFold] = 0x00ff4c}, NULL},
-	{0x00ff2d, {[CaseLower] = 0x00ff4d,[CaseTitle] = 0x00ff2d,[CaseUpper] = 0x00ff2d,[CaseFold] = 0x00ff4d}, NULL},
-	{0x00ff2e, {[CaseLower] = 0x00ff4e,[CaseTitle] = 0x00ff2e,[CaseUpper] = 0x00ff2e,[CaseFold] = 0x00ff4e}, NULL},
-	{0x00ff2f, {[CaseLower] = 0x00ff4f,[CaseTitle] = 0x00ff2f,[CaseUpper] = 0x00ff2f,[CaseFold] = 0x00ff4f}, NULL},
-	{0x00ff30, {[CaseLower] = 0x00ff50,[CaseTitle] = 0x00ff30,[CaseUpper] = 0x00ff30,[CaseFold] = 0x00ff50}, NULL},
-	{0x00ff31, {[CaseLower] = 0x00ff51,[CaseTitle] = 0x00ff31,[CaseUpper] = 0x00ff31,[CaseFold] = 0x00ff51}, NULL},
-	{0x00ff32, {[CaseLower] = 0x00ff52,[CaseTitle] = 0x00ff32,[CaseUpper] = 0x00ff32,[CaseFold] = 0x00ff52}, NULL},
-	{0x00ff33, {[CaseLower] = 0x00ff53,[CaseTitle] = 0x00ff33,[CaseUpper] = 0x00ff33,[CaseFold] = 0x00ff53}, NULL},
-	{0x00ff34, {[CaseLower] = 0x00ff54,[CaseTitle] = 0x00ff34,[CaseUpper] = 0x00ff34,[CaseFold] = 0x00ff54}, NULL},
-	{0x00ff35, {[CaseLower] = 0x00ff55,[CaseTitle] = 0x00ff35,[CaseUpper] = 0x00ff35,[CaseFold] = 0x00ff55}, NULL},
-	{0x00ff36, {[CaseLower] = 0x00ff56,[CaseTitle] = 0x00ff36,[CaseUpper] = 0x00ff36,[CaseFold] = 0x00ff56}, NULL},
-	{0x00ff37, {[CaseLower] = 0x00ff57,[CaseTitle] = 0x00ff37,[CaseUpper] = 0x00ff37,[CaseFold] = 0x00ff57}, NULL},
-	{0x00ff38, {[CaseLower] = 0x00ff58,[CaseTitle] = 0x00ff38,[CaseUpper] = 0x00ff38,[CaseFold] = 0x00ff58}, NULL},
-	{0x00ff39, {[CaseLower] = 0x00ff59,[CaseTitle] = 0x00ff39,[CaseUpper] = 0x00ff39,[CaseFold] = 0x00ff59}, NULL},
-	{0x00ff3a, {[CaseLower] = 0x00ff5a,[CaseTitle] = 0x00ff3a,[CaseUpper] = 0x00ff3a,[CaseFold] = 0x00ff5a}, NULL},
-	{0x00ff41, {[CaseLower] = 0x00ff41,[CaseTitle] = 0x00ff21,[CaseUpper] = 0x00ff21,[CaseFold] = 0x00ff41}, NULL},
-	{0x00ff42, {[CaseLower] = 0x00ff42,[CaseTitle] = 0x00ff22,[CaseUpper] = 0x00ff22,[CaseFold] = 0x00ff42}, NULL},
-	{0x00ff43, {[CaseLower] = 0x00ff43,[CaseTitle] = 0x00ff23,[CaseUpper] = 0x00ff23,[CaseFold] = 0x00ff43}, NULL},
-	{0x00ff44, {[CaseLower] = 0x00ff44,[CaseTitle] = 0x00ff24,[CaseUpper] = 0x00ff24,[CaseFold] = 0x00ff44}, NULL},
-	{0x00ff45, {[CaseLower] = 0x00ff45,[CaseTitle] = 0x00ff25,[CaseUpper] = 0x00ff25,[CaseFold] = 0x00ff45}, NULL},
-	{0x00ff46, {[CaseLower] = 0x00ff46,[CaseTitle] = 0x00ff26,[CaseUpper] = 0x00ff26,[CaseFold] = 0x00ff46}, NULL},
-	{0x00ff47, {[CaseLower] = 0x00ff47,[CaseTitle] = 0x00ff27,[CaseUpper] = 0x00ff27,[CaseFold] = 0x00ff47}, NULL},
-	{0x00ff48, {[CaseLower] = 0x00ff48,[CaseTitle] = 0x00ff28,[CaseUpper] = 0x00ff28,[CaseFold] = 0x00ff48}, NULL},
-	{0x00ff49, {[CaseLower] = 0x00ff49,[CaseTitle] = 0x00ff29,[CaseUpper] = 0x00ff29,[CaseFold] = 0x00ff49}, NULL},
-	{0x00ff4a, {[CaseLower] = 0x00ff4a,[CaseTitle] = 0x00ff2a,[CaseUpper] = 0x00ff2a,[CaseFold] = 0x00ff4a}, NULL},
-	{0x00ff4b, {[CaseLower] = 0x00ff4b,[CaseTitle] = 0x00ff2b,[CaseUpper] = 0x00ff2b,[CaseFold] = 0x00ff4b}, NULL},
-	{0x00ff4c, {[CaseLower] = 0x00ff4c,[CaseTitle] = 0x00ff2c,[CaseUpper] = 0x00ff2c,[CaseFold] = 0x00ff4c}, NULL},
-	{0x00ff4d, {[CaseLower] = 0x00ff4d,[CaseTitle] = 0x00ff2d,[CaseUpper] = 0x00ff2d,[CaseFold] = 0x00ff4d}, NULL},
-	{0x00ff4e, {[CaseLower] = 0x00ff4e,[CaseTitle] = 0x00ff2e,[CaseUpper] = 0x00ff2e,[CaseFold] = 0x00ff4e}, NULL},
-	{0x00ff4f, {[CaseLower] = 0x00ff4f,[CaseTitle] = 0x00ff2f,[CaseUpper] = 0x00ff2f,[CaseFold] = 0x00ff4f}, NULL},
-	{0x00ff50, {[CaseLower] = 0x00ff50,[CaseTitle] = 0x00ff30,[CaseUpper] = 0x00ff30,[CaseFold] = 0x00ff50}, NULL},
-	{0x00ff51, {[CaseLower] = 0x00ff51,[CaseTitle] = 0x00ff31,[CaseUpper] = 0x00ff31,[CaseFold] = 0x00ff51}, NULL},
-	{0x00ff52, {[CaseLower] = 0x00ff52,[CaseTitle] = 0x00ff32,[CaseUpper] = 0x00ff32,[CaseFold] = 0x00ff52}, NULL},
-	{0x00ff53, {[CaseLower] = 0x00ff53,[CaseTitle] = 0x00ff33,[CaseUpper] = 0x00ff33,[CaseFold] = 0x00ff53}, NULL},
-	{0x00ff54, {[CaseLower] = 0x00ff54,[CaseTitle] = 0x00ff34,[CaseUpper] = 0x00ff34,[CaseFold] = 0x00ff54}, NULL},
-	{0x00ff55, {[CaseLower] = 0x00ff55,[CaseTitle] = 0x00ff35,[CaseUpper] = 0x00ff35,[CaseFold] = 0x00ff55}, NULL},
-	{0x00ff56, {[CaseLower] = 0x00ff56,[CaseTitle] = 0x00ff36,[CaseUpper] = 0x00ff36,[CaseFold] = 0x00ff56}, NULL},
-	{0x00ff57, {[CaseLower] = 0x00ff57,[CaseTitle] = 0x00ff37,[CaseUpper] = 0x00ff37,[CaseFold] = 0x00ff57}, NULL},
-	{0x00ff58, {[CaseLower] = 0x00ff58,[CaseTitle] = 0x00ff38,[CaseUpper] = 0x00ff38,[CaseFold] = 0x00ff58}, NULL},
-	{0x00ff59, {[CaseLower] = 0x00ff59,[CaseTitle] = 0x00ff39,[CaseUpper] = 0x00ff39,[CaseFold] = 0x00ff59}, NULL},
-	{0x00ff5a, {[CaseLower] = 0x00ff5a,[CaseTitle] = 0x00ff3a,[CaseUpper] = 0x00ff3a,[CaseFold] = 0x00ff5a}, NULL},
-	{0x010400, {[CaseLower] = 0x010428,[CaseTitle] = 0x010400,[CaseUpper] = 0x010400,[CaseFold] = 0x010428}, NULL},
-	{0x010401, {[CaseLower] = 0x010429,[CaseTitle] = 0x010401,[CaseUpper] = 0x010401,[CaseFold] = 0x010429}, NULL},
-	{0x010402, {[CaseLower] = 0x01042a,[CaseTitle] = 0x010402,[CaseUpper] = 0x010402,[CaseFold] = 0x01042a}, NULL},
-	{0x010403, {[CaseLower] = 0x01042b,[CaseTitle] = 0x010403,[CaseUpper] = 0x010403,[CaseFold] = 0x01042b}, NULL},
-	{0x010404, {[CaseLower] = 0x01042c,[CaseTitle] = 0x010404,[CaseUpper] = 0x010404,[CaseFold] = 0x01042c}, NULL},
-	{0x010405, {[CaseLower] = 0x01042d,[CaseTitle] = 0x010405,[CaseUpper] = 0x010405,[CaseFold] = 0x01042d}, NULL},
-	{0x010406, {[CaseLower] = 0x01042e,[CaseTitle] = 0x010406,[CaseUpper] = 0x010406,[CaseFold] = 0x01042e}, NULL},
-	{0x010407, {[CaseLower] = 0x01042f,[CaseTitle] = 0x010407,[CaseUpper] = 0x010407,[CaseFold] = 0x01042f}, NULL},
-	{0x010408, {[CaseLower] = 0x010430,[CaseTitle] = 0x010408,[CaseUpper] = 0x010408,[CaseFold] = 0x010430}, NULL},
-	{0x010409, {[CaseLower] = 0x010431,[CaseTitle] = 0x010409,[CaseUpper] = 0x010409,[CaseFold] = 0x010431}, NULL},
-	{0x01040a, {[CaseLower] = 0x010432,[CaseTitle] = 0x01040a,[CaseUpper] = 0x01040a,[CaseFold] = 0x010432}, NULL},
-	{0x01040b, {[CaseLower] = 0x010433,[CaseTitle] = 0x01040b,[CaseUpper] = 0x01040b,[CaseFold] = 0x010433}, NULL},
-	{0x01040c, {[CaseLower] = 0x010434,[CaseTitle] = 0x01040c,[CaseUpper] = 0x01040c,[CaseFold] = 0x010434}, NULL},
-	{0x01040d, {[CaseLower] = 0x010435,[CaseTitle] = 0x01040d,[CaseUpper] = 0x01040d,[CaseFold] = 0x010435}, NULL},
-	{0x01040e, {[CaseLower] = 0x010436,[CaseTitle] = 0x01040e,[CaseUpper] = 0x01040e,[CaseFold] = 0x010436}, NULL},
-	{0x01040f, {[CaseLower] = 0x010437,[CaseTitle] = 0x01040f,[CaseUpper] = 0x01040f,[CaseFold] = 0x010437}, NULL},
-	{0x010410, {[CaseLower] = 0x010438,[CaseTitle] = 0x010410,[CaseUpper] = 0x010410,[CaseFold] = 0x010438}, NULL},
-	{0x010411, {[CaseLower] = 0x010439,[CaseTitle] = 0x010411,[CaseUpper] = 0x010411,[CaseFold] = 0x010439}, NULL},
-	{0x010412, {[CaseLower] = 0x01043a,[CaseTitle] = 0x010412,[CaseUpper] = 0x010412,[CaseFold] = 0x01043a}, NULL},
-	{0x010413, {[CaseLower] = 0x01043b,[CaseTitle] = 0x010413,[CaseUpper] = 0x010413,[CaseFold] = 0x01043b}, NULL},
-	{0x010414, {[CaseLower] = 0x01043c,[CaseTitle] = 0x010414,[CaseUpper] = 0x010414,[CaseFold] = 0x01043c}, NULL},
-	{0x010415, {[CaseLower] = 0x01043d,[CaseTitle] = 0x010415,[CaseUpper] = 0x010415,[CaseFold] = 0x01043d}, NULL},
-	{0x010416, {[CaseLower] = 0x01043e,[CaseTitle] = 0x010416,[CaseUpper] = 0x010416,[CaseFold] = 0x01043e}, NULL},
-	{0x010417, {[CaseLower] = 0x01043f,[CaseTitle] = 0x010417,[CaseUpper] = 0x010417,[CaseFold] = 0x01043f}, NULL},
-	{0x010418, {[CaseLower] = 0x010440,[CaseTitle] = 0x010418,[CaseUpper] = 0x010418,[CaseFold] = 0x010440}, NULL},
-	{0x010419, {[CaseLower] = 0x010441,[CaseTitle] = 0x010419,[CaseUpper] = 0x010419,[CaseFold] = 0x010441}, NULL},
-	{0x01041a, {[CaseLower] = 0x010442,[CaseTitle] = 0x01041a,[CaseUpper] = 0x01041a,[CaseFold] = 0x010442}, NULL},
-	{0x01041b, {[CaseLower] = 0x010443,[CaseTitle] = 0x01041b,[CaseUpper] = 0x01041b,[CaseFold] = 0x010443}, NULL},
-	{0x01041c, {[CaseLower] = 0x010444,[CaseTitle] = 0x01041c,[CaseUpper] = 0x01041c,[CaseFold] = 0x010444}, NULL},
-	{0x01041d, {[CaseLower] = 0x010445,[CaseTitle] = 0x01041d,[CaseUpper] = 0x01041d,[CaseFold] = 0x010445}, NULL},
-	{0x01041e, {[CaseLower] = 0x010446,[CaseTitle] = 0x01041e,[CaseUpper] = 0x01041e,[CaseFold] = 0x010446}, NULL},
-	{0x01041f, {[CaseLower] = 0x010447,[CaseTitle] = 0x01041f,[CaseUpper] = 0x01041f,[CaseFold] = 0x010447}, NULL},
-	{0x010420, {[CaseLower] = 0x010448,[CaseTitle] = 0x010420,[CaseUpper] = 0x010420,[CaseFold] = 0x010448}, NULL},
-	{0x010421, {[CaseLower] = 0x010449,[CaseTitle] = 0x010421,[CaseUpper] = 0x010421,[CaseFold] = 0x010449}, NULL},
-	{0x010422, {[CaseLower] = 0x01044a,[CaseTitle] = 0x010422,[CaseUpper] = 0x010422,[CaseFold] = 0x01044a}, NULL},
-	{0x010423, {[CaseLower] = 0x01044b,[CaseTitle] = 0x010423,[CaseUpper] = 0x010423,[CaseFold] = 0x01044b}, NULL},
-	{0x010424, {[CaseLower] = 0x01044c,[CaseTitle] = 0x010424,[CaseUpper] = 0x010424,[CaseFold] = 0x01044c}, NULL},
-	{0x010425, {[CaseLower] = 0x01044d,[CaseTitle] = 0x010425,[CaseUpper] = 0x010425,[CaseFold] = 0x01044d}, NULL},
-	{0x010426, {[CaseLower] = 0x01044e,[CaseTitle] = 0x010426,[CaseUpper] = 0x010426,[CaseFold] = 0x01044e}, NULL},
-	{0x010427, {[CaseLower] = 0x01044f,[CaseTitle] = 0x010427,[CaseUpper] = 0x010427,[CaseFold] = 0x01044f}, NULL},
-	{0x010428, {[CaseLower] = 0x010428,[CaseTitle] = 0x010400,[CaseUpper] = 0x010400,[CaseFold] = 0x010428}, NULL},
-	{0x010429, {[CaseLower] = 0x010429,[CaseTitle] = 0x010401,[CaseUpper] = 0x010401,[CaseFold] = 0x010429}, NULL},
-	{0x01042a, {[CaseLower] = 0x01042a,[CaseTitle] = 0x010402,[CaseUpper] = 0x010402,[CaseFold] = 0x01042a}, NULL},
-	{0x01042b, {[CaseLower] = 0x01042b,[CaseTitle] = 0x010403,[CaseUpper] = 0x010403,[CaseFold] = 0x01042b}, NULL},
-	{0x01042c, {[CaseLower] = 0x01042c,[CaseTitle] = 0x010404,[CaseUpper] = 0x010404,[CaseFold] = 0x01042c}, NULL},
-	{0x01042d, {[CaseLower] = 0x01042d,[CaseTitle] = 0x010405,[CaseUpper] = 0x010405,[CaseFold] = 0x01042d}, NULL},
-	{0x01042e, {[CaseLower] = 0x01042e,[CaseTitle] = 0x010406,[CaseUpper] = 0x010406,[CaseFold] = 0x01042e}, NULL},
-	{0x01042f, {[CaseLower] = 0x01042f,[CaseTitle] = 0x010407,[CaseUpper] = 0x010407,[CaseFold] = 0x01042f}, NULL},
-	{0x010430, {[CaseLower] = 0x010430,[CaseTitle] = 0x010408,[CaseUpper] = 0x010408,[CaseFold] = 0x010430}, NULL},
-	{0x010431, {[CaseLower] = 0x010431,[CaseTitle] = 0x010409,[CaseUpper] = 0x010409,[CaseFold] = 0x010431}, NULL},
-	{0x010432, {[CaseLower] = 0x010432,[CaseTitle] = 0x01040a,[CaseUpper] = 0x01040a,[CaseFold] = 0x010432}, NULL},
-	{0x010433, {[CaseLower] = 0x010433,[CaseTitle] = 0x01040b,[CaseUpper] = 0x01040b,[CaseFold] = 0x010433}, NULL},
-	{0x010434, {[CaseLower] = 0x010434,[CaseTitle] = 0x01040c,[CaseUpper] = 0x01040c,[CaseFold] = 0x010434}, NULL},
-	{0x010435, {[CaseLower] = 0x010435,[CaseTitle] = 0x01040d,[CaseUpper] = 0x01040d,[CaseFold] = 0x010435}, NULL},
-	{0x010436, {[CaseLower] = 0x010436,[CaseTitle] = 0x01040e,[CaseUpper] = 0x01040e,[CaseFold] = 0x010436}, NULL},
-	{0x010437, {[CaseLower] = 0x010437,[CaseTitle] = 0x01040f,[CaseUpper] = 0x01040f,[CaseFold] = 0x010437}, NULL},
-	{0x010438, {[CaseLower] = 0x010438,[CaseTitle] = 0x010410,[CaseUpper] = 0x010410,[CaseFold] = 0x010438}, NULL},
-	{0x010439, {[CaseLower] = 0x010439,[CaseTitle] = 0x010411,[CaseUpper] = 0x010411,[CaseFold] = 0x010439}, NULL},
-	{0x01043a, {[CaseLower] = 0x01043a,[CaseTitle] = 0x010412,[CaseUpper] = 0x010412,[CaseFold] = 0x01043a}, NULL},
-	{0x01043b, {[CaseLower] = 0x01043b,[CaseTitle] = 0x010413,[CaseUpper] = 0x010413,[CaseFold] = 0x01043b}, NULL},
-	{0x01043c, {[CaseLower] = 0x01043c,[CaseTitle] = 0x010414,[CaseUpper] = 0x010414,[CaseFold] = 0x01043c}, NULL},
-	{0x01043d, {[CaseLower] = 0x01043d,[CaseTitle] = 0x010415,[CaseUpper] = 0x010415,[CaseFold] = 0x01043d}, NULL},
-	{0x01043e, {[CaseLower] = 0x01043e,[CaseTitle] = 0x010416,[CaseUpper] = 0x010416,[CaseFold] = 0x01043e}, NULL},
-	{0x01043f, {[CaseLower] = 0x01043f,[CaseTitle] = 0x010417,[CaseUpper] = 0x010417,[CaseFold] = 0x01043f}, NULL},
-	{0x010440, {[CaseLower] = 0x010440,[CaseTitle] = 0x010418,[CaseUpper] = 0x010418,[CaseFold] = 0x010440}, NULL},
-	{0x010441, {[CaseLower] = 0x010441,[CaseTitle] = 0x010419,[CaseUpper] = 0x010419,[CaseFold] = 0x010441}, NULL},
-	{0x010442, {[CaseLower] = 0x010442,[CaseTitle] = 0x01041a,[CaseUpper] = 0x01041a,[CaseFold] = 0x010442}, NULL},
-	{0x010443, {[CaseLower] = 0x010443,[CaseTitle] = 0x01041b,[CaseUpper] = 0x01041b,[CaseFold] = 0x010443}, NULL},
-	{0x010444, {[CaseLower] = 0x010444,[CaseTitle] = 0x01041c,[CaseUpper] = 0x01041c,[CaseFold] = 0x010444}, NULL},
-	{0x010445, {[CaseLower] = 0x010445,[CaseTitle] = 0x01041d,[CaseUpper] = 0x01041d,[CaseFold] = 0x010445}, NULL},
-	{0x010446, {[CaseLower] = 0x010446,[CaseTitle] = 0x01041e,[CaseUpper] = 0x01041e,[CaseFold] = 0x010446}, NULL},
-	{0x010447, {[CaseLower] = 0x010447,[CaseTitle] = 0x01041f,[CaseUpper] = 0x01041f,[CaseFold] = 0x010447}, NULL},
-	{0x010448, {[CaseLower] = 0x010448,[CaseTitle] = 0x010420,[CaseUpper] = 0x010420,[CaseFold] = 0x010448}, NULL},
-	{0x010449, {[CaseLower] = 0x010449,[CaseTitle] = 0x010421,[CaseUpper] = 0x010421,[CaseFold] = 0x010449}, NULL},
-	{0x01044a, {[CaseLower] = 0x01044a,[CaseTitle] = 0x010422,[CaseUpper] = 0x010422,[CaseFold] = 0x01044a}, NULL},
-	{0x01044b, {[CaseLower] = 0x01044b,[CaseTitle] = 0x010423,[CaseUpper] = 0x010423,[CaseFold] = 0x01044b}, NULL},
-	{0x01044c, {[CaseLower] = 0x01044c,[CaseTitle] = 0x010424,[CaseUpper] = 0x010424,[CaseFold] = 0x01044c}, NULL},
-	{0x01044d, {[CaseLower] = 0x01044d,[CaseTitle] = 0x010425,[CaseUpper] = 0x010425,[CaseFold] = 0x01044d}, NULL},
-	{0x01044e, {[CaseLower] = 0x01044e,[CaseTitle] = 0x010426,[CaseUpper] = 0x010426,[CaseFold] = 0x01044e}, NULL},
-	{0x01044f, {[CaseLower] = 0x01044f,[CaseTitle] = 0x010427,[CaseUpper] = 0x010427,[CaseFold] = 0x01044f}, NULL},
-	{0x0104b0, {[CaseLower] = 0x0104d8,[CaseTitle] = 0x0104b0,[CaseUpper] = 0x0104b0,[CaseFold] = 0x0104d8}, NULL},
-	{0x0104b1, {[CaseLower] = 0x0104d9,[CaseTitle] = 0x0104b1,[CaseUpper] = 0x0104b1,[CaseFold] = 0x0104d9}, NULL},
-	{0x0104b2, {[CaseLower] = 0x0104da,[CaseTitle] = 0x0104b2,[CaseUpper] = 0x0104b2,[CaseFold] = 0x0104da}, NULL},
-	{0x0104b3, {[CaseLower] = 0x0104db,[CaseTitle] = 0x0104b3,[CaseUpper] = 0x0104b3,[CaseFold] = 0x0104db}, NULL},
-	{0x0104b4, {[CaseLower] = 0x0104dc,[CaseTitle] = 0x0104b4,[CaseUpper] = 0x0104b4,[CaseFold] = 0x0104dc}, NULL},
-	{0x0104b5, {[CaseLower] = 0x0104dd,[CaseTitle] = 0x0104b5,[CaseUpper] = 0x0104b5,[CaseFold] = 0x0104dd}, NULL},
-	{0x0104b6, {[CaseLower] = 0x0104de,[CaseTitle] = 0x0104b6,[CaseUpper] = 0x0104b6,[CaseFold] = 0x0104de}, NULL},
-	{0x0104b7, {[CaseLower] = 0x0104df,[CaseTitle] = 0x0104b7,[CaseUpper] = 0x0104b7,[CaseFold] = 0x0104df}, NULL},
-	{0x0104b8, {[CaseLower] = 0x0104e0,[CaseTitle] = 0x0104b8,[CaseUpper] = 0x0104b8,[CaseFold] = 0x0104e0}, NULL},
-	{0x0104b9, {[CaseLower] = 0x0104e1,[CaseTitle] = 0x0104b9,[CaseUpper] = 0x0104b9,[CaseFold] = 0x0104e1}, NULL},
-	{0x0104ba, {[CaseLower] = 0x0104e2,[CaseTitle] = 0x0104ba,[CaseUpper] = 0x0104ba,[CaseFold] = 0x0104e2}, NULL},
-	{0x0104bb, {[CaseLower] = 0x0104e3,[CaseTitle] = 0x0104bb,[CaseUpper] = 0x0104bb,[CaseFold] = 0x0104e3}, NULL},
-	{0x0104bc, {[CaseLower] = 0x0104e4,[CaseTitle] = 0x0104bc,[CaseUpper] = 0x0104bc,[CaseFold] = 0x0104e4}, NULL},
-	{0x0104bd, {[CaseLower] = 0x0104e5,[CaseTitle] = 0x0104bd,[CaseUpper] = 0x0104bd,[CaseFold] = 0x0104e5}, NULL},
-	{0x0104be, {[CaseLower] = 0x0104e6,[CaseTitle] = 0x0104be,[CaseUpper] = 0x0104be,[CaseFold] = 0x0104e6}, NULL},
-	{0x0104bf, {[CaseLower] = 0x0104e7,[CaseTitle] = 0x0104bf,[CaseUpper] = 0x0104bf,[CaseFold] = 0x0104e7}, NULL},
-	{0x0104c0, {[CaseLower] = 0x0104e8,[CaseTitle] = 0x0104c0,[CaseUpper] = 0x0104c0,[CaseFold] = 0x0104e8}, NULL},
-	{0x0104c1, {[CaseLower] = 0x0104e9,[CaseTitle] = 0x0104c1,[CaseUpper] = 0x0104c1,[CaseFold] = 0x0104e9}, NULL},
-	{0x0104c2, {[CaseLower] = 0x0104ea,[CaseTitle] = 0x0104c2,[CaseUpper] = 0x0104c2,[CaseFold] = 0x0104ea}, NULL},
-	{0x0104c3, {[CaseLower] = 0x0104eb,[CaseTitle] = 0x0104c3,[CaseUpper] = 0x0104c3,[CaseFold] = 0x0104eb}, NULL},
-	{0x0104c4, {[CaseLower] = 0x0104ec,[CaseTitle] = 0x0104c4,[CaseUpper] = 0x0104c4,[CaseFold] = 0x0104ec}, NULL},
-	{0x0104c5, {[CaseLower] = 0x0104ed,[CaseTitle] = 0x0104c5,[CaseUpper] = 0x0104c5,[CaseFold] = 0x0104ed}, NULL},
-	{0x0104c6, {[CaseLower] = 0x0104ee,[CaseTitle] = 0x0104c6,[CaseUpper] = 0x0104c6,[CaseFold] = 0x0104ee}, NULL},
-	{0x0104c7, {[CaseLower] = 0x0104ef,[CaseTitle] = 0x0104c7,[CaseUpper] = 0x0104c7,[CaseFold] = 0x0104ef}, NULL},
-	{0x0104c8, {[CaseLower] = 0x0104f0,[CaseTitle] = 0x0104c8,[CaseUpper] = 0x0104c8,[CaseFold] = 0x0104f0}, NULL},
-	{0x0104c9, {[CaseLower] = 0x0104f1,[CaseTitle] = 0x0104c9,[CaseUpper] = 0x0104c9,[CaseFold] = 0x0104f1}, NULL},
-	{0x0104ca, {[CaseLower] = 0x0104f2,[CaseTitle] = 0x0104ca,[CaseUpper] = 0x0104ca,[CaseFold] = 0x0104f2}, NULL},
-	{0x0104cb, {[CaseLower] = 0x0104f3,[CaseTitle] = 0x0104cb,[CaseUpper] = 0x0104cb,[CaseFold] = 0x0104f3}, NULL},
-	{0x0104cc, {[CaseLower] = 0x0104f4,[CaseTitle] = 0x0104cc,[CaseUpper] = 0x0104cc,[CaseFold] = 0x0104f4}, NULL},
-	{0x0104cd, {[CaseLower] = 0x0104f5,[CaseTitle] = 0x0104cd,[CaseUpper] = 0x0104cd,[CaseFold] = 0x0104f5}, NULL},
-	{0x0104ce, {[CaseLower] = 0x0104f6,[CaseTitle] = 0x0104ce,[CaseUpper] = 0x0104ce,[CaseFold] = 0x0104f6}, NULL},
-	{0x0104cf, {[CaseLower] = 0x0104f7,[CaseTitle] = 0x0104cf,[CaseUpper] = 0x0104cf,[CaseFold] = 0x0104f7}, NULL},
-	{0x0104d0, {[CaseLower] = 0x0104f8,[CaseTitle] = 0x0104d0,[CaseUpper] = 0x0104d0,[CaseFold] = 0x0104f8}, NULL},
-	{0x0104d1, {[CaseLower] = 0x0104f9,[CaseTitle] = 0x0104d1,[CaseUpper] = 0x0104d1,[CaseFold] = 0x0104f9}, NULL},
-	{0x0104d2, {[CaseLower] = 0x0104fa,[CaseTitle] = 0x0104d2,[CaseUpper] = 0x0104d2,[CaseFold] = 0x0104fa}, NULL},
-	{0x0104d3, {[CaseLower] = 0x0104fb,[CaseTitle] = 0x0104d3,[CaseUpper] = 0x0104d3,[CaseFold] = 0x0104fb}, NULL},
-	{0x0104d8, {[CaseLower] = 0x0104d8,[CaseTitle] = 0x0104b0,[CaseUpper] = 0x0104b0,[CaseFold] = 0x0104d8}, NULL},
-	{0x0104d9, {[CaseLower] = 0x0104d9,[CaseTitle] = 0x0104b1,[CaseUpper] = 0x0104b1,[CaseFold] = 0x0104d9}, NULL},
-	{0x0104da, {[CaseLower] = 0x0104da,[CaseTitle] = 0x0104b2,[CaseUpper] = 0x0104b2,[CaseFold] = 0x0104da}, NULL},
-	{0x0104db, {[CaseLower] = 0x0104db,[CaseTitle] = 0x0104b3,[CaseUpper] = 0x0104b3,[CaseFold] = 0x0104db}, NULL},
-	{0x0104dc, {[CaseLower] = 0x0104dc,[CaseTitle] = 0x0104b4,[CaseUpper] = 0x0104b4,[CaseFold] = 0x0104dc}, NULL},
-	{0x0104dd, {[CaseLower] = 0x0104dd,[CaseTitle] = 0x0104b5,[CaseUpper] = 0x0104b5,[CaseFold] = 0x0104dd}, NULL},
-	{0x0104de, {[CaseLower] = 0x0104de,[CaseTitle] = 0x0104b6,[CaseUpper] = 0x0104b6,[CaseFold] = 0x0104de}, NULL},
-	{0x0104df, {[CaseLower] = 0x0104df,[CaseTitle] = 0x0104b7,[CaseUpper] = 0x0104b7,[CaseFold] = 0x0104df}, NULL},
-	{0x0104e0, {[CaseLower] = 0x0104e0,[CaseTitle] = 0x0104b8,[CaseUpper] = 0x0104b8,[CaseFold] = 0x0104e0}, NULL},
-	{0x0104e1, {[CaseLower] = 0x0104e1,[CaseTitle] = 0x0104b9,[CaseUpper] = 0x0104b9,[CaseFold] = 0x0104e1}, NULL},
-	{0x0104e2, {[CaseLower] = 0x0104e2,[CaseTitle] = 0x0104ba,[CaseUpper] = 0x0104ba,[CaseFold] = 0x0104e2}, NULL},
-	{0x0104e3, {[CaseLower] = 0x0104e3,[CaseTitle] = 0x0104bb,[CaseUpper] = 0x0104bb,[CaseFold] = 0x0104e3}, NULL},
-	{0x0104e4, {[CaseLower] = 0x0104e4,[CaseTitle] = 0x0104bc,[CaseUpper] = 0x0104bc,[CaseFold] = 0x0104e4}, NULL},
-	{0x0104e5, {[CaseLower] = 0x0104e5,[CaseTitle] = 0x0104bd,[CaseUpper] = 0x0104bd,[CaseFold] = 0x0104e5}, NULL},
-	{0x0104e6, {[CaseLower] = 0x0104e6,[CaseTitle] = 0x0104be,[CaseUpper] = 0x0104be,[CaseFold] = 0x0104e6}, NULL},
-	{0x0104e7, {[CaseLower] = 0x0104e7,[CaseTitle] = 0x0104bf,[CaseUpper] = 0x0104bf,[CaseFold] = 0x0104e7}, NULL},
-	{0x0104e8, {[CaseLower] = 0x0104e8,[CaseTitle] = 0x0104c0,[CaseUpper] = 0x0104c0,[CaseFold] = 0x0104e8}, NULL},
-	{0x0104e9, {[CaseLower] = 0x0104e9,[CaseTitle] = 0x0104c1,[CaseUpper] = 0x0104c1,[CaseFold] = 0x0104e9}, NULL},
-	{0x0104ea, {[CaseLower] = 0x0104ea,[CaseTitle] = 0x0104c2,[CaseUpper] = 0x0104c2,[CaseFold] = 0x0104ea}, NULL},
-	{0x0104eb, {[CaseLower] = 0x0104eb,[CaseTitle] = 0x0104c3,[CaseUpper] = 0x0104c3,[CaseFold] = 0x0104eb}, NULL},
-	{0x0104ec, {[CaseLower] = 0x0104ec,[CaseTitle] = 0x0104c4,[CaseUpper] = 0x0104c4,[CaseFold] = 0x0104ec}, NULL},
-	{0x0104ed, {[CaseLower] = 0x0104ed,[CaseTitle] = 0x0104c5,[CaseUpper] = 0x0104c5,[CaseFold] = 0x0104ed}, NULL},
-	{0x0104ee, {[CaseLower] = 0x0104ee,[CaseTitle] = 0x0104c6,[CaseUpper] = 0x0104c6,[CaseFold] = 0x0104ee}, NULL},
-	{0x0104ef, {[CaseLower] = 0x0104ef,[CaseTitle] = 0x0104c7,[CaseUpper] = 0x0104c7,[CaseFold] = 0x0104ef}, NULL},
-	{0x0104f0, {[CaseLower] = 0x0104f0,[CaseTitle] = 0x0104c8,[CaseUpper] = 0x0104c8,[CaseFold] = 0x0104f0}, NULL},
-	{0x0104f1, {[CaseLower] = 0x0104f1,[CaseTitle] = 0x0104c9,[CaseUpper] = 0x0104c9,[CaseFold] = 0x0104f1}, NULL},
-	{0x0104f2, {[CaseLower] = 0x0104f2,[CaseTitle] = 0x0104ca,[CaseUpper] = 0x0104ca,[CaseFold] = 0x0104f2}, NULL},
-	{0x0104f3, {[CaseLower] = 0x0104f3,[CaseTitle] = 0x0104cb,[CaseUpper] = 0x0104cb,[CaseFold] = 0x0104f3}, NULL},
-	{0x0104f4, {[CaseLower] = 0x0104f4,[CaseTitle] = 0x0104cc,[CaseUpper] = 0x0104cc,[CaseFold] = 0x0104f4}, NULL},
-	{0x0104f5, {[CaseLower] = 0x0104f5,[CaseTitle] = 0x0104cd,[CaseUpper] = 0x0104cd,[CaseFold] = 0x0104f5}, NULL},
-	{0x0104f6, {[CaseLower] = 0x0104f6,[CaseTitle] = 0x0104ce,[CaseUpper] = 0x0104ce,[CaseFold] = 0x0104f6}, NULL},
-	{0x0104f7, {[CaseLower] = 0x0104f7,[CaseTitle] = 0x0104cf,[CaseUpper] = 0x0104cf,[CaseFold] = 0x0104f7}, NULL},
-	{0x0104f8, {[CaseLower] = 0x0104f8,[CaseTitle] = 0x0104d0,[CaseUpper] = 0x0104d0,[CaseFold] = 0x0104f8}, NULL},
-	{0x0104f9, {[CaseLower] = 0x0104f9,[CaseTitle] = 0x0104d1,[CaseUpper] = 0x0104d1,[CaseFold] = 0x0104f9}, NULL},
-	{0x0104fa, {[CaseLower] = 0x0104fa,[CaseTitle] = 0x0104d2,[CaseUpper] = 0x0104d2,[CaseFold] = 0x0104fa}, NULL},
-	{0x0104fb, {[CaseLower] = 0x0104fb,[CaseTitle] = 0x0104d3,[CaseUpper] = 0x0104d3,[CaseFold] = 0x0104fb}, NULL},
-	{0x010570, {[CaseLower] = 0x010597,[CaseTitle] = 0x010570,[CaseUpper] = 0x010570,[CaseFold] = 0x010597}, NULL},
-	{0x010571, {[CaseLower] = 0x010598,[CaseTitle] = 0x010571,[CaseUpper] = 0x010571,[CaseFold] = 0x010598}, NULL},
-	{0x010572, {[CaseLower] = 0x010599,[CaseTitle] = 0x010572,[CaseUpper] = 0x010572,[CaseFold] = 0x010599}, NULL},
-	{0x010573, {[CaseLower] = 0x01059a,[CaseTitle] = 0x010573,[CaseUpper] = 0x010573,[CaseFold] = 0x01059a}, NULL},
-	{0x010574, {[CaseLower] = 0x01059b,[CaseTitle] = 0x010574,[CaseUpper] = 0x010574,[CaseFold] = 0x01059b}, NULL},
-	{0x010575, {[CaseLower] = 0x01059c,[CaseTitle] = 0x010575,[CaseUpper] = 0x010575,[CaseFold] = 0x01059c}, NULL},
-	{0x010576, {[CaseLower] = 0x01059d,[CaseTitle] = 0x010576,[CaseUpper] = 0x010576,[CaseFold] = 0x01059d}, NULL},
-	{0x010577, {[CaseLower] = 0x01059e,[CaseTitle] = 0x010577,[CaseUpper] = 0x010577,[CaseFold] = 0x01059e}, NULL},
-	{0x010578, {[CaseLower] = 0x01059f,[CaseTitle] = 0x010578,[CaseUpper] = 0x010578,[CaseFold] = 0x01059f}, NULL},
-	{0x010579, {[CaseLower] = 0x0105a0,[CaseTitle] = 0x010579,[CaseUpper] = 0x010579,[CaseFold] = 0x0105a0}, NULL},
-	{0x01057a, {[CaseLower] = 0x0105a1,[CaseTitle] = 0x01057a,[CaseUpper] = 0x01057a,[CaseFold] = 0x0105a1}, NULL},
-	{0x01057c, {[CaseLower] = 0x0105a3,[CaseTitle] = 0x01057c,[CaseUpper] = 0x01057c,[CaseFold] = 0x0105a3}, NULL},
-	{0x01057d, {[CaseLower] = 0x0105a4,[CaseTitle] = 0x01057d,[CaseUpper] = 0x01057d,[CaseFold] = 0x0105a4}, NULL},
-	{0x01057e, {[CaseLower] = 0x0105a5,[CaseTitle] = 0x01057e,[CaseUpper] = 0x01057e,[CaseFold] = 0x0105a5}, NULL},
-	{0x01057f, {[CaseLower] = 0x0105a6,[CaseTitle] = 0x01057f,[CaseUpper] = 0x01057f,[CaseFold] = 0x0105a6}, NULL},
-	{0x010580, {[CaseLower] = 0x0105a7,[CaseTitle] = 0x010580,[CaseUpper] = 0x010580,[CaseFold] = 0x0105a7}, NULL},
-	{0x010581, {[CaseLower] = 0x0105a8,[CaseTitle] = 0x010581,[CaseUpper] = 0x010581,[CaseFold] = 0x0105a8}, NULL},
-	{0x010582, {[CaseLower] = 0x0105a9,[CaseTitle] = 0x010582,[CaseUpper] = 0x010582,[CaseFold] = 0x0105a9}, NULL},
-	{0x010583, {[CaseLower] = 0x0105aa,[CaseTitle] = 0x010583,[CaseUpper] = 0x010583,[CaseFold] = 0x0105aa}, NULL},
-	{0x010584, {[CaseLower] = 0x0105ab,[CaseTitle] = 0x010584,[CaseUpper] = 0x010584,[CaseFold] = 0x0105ab}, NULL},
-	{0x010585, {[CaseLower] = 0x0105ac,[CaseTitle] = 0x010585,[CaseUpper] = 0x010585,[CaseFold] = 0x0105ac}, NULL},
-	{0x010586, {[CaseLower] = 0x0105ad,[CaseTitle] = 0x010586,[CaseUpper] = 0x010586,[CaseFold] = 0x0105ad}, NULL},
-	{0x010587, {[CaseLower] = 0x0105ae,[CaseTitle] = 0x010587,[CaseUpper] = 0x010587,[CaseFold] = 0x0105ae}, NULL},
-	{0x010588, {[CaseLower] = 0x0105af,[CaseTitle] = 0x010588,[CaseUpper] = 0x010588,[CaseFold] = 0x0105af}, NULL},
-	{0x010589, {[CaseLower] = 0x0105b0,[CaseTitle] = 0x010589,[CaseUpper] = 0x010589,[CaseFold] = 0x0105b0}, NULL},
-	{0x01058a, {[CaseLower] = 0x0105b1,[CaseTitle] = 0x01058a,[CaseUpper] = 0x01058a,[CaseFold] = 0x0105b1}, NULL},
-	{0x01058c, {[CaseLower] = 0x0105b3,[CaseTitle] = 0x01058c,[CaseUpper] = 0x01058c,[CaseFold] = 0x0105b3}, NULL},
-	{0x01058d, {[CaseLower] = 0x0105b4,[CaseTitle] = 0x01058d,[CaseUpper] = 0x01058d,[CaseFold] = 0x0105b4}, NULL},
-	{0x01058e, {[CaseLower] = 0x0105b5,[CaseTitle] = 0x01058e,[CaseUpper] = 0x01058e,[CaseFold] = 0x0105b5}, NULL},
-	{0x01058f, {[CaseLower] = 0x0105b6,[CaseTitle] = 0x01058f,[CaseUpper] = 0x01058f,[CaseFold] = 0x0105b6}, NULL},
-	{0x010590, {[CaseLower] = 0x0105b7,[CaseTitle] = 0x010590,[CaseUpper] = 0x010590,[CaseFold] = 0x0105b7}, NULL},
-	{0x010591, {[CaseLower] = 0x0105b8,[CaseTitle] = 0x010591,[CaseUpper] = 0x010591,[CaseFold] = 0x0105b8}, NULL},
-	{0x010592, {[CaseLower] = 0x0105b9,[CaseTitle] = 0x010592,[CaseUpper] = 0x010592,[CaseFold] = 0x0105b9}, NULL},
-	{0x010594, {[CaseLower] = 0x0105bb,[CaseTitle] = 0x010594,[CaseUpper] = 0x010594,[CaseFold] = 0x0105bb}, NULL},
-	{0x010595, {[CaseLower] = 0x0105bc,[CaseTitle] = 0x010595,[CaseUpper] = 0x010595,[CaseFold] = 0x0105bc}, NULL},
-	{0x010597, {[CaseLower] = 0x010597,[CaseTitle] = 0x010570,[CaseUpper] = 0x010570,[CaseFold] = 0x010597}, NULL},
-	{0x010598, {[CaseLower] = 0x010598,[CaseTitle] = 0x010571,[CaseUpper] = 0x010571,[CaseFold] = 0x010598}, NULL},
-	{0x010599, {[CaseLower] = 0x010599,[CaseTitle] = 0x010572,[CaseUpper] = 0x010572,[CaseFold] = 0x010599}, NULL},
-	{0x01059a, {[CaseLower] = 0x01059a,[CaseTitle] = 0x010573,[CaseUpper] = 0x010573,[CaseFold] = 0x01059a}, NULL},
-	{0x01059b, {[CaseLower] = 0x01059b,[CaseTitle] = 0x010574,[CaseUpper] = 0x010574,[CaseFold] = 0x01059b}, NULL},
-	{0x01059c, {[CaseLower] = 0x01059c,[CaseTitle] = 0x010575,[CaseUpper] = 0x010575,[CaseFold] = 0x01059c}, NULL},
-	{0x01059d, {[CaseLower] = 0x01059d,[CaseTitle] = 0x010576,[CaseUpper] = 0x010576,[CaseFold] = 0x01059d}, NULL},
-	{0x01059e, {[CaseLower] = 0x01059e,[CaseTitle] = 0x010577,[CaseUpper] = 0x010577,[CaseFold] = 0x01059e}, NULL},
-	{0x01059f, {[CaseLower] = 0x01059f,[CaseTitle] = 0x010578,[CaseUpper] = 0x010578,[CaseFold] = 0x01059f}, NULL},
-	{0x0105a0, {[CaseLower] = 0x0105a0,[CaseTitle] = 0x010579,[CaseUpper] = 0x010579,[CaseFold] = 0x0105a0}, NULL},
-	{0x0105a1, {[CaseLower] = 0x0105a1,[CaseTitle] = 0x01057a,[CaseUpper] = 0x01057a,[CaseFold] = 0x0105a1}, NULL},
-	{0x0105a3, {[CaseLower] = 0x0105a3,[CaseTitle] = 0x01057c,[CaseUpper] = 0x01057c,[CaseFold] = 0x0105a3}, NULL},
-	{0x0105a4, {[CaseLower] = 0x0105a4,[CaseTitle] = 0x01057d,[CaseUpper] = 0x01057d,[CaseFold] = 0x0105a4}, NULL},
-	{0x0105a5, {[CaseLower] = 0x0105a5,[CaseTitle] = 0x01057e,[CaseUpper] = 0x01057e,[CaseFold] = 0x0105a5}, NULL},
-	{0x0105a6, {[CaseLower] = 0x0105a6,[CaseTitle] = 0x01057f,[CaseUpper] = 0x01057f,[CaseFold] = 0x0105a6}, NULL},
-	{0x0105a7, {[CaseLower] = 0x0105a7,[CaseTitle] = 0x010580,[CaseUpper] = 0x010580,[CaseFold] = 0x0105a7}, NULL},
-	{0x0105a8, {[CaseLower] = 0x0105a8,[CaseTitle] = 0x010581,[CaseUpper] = 0x010581,[CaseFold] = 0x0105a8}, NULL},
-	{0x0105a9, {[CaseLower] = 0x0105a9,[CaseTitle] = 0x010582,[CaseUpper] = 0x010582,[CaseFold] = 0x0105a9}, NULL},
-	{0x0105aa, {[CaseLower] = 0x0105aa,[CaseTitle] = 0x010583,[CaseUpper] = 0x010583,[CaseFold] = 0x0105aa}, NULL},
-	{0x0105ab, {[CaseLower] = 0x0105ab,[CaseTitle] = 0x010584,[CaseUpper] = 0x010584,[CaseFold] = 0x0105ab}, NULL},
-	{0x0105ac, {[CaseLower] = 0x0105ac,[CaseTitle] = 0x010585,[CaseUpper] = 0x010585,[CaseFold] = 0x0105ac}, NULL},
-	{0x0105ad, {[CaseLower] = 0x0105ad,[CaseTitle] = 0x010586,[CaseUpper] = 0x010586,[CaseFold] = 0x0105ad}, NULL},
-	{0x0105ae, {[CaseLower] = 0x0105ae,[CaseTitle] = 0x010587,[CaseUpper] = 0x010587,[CaseFold] = 0x0105ae}, NULL},
-	{0x0105af, {[CaseLower] = 0x0105af,[CaseTitle] = 0x010588,[CaseUpper] = 0x010588,[CaseFold] = 0x0105af}, NULL},
-	{0x0105b0, {[CaseLower] = 0x0105b0,[CaseTitle] = 0x010589,[CaseUpper] = 0x010589,[CaseFold] = 0x0105b0}, NULL},
-	{0x0105b1, {[CaseLower] = 0x0105b1,[CaseTitle] = 0x01058a,[CaseUpper] = 0x01058a,[CaseFold] = 0x0105b1}, NULL},
-	{0x0105b3, {[CaseLower] = 0x0105b3,[CaseTitle] = 0x01058c,[CaseUpper] = 0x01058c,[CaseFold] = 0x0105b3}, NULL},
-	{0x0105b4, {[CaseLower] = 0x0105b4,[CaseTitle] = 0x01058d,[CaseUpper] = 0x01058d,[CaseFold] = 0x0105b4}, NULL},
-	{0x0105b5, {[CaseLower] = 0x0105b5,[CaseTitle] = 0x01058e,[CaseUpper] = 0x01058e,[CaseFold] = 0x0105b5}, NULL},
-	{0x0105b6, {[CaseLower] = 0x0105b6,[CaseTitle] = 0x01058f,[CaseUpper] = 0x01058f,[CaseFold] = 0x0105b6}, NULL},
-	{0x0105b7, {[CaseLower] = 0x0105b7,[CaseTitle] = 0x010590,[CaseUpper] = 0x010590,[CaseFold] = 0x0105b7}, NULL},
-	{0x0105b8, {[CaseLower] = 0x0105b8,[CaseTitle] = 0x010591,[CaseUpper] = 0x010591,[CaseFold] = 0x0105b8}, NULL},
-	{0x0105b9, {[CaseLower] = 0x0105b9,[CaseTitle] = 0x010592,[CaseUpper] = 0x010592,[CaseFold] = 0x0105b9}, NULL},
-	{0x0105bb, {[CaseLower] = 0x0105bb,[CaseTitle] = 0x010594,[CaseUpper] = 0x010594,[CaseFold] = 0x0105bb}, NULL},
-	{0x0105bc, {[CaseLower] = 0x0105bc,[CaseTitle] = 0x010595,[CaseUpper] = 0x010595,[CaseFold] = 0x0105bc}, NULL},
-	{0x010c80, {[CaseLower] = 0x010cc0,[CaseTitle] = 0x010c80,[CaseUpper] = 0x010c80,[CaseFold] = 0x010cc0}, NULL},
-	{0x010c81, {[CaseLower] = 0x010cc1,[CaseTitle] = 0x010c81,[CaseUpper] = 0x010c81,[CaseFold] = 0x010cc1}, NULL},
-	{0x010c82, {[CaseLower] = 0x010cc2,[CaseTitle] = 0x010c82,[CaseUpper] = 0x010c82,[CaseFold] = 0x010cc2}, NULL},
-	{0x010c83, {[CaseLower] = 0x010cc3,[CaseTitle] = 0x010c83,[CaseUpper] = 0x010c83,[CaseFold] = 0x010cc3}, NULL},
-	{0x010c84, {[CaseLower] = 0x010cc4,[CaseTitle] = 0x010c84,[CaseUpper] = 0x010c84,[CaseFold] = 0x010cc4}, NULL},
-	{0x010c85, {[CaseLower] = 0x010cc5,[CaseTitle] = 0x010c85,[CaseUpper] = 0x010c85,[CaseFold] = 0x010cc5}, NULL},
-	{0x010c86, {[CaseLower] = 0x010cc6,[CaseTitle] = 0x010c86,[CaseUpper] = 0x010c86,[CaseFold] = 0x010cc6}, NULL},
-	{0x010c87, {[CaseLower] = 0x010cc7,[CaseTitle] = 0x010c87,[CaseUpper] = 0x010c87,[CaseFold] = 0x010cc7}, NULL},
-	{0x010c88, {[CaseLower] = 0x010cc8,[CaseTitle] = 0x010c88,[CaseUpper] = 0x010c88,[CaseFold] = 0x010cc8}, NULL},
-	{0x010c89, {[CaseLower] = 0x010cc9,[CaseTitle] = 0x010c89,[CaseUpper] = 0x010c89,[CaseFold] = 0x010cc9}, NULL},
-	{0x010c8a, {[CaseLower] = 0x010cca,[CaseTitle] = 0x010c8a,[CaseUpper] = 0x010c8a,[CaseFold] = 0x010cca}, NULL},
-	{0x010c8b, {[CaseLower] = 0x010ccb,[CaseTitle] = 0x010c8b,[CaseUpper] = 0x010c8b,[CaseFold] = 0x010ccb}, NULL},
-	{0x010c8c, {[CaseLower] = 0x010ccc,[CaseTitle] = 0x010c8c,[CaseUpper] = 0x010c8c,[CaseFold] = 0x010ccc}, NULL},
-	{0x010c8d, {[CaseLower] = 0x010ccd,[CaseTitle] = 0x010c8d,[CaseUpper] = 0x010c8d,[CaseFold] = 0x010ccd}, NULL},
-	{0x010c8e, {[CaseLower] = 0x010cce,[CaseTitle] = 0x010c8e,[CaseUpper] = 0x010c8e,[CaseFold] = 0x010cce}, NULL},
-	{0x010c8f, {[CaseLower] = 0x010ccf,[CaseTitle] = 0x010c8f,[CaseUpper] = 0x010c8f,[CaseFold] = 0x010ccf}, NULL},
-	{0x010c90, {[CaseLower] = 0x010cd0,[CaseTitle] = 0x010c90,[CaseUpper] = 0x010c90,[CaseFold] = 0x010cd0}, NULL},
-	{0x010c91, {[CaseLower] = 0x010cd1,[CaseTitle] = 0x010c91,[CaseUpper] = 0x010c91,[CaseFold] = 0x010cd1}, NULL},
-	{0x010c92, {[CaseLower] = 0x010cd2,[CaseTitle] = 0x010c92,[CaseUpper] = 0x010c92,[CaseFold] = 0x010cd2}, NULL},
-	{0x010c93, {[CaseLower] = 0x010cd3,[CaseTitle] = 0x010c93,[CaseUpper] = 0x010c93,[CaseFold] = 0x010cd3}, NULL},
-	{0x010c94, {[CaseLower] = 0x010cd4,[CaseTitle] = 0x010c94,[CaseUpper] = 0x010c94,[CaseFold] = 0x010cd4}, NULL},
-	{0x010c95, {[CaseLower] = 0x010cd5,[CaseTitle] = 0x010c95,[CaseUpper] = 0x010c95,[CaseFold] = 0x010cd5}, NULL},
-	{0x010c96, {[CaseLower] = 0x010cd6,[CaseTitle] = 0x010c96,[CaseUpper] = 0x010c96,[CaseFold] = 0x010cd6}, NULL},
-	{0x010c97, {[CaseLower] = 0x010cd7,[CaseTitle] = 0x010c97,[CaseUpper] = 0x010c97,[CaseFold] = 0x010cd7}, NULL},
-	{0x010c98, {[CaseLower] = 0x010cd8,[CaseTitle] = 0x010c98,[CaseUpper] = 0x010c98,[CaseFold] = 0x010cd8}, NULL},
-	{0x010c99, {[CaseLower] = 0x010cd9,[CaseTitle] = 0x010c99,[CaseUpper] = 0x010c99,[CaseFold] = 0x010cd9}, NULL},
-	{0x010c9a, {[CaseLower] = 0x010cda,[CaseTitle] = 0x010c9a,[CaseUpper] = 0x010c9a,[CaseFold] = 0x010cda}, NULL},
-	{0x010c9b, {[CaseLower] = 0x010cdb,[CaseTitle] = 0x010c9b,[CaseUpper] = 0x010c9b,[CaseFold] = 0x010cdb}, NULL},
-	{0x010c9c, {[CaseLower] = 0x010cdc,[CaseTitle] = 0x010c9c,[CaseUpper] = 0x010c9c,[CaseFold] = 0x010cdc}, NULL},
-	{0x010c9d, {[CaseLower] = 0x010cdd,[CaseTitle] = 0x010c9d,[CaseUpper] = 0x010c9d,[CaseFold] = 0x010cdd}, NULL},
-	{0x010c9e, {[CaseLower] = 0x010cde,[CaseTitle] = 0x010c9e,[CaseUpper] = 0x010c9e,[CaseFold] = 0x010cde}, NULL},
-	{0x010c9f, {[CaseLower] = 0x010cdf,[CaseTitle] = 0x010c9f,[CaseUpper] = 0x010c9f,[CaseFold] = 0x010cdf}, NULL},
-	{0x010ca0, {[CaseLower] = 0x010ce0,[CaseTitle] = 0x010ca0,[CaseUpper] = 0x010ca0,[CaseFold] = 0x010ce0}, NULL},
-	{0x010ca1, {[CaseLower] = 0x010ce1,[CaseTitle] = 0x010ca1,[CaseUpper] = 0x010ca1,[CaseFold] = 0x010ce1}, NULL},
-	{0x010ca2, {[CaseLower] = 0x010ce2,[CaseTitle] = 0x010ca2,[CaseUpper] = 0x010ca2,[CaseFold] = 0x010ce2}, NULL},
-	{0x010ca3, {[CaseLower] = 0x010ce3,[CaseTitle] = 0x010ca3,[CaseUpper] = 0x010ca3,[CaseFold] = 0x010ce3}, NULL},
-	{0x010ca4, {[CaseLower] = 0x010ce4,[CaseTitle] = 0x010ca4,[CaseUpper] = 0x010ca4,[CaseFold] = 0x010ce4}, NULL},
-	{0x010ca5, {[CaseLower] = 0x010ce5,[CaseTitle] = 0x010ca5,[CaseUpper] = 0x010ca5,[CaseFold] = 0x010ce5}, NULL},
-	{0x010ca6, {[CaseLower] = 0x010ce6,[CaseTitle] = 0x010ca6,[CaseUpper] = 0x010ca6,[CaseFold] = 0x010ce6}, NULL},
-	{0x010ca7, {[CaseLower] = 0x010ce7,[CaseTitle] = 0x010ca7,[CaseUpper] = 0x010ca7,[CaseFold] = 0x010ce7}, NULL},
-	{0x010ca8, {[CaseLower] = 0x010ce8,[CaseTitle] = 0x010ca8,[CaseUpper] = 0x010ca8,[CaseFold] = 0x010ce8}, NULL},
-	{0x010ca9, {[CaseLower] = 0x010ce9,[CaseTitle] = 0x010ca9,[CaseUpper] = 0x010ca9,[CaseFold] = 0x010ce9}, NULL},
-	{0x010caa, {[CaseLower] = 0x010cea,[CaseTitle] = 0x010caa,[CaseUpper] = 0x010caa,[CaseFold] = 0x010cea}, NULL},
-	{0x010cab, {[CaseLower] = 0x010ceb,[CaseTitle] = 0x010cab,[CaseUpper] = 0x010cab,[CaseFold] = 0x010ceb}, NULL},
-	{0x010cac, {[CaseLower] = 0x010cec,[CaseTitle] = 0x010cac,[CaseUpper] = 0x010cac,[CaseFold] = 0x010cec}, NULL},
-	{0x010cad, {[CaseLower] = 0x010ced,[CaseTitle] = 0x010cad,[CaseUpper] = 0x010cad,[CaseFold] = 0x010ced}, NULL},
-	{0x010cae, {[CaseLower] = 0x010cee,[CaseTitle] = 0x010cae,[CaseUpper] = 0x010cae,[CaseFold] = 0x010cee}, NULL},
-	{0x010caf, {[CaseLower] = 0x010cef,[CaseTitle] = 0x010caf,[CaseUpper] = 0x010caf,[CaseFold] = 0x010cef}, NULL},
-	{0x010cb0, {[CaseLower] = 0x010cf0,[CaseTitle] = 0x010cb0,[CaseUpper] = 0x010cb0,[CaseFold] = 0x010cf0}, NULL},
-	{0x010cb1, {[CaseLower] = 0x010cf1,[CaseTitle] = 0x010cb1,[CaseUpper] = 0x010cb1,[CaseFold] = 0x010cf1}, NULL},
-	{0x010cb2, {[CaseLower] = 0x010cf2,[CaseTitle] = 0x010cb2,[CaseUpper] = 0x010cb2,[CaseFold] = 0x010cf2}, NULL},
-	{0x010cc0, {[CaseLower] = 0x010cc0,[CaseTitle] = 0x010c80,[CaseUpper] = 0x010c80,[CaseFold] = 0x010cc0}, NULL},
-	{0x010cc1, {[CaseLower] = 0x010cc1,[CaseTitle] = 0x010c81,[CaseUpper] = 0x010c81,[CaseFold] = 0x010cc1}, NULL},
-	{0x010cc2, {[CaseLower] = 0x010cc2,[CaseTitle] = 0x010c82,[CaseUpper] = 0x010c82,[CaseFold] = 0x010cc2}, NULL},
-	{0x010cc3, {[CaseLower] = 0x010cc3,[CaseTitle] = 0x010c83,[CaseUpper] = 0x010c83,[CaseFold] = 0x010cc3}, NULL},
-	{0x010cc4, {[CaseLower] = 0x010cc4,[CaseTitle] = 0x010c84,[CaseUpper] = 0x010c84,[CaseFold] = 0x010cc4}, NULL},
-	{0x010cc5, {[CaseLower] = 0x010cc5,[CaseTitle] = 0x010c85,[CaseUpper] = 0x010c85,[CaseFold] = 0x010cc5}, NULL},
-	{0x010cc6, {[CaseLower] = 0x010cc6,[CaseTitle] = 0x010c86,[CaseUpper] = 0x010c86,[CaseFold] = 0x010cc6}, NULL},
-	{0x010cc7, {[CaseLower] = 0x010cc7,[CaseTitle] = 0x010c87,[CaseUpper] = 0x010c87,[CaseFold] = 0x010cc7}, NULL},
-	{0x010cc8, {[CaseLower] = 0x010cc8,[CaseTitle] = 0x010c88,[CaseUpper] = 0x010c88,[CaseFold] = 0x010cc8}, NULL},
-	{0x010cc9, {[CaseLower] = 0x010cc9,[CaseTitle] = 0x010c89,[CaseUpper] = 0x010c89,[CaseFold] = 0x010cc9}, NULL},
-	{0x010cca, {[CaseLower] = 0x010cca,[CaseTitle] = 0x010c8a,[CaseUpper] = 0x010c8a,[CaseFold] = 0x010cca}, NULL},
-	{0x010ccb, {[CaseLower] = 0x010ccb,[CaseTitle] = 0x010c8b,[CaseUpper] = 0x010c8b,[CaseFold] = 0x010ccb}, NULL},
-	{0x010ccc, {[CaseLower] = 0x010ccc,[CaseTitle] = 0x010c8c,[CaseUpper] = 0x010c8c,[CaseFold] = 0x010ccc}, NULL},
-	{0x010ccd, {[CaseLower] = 0x010ccd,[CaseTitle] = 0x010c8d,[CaseUpper] = 0x010c8d,[CaseFold] = 0x010ccd}, NULL},
-	{0x010cce, {[CaseLower] = 0x010cce,[CaseTitle] = 0x010c8e,[CaseUpper] = 0x010c8e,[CaseFold] = 0x010cce}, NULL},
-	{0x010ccf, {[CaseLower] = 0x010ccf,[CaseTitle] = 0x010c8f,[CaseUpper] = 0x010c8f,[CaseFold] = 0x010ccf}, NULL},
-	{0x010cd0, {[CaseLower] = 0x010cd0,[CaseTitle] = 0x010c90,[CaseUpper] = 0x010c90,[CaseFold] = 0x010cd0}, NULL},
-	{0x010cd1, {[CaseLower] = 0x010cd1,[CaseTitle] = 0x010c91,[CaseUpper] = 0x010c91,[CaseFold] = 0x010cd1}, NULL},
-	{0x010cd2, {[CaseLower] = 0x010cd2,[CaseTitle] = 0x010c92,[CaseUpper] = 0x010c92,[CaseFold] = 0x010cd2}, NULL},
-	{0x010cd3, {[CaseLower] = 0x010cd3,[CaseTitle] = 0x010c93,[CaseUpper] = 0x010c93,[CaseFold] = 0x010cd3}, NULL},
-	{0x010cd4, {[CaseLower] = 0x010cd4,[CaseTitle] = 0x010c94,[CaseUpper] = 0x010c94,[CaseFold] = 0x010cd4}, NULL},
-	{0x010cd5, {[CaseLower] = 0x010cd5,[CaseTitle] = 0x010c95,[CaseUpper] = 0x010c95,[CaseFold] = 0x010cd5}, NULL},
-	{0x010cd6, {[CaseLower] = 0x010cd6,[CaseTitle] = 0x010c96,[CaseUpper] = 0x010c96,[CaseFold] = 0x010cd6}, NULL},
-	{0x010cd7, {[CaseLower] = 0x010cd7,[CaseTitle] = 0x010c97,[CaseUpper] = 0x010c97,[CaseFold] = 0x010cd7}, NULL},
-	{0x010cd8, {[CaseLower] = 0x010cd8,[CaseTitle] = 0x010c98,[CaseUpper] = 0x010c98,[CaseFold] = 0x010cd8}, NULL},
-	{0x010cd9, {[CaseLower] = 0x010cd9,[CaseTitle] = 0x010c99,[CaseUpper] = 0x010c99,[CaseFold] = 0x010cd9}, NULL},
-	{0x010cda, {[CaseLower] = 0x010cda,[CaseTitle] = 0x010c9a,[CaseUpper] = 0x010c9a,[CaseFold] = 0x010cda}, NULL},
-	{0x010cdb, {[CaseLower] = 0x010cdb,[CaseTitle] = 0x010c9b,[CaseUpper] = 0x010c9b,[CaseFold] = 0x010cdb}, NULL},
-	{0x010cdc, {[CaseLower] = 0x010cdc,[CaseTitle] = 0x010c9c,[CaseUpper] = 0x010c9c,[CaseFold] = 0x010cdc}, NULL},
-	{0x010cdd, {[CaseLower] = 0x010cdd,[CaseTitle] = 0x010c9d,[CaseUpper] = 0x010c9d,[CaseFold] = 0x010cdd}, NULL},
-	{0x010cde, {[CaseLower] = 0x010cde,[CaseTitle] = 0x010c9e,[CaseUpper] = 0x010c9e,[CaseFold] = 0x010cde}, NULL},
-	{0x010cdf, {[CaseLower] = 0x010cdf,[CaseTitle] = 0x010c9f,[CaseUpper] = 0x010c9f,[CaseFold] = 0x010cdf}, NULL},
-	{0x010ce0, {[CaseLower] = 0x010ce0,[CaseTitle] = 0x010ca0,[CaseUpper] = 0x010ca0,[CaseFold] = 0x010ce0}, NULL},
-	{0x010ce1, {[CaseLower] = 0x010ce1,[CaseTitle] = 0x010ca1,[CaseUpper] = 0x010ca1,[CaseFold] = 0x010ce1}, NULL},
-	{0x010ce2, {[CaseLower] = 0x010ce2,[CaseTitle] = 0x010ca2,[CaseUpper] = 0x010ca2,[CaseFold] = 0x010ce2}, NULL},
-	{0x010ce3, {[CaseLower] = 0x010ce3,[CaseTitle] = 0x010ca3,[CaseUpper] = 0x010ca3,[CaseFold] = 0x010ce3}, NULL},
-	{0x010ce4, {[CaseLower] = 0x010ce4,[CaseTitle] = 0x010ca4,[CaseUpper] = 0x010ca4,[CaseFold] = 0x010ce4}, NULL},
-	{0x010ce5, {[CaseLower] = 0x010ce5,[CaseTitle] = 0x010ca5,[CaseUpper] = 0x010ca5,[CaseFold] = 0x010ce5}, NULL},
-	{0x010ce6, {[CaseLower] = 0x010ce6,[CaseTitle] = 0x010ca6,[CaseUpper] = 0x010ca6,[CaseFold] = 0x010ce6}, NULL},
-	{0x010ce7, {[CaseLower] = 0x010ce7,[CaseTitle] = 0x010ca7,[CaseUpper] = 0x010ca7,[CaseFold] = 0x010ce7}, NULL},
-	{0x010ce8, {[CaseLower] = 0x010ce8,[CaseTitle] = 0x010ca8,[CaseUpper] = 0x010ca8,[CaseFold] = 0x010ce8}, NULL},
-	{0x010ce9, {[CaseLower] = 0x010ce9,[CaseTitle] = 0x010ca9,[CaseUpper] = 0x010ca9,[CaseFold] = 0x010ce9}, NULL},
-	{0x010cea, {[CaseLower] = 0x010cea,[CaseTitle] = 0x010caa,[CaseUpper] = 0x010caa,[CaseFold] = 0x010cea}, NULL},
-	{0x010ceb, {[CaseLower] = 0x010ceb,[CaseTitle] = 0x010cab,[CaseUpper] = 0x010cab,[CaseFold] = 0x010ceb}, NULL},
-	{0x010cec, {[CaseLower] = 0x010cec,[CaseTitle] = 0x010cac,[CaseUpper] = 0x010cac,[CaseFold] = 0x010cec}, NULL},
-	{0x010ced, {[CaseLower] = 0x010ced,[CaseTitle] = 0x010cad,[CaseUpper] = 0x010cad,[CaseFold] = 0x010ced}, NULL},
-	{0x010cee, {[CaseLower] = 0x010cee,[CaseTitle] = 0x010cae,[CaseUpper] = 0x010cae,[CaseFold] = 0x010cee}, NULL},
-	{0x010cef, {[CaseLower] = 0x010cef,[CaseTitle] = 0x010caf,[CaseUpper] = 0x010caf,[CaseFold] = 0x010cef}, NULL},
-	{0x010cf0, {[CaseLower] = 0x010cf0,[CaseTitle] = 0x010cb0,[CaseUpper] = 0x010cb0,[CaseFold] = 0x010cf0}, NULL},
-	{0x010cf1, {[CaseLower] = 0x010cf1,[CaseTitle] = 0x010cb1,[CaseUpper] = 0x010cb1,[CaseFold] = 0x010cf1}, NULL},
-	{0x010cf2, {[CaseLower] = 0x010cf2,[CaseTitle] = 0x010cb2,[CaseUpper] = 0x010cb2,[CaseFold] = 0x010cf2}, NULL},
-	{0x0118a0, {[CaseLower] = 0x0118c0,[CaseTitle] = 0x0118a0,[CaseUpper] = 0x0118a0,[CaseFold] = 0x0118c0}, NULL},
-	{0x0118a1, {[CaseLower] = 0x0118c1,[CaseTitle] = 0x0118a1,[CaseUpper] = 0x0118a1,[CaseFold] = 0x0118c1}, NULL},
-	{0x0118a2, {[CaseLower] = 0x0118c2,[CaseTitle] = 0x0118a2,[CaseUpper] = 0x0118a2,[CaseFold] = 0x0118c2}, NULL},
-	{0x0118a3, {[CaseLower] = 0x0118c3,[CaseTitle] = 0x0118a3,[CaseUpper] = 0x0118a3,[CaseFold] = 0x0118c3}, NULL},
-	{0x0118a4, {[CaseLower] = 0x0118c4,[CaseTitle] = 0x0118a4,[CaseUpper] = 0x0118a4,[CaseFold] = 0x0118c4}, NULL},
-	{0x0118a5, {[CaseLower] = 0x0118c5,[CaseTitle] = 0x0118a5,[CaseUpper] = 0x0118a5,[CaseFold] = 0x0118c5}, NULL},
-	{0x0118a6, {[CaseLower] = 0x0118c6,[CaseTitle] = 0x0118a6,[CaseUpper] = 0x0118a6,[CaseFold] = 0x0118c6}, NULL},
-	{0x0118a7, {[CaseLower] = 0x0118c7,[CaseTitle] = 0x0118a7,[CaseUpper] = 0x0118a7,[CaseFold] = 0x0118c7}, NULL},
-	{0x0118a8, {[CaseLower] = 0x0118c8,[CaseTitle] = 0x0118a8,[CaseUpper] = 0x0118a8,[CaseFold] = 0x0118c8}, NULL},
-	{0x0118a9, {[CaseLower] = 0x0118c9,[CaseTitle] = 0x0118a9,[CaseUpper] = 0x0118a9,[CaseFold] = 0x0118c9}, NULL},
-	{0x0118aa, {[CaseLower] = 0x0118ca,[CaseTitle] = 0x0118aa,[CaseUpper] = 0x0118aa,[CaseFold] = 0x0118ca}, NULL},
-	{0x0118ab, {[CaseLower] = 0x0118cb,[CaseTitle] = 0x0118ab,[CaseUpper] = 0x0118ab,[CaseFold] = 0x0118cb}, NULL},
-	{0x0118ac, {[CaseLower] = 0x0118cc,[CaseTitle] = 0x0118ac,[CaseUpper] = 0x0118ac,[CaseFold] = 0x0118cc}, NULL},
-	{0x0118ad, {[CaseLower] = 0x0118cd,[CaseTitle] = 0x0118ad,[CaseUpper] = 0x0118ad,[CaseFold] = 0x0118cd}, NULL},
-	{0x0118ae, {[CaseLower] = 0x0118ce,[CaseTitle] = 0x0118ae,[CaseUpper] = 0x0118ae,[CaseFold] = 0x0118ce}, NULL},
-	{0x0118af, {[CaseLower] = 0x0118cf,[CaseTitle] = 0x0118af,[CaseUpper] = 0x0118af,[CaseFold] = 0x0118cf}, NULL},
-	{0x0118b0, {[CaseLower] = 0x0118d0,[CaseTitle] = 0x0118b0,[CaseUpper] = 0x0118b0,[CaseFold] = 0x0118d0}, NULL},
-	{0x0118b1, {[CaseLower] = 0x0118d1,[CaseTitle] = 0x0118b1,[CaseUpper] = 0x0118b1,[CaseFold] = 0x0118d1}, NULL},
-	{0x0118b2, {[CaseLower] = 0x0118d2,[CaseTitle] = 0x0118b2,[CaseUpper] = 0x0118b2,[CaseFold] = 0x0118d2}, NULL},
-	{0x0118b3, {[CaseLower] = 0x0118d3,[CaseTitle] = 0x0118b3,[CaseUpper] = 0x0118b3,[CaseFold] = 0x0118d3}, NULL},
-	{0x0118b4, {[CaseLower] = 0x0118d4,[CaseTitle] = 0x0118b4,[CaseUpper] = 0x0118b4,[CaseFold] = 0x0118d4}, NULL},
-	{0x0118b5, {[CaseLower] = 0x0118d5,[CaseTitle] = 0x0118b5,[CaseUpper] = 0x0118b5,[CaseFold] = 0x0118d5}, NULL},
-	{0x0118b6, {[CaseLower] = 0x0118d6,[CaseTitle] = 0x0118b6,[CaseUpper] = 0x0118b6,[CaseFold] = 0x0118d6}, NULL},
-	{0x0118b7, {[CaseLower] = 0x0118d7,[CaseTitle] = 0x0118b7,[CaseUpper] = 0x0118b7,[CaseFold] = 0x0118d7}, NULL},
-	{0x0118b8, {[CaseLower] = 0x0118d8,[CaseTitle] = 0x0118b8,[CaseUpper] = 0x0118b8,[CaseFold] = 0x0118d8}, NULL},
-	{0x0118b9, {[CaseLower] = 0x0118d9,[CaseTitle] = 0x0118b9,[CaseUpper] = 0x0118b9,[CaseFold] = 0x0118d9}, NULL},
-	{0x0118ba, {[CaseLower] = 0x0118da,[CaseTitle] = 0x0118ba,[CaseUpper] = 0x0118ba,[CaseFold] = 0x0118da}, NULL},
-	{0x0118bb, {[CaseLower] = 0x0118db,[CaseTitle] = 0x0118bb,[CaseUpper] = 0x0118bb,[CaseFold] = 0x0118db}, NULL},
-	{0x0118bc, {[CaseLower] = 0x0118dc,[CaseTitle] = 0x0118bc,[CaseUpper] = 0x0118bc,[CaseFold] = 0x0118dc}, NULL},
-	{0x0118bd, {[CaseLower] = 0x0118dd,[CaseTitle] = 0x0118bd,[CaseUpper] = 0x0118bd,[CaseFold] = 0x0118dd}, NULL},
-	{0x0118be, {[CaseLower] = 0x0118de,[CaseTitle] = 0x0118be,[CaseUpper] = 0x0118be,[CaseFold] = 0x0118de}, NULL},
-	{0x0118bf, {[CaseLower] = 0x0118df,[CaseTitle] = 0x0118bf,[CaseUpper] = 0x0118bf,[CaseFold] = 0x0118df}, NULL},
-	{0x0118c0, {[CaseLower] = 0x0118c0,[CaseTitle] = 0x0118a0,[CaseUpper] = 0x0118a0,[CaseFold] = 0x0118c0}, NULL},
-	{0x0118c1, {[CaseLower] = 0x0118c1,[CaseTitle] = 0x0118a1,[CaseUpper] = 0x0118a1,[CaseFold] = 0x0118c1}, NULL},
-	{0x0118c2, {[CaseLower] = 0x0118c2,[CaseTitle] = 0x0118a2,[CaseUpper] = 0x0118a2,[CaseFold] = 0x0118c2}, NULL},
-	{0x0118c3, {[CaseLower] = 0x0118c3,[CaseTitle] = 0x0118a3,[CaseUpper] = 0x0118a3,[CaseFold] = 0x0118c3}, NULL},
-	{0x0118c4, {[CaseLower] = 0x0118c4,[CaseTitle] = 0x0118a4,[CaseUpper] = 0x0118a4,[CaseFold] = 0x0118c4}, NULL},
-	{0x0118c5, {[CaseLower] = 0x0118c5,[CaseTitle] = 0x0118a5,[CaseUpper] = 0x0118a5,[CaseFold] = 0x0118c5}, NULL},
-	{0x0118c6, {[CaseLower] = 0x0118c6,[CaseTitle] = 0x0118a6,[CaseUpper] = 0x0118a6,[CaseFold] = 0x0118c6}, NULL},
-	{0x0118c7, {[CaseLower] = 0x0118c7,[CaseTitle] = 0x0118a7,[CaseUpper] = 0x0118a7,[CaseFold] = 0x0118c7}, NULL},
-	{0x0118c8, {[CaseLower] = 0x0118c8,[CaseTitle] = 0x0118a8,[CaseUpper] = 0x0118a8,[CaseFold] = 0x0118c8}, NULL},
-	{0x0118c9, {[CaseLower] = 0x0118c9,[CaseTitle] = 0x0118a9,[CaseUpper] = 0x0118a9,[CaseFold] = 0x0118c9}, NULL},
-	{0x0118ca, {[CaseLower] = 0x0118ca,[CaseTitle] = 0x0118aa,[CaseUpper] = 0x0118aa,[CaseFold] = 0x0118ca}, NULL},
-	{0x0118cb, {[CaseLower] = 0x0118cb,[CaseTitle] = 0x0118ab,[CaseUpper] = 0x0118ab,[CaseFold] = 0x0118cb}, NULL},
-	{0x0118cc, {[CaseLower] = 0x0118cc,[CaseTitle] = 0x0118ac,[CaseUpper] = 0x0118ac,[CaseFold] = 0x0118cc}, NULL},
-	{0x0118cd, {[CaseLower] = 0x0118cd,[CaseTitle] = 0x0118ad,[CaseUpper] = 0x0118ad,[CaseFold] = 0x0118cd}, NULL},
-	{0x0118ce, {[CaseLower] = 0x0118ce,[CaseTitle] = 0x0118ae,[CaseUpper] = 0x0118ae,[CaseFold] = 0x0118ce}, NULL},
-	{0x0118cf, {[CaseLower] = 0x0118cf,[CaseTitle] = 0x0118af,[CaseUpper] = 0x0118af,[CaseFold] = 0x0118cf}, NULL},
-	{0x0118d0, {[CaseLower] = 0x0118d0,[CaseTitle] = 0x0118b0,[CaseUpper] = 0x0118b0,[CaseFold] = 0x0118d0}, NULL},
-	{0x0118d1, {[CaseLower] = 0x0118d1,[CaseTitle] = 0x0118b1,[CaseUpper] = 0x0118b1,[CaseFold] = 0x0118d1}, NULL},
-	{0x0118d2, {[CaseLower] = 0x0118d2,[CaseTitle] = 0x0118b2,[CaseUpper] = 0x0118b2,[CaseFold] = 0x0118d2}, NULL},
-	{0x0118d3, {[CaseLower] = 0x0118d3,[CaseTitle] = 0x0118b3,[CaseUpper] = 0x0118b3,[CaseFold] = 0x0118d3}, NULL},
-	{0x0118d4, {[CaseLower] = 0x0118d4,[CaseTitle] = 0x0118b4,[CaseUpper] = 0x0118b4,[CaseFold] = 0x0118d4}, NULL},
-	{0x0118d5, {[CaseLower] = 0x0118d5,[CaseTitle] = 0x0118b5,[CaseUpper] = 0x0118b5,[CaseFold] = 0x0118d5}, NULL},
-	{0x0118d6, {[CaseLower] = 0x0118d6,[CaseTitle] = 0x0118b6,[CaseUpper] = 0x0118b6,[CaseFold] = 0x0118d6}, NULL},
-	{0x0118d7, {[CaseLower] = 0x0118d7,[CaseTitle] = 0x0118b7,[CaseUpper] = 0x0118b7,[CaseFold] = 0x0118d7}, NULL},
-	{0x0118d8, {[CaseLower] = 0x0118d8,[CaseTitle] = 0x0118b8,[CaseUpper] = 0x0118b8,[CaseFold] = 0x0118d8}, NULL},
-	{0x0118d9, {[CaseLower] = 0x0118d9,[CaseTitle] = 0x0118b9,[CaseUpper] = 0x0118b9,[CaseFold] = 0x0118d9}, NULL},
-	{0x0118da, {[CaseLower] = 0x0118da,[CaseTitle] = 0x0118ba,[CaseUpper] = 0x0118ba,[CaseFold] = 0x0118da}, NULL},
-	{0x0118db, {[CaseLower] = 0x0118db,[CaseTitle] = 0x0118bb,[CaseUpper] = 0x0118bb,[CaseFold] = 0x0118db}, NULL},
-	{0x0118dc, {[CaseLower] = 0x0118dc,[CaseTitle] = 0x0118bc,[CaseUpper] = 0x0118bc,[CaseFold] = 0x0118dc}, NULL},
-	{0x0118dd, {[CaseLower] = 0x0118dd,[CaseTitle] = 0x0118bd,[CaseUpper] = 0x0118bd,[CaseFold] = 0x0118dd}, NULL},
-	{0x0118de, {[CaseLower] = 0x0118de,[CaseTitle] = 0x0118be,[CaseUpper] = 0x0118be,[CaseFold] = 0x0118de}, NULL},
-	{0x0118df, {[CaseLower] = 0x0118df,[CaseTitle] = 0x0118bf,[CaseUpper] = 0x0118bf,[CaseFold] = 0x0118df}, NULL},
-	{0x016e40, {[CaseLower] = 0x016e60,[CaseTitle] = 0x016e40,[CaseUpper] = 0x016e40,[CaseFold] = 0x016e60}, NULL},
-	{0x016e41, {[CaseLower] = 0x016e61,[CaseTitle] = 0x016e41,[CaseUpper] = 0x016e41,[CaseFold] = 0x016e61}, NULL},
-	{0x016e42, {[CaseLower] = 0x016e62,[CaseTitle] = 0x016e42,[CaseUpper] = 0x016e42,[CaseFold] = 0x016e62}, NULL},
-	{0x016e43, {[CaseLower] = 0x016e63,[CaseTitle] = 0x016e43,[CaseUpper] = 0x016e43,[CaseFold] = 0x016e63}, NULL},
-	{0x016e44, {[CaseLower] = 0x016e64,[CaseTitle] = 0x016e44,[CaseUpper] = 0x016e44,[CaseFold] = 0x016e64}, NULL},
-	{0x016e45, {[CaseLower] = 0x016e65,[CaseTitle] = 0x016e45,[CaseUpper] = 0x016e45,[CaseFold] = 0x016e65}, NULL},
-	{0x016e46, {[CaseLower] = 0x016e66,[CaseTitle] = 0x016e46,[CaseUpper] = 0x016e46,[CaseFold] = 0x016e66}, NULL},
-	{0x016e47, {[CaseLower] = 0x016e67,[CaseTitle] = 0x016e47,[CaseUpper] = 0x016e47,[CaseFold] = 0x016e67}, NULL},
-	{0x016e48, {[CaseLower] = 0x016e68,[CaseTitle] = 0x016e48,[CaseUpper] = 0x016e48,[CaseFold] = 0x016e68}, NULL},
-	{0x016e49, {[CaseLower] = 0x016e69,[CaseTitle] = 0x016e49,[CaseUpper] = 0x016e49,[CaseFold] = 0x016e69}, NULL},
-	{0x016e4a, {[CaseLower] = 0x016e6a,[CaseTitle] = 0x016e4a,[CaseUpper] = 0x016e4a,[CaseFold] = 0x016e6a}, NULL},
-	{0x016e4b, {[CaseLower] = 0x016e6b,[CaseTitle] = 0x016e4b,[CaseUpper] = 0x016e4b,[CaseFold] = 0x016e6b}, NULL},
-	{0x016e4c, {[CaseLower] = 0x016e6c,[CaseTitle] = 0x016e4c,[CaseUpper] = 0x016e4c,[CaseFold] = 0x016e6c}, NULL},
-	{0x016e4d, {[CaseLower] = 0x016e6d,[CaseTitle] = 0x016e4d,[CaseUpper] = 0x016e4d,[CaseFold] = 0x016e6d}, NULL},
-	{0x016e4e, {[CaseLower] = 0x016e6e,[CaseTitle] = 0x016e4e,[CaseUpper] = 0x016e4e,[CaseFold] = 0x016e6e}, NULL},
-	{0x016e4f, {[CaseLower] = 0x016e6f,[CaseTitle] = 0x016e4f,[CaseUpper] = 0x016e4f,[CaseFold] = 0x016e6f}, NULL},
-	{0x016e50, {[CaseLower] = 0x016e70,[CaseTitle] = 0x016e50,[CaseUpper] = 0x016e50,[CaseFold] = 0x016e70}, NULL},
-	{0x016e51, {[CaseLower] = 0x016e71,[CaseTitle] = 0x016e51,[CaseUpper] = 0x016e51,[CaseFold] = 0x016e71}, NULL},
-	{0x016e52, {[CaseLower] = 0x016e72,[CaseTitle] = 0x016e52,[CaseUpper] = 0x016e52,[CaseFold] = 0x016e72}, NULL},
-	{0x016e53, {[CaseLower] = 0x016e73,[CaseTitle] = 0x016e53,[CaseUpper] = 0x016e53,[CaseFold] = 0x016e73}, NULL},
-	{0x016e54, {[CaseLower] = 0x016e74,[CaseTitle] = 0x016e54,[CaseUpper] = 0x016e54,[CaseFold] = 0x016e74}, NULL},
-	{0x016e55, {[CaseLower] = 0x016e75,[CaseTitle] = 0x016e55,[CaseUpper] = 0x016e55,[CaseFold] = 0x016e75}, NULL},
-	{0x016e56, {[CaseLower] = 0x016e76,[CaseTitle] = 0x016e56,[CaseUpper] = 0x016e56,[CaseFold] = 0x016e76}, NULL},
-	{0x016e57, {[CaseLower] = 0x016e77,[CaseTitle] = 0x016e57,[CaseUpper] = 0x016e57,[CaseFold] = 0x016e77}, NULL},
-	{0x016e58, {[CaseLower] = 0x016e78,[CaseTitle] = 0x016e58,[CaseUpper] = 0x016e58,[CaseFold] = 0x016e78}, NULL},
-	{0x016e59, {[CaseLower] = 0x016e79,[CaseTitle] = 0x016e59,[CaseUpper] = 0x016e59,[CaseFold] = 0x016e79}, NULL},
-	{0x016e5a, {[CaseLower] = 0x016e7a,[CaseTitle] = 0x016e5a,[CaseUpper] = 0x016e5a,[CaseFold] = 0x016e7a}, NULL},
-	{0x016e5b, {[CaseLower] = 0x016e7b,[CaseTitle] = 0x016e5b,[CaseUpper] = 0x016e5b,[CaseFold] = 0x016e7b}, NULL},
-	{0x016e5c, {[CaseLower] = 0x016e7c,[CaseTitle] = 0x016e5c,[CaseUpper] = 0x016e5c,[CaseFold] = 0x016e7c}, NULL},
-	{0x016e5d, {[CaseLower] = 0x016e7d,[CaseTitle] = 0x016e5d,[CaseUpper] = 0x016e5d,[CaseFold] = 0x016e7d}, NULL},
-	{0x016e5e, {[CaseLower] = 0x016e7e,[CaseTitle] = 0x016e5e,[CaseUpper] = 0x016e5e,[CaseFold] = 0x016e7e}, NULL},
-	{0x016e5f, {[CaseLower] = 0x016e7f,[CaseTitle] = 0x016e5f,[CaseUpper] = 0x016e5f,[CaseFold] = 0x016e7f}, NULL},
-	{0x016e60, {[CaseLower] = 0x016e60,[CaseTitle] = 0x016e40,[CaseUpper] = 0x016e40,[CaseFold] = 0x016e60}, NULL},
-	{0x016e61, {[CaseLower] = 0x016e61,[CaseTitle] = 0x016e41,[CaseUpper] = 0x016e41,[CaseFold] = 0x016e61}, NULL},
-	{0x016e62, {[CaseLower] = 0x016e62,[CaseTitle] = 0x016e42,[CaseUpper] = 0x016e42,[CaseFold] = 0x016e62}, NULL},
-	{0x016e63, {[CaseLower] = 0x016e63,[CaseTitle] = 0x016e43,[CaseUpper] = 0x016e43,[CaseFold] = 0x016e63}, NULL},
-	{0x016e64, {[CaseLower] = 0x016e64,[CaseTitle] = 0x016e44,[CaseUpper] = 0x016e44,[CaseFold] = 0x016e64}, NULL},
-	{0x016e65, {[CaseLower] = 0x016e65,[CaseTitle] = 0x016e45,[CaseUpper] = 0x016e45,[CaseFold] = 0x016e65}, NULL},
-	{0x016e66, {[CaseLower] = 0x016e66,[CaseTitle] = 0x016e46,[CaseUpper] = 0x016e46,[CaseFold] = 0x016e66}, NULL},
-	{0x016e67, {[CaseLower] = 0x016e67,[CaseTitle] = 0x016e47,[CaseUpper] = 0x016e47,[CaseFold] = 0x016e67}, NULL},
-	{0x016e68, {[CaseLower] = 0x016e68,[CaseTitle] = 0x016e48,[CaseUpper] = 0x016e48,[CaseFold] = 0x016e68}, NULL},
-	{0x016e69, {[CaseLower] = 0x016e69,[CaseTitle] = 0x016e49,[CaseUpper] = 0x016e49,[CaseFold] = 0x016e69}, NULL},
-	{0x016e6a, {[CaseLower] = 0x016e6a,[CaseTitle] = 0x016e4a,[CaseUpper] = 0x016e4a,[CaseFold] = 0x016e6a}, NULL},
-	{0x016e6b, {[CaseLower] = 0x016e6b,[CaseTitle] = 0x016e4b,[CaseUpper] = 0x016e4b,[CaseFold] = 0x016e6b}, NULL},
-	{0x016e6c, {[CaseLower] = 0x016e6c,[CaseTitle] = 0x016e4c,[CaseUpper] = 0x016e4c,[CaseFold] = 0x016e6c}, NULL},
-	{0x016e6d, {[CaseLower] = 0x016e6d,[CaseTitle] = 0x016e4d,[CaseUpper] = 0x016e4d,[CaseFold] = 0x016e6d}, NULL},
-	{0x016e6e, {[CaseLower] = 0x016e6e,[CaseTitle] = 0x016e4e,[CaseUpper] = 0x016e4e,[CaseFold] = 0x016e6e}, NULL},
-	{0x016e6f, {[CaseLower] = 0x016e6f,[CaseTitle] = 0x016e4f,[CaseUpper] = 0x016e4f,[CaseFold] = 0x016e6f}, NULL},
-	{0x016e70, {[CaseLower] = 0x016e70,[CaseTitle] = 0x016e50,[CaseUpper] = 0x016e50,[CaseFold] = 0x016e70}, NULL},
-	{0x016e71, {[CaseLower] = 0x016e71,[CaseTitle] = 0x016e51,[CaseUpper] = 0x016e51,[CaseFold] = 0x016e71}, NULL},
-	{0x016e72, {[CaseLower] = 0x016e72,[CaseTitle] = 0x016e52,[CaseUpper] = 0x016e52,[CaseFold] = 0x016e72}, NULL},
-	{0x016e73, {[CaseLower] = 0x016e73,[CaseTitle] = 0x016e53,[CaseUpper] = 0x016e53,[CaseFold] = 0x016e73}, NULL},
-	{0x016e74, {[CaseLower] = 0x016e74,[CaseTitle] = 0x016e54,[CaseUpper] = 0x016e54,[CaseFold] = 0x016e74}, NULL},
-	{0x016e75, {[CaseLower] = 0x016e75,[CaseTitle] = 0x016e55,[CaseUpper] = 0x016e55,[CaseFold] = 0x016e75}, NULL},
-	{0x016e76, {[CaseLower] = 0x016e76,[CaseTitle] = 0x016e56,[CaseUpper] = 0x016e56,[CaseFold] = 0x016e76}, NULL},
-	{0x016e77, {[CaseLower] = 0x016e77,[CaseTitle] = 0x016e57,[CaseUpper] = 0x016e57,[CaseFold] = 0x016e77}, NULL},
-	{0x016e78, {[CaseLower] = 0x016e78,[CaseTitle] = 0x016e58,[CaseUpper] = 0x016e58,[CaseFold] = 0x016e78}, NULL},
-	{0x016e79, {[CaseLower] = 0x016e79,[CaseTitle] = 0x016e59,[CaseUpper] = 0x016e59,[CaseFold] = 0x016e79}, NULL},
-	{0x016e7a, {[CaseLower] = 0x016e7a,[CaseTitle] = 0x016e5a,[CaseUpper] = 0x016e5a,[CaseFold] = 0x016e7a}, NULL},
-	{0x016e7b, {[CaseLower] = 0x016e7b,[CaseTitle] = 0x016e5b,[CaseUpper] = 0x016e5b,[CaseFold] = 0x016e7b}, NULL},
-	{0x016e7c, {[CaseLower] = 0x016e7c,[CaseTitle] = 0x016e5c,[CaseUpper] = 0x016e5c,[CaseFold] = 0x016e7c}, NULL},
-	{0x016e7d, {[CaseLower] = 0x016e7d,[CaseTitle] = 0x016e5d,[CaseUpper] = 0x016e5d,[CaseFold] = 0x016e7d}, NULL},
-	{0x016e7e, {[CaseLower] = 0x016e7e,[CaseTitle] = 0x016e5e,[CaseUpper] = 0x016e5e,[CaseFold] = 0x016e7e}, NULL},
-	{0x016e7f, {[CaseLower] = 0x016e7f,[CaseTitle] = 0x016e5f,[CaseUpper] = 0x016e5f,[CaseFold] = 0x016e7f}, NULL},
-	{0x01e900, {[CaseLower] = 0x01e922,[CaseTitle] = 0x01e900,[CaseUpper] = 0x01e900,[CaseFold] = 0x01e922}, NULL},
-	{0x01e901, {[CaseLower] = 0x01e923,[CaseTitle] = 0x01e901,[CaseUpper] = 0x01e901,[CaseFold] = 0x01e923}, NULL},
-	{0x01e902, {[CaseLower] = 0x01e924,[CaseTitle] = 0x01e902,[CaseUpper] = 0x01e902,[CaseFold] = 0x01e924}, NULL},
-	{0x01e903, {[CaseLower] = 0x01e925,[CaseTitle] = 0x01e903,[CaseUpper] = 0x01e903,[CaseFold] = 0x01e925}, NULL},
-	{0x01e904, {[CaseLower] = 0x01e926,[CaseTitle] = 0x01e904,[CaseUpper] = 0x01e904,[CaseFold] = 0x01e926}, NULL},
-	{0x01e905, {[CaseLower] = 0x01e927,[CaseTitle] = 0x01e905,[CaseUpper] = 0x01e905,[CaseFold] = 0x01e927}, NULL},
-	{0x01e906, {[CaseLower] = 0x01e928,[CaseTitle] = 0x01e906,[CaseUpper] = 0x01e906,[CaseFold] = 0x01e928}, NULL},
-	{0x01e907, {[CaseLower] = 0x01e929,[CaseTitle] = 0x01e907,[CaseUpper] = 0x01e907,[CaseFold] = 0x01e929}, NULL},
-	{0x01e908, {[CaseLower] = 0x01e92a,[CaseTitle] = 0x01e908,[CaseUpper] = 0x01e908,[CaseFold] = 0x01e92a}, NULL},
-	{0x01e909, {[CaseLower] = 0x01e92b,[CaseTitle] = 0x01e909,[CaseUpper] = 0x01e909,[CaseFold] = 0x01e92b}, NULL},
-	{0x01e90a, {[CaseLower] = 0x01e92c,[CaseTitle] = 0x01e90a,[CaseUpper] = 0x01e90a,[CaseFold] = 0x01e92c}, NULL},
-	{0x01e90b, {[CaseLower] = 0x01e92d,[CaseTitle] = 0x01e90b,[CaseUpper] = 0x01e90b,[CaseFold] = 0x01e92d}, NULL},
-	{0x01e90c, {[CaseLower] = 0x01e92e,[CaseTitle] = 0x01e90c,[CaseUpper] = 0x01e90c,[CaseFold] = 0x01e92e}, NULL},
-	{0x01e90d, {[CaseLower] = 0x01e92f,[CaseTitle] = 0x01e90d,[CaseUpper] = 0x01e90d,[CaseFold] = 0x01e92f}, NULL},
-	{0x01e90e, {[CaseLower] = 0x01e930,[CaseTitle] = 0x01e90e,[CaseUpper] = 0x01e90e,[CaseFold] = 0x01e930}, NULL},
-	{0x01e90f, {[CaseLower] = 0x01e931,[CaseTitle] = 0x01e90f,[CaseUpper] = 0x01e90f,[CaseFold] = 0x01e931}, NULL},
-	{0x01e910, {[CaseLower] = 0x01e932,[CaseTitle] = 0x01e910,[CaseUpper] = 0x01e910,[CaseFold] = 0x01e932}, NULL},
-	{0x01e911, {[CaseLower] = 0x01e933,[CaseTitle] = 0x01e911,[CaseUpper] = 0x01e911,[CaseFold] = 0x01e933}, NULL},
-	{0x01e912, {[CaseLower] = 0x01e934,[CaseTitle] = 0x01e912,[CaseUpper] = 0x01e912,[CaseFold] = 0x01e934}, NULL},
-	{0x01e913, {[CaseLower] = 0x01e935,[CaseTitle] = 0x01e913,[CaseUpper] = 0x01e913,[CaseFold] = 0x01e935}, NULL},
-	{0x01e914, {[CaseLower] = 0x01e936,[CaseTitle] = 0x01e914,[CaseUpper] = 0x01e914,[CaseFold] = 0x01e936}, NULL},
-	{0x01e915, {[CaseLower] = 0x01e937,[CaseTitle] = 0x01e915,[CaseUpper] = 0x01e915,[CaseFold] = 0x01e937}, NULL},
-	{0x01e916, {[CaseLower] = 0x01e938,[CaseTitle] = 0x01e916,[CaseUpper] = 0x01e916,[CaseFold] = 0x01e938}, NULL},
-	{0x01e917, {[CaseLower] = 0x01e939,[CaseTitle] = 0x01e917,[CaseUpper] = 0x01e917,[CaseFold] = 0x01e939}, NULL},
-	{0x01e918, {[CaseLower] = 0x01e93a,[CaseTitle] = 0x01e918,[CaseUpper] = 0x01e918,[CaseFold] = 0x01e93a}, NULL},
-	{0x01e919, {[CaseLower] = 0x01e93b,[CaseTitle] = 0x01e919,[CaseUpper] = 0x01e919,[CaseFold] = 0x01e93b}, NULL},
-	{0x01e91a, {[CaseLower] = 0x01e93c,[CaseTitle] = 0x01e91a,[CaseUpper] = 0x01e91a,[CaseFold] = 0x01e93c}, NULL},
-	{0x01e91b, {[CaseLower] = 0x01e93d,[CaseTitle] = 0x01e91b,[CaseUpper] = 0x01e91b,[CaseFold] = 0x01e93d}, NULL},
-	{0x01e91c, {[CaseLower] = 0x01e93e,[CaseTitle] = 0x01e91c,[CaseUpper] = 0x01e91c,[CaseFold] = 0x01e93e}, NULL},
-	{0x01e91d, {[CaseLower] = 0x01e93f,[CaseTitle] = 0x01e91d,[CaseUpper] = 0x01e91d,[CaseFold] = 0x01e93f}, NULL},
-	{0x01e91e, {[CaseLower] = 0x01e940,[CaseTitle] = 0x01e91e,[CaseUpper] = 0x01e91e,[CaseFold] = 0x01e940}, NULL},
-	{0x01e91f, {[CaseLower] = 0x01e941,[CaseTitle] = 0x01e91f,[CaseUpper] = 0x01e91f,[CaseFold] = 0x01e941}, NULL},
-	{0x01e920, {[CaseLower] = 0x01e942,[CaseTitle] = 0x01e920,[CaseUpper] = 0x01e920,[CaseFold] = 0x01e942}, NULL},
-	{0x01e921, {[CaseLower] = 0x01e943,[CaseTitle] = 0x01e921,[CaseUpper] = 0x01e921,[CaseFold] = 0x01e943}, NULL},
-	{0x01e922, {[CaseLower] = 0x01e922,[CaseTitle] = 0x01e900,[CaseUpper] = 0x01e900,[CaseFold] = 0x01e922}, NULL},
-	{0x01e923, {[CaseLower] = 0x01e923,[CaseTitle] = 0x01e901,[CaseUpper] = 0x01e901,[CaseFold] = 0x01e923}, NULL},
-	{0x01e924, {[CaseLower] = 0x01e924,[CaseTitle] = 0x01e902,[CaseUpper] = 0x01e902,[CaseFold] = 0x01e924}, NULL},
-	{0x01e925, {[CaseLower] = 0x01e925,[CaseTitle] = 0x01e903,[CaseUpper] = 0x01e903,[CaseFold] = 0x01e925}, NULL},
-	{0x01e926, {[CaseLower] = 0x01e926,[CaseTitle] = 0x01e904,[CaseUpper] = 0x01e904,[CaseFold] = 0x01e926}, NULL},
-	{0x01e927, {[CaseLower] = 0x01e927,[CaseTitle] = 0x01e905,[CaseUpper] = 0x01e905,[CaseFold] = 0x01e927}, NULL},
-	{0x01e928, {[CaseLower] = 0x01e928,[CaseTitle] = 0x01e906,[CaseUpper] = 0x01e906,[CaseFold] = 0x01e928}, NULL},
-	{0x01e929, {[CaseLower] = 0x01e929,[CaseTitle] = 0x01e907,[CaseUpper] = 0x01e907,[CaseFold] = 0x01e929}, NULL},
-	{0x01e92a, {[CaseLower] = 0x01e92a,[CaseTitle] = 0x01e908,[CaseUpper] = 0x01e908,[CaseFold] = 0x01e92a}, NULL},
-	{0x01e92b, {[CaseLower] = 0x01e92b,[CaseTitle] = 0x01e909,[CaseUpper] = 0x01e909,[CaseFold] = 0x01e92b}, NULL},
-	{0x01e92c, {[CaseLower] = 0x01e92c,[CaseTitle] = 0x01e90a,[CaseUpper] = 0x01e90a,[CaseFold] = 0x01e92c}, NULL},
-	{0x01e92d, {[CaseLower] = 0x01e92d,[CaseTitle] = 0x01e90b,[CaseUpper] = 0x01e90b,[CaseFold] = 0x01e92d}, NULL},
-	{0x01e92e, {[CaseLower] = 0x01e92e,[CaseTitle] = 0x01e90c,[CaseUpper] = 0x01e90c,[CaseFold] = 0x01e92e}, NULL},
-	{0x01e92f, {[CaseLower] = 0x01e92f,[CaseTitle] = 0x01e90d,[CaseUpper] = 0x01e90d,[CaseFold] = 0x01e92f}, NULL},
-	{0x01e930, {[CaseLower] = 0x01e930,[CaseTitle] = 0x01e90e,[CaseUpper] = 0x01e90e,[CaseFold] = 0x01e930}, NULL},
-	{0x01e931, {[CaseLower] = 0x01e931,[CaseTitle] = 0x01e90f,[CaseUpper] = 0x01e90f,[CaseFold] = 0x01e931}, NULL},
-	{0x01e932, {[CaseLower] = 0x01e932,[CaseTitle] = 0x01e910,[CaseUpper] = 0x01e910,[CaseFold] = 0x01e932}, NULL},
-	{0x01e933, {[CaseLower] = 0x01e933,[CaseTitle] = 0x01e911,[CaseUpper] = 0x01e911,[CaseFold] = 0x01e933}, NULL},
-	{0x01e934, {[CaseLower] = 0x01e934,[CaseTitle] = 0x01e912,[CaseUpper] = 0x01e912,[CaseFold] = 0x01e934}, NULL},
-	{0x01e935, {[CaseLower] = 0x01e935,[CaseTitle] = 0x01e913,[CaseUpper] = 0x01e913,[CaseFold] = 0x01e935}, NULL},
-	{0x01e936, {[CaseLower] = 0x01e936,[CaseTitle] = 0x01e914,[CaseUpper] = 0x01e914,[CaseFold] = 0x01e936}, NULL},
-	{0x01e937, {[CaseLower] = 0x01e937,[CaseTitle] = 0x01e915,[CaseUpper] = 0x01e915,[CaseFold] = 0x01e937}, NULL},
-	{0x01e938, {[CaseLower] = 0x01e938,[CaseTitle] = 0x01e916,[CaseUpper] = 0x01e916,[CaseFold] = 0x01e938}, NULL},
-	{0x01e939, {[CaseLower] = 0x01e939,[CaseTitle] = 0x01e917,[CaseUpper] = 0x01e917,[CaseFold] = 0x01e939}, NULL},
-	{0x01e93a, {[CaseLower] = 0x01e93a,[CaseTitle] = 0x01e918,[CaseUpper] = 0x01e918,[CaseFold] = 0x01e93a}, NULL},
-	{0x01e93b, {[CaseLower] = 0x01e93b,[CaseTitle] = 0x01e919,[CaseUpper] = 0x01e919,[CaseFold] = 0x01e93b}, NULL},
-	{0x01e93c, {[CaseLower] = 0x01e93c,[CaseTitle] = 0x01e91a,[CaseUpper] = 0x01e91a,[CaseFold] = 0x01e93c}, NULL},
-	{0x01e93d, {[CaseLower] = 0x01e93d,[CaseTitle] = 0x01e91b,[CaseUpper] = 0x01e91b,[CaseFold] = 0x01e93d}, NULL},
-	{0x01e93e, {[CaseLower] = 0x01e93e,[CaseTitle] = 0x01e91c,[CaseUpper] = 0x01e91c,[CaseFold] = 0x01e93e}, NULL},
-	{0x01e93f, {[CaseLower] = 0x01e93f,[CaseTitle] = 0x01e91d,[CaseUpper] = 0x01e91d,[CaseFold] = 0x01e93f}, NULL},
-	{0x01e940, {[CaseLower] = 0x01e940,[CaseTitle] = 0x01e91e,[CaseUpper] = 0x01e91e,[CaseFold] = 0x01e940}, NULL},
-	{0x01e941, {[CaseLower] = 0x01e941,[CaseTitle] = 0x01e91f,[CaseUpper] = 0x01e91f,[CaseFold] = 0x01e941}, NULL},
-	{0x01e942, {[CaseLower] = 0x01e942,[CaseTitle] = 0x01e920,[CaseUpper] = 0x01e920,[CaseFold] = 0x01e942}, NULL},
-	{0x01e943, {[CaseLower] = 0x01e943,[CaseTitle] = 0x01e921,[CaseUpper] = 0x01e921,[CaseFold] = 0x01e943}, NULL},
+/*
+ * Case mapping table for special.
+ */
+static uint8 case_map_special[1677] =
+{
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000000 */
+	0x000000, /* 0x000001 */
+	0x000000, /* 0x000002 */
+	0x000000, /* 0x000003 */
+	0x000000, /* 0x000004 */
+	0x000000, /* 0x000005 */
+	0x000000, /* 0x000006 */
+	0x000000, /* 0x000007 */
+	0x000000, /* 0x000008 */
+	0x000000, /* 0x000009 */
+	0x000000, /* 0x00000a */
+	0x000000, /* 0x00000b */
+	0x000000, /* 0x00000c */
+	0x000000, /* 0x00000d */
+	0x000000, /* 0x00000e */
+	0x000000, /* 0x00000f */
+	0x000000, /* 0x000010 */
+	0x000000, /* 0x000011 */
+	0x000000, /* 0x000012 */
+	0x000000, /* 0x000013 */
+	0x000000, /* 0x000014 */
+	0x000000, /* 0x000015 */
+	0x000000, /* 0x000016 */
+	0x000000, /* 0x000017 */
+	0x000000, /* 0x000018 */
+	0x000000, /* 0x000019 */
+	0x000000, /* 0x00001a */
+	0x000000, /* 0x00001b */
+	0x000000, /* 0x00001c */
+	0x000000, /* 0x00001d */
+	0x000000, /* 0x00001e */
+	0x000000, /* 0x00001f */
+	0x000000, /* 0x000020 */
+	0x000000, /* 0x000021 */
+	0x000000, /* 0x000022 */
+	0x000000, /* 0x000023 */
+	0x000000, /* 0x000024 */
+	0x000000, /* 0x000025 */
+	0x000000, /* 0x000026 */
+	0x000000, /* 0x000027 */
+	0x000000, /* 0x000028 */
+	0x000000, /* 0x000029 */
+	0x000000, /* 0x00002a */
+	0x000000, /* 0x00002b */
+	0x000000, /* 0x00002c */
+	0x000000, /* 0x00002d */
+	0x000000, /* 0x00002e */
+	0x000000, /* 0x00002f */
+	0x000000, /* 0x000030 */
+	0x000000, /* 0x000031 */
+	0x000000, /* 0x000032 */
+	0x000000, /* 0x000033 */
+	0x000000, /* 0x000034 */
+	0x000000, /* 0x000035 */
+	0x000000, /* 0x000036 */
+	0x000000, /* 0x000037 */
+	0x000000, /* 0x000038 */
+	0x000000, /* 0x000039 */
+	0x000000, /* 0x00003a */
+	0x000000, /* 0x00003b */
+	0x000000, /* 0x00003c */
+	0x000000, /* 0x00003d */
+	0x000000, /* 0x00003e */
+	0x000000, /* 0x00003f */
+	0x000000, /* 0x000040 */
+	0x000000, /* 0x000041 */
+	0x000000, /* 0x000042 */
+	0x000000, /* 0x000043 */
+	0x000000, /* 0x000044 */
+	0x000000, /* 0x000045 */
+	0x000000, /* 0x000046 */
+	0x000000, /* 0x000047 */
+	0x000000, /* 0x000048 */
+	0x000000, /* 0x000049 */
+	0x000000, /* 0x00004a */
+	0x000000, /* 0x00004b */
+	0x000000, /* 0x00004c */
+	0x000000, /* 0x00004d */
+	0x000000, /* 0x00004e */
+	0x000000, /* 0x00004f */
+	0x000000, /* 0x000050 */
+	0x000000, /* 0x000051 */
+	0x000000, /* 0x000052 */
+	0x000000, /* 0x000053 */
+	0x000000, /* 0x000054 */
+	0x000000, /* 0x000055 */
+	0x000000, /* 0x000056 */
+	0x000000, /* 0x000057 */
+	0x000000, /* 0x000058 */
+	0x000000, /* 0x000059 */
+	0x000000, /* 0x00005a */
+	0x000000, /* 0x00005b */
+	0x000000, /* 0x00005c */
+	0x000000, /* 0x00005d */
+	0x000000, /* 0x00005e */
+	0x000000, /* 0x00005f */
+	0x000000, /* 0x000060 */
+	0x000000, /* 0x000061 */
+	0x000000, /* 0x000062 */
+	0x000000, /* 0x000063 */
+	0x000000, /* 0x000064 */
+	0x000000, /* 0x000065 */
+	0x000000, /* 0x000066 */
+	0x000000, /* 0x000067 */
+	0x000000, /* 0x000068 */
+	0x000000, /* 0x000069 */
+	0x000000, /* 0x00006a */
+	0x000000, /* 0x00006b */
+	0x000000, /* 0x00006c */
+	0x000000, /* 0x00006d */
+	0x000000, /* 0x00006e */
+	0x000000, /* 0x00006f */
+	0x000000, /* 0x000070 */
+	0x000000, /* 0x000071 */
+	0x000000, /* 0x000072 */
+	0x000000, /* 0x000073 */
+	0x000000, /* 0x000074 */
+	0x000000, /* 0x000075 */
+	0x000000, /* 0x000076 */
+	0x000000, /* 0x000077 */
+	0x000000, /* 0x000078 */
+	0x000000, /* 0x000079 */
+	0x000000, /* 0x00007a */
+	0x000000, /* 0x00007b */
+	0x000000, /* 0x00007c */
+	0x000000, /* 0x00007d */
+	0x000000, /* 0x00007e */
+	0x000000, /* 0x00007f */
+	0x000000, /* 0x0000b5 */
+	0x000000, /* 0x0000c0 */
+	0x000000, /* 0x0000c1 */
+	0x000000, /* 0x0000c2 */
+	0x000000, /* 0x0000c3 */
+	0x000000, /* 0x0000c4 */
+	0x000000, /* 0x0000c5 */
+	0x000000, /* 0x0000c6 */
+	0x000000, /* 0x0000c7 */
+	0x000000, /* 0x0000c8 */
+	0x000000, /* 0x0000c9 */
+	0x000000, /* 0x0000ca */
+	0x000000, /* 0x0000cb */
+	0x000000, /* 0x0000cc */
+	0x000000, /* 0x0000cd */
+	0x000000, /* 0x0000ce */
+	0x000000, /* 0x0000cf */
+	0x000000, /* 0x0000d0 */
+	0x000000, /* 0x0000d1 */
+	0x000000, /* 0x0000d2 */
+	0x000000, /* 0x0000d3 */
+	0x000000, /* 0x0000d4 */
+	0x000000, /* 0x0000d5 */
+	0x000000, /* 0x0000d6 */
+	0x000000, /* 0x0000d8 */
+	0x000000, /* 0x0000d9 */
+	0x000000, /* 0x0000da */
+	0x000000, /* 0x0000db */
+	0x000000, /* 0x0000dc */
+	0x000000, /* 0x0000dd */
+	0x000000, /* 0x0000de */
+	0x000001, /* 0x0000df */
+	0x000000, /* 0x0000ff */
+	0x000000, /* 0x000100 */
+	0x000000, /* 0x000102 */
+	0x000000, /* 0x000104 */
+	0x000000, /* 0x000106 */
+	0x000000, /* 0x000108 */
+	0x000000, /* 0x00010a */
+	0x000000, /* 0x00010c */
+	0x000000, /* 0x00010e */
+	0x000000, /* 0x000110 */
+	0x000000, /* 0x000112 */
+	0x000000, /* 0x000114 */
+	0x000000, /* 0x000116 */
+	0x000000, /* 0x000118 */
+	0x000000, /* 0x00011a */
+	0x000000, /* 0x00011c */
+	0x000000, /* 0x00011e */
+	0x000000, /* 0x000120 */
+	0x000000, /* 0x000122 */
+	0x000000, /* 0x000124 */
+	0x000000, /* 0x000126 */
+	0x000000, /* 0x000128 */
+	0x000000, /* 0x00012a */
+	0x000000, /* 0x00012c */
+	0x000000, /* 0x00012e */
+	0x000002, /* 0x000130 */
+	0x000000, /* 0x000131 */
+	0x000000, /* 0x000132 */
+	0x000000, /* 0x000134 */
+	0x000000, /* 0x000136 */
+	0x000000, /* 0x000139 */
+	0x000000, /* 0x00013b */
+	0x000000, /* 0x00013d */
+	0x000000, /* 0x00013f */
+	0x000000, /* 0x000141 */
+	0x000000, /* 0x000143 */
+	0x000000, /* 0x000145 */
+	0x000000, /* 0x000147 */
+	0x000003, /* 0x000149 */
+	0x000000, /* 0x00014a */
+	0x000000, /* 0x00014c */
+	0x000000, /* 0x00014e */
+	0x000000, /* 0x000150 */
+	0x000000, /* 0x000152 */
+	0x000000, /* 0x000154 */
+	0x000000, /* 0x000156 */
+	0x000000, /* 0x000158 */
+	0x000000, /* 0x00015a */
+	0x000000, /* 0x00015c */
+	0x000000, /* 0x00015e */
+	0x000000, /* 0x000160 */
+	0x000000, /* 0x000162 */
+	0x000000, /* 0x000164 */
+	0x000000, /* 0x000166 */
+	0x000000, /* 0x000168 */
+	0x000000, /* 0x00016a */
+	0x000000, /* 0x00016c */
+	0x000000, /* 0x00016e */
+	0x000000, /* 0x000170 */
+	0x000000, /* 0x000172 */
+	0x000000, /* 0x000174 */
+	0x000000, /* 0x000176 */
+	0x000000, /* 0x000179 */
+	0x000000, /* 0x00017b */
+	0x000000, /* 0x00017d */
+	0x000000, /* 0x00017f */
+	0x000000, /* 0x000180 */
+	0x000000, /* 0x000181 */
+	0x000000, /* 0x000182 */
+	0x000000, /* 0x000184 */
+	0x000000, /* 0x000186 */
+	0x000000, /* 0x000187 */
+	0x000000, /* 0x000189 */
+	0x000000, /* 0x00018a */
+	0x000000, /* 0x00018b */
+	0x000000, /* 0x00018e */
+	0x000000, /* 0x00018f */
+	0x000000, /* 0x000190 */
+	0x000000, /* 0x000191 */
+	0x000000, /* 0x000193 */
+	0x000000, /* 0x000194 */
+	0x000000, /* 0x000195 */
+	0x000000, /* 0x000196 */
+	0x000000, /* 0x000197 */
+	0x000000, /* 0x000198 */
+	0x000000, /* 0x00019a */
+	0x000000, /* 0x00019c */
+	0x000000, /* 0x00019d */
+	0x000000, /* 0x00019e */
+	0x000000, /* 0x00019f */
+	0x000000, /* 0x0001a0 */
+	0x000000, /* 0x0001a2 */
+	0x000000, /* 0x0001a4 */
+	0x000000, /* 0x0001a6 */
+	0x000000, /* 0x0001a7 */
+	0x000000, /* 0x0001a9 */
+	0x000000, /* 0x0001ac */
+	0x000000, /* 0x0001ae */
+	0x000000, /* 0x0001af */
+	0x000000, /* 0x0001b1 */
+	0x000000, /* 0x0001b2 */
+	0x000000, /* 0x0001b3 */
+	0x000000, /* 0x0001b5 */
+	0x000000, /* 0x0001b7 */
+	0x000000, /* 0x0001b8 */
+	0x000000, /* 0x0001bc */
+	0x000000, /* 0x0001bf */
+	0x000000, /* 0x0001c4 */
+	0x000000, /* 0x0001c7 */
+	0x000000, /* 0x0001ca */
+	0x000000, /* 0x0001cd */
+	0x000000, /* 0x0001cf */
+	0x000000, /* 0x0001d1 */
+	0x000000, /* 0x0001d3 */
+	0x000000, /* 0x0001d5 */
+	0x000000, /* 0x0001d7 */
+	0x000000, /* 0x0001d9 */
+	0x000000, /* 0x0001db */
+	0x000000, /* 0x0001de */
+	0x000000, /* 0x0001e0 */
+	0x000000, /* 0x0001e2 */
+	0x000000, /* 0x0001e4 */
+	0x000000, /* 0x0001e6 */
+	0x000000, /* 0x0001e8 */
+	0x000000, /* 0x0001ea */
+	0x000000, /* 0x0001ec */
+	0x000000, /* 0x0001ee */
+	0x000004, /* 0x0001f0 */
+	0x000000, /* 0x0001f1 */
+	0x000000, /* 0x0001f4 */
+	0x000000, /* 0x0001f8 */
+	0x000000, /* 0x0001fa */
+	0x000000, /* 0x0001fc */
+	0x000000, /* 0x0001fe */
+	0x000000, /* 0x000200 */
+	0x000000, /* 0x000202 */
+	0x000000, /* 0x000204 */
+	0x000000, /* 0x000206 */
+	0x000000, /* 0x000208 */
+	0x000000, /* 0x00020a */
+	0x000000, /* 0x00020c */
+	0x000000, /* 0x00020e */
+	0x000000, /* 0x000210 */
+	0x000000, /* 0x000212 */
+	0x000000, /* 0x000214 */
+	0x000000, /* 0x000216 */
+	0x000000, /* 0x000218 */
+	0x000000, /* 0x00021a */
+	0x000000, /* 0x00021c */
+	0x000000, /* 0x00021e */
+	0x000000, /* 0x000222 */
+	0x000000, /* 0x000224 */
+	0x000000, /* 0x000226 */
+	0x000000, /* 0x000228 */
+	0x000000, /* 0x00022a */
+	0x000000, /* 0x00022c */
+	0x000000, /* 0x00022e */
+	0x000000, /* 0x000230 */
+	0x000000, /* 0x000232 */
+	0x000000, /* 0x00023a */
+	0x000000, /* 0x00023b */
+	0x000000, /* 0x00023e */
+	0x000000, /* 0x00023f */
+	0x000000, /* 0x000240 */
+	0x000000, /* 0x000241 */
+	0x000000, /* 0x000244 */
+	0x000000, /* 0x000245 */
+	0x000000, /* 0x000246 */
+	0x000000, /* 0x000248 */
+	0x000000, /* 0x00024a */
+	0x000000, /* 0x00024c */
+	0x000000, /* 0x00024e */
+	0x000000, /* 0x000250 */
+	0x000000, /* 0x000251 */
+	0x000000, /* 0x000252 */
+	0x000000, /* 0x00025c */
+	0x000000, /* 0x000261 */
+	0x000000, /* 0x000265 */
+	0x000000, /* 0x000266 */
+	0x000000, /* 0x00026a */
+	0x000000, /* 0x00026b */
+	0x000000, /* 0x00026c */
+	0x000000, /* 0x000271 */
+	0x000000, /* 0x00027d */
+	0x000000, /* 0x000282 */
+	0x000000, /* 0x000287 */
+	0x000000, /* 0x00029d */
+	0x000000, /* 0x00029e */
+	0x000000, /* 0x000345 */
+	0x000000, /* 0x000370 */
+	0x000000, /* 0x000372 */
+	0x000000, /* 0x000376 */
+	0x000000, /* 0x00037b */
+	0x000000, /* 0x00037c */
+	0x000000, /* 0x00037d */
+	0x000000, /* 0x00037f */
+	0x000000, /* 0x000386 */
+	0x000000, /* 0x000388 */
+	0x000000, /* 0x000389 */
+	0x000000, /* 0x00038a */
+	0x000000, /* 0x00038c */
+	0x000000, /* 0x00038e */
+	0x000000, /* 0x00038f */
+	0x000005, /* 0x000390 */
+	0x000000, /* 0x000391 */
+	0x000000, /* 0x000392 */
+	0x000000, /* 0x000393 */
+	0x000000, /* 0x000394 */
+	0x000000, /* 0x000395 */
+	0x000000, /* 0x000396 */
+	0x000000, /* 0x000397 */
+	0x000000, /* 0x000398 */
+	0x000000, /* 0x000399 */
+	0x000000, /* 0x00039a */
+	0x000000, /* 0x00039b */
+	0x000000, /* 0x00039c */
+	0x000000, /* 0x00039d */
+	0x000000, /* 0x00039e */
+	0x000000, /* 0x00039f */
+	0x000000, /* 0x0003a0 */
+	0x000000, /* 0x0003a1 */
+	0x000006, /* 0x0003a3 */
+	0x000000, /* 0x0003a4 */
+	0x000000, /* 0x0003a5 */
+	0x000000, /* 0x0003a6 */
+	0x000000, /* 0x0003a7 */
+	0x000000, /* 0x0003a8 */
+	0x000000, /* 0x0003a9 */
+	0x000000, /* 0x0003aa */
+	0x000000, /* 0x0003ab */
+	0x000007, /* 0x0003b0 */
+	0x000000, /* 0x0003c2 */
+	0x000000, /* 0x0003c3 */
+	0x000000, /* 0x0003cf */
+	0x000000, /* 0x0003d0 */
+	0x000000, /* 0x0003d1 */
+	0x000000, /* 0x0003d5 */
+	0x000000, /* 0x0003d6 */
+	0x000000, /* 0x0003d8 */
+	0x000000, /* 0x0003da */
+	0x000000, /* 0x0003dc */
+	0x000000, /* 0x0003de */
+	0x000000, /* 0x0003e0 */
+	0x000000, /* 0x0003e2 */
+	0x000000, /* 0x0003e4 */
+	0x000000, /* 0x0003e6 */
+	0x000000, /* 0x0003e8 */
+	0x000000, /* 0x0003ea */
+	0x000000, /* 0x0003ec */
+	0x000000, /* 0x0003ee */
+	0x000000, /* 0x0003f0 */
+	0x000000, /* 0x0003f1 */
+	0x000000, /* 0x0003f2 */
+	0x000000, /* 0x0003f4 */
+	0x000000, /* 0x0003f5 */
+	0x000000, /* 0x0003f7 */
+	0x000000, /* 0x0003fa */
+	0x000000, /* 0x000400 */
+	0x000000, /* 0x000401 */
+	0x000000, /* 0x000402 */
+	0x000000, /* 0x000403 */
+	0x000000, /* 0x000404 */
+	0x000000, /* 0x000405 */
+	0x000000, /* 0x000406 */
+	0x000000, /* 0x000407 */
+	0x000000, /* 0x000408 */
+	0x000000, /* 0x000409 */
+	0x000000, /* 0x00040a */
+	0x000000, /* 0x00040b */
+	0x000000, /* 0x00040c */
+	0x000000, /* 0x00040d */
+	0x000000, /* 0x00040e */
+	0x000000, /* 0x00040f */
+	0x000000, /* 0x000410 */
+	0x000000, /* 0x000411 */
+	0x000000, /* 0x000412 */
+	0x000000, /* 0x000413 */
+	0x000000, /* 0x000414 */
+	0x000000, /* 0x000415 */
+	0x000000, /* 0x000416 */
+	0x000000, /* 0x000417 */
+	0x000000, /* 0x000418 */
+	0x000000, /* 0x000419 */
+	0x000000, /* 0x00041a */
+	0x000000, /* 0x00041b */
+	0x000000, /* 0x00041c */
+	0x000000, /* 0x00041d */
+	0x000000, /* 0x00041e */
+	0x000000, /* 0x00041f */
+	0x000000, /* 0x000420 */
+	0x000000, /* 0x000421 */
+	0x000000, /* 0x000422 */
+	0x000000, /* 0x000423 */
+	0x000000, /* 0x000424 */
+	0x000000, /* 0x000425 */
+	0x000000, /* 0x000426 */
+	0x000000, /* 0x000427 */
+	0x000000, /* 0x000428 */
+	0x000000, /* 0x000429 */
+	0x000000, /* 0x00042a */
+	0x000000, /* 0x00042b */
+	0x000000, /* 0x00042c */
+	0x000000, /* 0x00042d */
+	0x000000, /* 0x00042e */
+	0x000000, /* 0x00042f */
+	0x000000, /* 0x000460 */
+	0x000000, /* 0x000462 */
+	0x000000, /* 0x000464 */
+	0x000000, /* 0x000466 */
+	0x000000, /* 0x000468 */
+	0x000000, /* 0x00046a */
+	0x000000, /* 0x00046c */
+	0x000000, /* 0x00046e */
+	0x000000, /* 0x000470 */
+	0x000000, /* 0x000472 */
+	0x000000, /* 0x000474 */
+	0x000000, /* 0x000476 */
+	0x000000, /* 0x000478 */
+	0x000000, /* 0x00047a */
+	0x000000, /* 0x00047c */
+	0x000000, /* 0x00047e */
+	0x000000, /* 0x000480 */
+	0x000000, /* 0x00048a */
+	0x000000, /* 0x00048c */
+	0x000000, /* 0x00048e */
+	0x000000, /* 0x000490 */
+	0x000000, /* 0x000492 */
+	0x000000, /* 0x000494 */
+	0x000000, /* 0x000496 */
+	0x000000, /* 0x000498 */
+	0x000000, /* 0x00049a */
+	0x000000, /* 0x00049c */
+	0x000000, /* 0x00049e */
+	0x000000, /* 0x0004a0 */
+	0x000000, /* 0x0004a2 */
+	0x000000, /* 0x0004a4 */
+	0x000000, /* 0x0004a6 */
+	0x000000, /* 0x0004a8 */
+	0x000000, /* 0x0004aa */
+	0x000000, /* 0x0004ac */
+	0x000000, /* 0x0004ae */
+	0x000000, /* 0x0004b0 */
+	0x000000, /* 0x0004b2 */
+	0x000000, /* 0x0004b4 */
+	0x000000, /* 0x0004b6 */
+	0x000000, /* 0x0004b8 */
+	0x000000, /* 0x0004ba */
+	0x000000, /* 0x0004bc */
+	0x000000, /* 0x0004be */
+	0x000000, /* 0x0004c0 */
+	0x000000, /* 0x0004c1 */
+	0x000000, /* 0x0004c3 */
+	0x000000, /* 0x0004c5 */
+	0x000000, /* 0x0004c7 */
+	0x000000, /* 0x0004c9 */
+	0x000000, /* 0x0004cb */
+	0x000000, /* 0x0004cd */
+	0x000000, /* 0x0004d0 */
+	0x000000, /* 0x0004d2 */
+	0x000000, /* 0x0004d4 */
+	0x000000, /* 0x0004d6 */
+	0x000000, /* 0x0004d8 */
+	0x000000, /* 0x0004da */
+	0x000000, /* 0x0004dc */
+	0x000000, /* 0x0004de */
+	0x000000, /* 0x0004e0 */
+	0x000000, /* 0x0004e2 */
+	0x000000, /* 0x0004e4 */
+	0x000000, /* 0x0004e6 */
+	0x000000, /* 0x0004e8 */
+	0x000000, /* 0x0004ea */
+	0x000000, /* 0x0004ec */
+	0x000000, /* 0x0004ee */
+	0x000000, /* 0x0004f0 */
+	0x000000, /* 0x0004f2 */
+	0x000000, /* 0x0004f4 */
+	0x000000, /* 0x0004f6 */
+	0x000000, /* 0x0004f8 */
+	0x000000, /* 0x0004fa */
+	0x000000, /* 0x0004fc */
+	0x000000, /* 0x0004fe */
+	0x000000, /* 0x000500 */
+	0x000000, /* 0x000502 */
+	0x000000, /* 0x000504 */
+	0x000000, /* 0x000506 */
+	0x000000, /* 0x000508 */
+	0x000000, /* 0x00050a */
+	0x000000, /* 0x00050c */
+	0x000000, /* 0x00050e */
+	0x000000, /* 0x000510 */
+	0x000000, /* 0x000512 */
+	0x000000, /* 0x000514 */
+	0x000000, /* 0x000516 */
+	0x000000, /* 0x000518 */
+	0x000000, /* 0x00051a */
+	0x000000, /* 0x00051c */
+	0x000000, /* 0x00051e */
+	0x000000, /* 0x000520 */
+	0x000000, /* 0x000522 */
+	0x000000, /* 0x000524 */
+	0x000000, /* 0x000526 */
+	0x000000, /* 0x000528 */
+	0x000000, /* 0x00052a */
+	0x000000, /* 0x00052c */
+	0x000000, /* 0x00052e */
+	0x000000, /* 0x000531 */
+	0x000000, /* 0x000532 */
+	0x000000, /* 0x000533 */
+	0x000000, /* 0x000534 */
+	0x000000, /* 0x000535 */
+	0x000000, /* 0x000536 */
+	0x000000, /* 0x000537 */
+	0x000000, /* 0x000538 */
+	0x000000, /* 0x000539 */
+	0x000000, /* 0x00053a */
+	0x000000, /* 0x00053b */
+	0x000000, /* 0x00053c */
+	0x000000, /* 0x00053d */
+	0x000000, /* 0x00053e */
+	0x000000, /* 0x00053f */
+	0x000000, /* 0x000540 */
+	0x000000, /* 0x000541 */
+	0x000000, /* 0x000542 */
+	0x000000, /* 0x000543 */
+	0x000000, /* 0x000544 */
+	0x000000, /* 0x000545 */
+	0x000000, /* 0x000546 */
+	0x000000, /* 0x000547 */
+	0x000000, /* 0x000548 */
+	0x000000, /* 0x000549 */
+	0x000000, /* 0x00054a */
+	0x000000, /* 0x00054b */
+	0x000000, /* 0x00054c */
+	0x000000, /* 0x00054d */
+	0x000000, /* 0x00054e */
+	0x000000, /* 0x00054f */
+	0x000000, /* 0x000550 */
+	0x000000, /* 0x000551 */
+	0x000000, /* 0x000552 */
+	0x000000, /* 0x000553 */
+	0x000000, /* 0x000554 */
+	0x000000, /* 0x000555 */
+	0x000000, /* 0x000556 */
+	0x000008, /* 0x000587 */
+	0x000000, /* 0x0010a0 */
+	0x000000, /* 0x0010a1 */
+	0x000000, /* 0x0010a2 */
+	0x000000, /* 0x0010a3 */
+	0x000000, /* 0x0010a4 */
+	0x000000, /* 0x0010a5 */
+	0x000000, /* 0x0010a6 */
+	0x000000, /* 0x0010a7 */
+	0x000000, /* 0x0010a8 */
+	0x000000, /* 0x0010a9 */
+	0x000000, /* 0x0010aa */
+	0x000000, /* 0x0010ab */
+	0x000000, /* 0x0010ac */
+	0x000000, /* 0x0010ad */
+	0x000000, /* 0x0010ae */
+	0x000000, /* 0x0010af */
+	0x000000, /* 0x0010b0 */
+	0x000000, /* 0x0010b1 */
+	0x000000, /* 0x0010b2 */
+	0x000000, /* 0x0010b3 */
+	0x000000, /* 0x0010b4 */
+	0x000000, /* 0x0010b5 */
+	0x000000, /* 0x0010b6 */
+	0x000000, /* 0x0010b7 */
+	0x000000, /* 0x0010b8 */
+	0x000000, /* 0x0010b9 */
+	0x000000, /* 0x0010ba */
+	0x000000, /* 0x0010bb */
+	0x000000, /* 0x0010bc */
+	0x000000, /* 0x0010bd */
+	0x000000, /* 0x0010be */
+	0x000000, /* 0x0010bf */
+	0x000000, /* 0x0010c0 */
+	0x000000, /* 0x0010c1 */
+	0x000000, /* 0x0010c2 */
+	0x000000, /* 0x0010c3 */
+	0x000000, /* 0x0010c4 */
+	0x000000, /* 0x0010c5 */
+	0x000000, /* 0x0010c7 */
+	0x000000, /* 0x0010cd */
+	0x000000, /* 0x0010d0 */
+	0x000000, /* 0x0010d1 */
+	0x000000, /* 0x0010d2 */
+	0x000000, /* 0x0010d3 */
+	0x000000, /* 0x0010d4 */
+	0x000000, /* 0x0010d5 */
+	0x000000, /* 0x0010d6 */
+	0x000000, /* 0x0010d7 */
+	0x000000, /* 0x0010d8 */
+	0x000000, /* 0x0010d9 */
+	0x000000, /* 0x0010da */
+	0x000000, /* 0x0010db */
+	0x000000, /* 0x0010dc */
+	0x000000, /* 0x0010dd */
+	0x000000, /* 0x0010de */
+	0x000000, /* 0x0010df */
+	0x000000, /* 0x0010e0 */
+	0x000000, /* 0x0010e1 */
+	0x000000, /* 0x0010e2 */
+	0x000000, /* 0x0010e3 */
+	0x000000, /* 0x0010e4 */
+	0x000000, /* 0x0010e5 */
+	0x000000, /* 0x0010e6 */
+	0x000000, /* 0x0010e7 */
+	0x000000, /* 0x0010e8 */
+	0x000000, /* 0x0010e9 */
+	0x000000, /* 0x0010ea */
+	0x000000, /* 0x0010eb */
+	0x000000, /* 0x0010ec */
+	0x000000, /* 0x0010ed */
+	0x000000, /* 0x0010ee */
+	0x000000, /* 0x0010ef */
+	0x000000, /* 0x0010f0 */
+	0x000000, /* 0x0010f1 */
+	0x000000, /* 0x0010f2 */
+	0x000000, /* 0x0010f3 */
+	0x000000, /* 0x0010f4 */
+	0x000000, /* 0x0010f5 */
+	0x000000, /* 0x0010f6 */
+	0x000000, /* 0x0010f7 */
+	0x000000, /* 0x0010f8 */
+	0x000000, /* 0x0010f9 */
+	0x000000, /* 0x0010fa */
+	0x000000, /* 0x0010fd */
+	0x000000, /* 0x0010fe */
+	0x000000, /* 0x0010ff */
+	0x000000, /* 0x0013a0 */
+	0x000000, /* 0x0013a1 */
+	0x000000, /* 0x0013a2 */
+	0x000000, /* 0x0013a3 */
+	0x000000, /* 0x0013a4 */
+	0x000000, /* 0x0013a5 */
+	0x000000, /* 0x0013a6 */
+	0x000000, /* 0x0013a7 */
+	0x000000, /* 0x0013a8 */
+	0x000000, /* 0x0013a9 */
+	0x000000, /* 0x0013aa */
+	0x000000, /* 0x0013ab */
+	0x000000, /* 0x0013ac */
+	0x000000, /* 0x0013ad */
+	0x000000, /* 0x0013ae */
+	0x000000, /* 0x0013af */
+	0x000000, /* 0x0013b0 */
+	0x000000, /* 0x0013b1 */
+	0x000000, /* 0x0013b2 */
+	0x000000, /* 0x0013b3 */
+	0x000000, /* 0x0013b4 */
+	0x000000, /* 0x0013b5 */
+	0x000000, /* 0x0013b6 */
+	0x000000, /* 0x0013b7 */
+	0x000000, /* 0x0013b8 */
+	0x000000, /* 0x0013b9 */
+	0x000000, /* 0x0013ba */
+	0x000000, /* 0x0013bb */
+	0x000000, /* 0x0013bc */
+	0x000000, /* 0x0013bd */
+	0x000000, /* 0x0013be */
+	0x000000, /* 0x0013bf */
+	0x000000, /* 0x0013c0 */
+	0x000000, /* 0x0013c1 */
+	0x000000, /* 0x0013c2 */
+	0x000000, /* 0x0013c3 */
+	0x000000, /* 0x0013c4 */
+	0x000000, /* 0x0013c5 */
+	0x000000, /* 0x0013c6 */
+	0x000000, /* 0x0013c7 */
+	0x000000, /* 0x0013c8 */
+	0x000000, /* 0x0013c9 */
+	0x000000, /* 0x0013ca */
+	0x000000, /* 0x0013cb */
+	0x000000, /* 0x0013cc */
+	0x000000, /* 0x0013cd */
+	0x000000, /* 0x0013ce */
+	0x000000, /* 0x0013cf */
+	0x000000, /* 0x0013d0 */
+	0x000000, /* 0x0013d1 */
+	0x000000, /* 0x0013d2 */
+	0x000000, /* 0x0013d3 */
+	0x000000, /* 0x0013d4 */
+	0x000000, /* 0x0013d5 */
+	0x000000, /* 0x0013d6 */
+	0x000000, /* 0x0013d7 */
+	0x000000, /* 0x0013d8 */
+	0x000000, /* 0x0013d9 */
+	0x000000, /* 0x0013da */
+	0x000000, /* 0x0013db */
+	0x000000, /* 0x0013dc */
+	0x000000, /* 0x0013dd */
+	0x000000, /* 0x0013de */
+	0x000000, /* 0x0013df */
+	0x000000, /* 0x0013e0 */
+	0x000000, /* 0x0013e1 */
+	0x000000, /* 0x0013e2 */
+	0x000000, /* 0x0013e3 */
+	0x000000, /* 0x0013e4 */
+	0x000000, /* 0x0013e5 */
+	0x000000, /* 0x0013e6 */
+	0x000000, /* 0x0013e7 */
+	0x000000, /* 0x0013e8 */
+	0x000000, /* 0x0013e9 */
+	0x000000, /* 0x0013ea */
+	0x000000, /* 0x0013eb */
+	0x000000, /* 0x0013ec */
+	0x000000, /* 0x0013ed */
+	0x000000, /* 0x0013ee */
+	0x000000, /* 0x0013ef */
+	0x000000, /* 0x0013f0 */
+	0x000000, /* 0x0013f1 */
+	0x000000, /* 0x0013f2 */
+	0x000000, /* 0x0013f3 */
+	0x000000, /* 0x0013f4 */
+	0x000000, /* 0x0013f5 */
+	0x000000, /* 0x001c80 */
+	0x000000, /* 0x001c81 */
+	0x000000, /* 0x001c82 */
+	0x000000, /* 0x001c83 */
+	0x000000, /* 0x001c84 */
+	0x000000, /* 0x001c85 */
+	0x000000, /* 0x001c86 */
+	0x000000, /* 0x001c87 */
+	0x000000, /* 0x001c88 */
+	0x000000, /* 0x001c90 */
+	0x000000, /* 0x001c91 */
+	0x000000, /* 0x001c92 */
+	0x000000, /* 0x001c93 */
+	0x000000, /* 0x001c94 */
+	0x000000, /* 0x001c95 */
+	0x000000, /* 0x001c96 */
+	0x000000, /* 0x001c97 */
+	0x000000, /* 0x001c98 */
+	0x000000, /* 0x001c99 */
+	0x000000, /* 0x001c9a */
+	0x000000, /* 0x001c9b */
+	0x000000, /* 0x001c9c */
+	0x000000, /* 0x001c9d */
+	0x000000, /* 0x001c9e */
+	0x000000, /* 0x001c9f */
+	0x000000, /* 0x001ca0 */
+	0x000000, /* 0x001ca1 */
+	0x000000, /* 0x001ca2 */
+	0x000000, /* 0x001ca3 */
+	0x000000, /* 0x001ca4 */
+	0x000000, /* 0x001ca5 */
+	0x000000, /* 0x001ca6 */
+	0x000000, /* 0x001ca7 */
+	0x000000, /* 0x001ca8 */
+	0x000000, /* 0x001ca9 */
+	0x000000, /* 0x001caa */
+	0x000000, /* 0x001cab */
+	0x000000, /* 0x001cac */
+	0x000000, /* 0x001cad */
+	0x000000, /* 0x001cae */
+	0x000000, /* 0x001caf */
+	0x000000, /* 0x001cb0 */
+	0x000000, /* 0x001cb1 */
+	0x000000, /* 0x001cb2 */
+	0x000000, /* 0x001cb3 */
+	0x000000, /* 0x001cb4 */
+	0x000000, /* 0x001cb5 */
+	0x000000, /* 0x001cb6 */
+	0x000000, /* 0x001cb7 */
+	0x000000, /* 0x001cb8 */
+	0x000000, /* 0x001cb9 */
+	0x000000, /* 0x001cba */
+	0x000000, /* 0x001cbd */
+	0x000000, /* 0x001cbe */
+	0x000000, /* 0x001cbf */
+	0x000000, /* 0x001d79 */
+	0x000000, /* 0x001d7d */
+	0x000000, /* 0x001d8e */
+	0x000000, /* 0x001e00 */
+	0x000000, /* 0x001e02 */
+	0x000000, /* 0x001e04 */
+	0x000000, /* 0x001e06 */
+	0x000000, /* 0x001e08 */
+	0x000000, /* 0x001e0a */
+	0x000000, /* 0x001e0c */
+	0x000000, /* 0x001e0e */
+	0x000000, /* 0x001e10 */
+	0x000000, /* 0x001e12 */
+	0x000000, /* 0x001e14 */
+	0x000000, /* 0x001e16 */
+	0x000000, /* 0x001e18 */
+	0x000000, /* 0x001e1a */
+	0x000000, /* 0x001e1c */
+	0x000000, /* 0x001e1e */
+	0x000000, /* 0x001e20 */
+	0x000000, /* 0x001e22 */
+	0x000000, /* 0x001e24 */
+	0x000000, /* 0x001e26 */
+	0x000000, /* 0x001e28 */
+	0x000000, /* 0x001e2a */
+	0x000000, /* 0x001e2c */
+	0x000000, /* 0x001e2e */
+	0x000000, /* 0x001e30 */
+	0x000000, /* 0x001e32 */
+	0x000000, /* 0x001e34 */
+	0x000000, /* 0x001e36 */
+	0x000000, /* 0x001e38 */
+	0x000000, /* 0x001e3a */
+	0x000000, /* 0x001e3c */
+	0x000000, /* 0x001e3e */
+	0x000000, /* 0x001e40 */
+	0x000000, /* 0x001e42 */
+	0x000000, /* 0x001e44 */
+	0x000000, /* 0x001e46 */
+	0x000000, /* 0x001e48 */
+	0x000000, /* 0x001e4a */
+	0x000000, /* 0x001e4c */
+	0x000000, /* 0x001e4e */
+	0x000000, /* 0x001e50 */
+	0x000000, /* 0x001e52 */
+	0x000000, /* 0x001e54 */
+	0x000000, /* 0x001e56 */
+	0x000000, /* 0x001e58 */
+	0x000000, /* 0x001e5a */
+	0x000000, /* 0x001e5c */
+	0x000000, /* 0x001e5e */
+	0x000000, /* 0x001e60 */
+	0x000000, /* 0x001e62 */
+	0x000000, /* 0x001e64 */
+	0x000000, /* 0x001e66 */
+	0x000000, /* 0x001e68 */
+	0x000000, /* 0x001e6a */
+	0x000000, /* 0x001e6c */
+	0x000000, /* 0x001e6e */
+	0x000000, /* 0x001e70 */
+	0x000000, /* 0x001e72 */
+	0x000000, /* 0x001e74 */
+	0x000000, /* 0x001e76 */
+	0x000000, /* 0x001e78 */
+	0x000000, /* 0x001e7a */
+	0x000000, /* 0x001e7c */
+	0x000000, /* 0x001e7e */
+	0x000000, /* 0x001e80 */
+	0x000000, /* 0x001e82 */
+	0x000000, /* 0x001e84 */
+	0x000000, /* 0x001e86 */
+	0x000000, /* 0x001e88 */
+	0x000000, /* 0x001e8a */
+	0x000000, /* 0x001e8c */
+	0x000000, /* 0x001e8e */
+	0x000000, /* 0x001e90 */
+	0x000000, /* 0x001e92 */
+	0x000000, /* 0x001e94 */
+	0x000009, /* 0x001e96 */
+	0x00000a, /* 0x001e97 */
+	0x00000b, /* 0x001e98 */
+	0x00000c, /* 0x001e99 */
+	0x00000d, /* 0x001e9a */
+	0x000000, /* 0x001e9b */
+	0x00000e, /* 0x001e9e */
+	0x000000, /* 0x001ea0 */
+	0x000000, /* 0x001ea2 */
+	0x000000, /* 0x001ea4 */
+	0x000000, /* 0x001ea6 */
+	0x000000, /* 0x001ea8 */
+	0x000000, /* 0x001eaa */
+	0x000000, /* 0x001eac */
+	0x000000, /* 0x001eae */
+	0x000000, /* 0x001eb0 */
+	0x000000, /* 0x001eb2 */
+	0x000000, /* 0x001eb4 */
+	0x000000, /* 0x001eb6 */
+	0x000000, /* 0x001eb8 */
+	0x000000, /* 0x001eba */
+	0x000000, /* 0x001ebc */
+	0x000000, /* 0x001ebe */
+	0x000000, /* 0x001ec0 */
+	0x000000, /* 0x001ec2 */
+	0x000000, /* 0x001ec4 */
+	0x000000, /* 0x001ec6 */
+	0x000000, /* 0x001ec8 */
+	0x000000, /* 0x001eca */
+	0x000000, /* 0x001ecc */
+	0x000000, /* 0x001ece */
+	0x000000, /* 0x001ed0 */
+	0x000000, /* 0x001ed2 */
+	0x000000, /* 0x001ed4 */
+	0x000000, /* 0x001ed6 */
+	0x000000, /* 0x001ed8 */
+	0x000000, /* 0x001eda */
+	0x000000, /* 0x001edc */
+	0x000000, /* 0x001ede */
+	0x000000, /* 0x001ee0 */
+	0x000000, /* 0x001ee2 */
+	0x000000, /* 0x001ee4 */
+	0x000000, /* 0x001ee6 */
+	0x000000, /* 0x001ee8 */
+	0x000000, /* 0x001eea */
+	0x000000, /* 0x001eec */
+	0x000000, /* 0x001eee */
+	0x000000, /* 0x001ef0 */
+	0x000000, /* 0x001ef2 */
+	0x000000, /* 0x001ef4 */
+	0x000000, /* 0x001ef6 */
+	0x000000, /* 0x001ef8 */
+	0x000000, /* 0x001efa */
+	0x000000, /* 0x001efc */
+	0x000000, /* 0x001efe */
+	0x000000, /* 0x001f00 */
+	0x000000, /* 0x001f01 */
+	0x000000, /* 0x001f02 */
+	0x000000, /* 0x001f03 */
+	0x000000, /* 0x001f04 */
+	0x000000, /* 0x001f05 */
+	0x000000, /* 0x001f06 */
+	0x000000, /* 0x001f07 */
+	0x000000, /* 0x001f10 */
+	0x000000, /* 0x001f11 */
+	0x000000, /* 0x001f12 */
+	0x000000, /* 0x001f13 */
+	0x000000, /* 0x001f14 */
+	0x000000, /* 0x001f15 */
+	0x000000, /* 0x001f20 */
+	0x000000, /* 0x001f21 */
+	0x000000, /* 0x001f22 */
+	0x000000, /* 0x001f23 */
+	0x000000, /* 0x001f24 */
+	0x000000, /* 0x001f25 */
+	0x000000, /* 0x001f26 */
+	0x000000, /* 0x001f27 */
+	0x000000, /* 0x001f30 */
+	0x000000, /* 0x001f31 */
+	0x000000, /* 0x001f32 */
+	0x000000, /* 0x001f33 */
+	0x000000, /* 0x001f34 */
+	0x000000, /* 0x001f35 */
+	0x000000, /* 0x001f36 */
+	0x000000, /* 0x001f37 */
+	0x000000, /* 0x001f40 */
+	0x000000, /* 0x001f41 */
+	0x000000, /* 0x001f42 */
+	0x000000, /* 0x001f43 */
+	0x000000, /* 0x001f44 */
+	0x000000, /* 0x001f45 */
+	0x00000f, /* 0x001f50 */
+	0x000000, /* 0x001f51 */
+	0x000010, /* 0x001f52 */
+	0x000000, /* 0x001f53 */
+	0x000011, /* 0x001f54 */
+	0x000000, /* 0x001f55 */
+	0x000012, /* 0x001f56 */
+	0x000000, /* 0x001f57 */
+	0x000000, /* 0x001f60 */
+	0x000000, /* 0x001f61 */
+	0x000000, /* 0x001f62 */
+	0x000000, /* 0x001f63 */
+	0x000000, /* 0x001f64 */
+	0x000000, /* 0x001f65 */
+	0x000000, /* 0x001f66 */
+	0x000000, /* 0x001f67 */
+	0x000000, /* 0x001f70 */
+	0x000000, /* 0x001f71 */
+	0x000000, /* 0x001f72 */
+	0x000000, /* 0x001f73 */
+	0x000000, /* 0x001f74 */
+	0x000000, /* 0x001f75 */
+	0x000000, /* 0x001f76 */
+	0x000000, /* 0x001f77 */
+	0x000000, /* 0x001f78 */
+	0x000000, /* 0x001f79 */
+	0x000000, /* 0x001f7a */
+	0x000000, /* 0x001f7b */
+	0x000000, /* 0x001f7c */
+	0x000000, /* 0x001f7d */
+	0x000013, /* 0x001f80 */
+	0x000014, /* 0x001f81 */
+	0x000015, /* 0x001f82 */
+	0x000016, /* 0x001f83 */
+	0x000017, /* 0x001f84 */
+	0x000018, /* 0x001f85 */
+	0x000019, /* 0x001f86 */
+	0x00001a, /* 0x001f87 */
+	0x00001b, /* 0x001f88 */
+	0x00001c, /* 0x001f89 */
+	0x00001d, /* 0x001f8a */
+	0x00001e, /* 0x001f8b */
+	0x00001f, /* 0x001f8c */
+	0x000020, /* 0x001f8d */
+	0x000021, /* 0x001f8e */
+	0x000022, /* 0x001f8f */
+	0x000023, /* 0x001f90 */
+	0x000024, /* 0x001f91 */
+	0x000025, /* 0x001f92 */
+	0x000026, /* 0x001f93 */
+	0x000027, /* 0x001f94 */
+	0x000028, /* 0x001f95 */
+	0x000029, /* 0x001f96 */
+	0x00002a, /* 0x001f97 */
+	0x00002b, /* 0x001f98 */
+	0x00002c, /* 0x001f99 */
+	0x00002d, /* 0x001f9a */
+	0x00002e, /* 0x001f9b */
+	0x00002f, /* 0x001f9c */
+	0x000030, /* 0x001f9d */
+	0x000031, /* 0x001f9e */
+	0x000032, /* 0x001f9f */
+	0x000033, /* 0x001fa0 */
+	0x000034, /* 0x001fa1 */
+	0x000035, /* 0x001fa2 */
+	0x000036, /* 0x001fa3 */
+	0x000037, /* 0x001fa4 */
+	0x000038, /* 0x001fa5 */
+	0x000039, /* 0x001fa6 */
+	0x00003a, /* 0x001fa7 */
+	0x00003b, /* 0x001fa8 */
+	0x00003c, /* 0x001fa9 */
+	0x00003d, /* 0x001faa */
+	0x00003e, /* 0x001fab */
+	0x00003f, /* 0x001fac */
+	0x000040, /* 0x001fad */
+	0x000041, /* 0x001fae */
+	0x000042, /* 0x001faf */
+	0x000000, /* 0x001fb0 */
+	0x000000, /* 0x001fb1 */
+	0x000043, /* 0x001fb2 */
+	0x000044, /* 0x001fb3 */
+	0x000045, /* 0x001fb4 */
+	0x000046, /* 0x001fb6 */
+	0x000047, /* 0x001fb7 */
+	0x000048, /* 0x001fbc */
+	0x000000, /* 0x001fbe */
+	0x000049, /* 0x001fc2 */
+	0x00004a, /* 0x001fc3 */
+	0x00004b, /* 0x001fc4 */
+	0x00004c, /* 0x001fc6 */
+	0x00004d, /* 0x001fc7 */
+	0x00004e, /* 0x001fcc */
+	0x000000, /* 0x001fd0 */
+	0x000000, /* 0x001fd1 */
+	0x00004f, /* 0x001fd2 */
+	0x000050, /* 0x001fd3 */
+	0x000051, /* 0x001fd6 */
+	0x000052, /* 0x001fd7 */
+	0x000000, /* 0x001fe0 */
+	0x000000, /* 0x001fe1 */
+	0x000053, /* 0x001fe2 */
+	0x000054, /* 0x001fe3 */
+	0x000055, /* 0x001fe4 */
+	0x000000, /* 0x001fe5 */
+	0x000056, /* 0x001fe6 */
+	0x000057, /* 0x001fe7 */
+	0x000058, /* 0x001ff2 */
+	0x000059, /* 0x001ff3 */
+	0x00005a, /* 0x001ff4 */
+	0x00005b, /* 0x001ff6 */
+	0x00005c, /* 0x001ff7 */
+	0x00005d, /* 0x001ffc */
+	0x000000, /* 0x002126 */
+	0x000000, /* 0x00212a */
+	0x000000, /* 0x00212b */
+	0x000000, /* 0x002132 */
+	0x000000, /* 0x002160 */
+	0x000000, /* 0x002161 */
+	0x000000, /* 0x002162 */
+	0x000000, /* 0x002163 */
+	0x000000, /* 0x002164 */
+	0x000000, /* 0x002165 */
+	0x000000, /* 0x002166 */
+	0x000000, /* 0x002167 */
+	0x000000, /* 0x002168 */
+	0x000000, /* 0x002169 */
+	0x000000, /* 0x00216a */
+	0x000000, /* 0x00216b */
+	0x000000, /* 0x00216c */
+	0x000000, /* 0x00216d */
+	0x000000, /* 0x00216e */
+	0x000000, /* 0x00216f */
+	0x000000, /* 0x002183 */
+	0x000000, /* 0x0024b6 */
+	0x000000, /* 0x0024b7 */
+	0x000000, /* 0x0024b8 */
+	0x000000, /* 0x0024b9 */
+	0x000000, /* 0x0024ba */
+	0x000000, /* 0x0024bb */
+	0x000000, /* 0x0024bc */
+	0x000000, /* 0x0024bd */
+	0x000000, /* 0x0024be */
+	0x000000, /* 0x0024bf */
+	0x000000, /* 0x0024c0 */
+	0x000000, /* 0x0024c1 */
+	0x000000, /* 0x0024c2 */
+	0x000000, /* 0x0024c3 */
+	0x000000, /* 0x0024c4 */
+	0x000000, /* 0x0024c5 */
+	0x000000, /* 0x0024c6 */
+	0x000000, /* 0x0024c7 */
+	0x000000, /* 0x0024c8 */
+	0x000000, /* 0x0024c9 */
+	0x000000, /* 0x0024ca */
+	0x000000, /* 0x0024cb */
+	0x000000, /* 0x0024cc */
+	0x000000, /* 0x0024cd */
+	0x000000, /* 0x0024ce */
+	0x000000, /* 0x0024cf */
+	0x000000, /* 0x002c00 */
+	0x000000, /* 0x002c01 */
+	0x000000, /* 0x002c02 */
+	0x000000, /* 0x002c03 */
+	0x000000, /* 0x002c04 */
+	0x000000, /* 0x002c05 */
+	0x000000, /* 0x002c06 */
+	0x000000, /* 0x002c07 */
+	0x000000, /* 0x002c08 */
+	0x000000, /* 0x002c09 */
+	0x000000, /* 0x002c0a */
+	0x000000, /* 0x002c0b */
+	0x000000, /* 0x002c0c */
+	0x000000, /* 0x002c0d */
+	0x000000, /* 0x002c0e */
+	0x000000, /* 0x002c0f */
+	0x000000, /* 0x002c10 */
+	0x000000, /* 0x002c11 */
+	0x000000, /* 0x002c12 */
+	0x000000, /* 0x002c13 */
+	0x000000, /* 0x002c14 */
+	0x000000, /* 0x002c15 */
+	0x000000, /* 0x002c16 */
+	0x000000, /* 0x002c17 */
+	0x000000, /* 0x002c18 */
+	0x000000, /* 0x002c19 */
+	0x000000, /* 0x002c1a */
+	0x000000, /* 0x002c1b */
+	0x000000, /* 0x002c1c */
+	0x000000, /* 0x002c1d */
+	0x000000, /* 0x002c1e */
+	0x000000, /* 0x002c1f */
+	0x000000, /* 0x002c20 */
+	0x000000, /* 0x002c21 */
+	0x000000, /* 0x002c22 */
+	0x000000, /* 0x002c23 */
+	0x000000, /* 0x002c24 */
+	0x000000, /* 0x002c25 */
+	0x000000, /* 0x002c26 */
+	0x000000, /* 0x002c27 */
+	0x000000, /* 0x002c28 */
+	0x000000, /* 0x002c29 */
+	0x000000, /* 0x002c2a */
+	0x000000, /* 0x002c2b */
+	0x000000, /* 0x002c2c */
+	0x000000, /* 0x002c2d */
+	0x000000, /* 0x002c2e */
+	0x000000, /* 0x002c2f */
+	0x000000, /* 0x002c60 */
+	0x000000, /* 0x002c67 */
+	0x000000, /* 0x002c69 */
+	0x000000, /* 0x002c6b */
+	0x000000, /* 0x002c72 */
+	0x000000, /* 0x002c75 */
+	0x000000, /* 0x002c80 */
+	0x000000, /* 0x002c82 */
+	0x000000, /* 0x002c84 */
+	0x000000, /* 0x002c86 */
+	0x000000, /* 0x002c88 */
+	0x000000, /* 0x002c8a */
+	0x000000, /* 0x002c8c */
+	0x000000, /* 0x002c8e */
+	0x000000, /* 0x002c90 */
+	0x000000, /* 0x002c92 */
+	0x000000, /* 0x002c94 */
+	0x000000, /* 0x002c96 */
+	0x000000, /* 0x002c98 */
+	0x000000, /* 0x002c9a */
+	0x000000, /* 0x002c9c */
+	0x000000, /* 0x002c9e */
+	0x000000, /* 0x002ca0 */
+	0x000000, /* 0x002ca2 */
+	0x000000, /* 0x002ca4 */
+	0x000000, /* 0x002ca6 */
+	0x000000, /* 0x002ca8 */
+	0x000000, /* 0x002caa */
+	0x000000, /* 0x002cac */
+	0x000000, /* 0x002cae */
+	0x000000, /* 0x002cb0 */
+	0x000000, /* 0x002cb2 */
+	0x000000, /* 0x002cb4 */
+	0x000000, /* 0x002cb6 */
+	0x000000, /* 0x002cb8 */
+	0x000000, /* 0x002cba */
+	0x000000, /* 0x002cbc */
+	0x000000, /* 0x002cbe */
+	0x000000, /* 0x002cc0 */
+	0x000000, /* 0x002cc2 */
+	0x000000, /* 0x002cc4 */
+	0x000000, /* 0x002cc6 */
+	0x000000, /* 0x002cc8 */
+	0x000000, /* 0x002cca */
+	0x000000, /* 0x002ccc */
+	0x000000, /* 0x002cce */
+	0x000000, /* 0x002cd0 */
+	0x000000, /* 0x002cd2 */
+	0x000000, /* 0x002cd4 */
+	0x000000, /* 0x002cd6 */
+	0x000000, /* 0x002cd8 */
+	0x000000, /* 0x002cda */
+	0x000000, /* 0x002cdc */
+	0x000000, /* 0x002cde */
+	0x000000, /* 0x002ce0 */
+	0x000000, /* 0x002ce2 */
+	0x000000, /* 0x002ceb */
+	0x000000, /* 0x002ced */
+	0x000000, /* 0x002cf2 */
+	0x000000, /* 0x00a640 */
+	0x000000, /* 0x00a642 */
+	0x000000, /* 0x00a644 */
+	0x000000, /* 0x00a646 */
+	0x000000, /* 0x00a648 */
+	0x000000, /* 0x00a64a */
+	0x000000, /* 0x00a64c */
+	0x000000, /* 0x00a64e */
+	0x000000, /* 0x00a650 */
+	0x000000, /* 0x00a652 */
+	0x000000, /* 0x00a654 */
+	0x000000, /* 0x00a656 */
+	0x000000, /* 0x00a658 */
+	0x000000, /* 0x00a65a */
+	0x000000, /* 0x00a65c */
+	0x000000, /* 0x00a65e */
+	0x000000, /* 0x00a660 */
+	0x000000, /* 0x00a662 */
+	0x000000, /* 0x00a664 */
+	0x000000, /* 0x00a666 */
+	0x000000, /* 0x00a668 */
+	0x000000, /* 0x00a66a */
+	0x000000, /* 0x00a66c */
+	0x000000, /* 0x00a680 */
+	0x000000, /* 0x00a682 */
+	0x000000, /* 0x00a684 */
+	0x000000, /* 0x00a686 */
+	0x000000, /* 0x00a688 */
+	0x000000, /* 0x00a68a */
+	0x000000, /* 0x00a68c */
+	0x000000, /* 0x00a68e */
+	0x000000, /* 0x00a690 */
+	0x000000, /* 0x00a692 */
+	0x000000, /* 0x00a694 */
+	0x000000, /* 0x00a696 */
+	0x000000, /* 0x00a698 */
+	0x000000, /* 0x00a69a */
+	0x000000, /* 0x00a722 */
+	0x000000, /* 0x00a724 */
+	0x000000, /* 0x00a726 */
+	0x000000, /* 0x00a728 */
+	0x000000, /* 0x00a72a */
+	0x000000, /* 0x00a72c */
+	0x000000, /* 0x00a72e */
+	0x000000, /* 0x00a732 */
+	0x000000, /* 0x00a734 */
+	0x000000, /* 0x00a736 */
+	0x000000, /* 0x00a738 */
+	0x000000, /* 0x00a73a */
+	0x000000, /* 0x00a73c */
+	0x000000, /* 0x00a73e */
+	0x000000, /* 0x00a740 */
+	0x000000, /* 0x00a742 */
+	0x000000, /* 0x00a744 */
+	0x000000, /* 0x00a746 */
+	0x000000, /* 0x00a748 */
+	0x000000, /* 0x00a74a */
+	0x000000, /* 0x00a74c */
+	0x000000, /* 0x00a74e */
+	0x000000, /* 0x00a750 */
+	0x000000, /* 0x00a752 */
+	0x000000, /* 0x00a754 */
+	0x000000, /* 0x00a756 */
+	0x000000, /* 0x00a758 */
+	0x000000, /* 0x00a75a */
+	0x000000, /* 0x00a75c */
+	0x000000, /* 0x00a75e */
+	0x000000, /* 0x00a760 */
+	0x000000, /* 0x00a762 */
+	0x000000, /* 0x00a764 */
+	0x000000, /* 0x00a766 */
+	0x000000, /* 0x00a768 */
+	0x000000, /* 0x00a76a */
+	0x000000, /* 0x00a76c */
+	0x000000, /* 0x00a76e */
+	0x000000, /* 0x00a779 */
+	0x000000, /* 0x00a77b */
+	0x000000, /* 0x00a77e */
+	0x000000, /* 0x00a780 */
+	0x000000, /* 0x00a782 */
+	0x000000, /* 0x00a784 */
+	0x000000, /* 0x00a786 */
+	0x000000, /* 0x00a78b */
+	0x000000, /* 0x00a790 */
+	0x000000, /* 0x00a792 */
+	0x000000, /* 0x00a794 */
+	0x000000, /* 0x00a796 */
+	0x000000, /* 0x00a798 */
+	0x000000, /* 0x00a79a */
+	0x000000, /* 0x00a79c */
+	0x000000, /* 0x00a79e */
+	0x000000, /* 0x00a7a0 */
+	0x000000, /* 0x00a7a2 */
+	0x000000, /* 0x00a7a4 */
+	0x000000, /* 0x00a7a6 */
+	0x000000, /* 0x00a7a8 */
+	0x000000, /* 0x00a7b3 */
+	0x000000, /* 0x00a7b4 */
+	0x000000, /* 0x00a7b6 */
+	0x000000, /* 0x00a7b8 */
+	0x000000, /* 0x00a7ba */
+	0x000000, /* 0x00a7bc */
+	0x000000, /* 0x00a7be */
+	0x000000, /* 0x00a7c0 */
+	0x000000, /* 0x00a7c2 */
+	0x000000, /* 0x00a7c7 */
+	0x000000, /* 0x00a7c9 */
+	0x000000, /* 0x00a7d0 */
+	0x000000, /* 0x00a7d6 */
+	0x000000, /* 0x00a7d8 */
+	0x000000, /* 0x00a7f5 */
+	0x00005e, /* 0x00fb00 */
+	0x00005f, /* 0x00fb01 */
+	0x000060, /* 0x00fb02 */
+	0x000061, /* 0x00fb03 */
+	0x000062, /* 0x00fb04 */
+	0x000063, /* 0x00fb05 */
+	0x000064, /* 0x00fb06 */
+	0x000065, /* 0x00fb13 */
+	0x000066, /* 0x00fb14 */
+	0x000067, /* 0x00fb15 */
+	0x000068, /* 0x00fb16 */
+	0x000069, /* 0x00fb17 */
+	0x000000, /* 0x00ff21 */
+	0x000000, /* 0x00ff22 */
+	0x000000, /* 0x00ff23 */
+	0x000000, /* 0x00ff24 */
+	0x000000, /* 0x00ff25 */
+	0x000000, /* 0x00ff26 */
+	0x000000, /* 0x00ff27 */
+	0x000000, /* 0x00ff28 */
+	0x000000, /* 0x00ff29 */
+	0x000000, /* 0x00ff2a */
+	0x000000, /* 0x00ff2b */
+	0x000000, /* 0x00ff2c */
+	0x000000, /* 0x00ff2d */
+	0x000000, /* 0x00ff2e */
+	0x000000, /* 0x00ff2f */
+	0x000000, /* 0x00ff30 */
+	0x000000, /* 0x00ff31 */
+	0x000000, /* 0x00ff32 */
+	0x000000, /* 0x00ff33 */
+	0x000000, /* 0x00ff34 */
+	0x000000, /* 0x00ff35 */
+	0x000000, /* 0x00ff36 */
+	0x000000, /* 0x00ff37 */
+	0x000000, /* 0x00ff38 */
+	0x000000, /* 0x00ff39 */
+	0x000000, /* 0x00ff3a */
+	0x000000, /* 0x010400 */
+	0x000000, /* 0x010401 */
+	0x000000, /* 0x010402 */
+	0x000000, /* 0x010403 */
+	0x000000, /* 0x010404 */
+	0x000000, /* 0x010405 */
+	0x000000, /* 0x010406 */
+	0x000000, /* 0x010407 */
+	0x000000, /* 0x010408 */
+	0x000000, /* 0x010409 */
+	0x000000, /* 0x01040a */
+	0x000000, /* 0x01040b */
+	0x000000, /* 0x01040c */
+	0x000000, /* 0x01040d */
+	0x000000, /* 0x01040e */
+	0x000000, /* 0x01040f */
+	0x000000, /* 0x010410 */
+	0x000000, /* 0x010411 */
+	0x000000, /* 0x010412 */
+	0x000000, /* 0x010413 */
+	0x000000, /* 0x010414 */
+	0x000000, /* 0x010415 */
+	0x000000, /* 0x010416 */
+	0x000000, /* 0x010417 */
+	0x000000, /* 0x010418 */
+	0x000000, /* 0x010419 */
+	0x000000, /* 0x01041a */
+	0x000000, /* 0x01041b */
+	0x000000, /* 0x01041c */
+	0x000000, /* 0x01041d */
+	0x000000, /* 0x01041e */
+	0x000000, /* 0x01041f */
+	0x000000, /* 0x010420 */
+	0x000000, /* 0x010421 */
+	0x000000, /* 0x010422 */
+	0x000000, /* 0x010423 */
+	0x000000, /* 0x010424 */
+	0x000000, /* 0x010425 */
+	0x000000, /* 0x010426 */
+	0x000000, /* 0x010427 */
+	0x000000, /* 0x0104b0 */
+	0x000000, /* 0x0104b1 */
+	0x000000, /* 0x0104b2 */
+	0x000000, /* 0x0104b3 */
+	0x000000, /* 0x0104b4 */
+	0x000000, /* 0x0104b5 */
+	0x000000, /* 0x0104b6 */
+	0x000000, /* 0x0104b7 */
+	0x000000, /* 0x0104b8 */
+	0x000000, /* 0x0104b9 */
+	0x000000, /* 0x0104ba */
+	0x000000, /* 0x0104bb */
+	0x000000, /* 0x0104bc */
+	0x000000, /* 0x0104bd */
+	0x000000, /* 0x0104be */
+	0x000000, /* 0x0104bf */
+	0x000000, /* 0x0104c0 */
+	0x000000, /* 0x0104c1 */
+	0x000000, /* 0x0104c2 */
+	0x000000, /* 0x0104c3 */
+	0x000000, /* 0x0104c4 */
+	0x000000, /* 0x0104c5 */
+	0x000000, /* 0x0104c6 */
+	0x000000, /* 0x0104c7 */
+	0x000000, /* 0x0104c8 */
+	0x000000, /* 0x0104c9 */
+	0x000000, /* 0x0104ca */
+	0x000000, /* 0x0104cb */
+	0x000000, /* 0x0104cc */
+	0x000000, /* 0x0104cd */
+	0x000000, /* 0x0104ce */
+	0x000000, /* 0x0104cf */
+	0x000000, /* 0x0104d0 */
+	0x000000, /* 0x0104d1 */
+	0x000000, /* 0x0104d2 */
+	0x000000, /* 0x0104d3 */
+	0x000000, /* 0x010570 */
+	0x000000, /* 0x010571 */
+	0x000000, /* 0x010572 */
+	0x000000, /* 0x010573 */
+	0x000000, /* 0x010574 */
+	0x000000, /* 0x010575 */
+	0x000000, /* 0x010576 */
+	0x000000, /* 0x010577 */
+	0x000000, /* 0x010578 */
+	0x000000, /* 0x010579 */
+	0x000000, /* 0x01057a */
+	0x000000, /* 0x01057c */
+	0x000000, /* 0x01057d */
+	0x000000, /* 0x01057e */
+	0x000000, /* 0x01057f */
+	0x000000, /* 0x010580 */
+	0x000000, /* 0x010581 */
+	0x000000, /* 0x010582 */
+	0x000000, /* 0x010583 */
+	0x000000, /* 0x010584 */
+	0x000000, /* 0x010585 */
+	0x000000, /* 0x010586 */
+	0x000000, /* 0x010587 */
+	0x000000, /* 0x010588 */
+	0x000000, /* 0x010589 */
+	0x000000, /* 0x01058a */
+	0x000000, /* 0x01058c */
+	0x000000, /* 0x01058d */
+	0x000000, /* 0x01058e */
+	0x000000, /* 0x01058f */
+	0x000000, /* 0x010590 */
+	0x000000, /* 0x010591 */
+	0x000000, /* 0x010592 */
+	0x000000, /* 0x010594 */
+	0x000000, /* 0x010595 */
+	0x000000, /* 0x010c80 */
+	0x000000, /* 0x010c81 */
+	0x000000, /* 0x010c82 */
+	0x000000, /* 0x010c83 */
+	0x000000, /* 0x010c84 */
+	0x000000, /* 0x010c85 */
+	0x000000, /* 0x010c86 */
+	0x000000, /* 0x010c87 */
+	0x000000, /* 0x010c88 */
+	0x000000, /* 0x010c89 */
+	0x000000, /* 0x010c8a */
+	0x000000, /* 0x010c8b */
+	0x000000, /* 0x010c8c */
+	0x000000, /* 0x010c8d */
+	0x000000, /* 0x010c8e */
+	0x000000, /* 0x010c8f */
+	0x000000, /* 0x010c90 */
+	0x000000, /* 0x010c91 */
+	0x000000, /* 0x010c92 */
+	0x000000, /* 0x010c93 */
+	0x000000, /* 0x010c94 */
+	0x000000, /* 0x010c95 */
+	0x000000, /* 0x010c96 */
+	0x000000, /* 0x010c97 */
+	0x000000, /* 0x010c98 */
+	0x000000, /* 0x010c99 */
+	0x000000, /* 0x010c9a */
+	0x000000, /* 0x010c9b */
+	0x000000, /* 0x010c9c */
+	0x000000, /* 0x010c9d */
+	0x000000, /* 0x010c9e */
+	0x000000, /* 0x010c9f */
+	0x000000, /* 0x010ca0 */
+	0x000000, /* 0x010ca1 */
+	0x000000, /* 0x010ca2 */
+	0x000000, /* 0x010ca3 */
+	0x000000, /* 0x010ca4 */
+	0x000000, /* 0x010ca5 */
+	0x000000, /* 0x010ca6 */
+	0x000000, /* 0x010ca7 */
+	0x000000, /* 0x010ca8 */
+	0x000000, /* 0x010ca9 */
+	0x000000, /* 0x010caa */
+	0x000000, /* 0x010cab */
+	0x000000, /* 0x010cac */
+	0x000000, /* 0x010cad */
+	0x000000, /* 0x010cae */
+	0x000000, /* 0x010caf */
+	0x000000, /* 0x010cb0 */
+	0x000000, /* 0x010cb1 */
+	0x000000, /* 0x010cb2 */
+	0x000000, /* 0x0118a0 */
+	0x000000, /* 0x0118a1 */
+	0x000000, /* 0x0118a2 */
+	0x000000, /* 0x0118a3 */
+	0x000000, /* 0x0118a4 */
+	0x000000, /* 0x0118a5 */
+	0x000000, /* 0x0118a6 */
+	0x000000, /* 0x0118a7 */
+	0x000000, /* 0x0118a8 */
+	0x000000, /* 0x0118a9 */
+	0x000000, /* 0x0118aa */
+	0x000000, /* 0x0118ab */
+	0x000000, /* 0x0118ac */
+	0x000000, /* 0x0118ad */
+	0x000000, /* 0x0118ae */
+	0x000000, /* 0x0118af */
+	0x000000, /* 0x0118b0 */
+	0x000000, /* 0x0118b1 */
+	0x000000, /* 0x0118b2 */
+	0x000000, /* 0x0118b3 */
+	0x000000, /* 0x0118b4 */
+	0x000000, /* 0x0118b5 */
+	0x000000, /* 0x0118b6 */
+	0x000000, /* 0x0118b7 */
+	0x000000, /* 0x0118b8 */
+	0x000000, /* 0x0118b9 */
+	0x000000, /* 0x0118ba */
+	0x000000, /* 0x0118bb */
+	0x000000, /* 0x0118bc */
+	0x000000, /* 0x0118bd */
+	0x000000, /* 0x0118be */
+	0x000000, /* 0x0118bf */
+	0x000000, /* 0x016e40 */
+	0x000000, /* 0x016e41 */
+	0x000000, /* 0x016e42 */
+	0x000000, /* 0x016e43 */
+	0x000000, /* 0x016e44 */
+	0x000000, /* 0x016e45 */
+	0x000000, /* 0x016e46 */
+	0x000000, /* 0x016e47 */
+	0x000000, /* 0x016e48 */
+	0x000000, /* 0x016e49 */
+	0x000000, /* 0x016e4a */
+	0x000000, /* 0x016e4b */
+	0x000000, /* 0x016e4c */
+	0x000000, /* 0x016e4d */
+	0x000000, /* 0x016e4e */
+	0x000000, /* 0x016e4f */
+	0x000000, /* 0x016e50 */
+	0x000000, /* 0x016e51 */
+	0x000000, /* 0x016e52 */
+	0x000000, /* 0x016e53 */
+	0x000000, /* 0x016e54 */
+	0x000000, /* 0x016e55 */
+	0x000000, /* 0x016e56 */
+	0x000000, /* 0x016e57 */
+	0x000000, /* 0x016e58 */
+	0x000000, /* 0x016e59 */
+	0x000000, /* 0x016e5a */
+	0x000000, /* 0x016e5b */
+	0x000000, /* 0x016e5c */
+	0x000000, /* 0x016e5d */
+	0x000000, /* 0x016e5e */
+	0x000000, /* 0x016e5f */
+	0x000000, /* 0x01e900 */
+	0x000000, /* 0x01e901 */
+	0x000000, /* 0x01e902 */
+	0x000000, /* 0x01e903 */
+	0x000000, /* 0x01e904 */
+	0x000000, /* 0x01e905 */
+	0x000000, /* 0x01e906 */
+	0x000000, /* 0x01e907 */
+	0x000000, /* 0x01e908 */
+	0x000000, /* 0x01e909 */
+	0x000000, /* 0x01e90a */
+	0x000000, /* 0x01e90b */
+	0x000000, /* 0x01e90c */
+	0x000000, /* 0x01e90d */
+	0x000000, /* 0x01e90e */
+	0x000000, /* 0x01e90f */
+	0x000000, /* 0x01e910 */
+	0x000000, /* 0x01e911 */
+	0x000000, /* 0x01e912 */
+	0x000000, /* 0x01e913 */
+	0x000000, /* 0x01e914 */
+	0x000000, /* 0x01e915 */
+	0x000000, /* 0x01e916 */
+	0x000000, /* 0x01e917 */
+	0x000000, /* 0x01e918 */
+	0x000000, /* 0x01e919 */
+	0x000000, /* 0x01e91a */
+	0x000000, /* 0x01e91b */
+	0x000000, /* 0x01e91c */
+	0x000000, /* 0x01e91d */
+	0x000000, /* 0x01e91e */
+	0x000000, /* 0x01e91f */
+	0x000000, /* 0x01e920 */
+	0x000000, /* 0x01e921 */
 };
+
+/*
+ * Case mapping.
+ */
+static uint32 *casekind_map[NCaseKind] =
+{
+	case_map_lower,
+	case_map_title,
+	case_map_upper,
+	case_map_fold
+};
+
+static const uint16_t case_map[4631] =
+{
+	1, /* U+000000 */
+	2, /* U+000001 */
+	3, /* U+000002 */
+	4, /* U+000003 */
+	5, /* U+000004 */
+	6, /* U+000005 */
+	7, /* U+000006 */
+	8, /* U+000007 */
+	9, /* U+000008 */
+	10, /* U+000009 */
+	11, /* U+00000A */
+	12, /* U+00000B */
+	13, /* U+00000C */
+	14, /* U+00000D */
+	15, /* U+00000E */
+	16, /* U+00000F */
+	17, /* U+000010 */
+	18, /* U+000011 */
+	19, /* U+000012 */
+	20, /* U+000013 */
+	21, /* U+000014 */
+	22, /* U+000015 */
+	23, /* U+000016 */
+	24, /* U+000017 */
+	25, /* U+000018 */
+	26, /* U+000019 */
+	27, /* U+00001A */
+	28, /* U+00001B */
+	29, /* U+00001C */
+	30, /* U+00001D */
+	31, /* U+00001E */
+	32, /* U+00001F */
+	33, /* U+000020 */
+	34, /* U+000021 */
+	35, /* U+000022 */
+	36, /* U+000023 */
+	37, /* U+000024 */
+	38, /* U+000025 */
+	39, /* U+000026 */
+	40, /* U+000027 */
+	41, /* U+000028 */
+	42, /* U+000029 */
+	43, /* U+00002A */
+	44, /* U+00002B */
+	45, /* U+00002C */
+	46, /* U+00002D */
+	47, /* U+00002E */
+	48, /* U+00002F */
+	49, /* U+000030 */
+	50, /* U+000031 */
+	51, /* U+000032 */
+	52, /* U+000033 */
+	53, /* U+000034 */
+	54, /* U+000035 */
+	55, /* U+000036 */
+	56, /* U+000037 */
+	57, /* U+000038 */
+	58, /* U+000039 */
+	59, /* U+00003A */
+	60, /* U+00003B */
+	61, /* U+00003C */
+	62, /* U+00003D */
+	63, /* U+00003E */
+	64, /* U+00003F */
+	65, /* U+000040 */
+	66, /* U+000041 */
+	67, /* U+000042 */
+	68, /* U+000043 */
+	69, /* U+000044 */
+	70, /* U+000045 */
+	71, /* U+000046 */
+	72, /* U+000047 */
+	73, /* U+000048 */
+	74, /* U+000049 */
+	75, /* U+00004A */
+	76, /* U+00004B */
+	77, /* U+00004C */
+	78, /* U+00004D */
+	79, /* U+00004E */
+	80, /* U+00004F */
+	81, /* U+000050 */
+	82, /* U+000051 */
+	83, /* U+000052 */
+	84, /* U+000053 */
+	85, /* U+000054 */
+	86, /* U+000055 */
+	87, /* U+000056 */
+	88, /* U+000057 */
+	89, /* U+000058 */
+	90, /* U+000059 */
+	91, /* U+00005A */
+	92, /* U+00005B */
+	93, /* U+00005C */
+	94, /* U+00005D */
+	95, /* U+00005E */
+	96, /* U+00005F */
+	97, /* U+000060 */
+	98, /* U+000061 */
+	99, /* U+000062 */
+	100, /* U+000063 */
+	101, /* U+000064 */
+	102, /* U+000065 */
+	103, /* U+000066 */
+	104, /* U+000067 */
+	105, /* U+000068 */
+	106, /* U+000069 */
+	107, /* U+00006A */
+	108, /* U+00006B */
+	109, /* U+00006C */
+	110, /* U+00006D */
+	111, /* U+00006E */
+	112, /* U+00006F */
+	113, /* U+000070 */
+	114, /* U+000071 */
+	115, /* U+000072 */
+	116, /* U+000073 */
+	117, /* U+000074 */
+	118, /* U+000075 */
+	119, /* U+000076 */
+	120, /* U+000077 */
+	121, /* U+000078 */
+	122, /* U+000079 */
+	123, /* U+00007A */
+	124, /* U+00007B */
+	125, /* U+00007C */
+	126, /* U+00007D */
+	127, /* U+00007E */
+	128, /* U+00007F */
+	0, /* U+000080 */
+	0, /* U+000081 */
+	0, /* U+000082 */
+	0, /* U+000083 */
+	0, /* U+000084 */
+	0, /* U+000085 */
+	0, /* U+000086 */
+	0, /* U+000087 */
+	0, /* U+000088 */
+	0, /* U+000089 */
+	0, /* U+00008A */
+	0, /* U+00008B */
+	0, /* U+00008C */
+	0, /* U+00008D */
+	0, /* U+00008E */
+	0, /* U+00008F */
+	0, /* U+000090 */
+	0, /* U+000091 */
+	0, /* U+000092 */
+	0, /* U+000093 */
+	0, /* U+000094 */
+	0, /* U+000095 */
+	0, /* U+000096 */
+	0, /* U+000097 */
+	0, /* U+000098 */
+	0, /* U+000099 */
+	0, /* U+00009A */
+	0, /* U+00009B */
+	0, /* U+00009C */
+	0, /* U+00009D */
+	0, /* U+00009E */
+	0, /* U+00009F */
+	0, /* U+0000A0 */
+	0, /* U+0000A1 */
+	0, /* U+0000A2 */
+	0, /* U+0000A3 */
+	0, /* U+0000A4 */
+	0, /* U+0000A5 */
+	0, /* U+0000A6 */
+	0, /* U+0000A7 */
+	0, /* U+0000A8 */
+	0, /* U+0000A9 */
+	0, /* U+0000AA */
+	0, /* U+0000AB */
+	0, /* U+0000AC */
+	0, /* U+0000AD */
+	0, /* U+0000AE */
+	0, /* U+0000AF */
+	0, /* U+0000B0 */
+	0, /* U+0000B1 */
+	0, /* U+0000B2 */
+	0, /* U+0000B3 */
+	0, /* U+0000B4 */
+	129, /* U+0000B5 */
+	0, /* U+0000B6 */
+	0, /* U+0000B7 */
+	0, /* U+0000B8 */
+	0, /* U+0000B9 */
+	0, /* U+0000BA */
+	0, /* U+0000BB */
+	0, /* U+0000BC */
+	0, /* U+0000BD */
+	0, /* U+0000BE */
+	0, /* U+0000BF */
+	130, /* U+0000C0 */
+	131, /* U+0000C1 */
+	132, /* U+0000C2 */
+	133, /* U+0000C3 */
+	134, /* U+0000C4 */
+	135, /* U+0000C5 */
+	136, /* U+0000C6 */
+	137, /* U+0000C7 */
+	138, /* U+0000C8 */
+	139, /* U+0000C9 */
+	140, /* U+0000CA */
+	141, /* U+0000CB */
+	142, /* U+0000CC */
+	143, /* U+0000CD */
+	144, /* U+0000CE */
+	145, /* U+0000CF */
+	146, /* U+0000D0 */
+	147, /* U+0000D1 */
+	148, /* U+0000D2 */
+	149, /* U+0000D3 */
+	150, /* U+0000D4 */
+	151, /* U+0000D5 */
+	152, /* U+0000D6 */
+	0, /* U+0000D7 */
+	153, /* U+0000D8 */
+	154, /* U+0000D9 */
+	155, /* U+0000DA */
+	156, /* U+0000DB */
+	157, /* U+0000DC */
+	158, /* U+0000DD */
+	159, /* U+0000DE */
+	160, /* U+0000DF */
+	130, /* U+0000E0 */
+	131, /* U+0000E1 */
+	132, /* U+0000E2 */
+	133, /* U+0000E3 */
+	134, /* U+0000E4 */
+	135, /* U+0000E5 */
+	136, /* U+0000E6 */
+	137, /* U+0000E7 */
+	138, /* U+0000E8 */
+	139, /* U+0000E9 */
+	140, /* U+0000EA */
+	141, /* U+0000EB */
+	142, /* U+0000EC */
+	143, /* U+0000ED */
+	144, /* U+0000EE */
+	145, /* U+0000EF */
+	146, /* U+0000F0 */
+	147, /* U+0000F1 */
+	148, /* U+0000F2 */
+	149, /* U+0000F3 */
+	150, /* U+0000F4 */
+	151, /* U+0000F5 */
+	152, /* U+0000F6 */
+	0, /* U+0000F7 */
+	153, /* U+0000F8 */
+	154, /* U+0000F9 */
+	155, /* U+0000FA */
+	156, /* U+0000FB */
+	157, /* U+0000FC */
+	158, /* U+0000FD */
+	159, /* U+0000FE */
+	161, /* U+0000FF */
+	162, /* U+000100 */
+	162, /* U+000101 */
+	163, /* U+000102 */
+	163, /* U+000103 */
+	164, /* U+000104 */
+	164, /* U+000105 */
+	165, /* U+000106 */
+	165, /* U+000107 */
+	166, /* U+000108 */
+	166, /* U+000109 */
+	167, /* U+00010A */
+	167, /* U+00010B */
+	168, /* U+00010C */
+	168, /* U+00010D */
+	169, /* U+00010E */
+	169, /* U+00010F */
+	170, /* U+000110 */
+	170, /* U+000111 */
+	171, /* U+000112 */
+	171, /* U+000113 */
+	172, /* U+000114 */
+	172, /* U+000115 */
+	173, /* U+000116 */
+	173, /* U+000117 */
+	174, /* U+000118 */
+	174, /* U+000119 */
+	175, /* U+00011A */
+	175, /* U+00011B */
+	176, /* U+00011C */
+	176, /* U+00011D */
+	177, /* U+00011E */
+	177, /* U+00011F */
+	178, /* U+000120 */
+	178, /* U+000121 */
+	179, /* U+000122 */
+	179, /* U+000123 */
+	180, /* U+000124 */
+	180, /* U+000125 */
+	181, /* U+000126 */
+	181, /* U+000127 */
+	182, /* U+000128 */
+	182, /* U+000129 */
+	183, /* U+00012A */
+	183, /* U+00012B */
+	184, /* U+00012C */
+	184, /* U+00012D */
+	185, /* U+00012E */
+	185, /* U+00012F */
+	186, /* U+000130 */
+	187, /* U+000131 */
+	188, /* U+000132 */
+	188, /* U+000133 */
+	189, /* U+000134 */
+	189, /* U+000135 */
+	190, /* U+000136 */
+	190, /* U+000137 */
+	0, /* U+000138 */
+	191, /* U+000139 */
+	191, /* U+00013A */
+	192, /* U+00013B */
+	192, /* U+00013C */
+	193, /* U+00013D */
+	193, /* U+00013E */
+	194, /* U+00013F */
+	194, /* U+000140 */
+	195, /* U+000141 */
+	195, /* U+000142 */
+	196, /* U+000143 */
+	196, /* U+000144 */
+	197, /* U+000145 */
+	197, /* U+000146 */
+	198, /* U+000147 */
+	198, /* U+000148 */
+	199, /* U+000149 */
+	200, /* U+00014A */
+	200, /* U+00014B */
+	201, /* U+00014C */
+	201, /* U+00014D */
+	202, /* U+00014E */
+	202, /* U+00014F */
+	203, /* U+000150 */
+	203, /* U+000151 */
+	204, /* U+000152 */
+	204, /* U+000153 */
+	205, /* U+000154 */
+	205, /* U+000155 */
+	206, /* U+000156 */
+	206, /* U+000157 */
+	207, /* U+000158 */
+	207, /* U+000159 */
+	208, /* U+00015A */
+	208, /* U+00015B */
+	209, /* U+00015C */
+	209, /* U+00015D */
+	210, /* U+00015E */
+	210, /* U+00015F */
+	211, /* U+000160 */
+	211, /* U+000161 */
+	212, /* U+000162 */
+	212, /* U+000163 */
+	213, /* U+000164 */
+	213, /* U+000165 */
+	214, /* U+000166 */
+	214, /* U+000167 */
+	215, /* U+000168 */
+	215, /* U+000169 */
+	216, /* U+00016A */
+	216, /* U+00016B */
+	217, /* U+00016C */
+	217, /* U+00016D */
+	218, /* U+00016E */
+	218, /* U+00016F */
+	219, /* U+000170 */
+	219, /* U+000171 */
+	220, /* U+000172 */
+	220, /* U+000173 */
+	221, /* U+000174 */
+	221, /* U+000175 */
+	222, /* U+000176 */
+	222, /* U+000177 */
+	161, /* U+000178 */
+	223, /* U+000179 */
+	223, /* U+00017A */
+	224, /* U+00017B */
+	224, /* U+00017C */
+	225, /* U+00017D */
+	225, /* U+00017E */
+	226, /* U+00017F */
+	227, /* U+000180 */
+	228, /* U+000181 */
+	229, /* U+000182 */
+	229, /* U+000183 */
+	230, /* U+000184 */
+	230, /* U+000185 */
+	231, /* U+000186 */
+	232, /* U+000187 */
+	232, /* U+000188 */
+	233, /* U+000189 */
+	234, /* U+00018A */
+	235, /* U+00018B */
+	235, /* U+00018C */
+	0, /* U+00018D */
+	236, /* U+00018E */
+	237, /* U+00018F */
+	238, /* U+000190 */
+	239, /* U+000191 */
+	239, /* U+000192 */
+	240, /* U+000193 */
+	241, /* U+000194 */
+	242, /* U+000195 */
+	243, /* U+000196 */
+	244, /* U+000197 */
+	245, /* U+000198 */
+	245, /* U+000199 */
+	246, /* U+00019A */
+	0, /* U+00019B */
+	247, /* U+00019C */
+	248, /* U+00019D */
+	249, /* U+00019E */
+	250, /* U+00019F */
+	251, /* U+0001A0 */
+	251, /* U+0001A1 */
+	252, /* U+0001A2 */
+	252, /* U+0001A3 */
+	253, /* U+0001A4 */
+	253, /* U+0001A5 */
+	254, /* U+0001A6 */
+	255, /* U+0001A7 */
+	255, /* U+0001A8 */
+	256, /* U+0001A9 */
+	0, /* U+0001AA */
+	0, /* U+0001AB */
+	257, /* U+0001AC */
+	257, /* U+0001AD */
+	258, /* U+0001AE */
+	259, /* U+0001AF */
+	259, /* U+0001B0 */
+	260, /* U+0001B1 */
+	261, /* U+0001B2 */
+	262, /* U+0001B3 */
+	262, /* U+0001B4 */
+	263, /* U+0001B5 */
+	263, /* U+0001B6 */
+	264, /* U+0001B7 */
+	265, /* U+0001B8 */
+	265, /* U+0001B9 */
+	0, /* U+0001BA */
+	0, /* U+0001BB */
+	266, /* U+0001BC */
+	266, /* U+0001BD */
+	0, /* U+0001BE */
+	267, /* U+0001BF */
+	0, /* U+0001C0 */
+	0, /* U+0001C1 */
+	0, /* U+0001C2 */
+	0, /* U+0001C3 */
+	268, /* U+0001C4 */
+	268, /* U+0001C5 */
+	268, /* U+0001C6 */
+	269, /* U+0001C7 */
+	269, /* U+0001C8 */
+	269, /* U+0001C9 */
+	270, /* U+0001CA */
+	270, /* U+0001CB */
+	270, /* U+0001CC */
+	271, /* U+0001CD */
+	271, /* U+0001CE */
+	272, /* U+0001CF */
+	272, /* U+0001D0 */
+	273, /* U+0001D1 */
+	273, /* U+0001D2 */
+	274, /* U+0001D3 */
+	274, /* U+0001D4 */
+	275, /* U+0001D5 */
+	275, /* U+0001D6 */
+	276, /* U+0001D7 */
+	276, /* U+0001D8 */
+	277, /* U+0001D9 */
+	277, /* U+0001DA */
+	278, /* U+0001DB */
+	278, /* U+0001DC */
+	236, /* U+0001DD */
+	279, /* U+0001DE */
+	279, /* U+0001DF */
+	280, /* U+0001E0 */
+	280, /* U+0001E1 */
+	281, /* U+0001E2 */
+	281, /* U+0001E3 */
+	282, /* U+0001E4 */
+	282, /* U+0001E5 */
+	283, /* U+0001E6 */
+	283, /* U+0001E7 */
+	284, /* U+0001E8 */
+	284, /* U+0001E9 */
+	285, /* U+0001EA */
+	285, /* U+0001EB */
+	286, /* U+0001EC */
+	286, /* U+0001ED */
+	287, /* U+0001EE */
+	287, /* U+0001EF */
+	288, /* U+0001F0 */
+	289, /* U+0001F1 */
+	289, /* U+0001F2 */
+	289, /* U+0001F3 */
+	290, /* U+0001F4 */
+	290, /* U+0001F5 */
+	242, /* U+0001F6 */
+	267, /* U+0001F7 */
+	291, /* U+0001F8 */
+	291, /* U+0001F9 */
+	292, /* U+0001FA */
+	292, /* U+0001FB */
+	293, /* U+0001FC */
+	293, /* U+0001FD */
+	294, /* U+0001FE */
+	294, /* U+0001FF */
+	295, /* U+000200 */
+	295, /* U+000201 */
+	296, /* U+000202 */
+	296, /* U+000203 */
+	297, /* U+000204 */
+	297, /* U+000205 */
+	298, /* U+000206 */
+	298, /* U+000207 */
+	299, /* U+000208 */
+	299, /* U+000209 */
+	300, /* U+00020A */
+	300, /* U+00020B */
+	301, /* U+00020C */
+	301, /* U+00020D */
+	302, /* U+00020E */
+	302, /* U+00020F */
+	303, /* U+000210 */
+	303, /* U+000211 */
+	304, /* U+000212 */
+	304, /* U+000213 */
+	305, /* U+000214 */
+	305, /* U+000215 */
+	306, /* U+000216 */
+	306, /* U+000217 */
+	307, /* U+000218 */
+	307, /* U+000219 */
+	308, /* U+00021A */
+	308, /* U+00021B */
+	309, /* U+00021C */
+	309, /* U+00021D */
+	310, /* U+00021E */
+	310, /* U+00021F */
+	249, /* U+000220 */
+	0, /* U+000221 */
+	311, /* U+000222 */
+	311, /* U+000223 */
+	312, /* U+000224 */
+	312, /* U+000225 */
+	313, /* U+000226 */
+	313, /* U+000227 */
+	314, /* U+000228 */
+	314, /* U+000229 */
+	315, /* U+00022A */
+	315, /* U+00022B */
+	316, /* U+00022C */
+	316, /* U+00022D */
+	317, /* U+00022E */
+	317, /* U+00022F */
+	318, /* U+000230 */
+	318, /* U+000231 */
+	319, /* U+000232 */
+	319, /* U+000233 */
+	0, /* U+000234 */
+	0, /* U+000235 */
+	0, /* U+000236 */
+	0, /* U+000237 */
+	0, /* U+000238 */
+	0, /* U+000239 */
+	320, /* U+00023A */
+	321, /* U+00023B */
+	321, /* U+00023C */
+	246, /* U+00023D */
+	322, /* U+00023E */
+	323, /* U+00023F */
+	324, /* U+000240 */
+	325, /* U+000241 */
+	325, /* U+000242 */
+	227, /* U+000243 */
+	326, /* U+000244 */
+	327, /* U+000245 */
+	328, /* U+000246 */
+	328, /* U+000247 */
+	329, /* U+000248 */
+	329, /* U+000249 */
+	330, /* U+00024A */
+	330, /* U+00024B */
+	331, /* U+00024C */
+	331, /* U+00024D */
+	332, /* U+00024E */
+	332, /* U+00024F */
+	333, /* U+000250 */
+	334, /* U+000251 */
+	335, /* U+000252 */
+	228, /* U+000253 */
+	231, /* U+000254 */
+	0, /* U+000255 */
+	233, /* U+000256 */
+	234, /* U+000257 */
+	0, /* U+000258 */
+	237, /* U+000259 */
+	0, /* U+00025A */
+	238, /* U+00025B */
+	336, /* U+00025C */
+	0, /* U+00025D */
+	0, /* U+00025E */
+	0, /* U+00025F */
+	240, /* U+000260 */
+	337, /* U+000261 */
+	0, /* U+000262 */
+	241, /* U+000263 */
+	0, /* U+000264 */
+	338, /* U+000265 */
+	339, /* U+000266 */
+	0, /* U+000267 */
+	244, /* U+000268 */
+	243, /* U+000269 */
+	340, /* U+00026A */
+	341, /* U+00026B */
+	342, /* U+00026C */
+	0, /* U+00026D */
+	0, /* U+00026E */
+	247, /* U+00026F */
+	0, /* U+000270 */
+	343, /* U+000271 */
+	248, /* U+000272 */
+	0, /* U+000273 */
+	0, /* U+000274 */
+	250, /* U+000275 */
+	0, /* U+000276 */
+	0, /* U+000277 */
+	0, /* U+000278 */
+	0, /* U+000279 */
+	0, /* U+00027A */
+	0, /* U+00027B */
+	0, /* U+00027C */
+	344, /* U+00027D */
+	0, /* U+00027E */
+	0, /* U+00027F */
+	254, /* U+000280 */
+	0, /* U+000281 */
+	345, /* U+000282 */
+	256, /* U+000283 */
+	0, /* U+000284 */
+	0, /* U+000285 */
+	0, /* U+000286 */
+	346, /* U+000287 */
+	258, /* U+000288 */
+	326, /* U+000289 */
+	260, /* U+00028A */
+	261, /* U+00028B */
+	327, /* U+00028C */
+	0, /* U+00028D */
+	0, /* U+00028E */
+	0, /* U+00028F */
+	0, /* U+000290 */
+	0, /* U+000291 */
+	264, /* U+000292 */
+	0, /* U+000293 */
+	0, /* U+000294 */
+	0, /* U+000295 */
+	0, /* U+000296 */
+	0, /* U+000297 */
+	0, /* U+000298 */
+	0, /* U+000299 */
+	0, /* U+00029A */
+	0, /* U+00029B */
+	0, /* U+00029C */
+	347, /* U+00029D */
+	348, /* U+00029E */
+	0, /* U+00029F */
+	0, /* U+0002A0 */
+	0, /* U+0002A1 */
+	0, /* U+0002A2 */
+	0, /* U+0002A3 */
+	0, /* U+0002A4 */
+	0, /* U+0002A5 */
+	0, /* U+0002A6 */
+	0, /* U+0002A7 */
+	0, /* U+0002A8 */
+	0, /* U+0002A9 */
+	0, /* U+0002AA */
+	0, /* U+0002AB */
+	0, /* U+0002AC */
+	0, /* U+0002AD */
+	0, /* U+0002AE */
+	0, /* U+0002AF */
+	0, /* U+0002B0 */
+	0, /* U+0002B1 */
+	0, /* U+0002B2 */
+	0, /* U+0002B3 */
+	0, /* U+0002B4 */
+	0, /* U+0002B5 */
+	0, /* U+0002B6 */
+	0, /* U+0002B7 */
+	0, /* U+0002B8 */
+	0, /* U+0002B9 */
+	0, /* U+0002BA */
+	0, /* U+0002BB */
+	0, /* U+0002BC */
+	0, /* U+0002BD */
+	0, /* U+0002BE */
+	0, /* U+0002BF */
+	0, /* U+0002C0 */
+	0, /* U+0002C1 */
+	0, /* U+0002C2 */
+	0, /* U+0002C3 */
+	0, /* U+0002C4 */
+	0, /* U+0002C5 */
+	0, /* U+0002C6 */
+	0, /* U+0002C7 */
+	0, /* U+0002C8 */
+	0, /* U+0002C9 */
+	0, /* U+0002CA */
+	0, /* U+0002CB */
+	0, /* U+0002CC */
+	0, /* U+0002CD */
+	0, /* U+0002CE */
+	0, /* U+0002CF */
+	0, /* U+0002D0 */
+	0, /* U+0002D1 */
+	0, /* U+0002D2 */
+	0, /* U+0002D3 */
+	0, /* U+0002D4 */
+	0, /* U+0002D5 */
+	0, /* U+0002D6 */
+	0, /* U+0002D7 */
+	0, /* U+0002D8 */
+	0, /* U+0002D9 */
+	0, /* U+0002DA */
+	0, /* U+0002DB */
+	0, /* U+0002DC */
+	0, /* U+0002DD */
+	0, /* U+0002DE */
+	0, /* U+0002DF */
+	0, /* U+0002E0 */
+	0, /* U+0002E1 */
+	0, /* U+0002E2 */
+	0, /* U+0002E3 */
+	0, /* U+0002E4 */
+	0, /* U+0002E5 */
+	0, /* U+0002E6 */
+	0, /* U+0002E7 */
+	0, /* U+0002E8 */
+	0, /* U+0002E9 */
+	0, /* U+0002EA */
+	0, /* U+0002EB */
+	0, /* U+0002EC */
+	0, /* U+0002ED */
+	0, /* U+0002EE */
+	0, /* U+0002EF */
+	0, /* U+0002F0 */
+	0, /* U+0002F1 */
+	0, /* U+0002F2 */
+	0, /* U+0002F3 */
+	0, /* U+0002F4 */
+	0, /* U+0002F5 */
+	0, /* U+0002F6 */
+	0, /* U+0002F7 */
+	0, /* U+0002F8 */
+	0, /* U+0002F9 */
+	0, /* U+0002FA */
+	0, /* U+0002FB */
+	0, /* U+0002FC */
+	0, /* U+0002FD */
+	0, /* U+0002FE */
+	0, /* U+0002FF */
+	0, /* U+000300 */
+	0, /* U+000301 */
+	0, /* U+000302 */
+	0, /* U+000303 */
+	0, /* U+000304 */
+	0, /* U+000305 */
+	0, /* U+000306 */
+	0, /* U+000307 */
+	0, /* U+000308 */
+	0, /* U+000309 */
+	0, /* U+00030A */
+	0, /* U+00030B */
+	0, /* U+00030C */
+	0, /* U+00030D */
+	0, /* U+00030E */
+	0, /* U+00030F */
+	0, /* U+000310 */
+	0, /* U+000311 */
+	0, /* U+000312 */
+	0, /* U+000313 */
+	0, /* U+000314 */
+	0, /* U+000315 */
+	0, /* U+000316 */
+	0, /* U+000317 */
+	0, /* U+000318 */
+	0, /* U+000319 */
+	0, /* U+00031A */
+	0, /* U+00031B */
+	0, /* U+00031C */
+	0, /* U+00031D */
+	0, /* U+00031E */
+	0, /* U+00031F */
+	0, /* U+000320 */
+	0, /* U+000321 */
+	0, /* U+000322 */
+	0, /* U+000323 */
+	0, /* U+000324 */
+	0, /* U+000325 */
+	0, /* U+000326 */
+	0, /* U+000327 */
+	0, /* U+000328 */
+	0, /* U+000329 */
+	0, /* U+00032A */
+	0, /* U+00032B */
+	0, /* U+00032C */
+	0, /* U+00032D */
+	0, /* U+00032E */
+	0, /* U+00032F */
+	0, /* U+000330 */
+	0, /* U+000331 */
+	0, /* U+000332 */
+	0, /* U+000333 */
+	0, /* U+000334 */
+	0, /* U+000335 */
+	0, /* U+000336 */
+	0, /* U+000337 */
+	0, /* U+000338 */
+	0, /* U+000339 */
+	0, /* U+00033A */
+	0, /* U+00033B */
+	0, /* U+00033C */
+	0, /* U+00033D */
+	0, /* U+00033E */
+	0, /* U+00033F */
+	0, /* U+000340 */
+	0, /* U+000341 */
+	0, /* U+000342 */
+	0, /* U+000343 */
+	0, /* U+000344 */
+	349, /* U+000345 */
+	0, /* U+000346 */
+	0, /* U+000347 */
+	0, /* U+000348 */
+	0, /* U+000349 */
+	0, /* U+00034A */
+	0, /* U+00034B */
+	0, /* U+00034C */
+	0, /* U+00034D */
+	0, /* U+00034E */
+	0, /* U+00034F */
+	0, /* U+000350 */
+	0, /* U+000351 */
+	0, /* U+000352 */
+	0, /* U+000353 */
+	0, /* U+000354 */
+	0, /* U+000355 */
+	0, /* U+000356 */
+	0, /* U+000357 */
+	0, /* U+000358 */
+	0, /* U+000359 */
+	0, /* U+00035A */
+	0, /* U+00035B */
+	0, /* U+00035C */
+	0, /* U+00035D */
+	0, /* U+00035E */
+	0, /* U+00035F */
+	0, /* U+000360 */
+	0, /* U+000361 */
+	0, /* U+000362 */
+	0, /* U+000363 */
+	0, /* U+000364 */
+	0, /* U+000365 */
+	0, /* U+000366 */
+	0, /* U+000367 */
+	0, /* U+000368 */
+	0, /* U+000369 */
+	0, /* U+00036A */
+	0, /* U+00036B */
+	0, /* U+00036C */
+	0, /* U+00036D */
+	0, /* U+00036E */
+	0, /* U+00036F */
+	350, /* U+000370 */
+	350, /* U+000371 */
+	351, /* U+000372 */
+	351, /* U+000373 */
+	0, /* U+000374 */
+	0, /* U+000375 */
+	352, /* U+000376 */
+	352, /* U+000377 */
+	0, /* U+000378 */
+	0, /* U+000379 */
+	0, /* U+00037A */
+	353, /* U+00037B */
+	354, /* U+00037C */
+	355, /* U+00037D */
+	0, /* U+00037E */
+	356, /* U+00037F */
+	0, /* U+000380 */
+	0, /* U+000381 */
+	0, /* U+000382 */
+	0, /* U+000383 */
+	0, /* U+000384 */
+	0, /* U+000385 */
+	357, /* U+000386 */
+	0, /* U+000387 */
+	358, /* U+000388 */
+	359, /* U+000389 */
+	360, /* U+00038A */
+	0, /* U+00038B */
+	361, /* U+00038C */
+	0, /* U+00038D */
+	362, /* U+00038E */
+	363, /* U+00038F */
+	364, /* U+000390 */
+	365, /* U+000391 */
+	366, /* U+000392 */
+	367, /* U+000393 */
+	368, /* U+000394 */
+	369, /* U+000395 */
+	370, /* U+000396 */
+	371, /* U+000397 */
+	372, /* U+000398 */
+	373, /* U+000399 */
+	374, /* U+00039A */
+	375, /* U+00039B */
+	376, /* U+00039C */
+	377, /* U+00039D */
+	378, /* U+00039E */
+	379, /* U+00039F */
+	380, /* U+0003A0 */
+	381, /* U+0003A1 */
+	0, /* U+0003A2 */
+	382, /* U+0003A3 */
+	383, /* U+0003A4 */
+	384, /* U+0003A5 */
+	385, /* U+0003A6 */
+	386, /* U+0003A7 */
+	387, /* U+0003A8 */
+	388, /* U+0003A9 */
+	389, /* U+0003AA */
+	390, /* U+0003AB */
+	357, /* U+0003AC */
+	358, /* U+0003AD */
+	359, /* U+0003AE */
+	360, /* U+0003AF */
+	391, /* U+0003B0 */
+	365, /* U+0003B1 */
+	366, /* U+0003B2 */
+	367, /* U+0003B3 */
+	368, /* U+0003B4 */
+	369, /* U+0003B5 */
+	370, /* U+0003B6 */
+	371, /* U+0003B7 */
+	372, /* U+0003B8 */
+	373, /* U+0003B9 */
+	374, /* U+0003BA */
+	375, /* U+0003BB */
+	376, /* U+0003BC */
+	377, /* U+0003BD */
+	378, /* U+0003BE */
+	379, /* U+0003BF */
+	380, /* U+0003C0 */
+	381, /* U+0003C1 */
+	392, /* U+0003C2 */
+	393, /* U+0003C3 */
+	383, /* U+0003C4 */
+	384, /* U+0003C5 */
+	385, /* U+0003C6 */
+	386, /* U+0003C7 */
+	387, /* U+0003C8 */
+	388, /* U+0003C9 */
+	389, /* U+0003CA */
+	390, /* U+0003CB */
+	361, /* U+0003CC */
+	362, /* U+0003CD */
+	363, /* U+0003CE */
+	394, /* U+0003CF */
+	395, /* U+0003D0 */
+	396, /* U+0003D1 */
+	0, /* U+0003D2 */
+	0, /* U+0003D3 */
+	0, /* U+0003D4 */
+	397, /* U+0003D5 */
+	398, /* U+0003D6 */
+	394, /* U+0003D7 */
+	399, /* U+0003D8 */
+	399, /* U+0003D9 */
+	400, /* U+0003DA */
+	400, /* U+0003DB */
+	401, /* U+0003DC */
+	401, /* U+0003DD */
+	402, /* U+0003DE */
+	402, /* U+0003DF */
+	403, /* U+0003E0 */
+	403, /* U+0003E1 */
+	404, /* U+0003E2 */
+	404, /* U+0003E3 */
+	405, /* U+0003E4 */
+	405, /* U+0003E5 */
+	406, /* U+0003E6 */
+	406, /* U+0003E7 */
+	407, /* U+0003E8 */
+	407, /* U+0003E9 */
+	408, /* U+0003EA */
+	408, /* U+0003EB */
+	409, /* U+0003EC */
+	409, /* U+0003ED */
+	410, /* U+0003EE */
+	410, /* U+0003EF */
+	411, /* U+0003F0 */
+	412, /* U+0003F1 */
+	413, /* U+0003F2 */
+	356, /* U+0003F3 */
+	414, /* U+0003F4 */
+	415, /* U+0003F5 */
+	0, /* U+0003F6 */
+	416, /* U+0003F7 */
+	416, /* U+0003F8 */
+	413, /* U+0003F9 */
+	417, /* U+0003FA */
+	417, /* U+0003FB */
+	0, /* U+0003FC */
+	353, /* U+0003FD */
+	354, /* U+0003FE */
+	355, /* U+0003FF */
+	418, /* U+000400 */
+	419, /* U+000401 */
+	420, /* U+000402 */
+	421, /* U+000403 */
+	422, /* U+000404 */
+	423, /* U+000405 */
+	424, /* U+000406 */
+	425, /* U+000407 */
+	426, /* U+000408 */
+	427, /* U+000409 */
+	428, /* U+00040A */
+	429, /* U+00040B */
+	430, /* U+00040C */
+	431, /* U+00040D */
+	432, /* U+00040E */
+	433, /* U+00040F */
+	434, /* U+000410 */
+	435, /* U+000411 */
+	436, /* U+000412 */
+	437, /* U+000413 */
+	438, /* U+000414 */
+	439, /* U+000415 */
+	440, /* U+000416 */
+	441, /* U+000417 */
+	442, /* U+000418 */
+	443, /* U+000419 */
+	444, /* U+00041A */
+	445, /* U+00041B */
+	446, /* U+00041C */
+	447, /* U+00041D */
+	448, /* U+00041E */
+	449, /* U+00041F */
+	450, /* U+000420 */
+	451, /* U+000421 */
+	452, /* U+000422 */
+	453, /* U+000423 */
+	454, /* U+000424 */
+	455, /* U+000425 */
+	456, /* U+000426 */
+	457, /* U+000427 */
+	458, /* U+000428 */
+	459, /* U+000429 */
+	460, /* U+00042A */
+	461, /* U+00042B */
+	462, /* U+00042C */
+	463, /* U+00042D */
+	464, /* U+00042E */
+	465, /* U+00042F */
+	434, /* U+000430 */
+	435, /* U+000431 */
+	436, /* U+000432 */
+	437, /* U+000433 */
+	438, /* U+000434 */
+	439, /* U+000435 */
+	440, /* U+000436 */
+	441, /* U+000437 */
+	442, /* U+000438 */
+	443, /* U+000439 */
+	444, /* U+00043A */
+	445, /* U+00043B */
+	446, /* U+00043C */
+	447, /* U+00043D */
+	448, /* U+00043E */
+	449, /* U+00043F */
+	450, /* U+000440 */
+	451, /* U+000441 */
+	452, /* U+000442 */
+	453, /* U+000443 */
+	454, /* U+000444 */
+	455, /* U+000445 */
+	456, /* U+000446 */
+	457, /* U+000447 */
+	458, /* U+000448 */
+	459, /* U+000449 */
+	460, /* U+00044A */
+	461, /* U+00044B */
+	462, /* U+00044C */
+	463, /* U+00044D */
+	464, /* U+00044E */
+	465, /* U+00044F */
+	418, /* U+000450 */
+	419, /* U+000451 */
+	420, /* U+000452 */
+	421, /* U+000453 */
+	422, /* U+000454 */
+	423, /* U+000455 */
+	424, /* U+000456 */
+	425, /* U+000457 */
+	426, /* U+000458 */
+	427, /* U+000459 */
+	428, /* U+00045A */
+	429, /* U+00045B */
+	430, /* U+00045C */
+	431, /* U+00045D */
+	432, /* U+00045E */
+	433, /* U+00045F */
+	466, /* U+000460 */
+	466, /* U+000461 */
+	467, /* U+000462 */
+	467, /* U+000463 */
+	468, /* U+000464 */
+	468, /* U+000465 */
+	469, /* U+000466 */
+	469, /* U+000467 */
+	470, /* U+000468 */
+	470, /* U+000469 */
+	471, /* U+00046A */
+	471, /* U+00046B */
+	472, /* U+00046C */
+	472, /* U+00046D */
+	473, /* U+00046E */
+	473, /* U+00046F */
+	474, /* U+000470 */
+	474, /* U+000471 */
+	475, /* U+000472 */
+	475, /* U+000473 */
+	476, /* U+000474 */
+	476, /* U+000475 */
+	477, /* U+000476 */
+	477, /* U+000477 */
+	478, /* U+000478 */
+	478, /* U+000479 */
+	479, /* U+00047A */
+	479, /* U+00047B */
+	480, /* U+00047C */
+	480, /* U+00047D */
+	481, /* U+00047E */
+	481, /* U+00047F */
+	482, /* U+000480 */
+	482, /* U+000481 */
+	0, /* U+000482 */
+	0, /* U+000483 */
+	0, /* U+000484 */
+	0, /* U+000485 */
+	0, /* U+000486 */
+	0, /* U+000487 */
+	0, /* U+000488 */
+	0, /* U+000489 */
+	483, /* U+00048A */
+	483, /* U+00048B */
+	484, /* U+00048C */
+	484, /* U+00048D */
+	485, /* U+00048E */
+	485, /* U+00048F */
+	486, /* U+000490 */
+	486, /* U+000491 */
+	487, /* U+000492 */
+	487, /* U+000493 */
+	488, /* U+000494 */
+	488, /* U+000495 */
+	489, /* U+000496 */
+	489, /* U+000497 */
+	490, /* U+000498 */
+	490, /* U+000499 */
+	491, /* U+00049A */
+	491, /* U+00049B */
+	492, /* U+00049C */
+	492, /* U+00049D */
+	493, /* U+00049E */
+	493, /* U+00049F */
+	494, /* U+0004A0 */
+	494, /* U+0004A1 */
+	495, /* U+0004A2 */
+	495, /* U+0004A3 */
+	496, /* U+0004A4 */
+	496, /* U+0004A5 */
+	497, /* U+0004A6 */
+	497, /* U+0004A7 */
+	498, /* U+0004A8 */
+	498, /* U+0004A9 */
+	499, /* U+0004AA */
+	499, /* U+0004AB */
+	500, /* U+0004AC */
+	500, /* U+0004AD */
+	501, /* U+0004AE */
+	501, /* U+0004AF */
+	502, /* U+0004B0 */
+	502, /* U+0004B1 */
+	503, /* U+0004B2 */
+	503, /* U+0004B3 */
+	504, /* U+0004B4 */
+	504, /* U+0004B5 */
+	505, /* U+0004B6 */
+	505, /* U+0004B7 */
+	506, /* U+0004B8 */
+	506, /* U+0004B9 */
+	507, /* U+0004BA */
+	507, /* U+0004BB */
+	508, /* U+0004BC */
+	508, /* U+0004BD */
+	509, /* U+0004BE */
+	509, /* U+0004BF */
+	510, /* U+0004C0 */
+	511, /* U+0004C1 */
+	511, /* U+0004C2 */
+	512, /* U+0004C3 */
+	512, /* U+0004C4 */
+	513, /* U+0004C5 */
+	513, /* U+0004C6 */
+	514, /* U+0004C7 */
+	514, /* U+0004C8 */
+	515, /* U+0004C9 */
+	515, /* U+0004CA */
+	516, /* U+0004CB */
+	516, /* U+0004CC */
+	517, /* U+0004CD */
+	517, /* U+0004CE */
+	510, /* U+0004CF */
+	518, /* U+0004D0 */
+	518, /* U+0004D1 */
+	519, /* U+0004D2 */
+	519, /* U+0004D3 */
+	520, /* U+0004D4 */
+	520, /* U+0004D5 */
+	521, /* U+0004D6 */
+	521, /* U+0004D7 */
+	522, /* U+0004D8 */
+	522, /* U+0004D9 */
+	523, /* U+0004DA */
+	523, /* U+0004DB */
+	524, /* U+0004DC */
+	524, /* U+0004DD */
+	525, /* U+0004DE */
+	525, /* U+0004DF */
+	526, /* U+0004E0 */
+	526, /* U+0004E1 */
+	527, /* U+0004E2 */
+	527, /* U+0004E3 */
+	528, /* U+0004E4 */
+	528, /* U+0004E5 */
+	529, /* U+0004E6 */
+	529, /* U+0004E7 */
+	530, /* U+0004E8 */
+	530, /* U+0004E9 */
+	531, /* U+0004EA */
+	531, /* U+0004EB */
+	532, /* U+0004EC */
+	532, /* U+0004ED */
+	533, /* U+0004EE */
+	533, /* U+0004EF */
+	534, /* U+0004F0 */
+	534, /* U+0004F1 */
+	535, /* U+0004F2 */
+	535, /* U+0004F3 */
+	536, /* U+0004F4 */
+	536, /* U+0004F5 */
+	537, /* U+0004F6 */
+	537, /* U+0004F7 */
+	538, /* U+0004F8 */
+	538, /* U+0004F9 */
+	539, /* U+0004FA */
+	539, /* U+0004FB */
+	540, /* U+0004FC */
+	540, /* U+0004FD */
+	541, /* U+0004FE */
+	541, /* U+0004FF */
+	542, /* U+000500 */
+	542, /* U+000501 */
+	543, /* U+000502 */
+	543, /* U+000503 */
+	544, /* U+000504 */
+	544, /* U+000505 */
+	545, /* U+000506 */
+	545, /* U+000507 */
+	546, /* U+000508 */
+	546, /* U+000509 */
+	547, /* U+00050A */
+	547, /* U+00050B */
+	548, /* U+00050C */
+	548, /* U+00050D */
+	549, /* U+00050E */
+	549, /* U+00050F */
+	550, /* U+000510 */
+	550, /* U+000511 */
+	551, /* U+000512 */
+	551, /* U+000513 */
+	552, /* U+000514 */
+	552, /* U+000515 */
+	553, /* U+000516 */
+	553, /* U+000517 */
+	554, /* U+000518 */
+	554, /* U+000519 */
+	555, /* U+00051A */
+	555, /* U+00051B */
+	556, /* U+00051C */
+	556, /* U+00051D */
+	557, /* U+00051E */
+	557, /* U+00051F */
+	558, /* U+000520 */
+	558, /* U+000521 */
+	559, /* U+000522 */
+	559, /* U+000523 */
+	560, /* U+000524 */
+	560, /* U+000525 */
+	561, /* U+000526 */
+	561, /* U+000527 */
+	562, /* U+000528 */
+	562, /* U+000529 */
+	563, /* U+00052A */
+	563, /* U+00052B */
+	564, /* U+00052C */
+	564, /* U+00052D */
+	565, /* U+00052E */
+	565, /* U+00052F */
+	0, /* U+000530 */
+	566, /* U+000531 */
+	567, /* U+000532 */
+	568, /* U+000533 */
+	569, /* U+000534 */
+	570, /* U+000535 */
+	571, /* U+000536 */
+	572, /* U+000537 */
+	573, /* U+000538 */
+	574, /* U+000539 */
+	575, /* U+00053A */
+	576, /* U+00053B */
+	577, /* U+00053C */
+	578, /* U+00053D */
+	579, /* U+00053E */
+	580, /* U+00053F */
+	581, /* U+000540 */
+	582, /* U+000541 */
+	583, /* U+000542 */
+	584, /* U+000543 */
+	585, /* U+000544 */
+	586, /* U+000545 */
+	587, /* U+000546 */
+	588, /* U+000547 */
+	589, /* U+000548 */
+	590, /* U+000549 */
+	591, /* U+00054A */
+	592, /* U+00054B */
+	593, /* U+00054C */
+	594, /* U+00054D */
+	595, /* U+00054E */
+	596, /* U+00054F */
+	597, /* U+000550 */
+	598, /* U+000551 */
+	599, /* U+000552 */
+	600, /* U+000553 */
+	601, /* U+000554 */
+	602, /* U+000555 */
+	603, /* U+000556 */
+	0, /* U+000557 */
+	0, /* U+000558 */
+	0, /* U+000559 */
+	0, /* U+00055A */
+	0, /* U+00055B */
+	0, /* U+00055C */
+	0, /* U+00055D */
+	0, /* U+00055E */
+	0, /* U+00055F */
+	0, /* U+000560 */
+	566, /* U+000561 */
+	567, /* U+000562 */
+	568, /* U+000563 */
+	569, /* U+000564 */
+	570, /* U+000565 */
+	571, /* U+000566 */
+	572, /* U+000567 */
+	573, /* U+000568 */
+	574, /* U+000569 */
+	575, /* U+00056A */
+	576, /* U+00056B */
+	577, /* U+00056C */
+	578, /* U+00056D */
+	579, /* U+00056E */
+	580, /* U+00056F */
+	581, /* U+000570 */
+	582, /* U+000571 */
+	583, /* U+000572 */
+	584, /* U+000573 */
+	585, /* U+000574 */
+	586, /* U+000575 */
+	587, /* U+000576 */
+	588, /* U+000577 */
+	589, /* U+000578 */
+	590, /* U+000579 */
+	591, /* U+00057A */
+	592, /* U+00057B */
+	593, /* U+00057C */
+	594, /* U+00057D */
+	595, /* U+00057E */
+	596, /* U+00057F */
+	597, /* U+000580 */
+	598, /* U+000581 */
+	599, /* U+000582 */
+	600, /* U+000583 */
+	601, /* U+000584 */
+	602, /* U+000585 */
+	603, /* U+000586 */
+	604, /* U+000587 */
+	605, /* U+0010A0 */
+	606, /* U+0010A1 */
+	607, /* U+0010A2 */
+	608, /* U+0010A3 */
+	609, /* U+0010A4 */
+	610, /* U+0010A5 */
+	611, /* U+0010A6 */
+	612, /* U+0010A7 */
+	613, /* U+0010A8 */
+	614, /* U+0010A9 */
+	615, /* U+0010AA */
+	616, /* U+0010AB */
+	617, /* U+0010AC */
+	618, /* U+0010AD */
+	619, /* U+0010AE */
+	620, /* U+0010AF */
+	621, /* U+0010B0 */
+	622, /* U+0010B1 */
+	623, /* U+0010B2 */
+	624, /* U+0010B3 */
+	625, /* U+0010B4 */
+	626, /* U+0010B5 */
+	627, /* U+0010B6 */
+	628, /* U+0010B7 */
+	629, /* U+0010B8 */
+	630, /* U+0010B9 */
+	631, /* U+0010BA */
+	632, /* U+0010BB */
+	633, /* U+0010BC */
+	634, /* U+0010BD */
+	635, /* U+0010BE */
+	636, /* U+0010BF */
+	637, /* U+0010C0 */
+	638, /* U+0010C1 */
+	639, /* U+0010C2 */
+	640, /* U+0010C3 */
+	641, /* U+0010C4 */
+	642, /* U+0010C5 */
+	0, /* U+0010C6 */
+	643, /* U+0010C7 */
+	0, /* U+0010C8 */
+	0, /* U+0010C9 */
+	0, /* U+0010CA */
+	0, /* U+0010CB */
+	0, /* U+0010CC */
+	644, /* U+0010CD */
+	0, /* U+0010CE */
+	0, /* U+0010CF */
+	645, /* U+0010D0 */
+	646, /* U+0010D1 */
+	647, /* U+0010D2 */
+	648, /* U+0010D3 */
+	649, /* U+0010D4 */
+	650, /* U+0010D5 */
+	651, /* U+0010D6 */
+	652, /* U+0010D7 */
+	653, /* U+0010D8 */
+	654, /* U+0010D9 */
+	655, /* U+0010DA */
+	656, /* U+0010DB */
+	657, /* U+0010DC */
+	658, /* U+0010DD */
+	659, /* U+0010DE */
+	660, /* U+0010DF */
+	661, /* U+0010E0 */
+	662, /* U+0010E1 */
+	663, /* U+0010E2 */
+	664, /* U+0010E3 */
+	665, /* U+0010E4 */
+	666, /* U+0010E5 */
+	667, /* U+0010E6 */
+	668, /* U+0010E7 */
+	669, /* U+0010E8 */
+	670, /* U+0010E9 */
+	671, /* U+0010EA */
+	672, /* U+0010EB */
+	673, /* U+0010EC */
+	674, /* U+0010ED */
+	675, /* U+0010EE */
+	676, /* U+0010EF */
+	677, /* U+0010F0 */
+	678, /* U+0010F1 */
+	679, /* U+0010F2 */
+	680, /* U+0010F3 */
+	681, /* U+0010F4 */
+	682, /* U+0010F5 */
+	683, /* U+0010F6 */
+	684, /* U+0010F7 */
+	685, /* U+0010F8 */
+	686, /* U+0010F9 */
+	687, /* U+0010FA */
+	0, /* U+0010FB */
+	0, /* U+0010FC */
+	688, /* U+0010FD */
+	689, /* U+0010FE */
+	690, /* U+0010FF */
+	691, /* U+0013A0 */
+	692, /* U+0013A1 */
+	693, /* U+0013A2 */
+	694, /* U+0013A3 */
+	695, /* U+0013A4 */
+	696, /* U+0013A5 */
+	697, /* U+0013A6 */
+	698, /* U+0013A7 */
+	699, /* U+0013A8 */
+	700, /* U+0013A9 */
+	701, /* U+0013AA */
+	702, /* U+0013AB */
+	703, /* U+0013AC */
+	704, /* U+0013AD */
+	705, /* U+0013AE */
+	706, /* U+0013AF */
+	707, /* U+0013B0 */
+	708, /* U+0013B1 */
+	709, /* U+0013B2 */
+	710, /* U+0013B3 */
+	711, /* U+0013B4 */
+	712, /* U+0013B5 */
+	713, /* U+0013B6 */
+	714, /* U+0013B7 */
+	715, /* U+0013B8 */
+	716, /* U+0013B9 */
+	717, /* U+0013BA */
+	718, /* U+0013BB */
+	719, /* U+0013BC */
+	720, /* U+0013BD */
+	721, /* U+0013BE */
+	722, /* U+0013BF */
+	723, /* U+0013C0 */
+	724, /* U+0013C1 */
+	725, /* U+0013C2 */
+	726, /* U+0013C3 */
+	727, /* U+0013C4 */
+	728, /* U+0013C5 */
+	729, /* U+0013C6 */
+	730, /* U+0013C7 */
+	731, /* U+0013C8 */
+	732, /* U+0013C9 */
+	733, /* U+0013CA */
+	734, /* U+0013CB */
+	735, /* U+0013CC */
+	736, /* U+0013CD */
+	737, /* U+0013CE */
+	738, /* U+0013CF */
+	739, /* U+0013D0 */
+	740, /* U+0013D1 */
+	741, /* U+0013D2 */
+	742, /* U+0013D3 */
+	743, /* U+0013D4 */
+	744, /* U+0013D5 */
+	745, /* U+0013D6 */
+	746, /* U+0013D7 */
+	747, /* U+0013D8 */
+	748, /* U+0013D9 */
+	749, /* U+0013DA */
+	750, /* U+0013DB */
+	751, /* U+0013DC */
+	752, /* U+0013DD */
+	753, /* U+0013DE */
+	754, /* U+0013DF */
+	755, /* U+0013E0 */
+	756, /* U+0013E1 */
+	757, /* U+0013E2 */
+	758, /* U+0013E3 */
+	759, /* U+0013E4 */
+	760, /* U+0013E5 */
+	761, /* U+0013E6 */
+	762, /* U+0013E7 */
+	763, /* U+0013E8 */
+	764, /* U+0013E9 */
+	765, /* U+0013EA */
+	766, /* U+0013EB */
+	767, /* U+0013EC */
+	768, /* U+0013ED */
+	769, /* U+0013EE */
+	770, /* U+0013EF */
+	771, /* U+0013F0 */
+	772, /* U+0013F1 */
+	773, /* U+0013F2 */
+	774, /* U+0013F3 */
+	775, /* U+0013F4 */
+	776, /* U+0013F5 */
+	0, /* U+0013F6 */
+	0, /* U+0013F7 */
+	771, /* U+0013F8 */
+	772, /* U+0013F9 */
+	773, /* U+0013FA */
+	774, /* U+0013FB */
+	775, /* U+0013FC */
+	776, /* U+0013FD */
+	777, /* U+001C80 */
+	778, /* U+001C81 */
+	779, /* U+001C82 */
+	780, /* U+001C83 */
+	781, /* U+001C84 */
+	782, /* U+001C85 */
+	783, /* U+001C86 */
+	784, /* U+001C87 */
+	785, /* U+001C88 */
+	0, /* U+001C89 */
+	0, /* U+001C8A */
+	0, /* U+001C8B */
+	0, /* U+001C8C */
+	0, /* U+001C8D */
+	0, /* U+001C8E */
+	0, /* U+001C8F */
+	786, /* U+001C90 */
+	787, /* U+001C91 */
+	788, /* U+001C92 */
+	789, /* U+001C93 */
+	790, /* U+001C94 */
+	791, /* U+001C95 */
+	792, /* U+001C96 */
+	793, /* U+001C97 */
+	794, /* U+001C98 */
+	795, /* U+001C99 */
+	796, /* U+001C9A */
+	797, /* U+001C9B */
+	798, /* U+001C9C */
+	799, /* U+001C9D */
+	800, /* U+001C9E */
+	801, /* U+001C9F */
+	802, /* U+001CA0 */
+	803, /* U+001CA1 */
+	804, /* U+001CA2 */
+	805, /* U+001CA3 */
+	806, /* U+001CA4 */
+	807, /* U+001CA5 */
+	808, /* U+001CA6 */
+	809, /* U+001CA7 */
+	810, /* U+001CA8 */
+	811, /* U+001CA9 */
+	812, /* U+001CAA */
+	813, /* U+001CAB */
+	814, /* U+001CAC */
+	815, /* U+001CAD */
+	816, /* U+001CAE */
+	817, /* U+001CAF */
+	818, /* U+001CB0 */
+	819, /* U+001CB1 */
+	820, /* U+001CB2 */
+	821, /* U+001CB3 */
+	822, /* U+001CB4 */
+	823, /* U+001CB5 */
+	824, /* U+001CB6 */
+	825, /* U+001CB7 */
+	826, /* U+001CB8 */
+	827, /* U+001CB9 */
+	828, /* U+001CBA */
+	0, /* U+001CBB */
+	0, /* U+001CBC */
+	829, /* U+001CBD */
+	830, /* U+001CBE */
+	831, /* U+001CBF */
+	0, /* U+001CC0 */
+	0, /* U+001CC1 */
+	0, /* U+001CC2 */
+	0, /* U+001CC3 */
+	0, /* U+001CC4 */
+	0, /* U+001CC5 */
+	0, /* U+001CC6 */
+	0, /* U+001CC7 */
+	0, /* U+001CC8 */
+	0, /* U+001CC9 */
+	0, /* U+001CCA */
+	0, /* U+001CCB */
+	0, /* U+001CCC */
+	0, /* U+001CCD */
+	0, /* U+001CCE */
+	0, /* U+001CCF */
+	0, /* U+001CD0 */
+	0, /* U+001CD1 */
+	0, /* U+001CD2 */
+	0, /* U+001CD3 */
+	0, /* U+001CD4 */
+	0, /* U+001CD5 */
+	0, /* U+001CD6 */
+	0, /* U+001CD7 */
+	0, /* U+001CD8 */
+	0, /* U+001CD9 */
+	0, /* U+001CDA */
+	0, /* U+001CDB */
+	0, /* U+001CDC */
+	0, /* U+001CDD */
+	0, /* U+001CDE */
+	0, /* U+001CDF */
+	0, /* U+001CE0 */
+	0, /* U+001CE1 */
+	0, /* U+001CE2 */
+	0, /* U+001CE3 */
+	0, /* U+001CE4 */
+	0, /* U+001CE5 */
+	0, /* U+001CE6 */
+	0, /* U+001CE7 */
+	0, /* U+001CE8 */
+	0, /* U+001CE9 */
+	0, /* U+001CEA */
+	0, /* U+001CEB */
+	0, /* U+001CEC */
+	0, /* U+001CED */
+	0, /* U+001CEE */
+	0, /* U+001CEF */
+	0, /* U+001CF0 */
+	0, /* U+001CF1 */
+	0, /* U+001CF2 */
+	0, /* U+001CF3 */
+	0, /* U+001CF4 */
+	0, /* U+001CF5 */
+	0, /* U+001CF6 */
+	0, /* U+001CF7 */
+	0, /* U+001CF8 */
+	0, /* U+001CF9 */
+	0, /* U+001CFA */
+	0, /* U+001CFB */
+	0, /* U+001CFC */
+	0, /* U+001CFD */
+	0, /* U+001CFE */
+	0, /* U+001CFF */
+	0, /* U+001D00 */
+	0, /* U+001D01 */
+	0, /* U+001D02 */
+	0, /* U+001D03 */
+	0, /* U+001D04 */
+	0, /* U+001D05 */
+	0, /* U+001D06 */
+	0, /* U+001D07 */
+	0, /* U+001D08 */
+	0, /* U+001D09 */
+	0, /* U+001D0A */
+	0, /* U+001D0B */
+	0, /* U+001D0C */
+	0, /* U+001D0D */
+	0, /* U+001D0E */
+	0, /* U+001D0F */
+	0, /* U+001D10 */
+	0, /* U+001D11 */
+	0, /* U+001D12 */
+	0, /* U+001D13 */
+	0, /* U+001D14 */
+	0, /* U+001D15 */
+	0, /* U+001D16 */
+	0, /* U+001D17 */
+	0, /* U+001D18 */
+	0, /* U+001D19 */
+	0, /* U+001D1A */
+	0, /* U+001D1B */
+	0, /* U+001D1C */
+	0, /* U+001D1D */
+	0, /* U+001D1E */
+	0, /* U+001D1F */
+	0, /* U+001D20 */
+	0, /* U+001D21 */
+	0, /* U+001D22 */
+	0, /* U+001D23 */
+	0, /* U+001D24 */
+	0, /* U+001D25 */
+	0, /* U+001D26 */
+	0, /* U+001D27 */
+	0, /* U+001D28 */
+	0, /* U+001D29 */
+	0, /* U+001D2A */
+	0, /* U+001D2B */
+	0, /* U+001D2C */
+	0, /* U+001D2D */
+	0, /* U+001D2E */
+	0, /* U+001D2F */
+	0, /* U+001D30 */
+	0, /* U+001D31 */
+	0, /* U+001D32 */
+	0, /* U+001D33 */
+	0, /* U+001D34 */
+	0, /* U+001D35 */
+	0, /* U+001D36 */
+	0, /* U+001D37 */
+	0, /* U+001D38 */
+	0, /* U+001D39 */
+	0, /* U+001D3A */
+	0, /* U+001D3B */
+	0, /* U+001D3C */
+	0, /* U+001D3D */
+	0, /* U+001D3E */
+	0, /* U+001D3F */
+	0, /* U+001D40 */
+	0, /* U+001D41 */
+	0, /* U+001D42 */
+	0, /* U+001D43 */
+	0, /* U+001D44 */
+	0, /* U+001D45 */
+	0, /* U+001D46 */
+	0, /* U+001D47 */
+	0, /* U+001D48 */
+	0, /* U+001D49 */
+	0, /* U+001D4A */
+	0, /* U+001D4B */
+	0, /* U+001D4C */
+	0, /* U+001D4D */
+	0, /* U+001D4E */
+	0, /* U+001D4F */
+	0, /* U+001D50 */
+	0, /* U+001D51 */
+	0, /* U+001D52 */
+	0, /* U+001D53 */
+	0, /* U+001D54 */
+	0, /* U+001D55 */
+	0, /* U+001D56 */
+	0, /* U+001D57 */
+	0, /* U+001D58 */
+	0, /* U+001D59 */
+	0, /* U+001D5A */
+	0, /* U+001D5B */
+	0, /* U+001D5C */
+	0, /* U+001D5D */
+	0, /* U+001D5E */
+	0, /* U+001D5F */
+	0, /* U+001D60 */
+	0, /* U+001D61 */
+	0, /* U+001D62 */
+	0, /* U+001D63 */
+	0, /* U+001D64 */
+	0, /* U+001D65 */
+	0, /* U+001D66 */
+	0, /* U+001D67 */
+	0, /* U+001D68 */
+	0, /* U+001D69 */
+	0, /* U+001D6A */
+	0, /* U+001D6B */
+	0, /* U+001D6C */
+	0, /* U+001D6D */
+	0, /* U+001D6E */
+	0, /* U+001D6F */
+	0, /* U+001D70 */
+	0, /* U+001D71 */
+	0, /* U+001D72 */
+	0, /* U+001D73 */
+	0, /* U+001D74 */
+	0, /* U+001D75 */
+	0, /* U+001D76 */
+	0, /* U+001D77 */
+	0, /* U+001D78 */
+	832, /* U+001D79 */
+	0, /* U+001D7A */
+	0, /* U+001D7B */
+	0, /* U+001D7C */
+	833, /* U+001D7D */
+	0, /* U+001D7E */
+	0, /* U+001D7F */
+	0, /* U+001D80 */
+	0, /* U+001D81 */
+	0, /* U+001D82 */
+	0, /* U+001D83 */
+	0, /* U+001D84 */
+	0, /* U+001D85 */
+	0, /* U+001D86 */
+	0, /* U+001D87 */
+	0, /* U+001D88 */
+	0, /* U+001D89 */
+	0, /* U+001D8A */
+	0, /* U+001D8B */
+	0, /* U+001D8C */
+	0, /* U+001D8D */
+	834, /* U+001D8E */
+	0, /* U+001D8F */
+	0, /* U+001D90 */
+	0, /* U+001D91 */
+	0, /* U+001D92 */
+	0, /* U+001D93 */
+	0, /* U+001D94 */
+	0, /* U+001D95 */
+	0, /* U+001D96 */
+	0, /* U+001D97 */
+	0, /* U+001D98 */
+	0, /* U+001D99 */
+	0, /* U+001D9A */
+	0, /* U+001D9B */
+	0, /* U+001D9C */
+	0, /* U+001D9D */
+	0, /* U+001D9E */
+	0, /* U+001D9F */
+	0, /* U+001DA0 */
+	0, /* U+001DA1 */
+	0, /* U+001DA2 */
+	0, /* U+001DA3 */
+	0, /* U+001DA4 */
+	0, /* U+001DA5 */
+	0, /* U+001DA6 */
+	0, /* U+001DA7 */
+	0, /* U+001DA8 */
+	0, /* U+001DA9 */
+	0, /* U+001DAA */
+	0, /* U+001DAB */
+	0, /* U+001DAC */
+	0, /* U+001DAD */
+	0, /* U+001DAE */
+	0, /* U+001DAF */
+	0, /* U+001DB0 */
+	0, /* U+001DB1 */
+	0, /* U+001DB2 */
+	0, /* U+001DB3 */
+	0, /* U+001DB4 */
+	0, /* U+001DB5 */
+	0, /* U+001DB6 */
+	0, /* U+001DB7 */
+	0, /* U+001DB8 */
+	0, /* U+001DB9 */
+	0, /* U+001DBA */
+	0, /* U+001DBB */
+	0, /* U+001DBC */
+	0, /* U+001DBD */
+	0, /* U+001DBE */
+	0, /* U+001DBF */
+	0, /* U+001DC0 */
+	0, /* U+001DC1 */
+	0, /* U+001DC2 */
+	0, /* U+001DC3 */
+	0, /* U+001DC4 */
+	0, /* U+001DC5 */
+	0, /* U+001DC6 */
+	0, /* U+001DC7 */
+	0, /* U+001DC8 */
+	0, /* U+001DC9 */
+	0, /* U+001DCA */
+	0, /* U+001DCB */
+	0, /* U+001DCC */
+	0, /* U+001DCD */
+	0, /* U+001DCE */
+	0, /* U+001DCF */
+	0, /* U+001DD0 */
+	0, /* U+001DD1 */
+	0, /* U+001DD2 */
+	0, /* U+001DD3 */
+	0, /* U+001DD4 */
+	0, /* U+001DD5 */
+	0, /* U+001DD6 */
+	0, /* U+001DD7 */
+	0, /* U+001DD8 */
+	0, /* U+001DD9 */
+	0, /* U+001DDA */
+	0, /* U+001DDB */
+	0, /* U+001DDC */
+	0, /* U+001DDD */
+	0, /* U+001DDE */
+	0, /* U+001DDF */
+	0, /* U+001DE0 */
+	0, /* U+001DE1 */
+	0, /* U+001DE2 */
+	0, /* U+001DE3 */
+	0, /* U+001DE4 */
+	0, /* U+001DE5 */
+	0, /* U+001DE6 */
+	0, /* U+001DE7 */
+	0, /* U+001DE8 */
+	0, /* U+001DE9 */
+	0, /* U+001DEA */
+	0, /* U+001DEB */
+	0, /* U+001DEC */
+	0, /* U+001DED */
+	0, /* U+001DEE */
+	0, /* U+001DEF */
+	0, /* U+001DF0 */
+	0, /* U+001DF1 */
+	0, /* U+001DF2 */
+	0, /* U+001DF3 */
+	0, /* U+001DF4 */
+	0, /* U+001DF5 */
+	0, /* U+001DF6 */
+	0, /* U+001DF7 */
+	0, /* U+001DF8 */
+	0, /* U+001DF9 */
+	0, /* U+001DFA */
+	0, /* U+001DFB */
+	0, /* U+001DFC */
+	0, /* U+001DFD */
+	0, /* U+001DFE */
+	0, /* U+001DFF */
+	835, /* U+001E00 */
+	835, /* U+001E01 */
+	836, /* U+001E02 */
+	836, /* U+001E03 */
+	837, /* U+001E04 */
+	837, /* U+001E05 */
+	838, /* U+001E06 */
+	838, /* U+001E07 */
+	839, /* U+001E08 */
+	839, /* U+001E09 */
+	840, /* U+001E0A */
+	840, /* U+001E0B */
+	841, /* U+001E0C */
+	841, /* U+001E0D */
+	842, /* U+001E0E */
+	842, /* U+001E0F */
+	843, /* U+001E10 */
+	843, /* U+001E11 */
+	844, /* U+001E12 */
+	844, /* U+001E13 */
+	845, /* U+001E14 */
+	845, /* U+001E15 */
+	846, /* U+001E16 */
+	846, /* U+001E17 */
+	847, /* U+001E18 */
+	847, /* U+001E19 */
+	848, /* U+001E1A */
+	848, /* U+001E1B */
+	849, /* U+001E1C */
+	849, /* U+001E1D */
+	850, /* U+001E1E */
+	850, /* U+001E1F */
+	851, /* U+001E20 */
+	851, /* U+001E21 */
+	852, /* U+001E22 */
+	852, /* U+001E23 */
+	853, /* U+001E24 */
+	853, /* U+001E25 */
+	854, /* U+001E26 */
+	854, /* U+001E27 */
+	855, /* U+001E28 */
+	855, /* U+001E29 */
+	856, /* U+001E2A */
+	856, /* U+001E2B */
+	857, /* U+001E2C */
+	857, /* U+001E2D */
+	858, /* U+001E2E */
+	858, /* U+001E2F */
+	859, /* U+001E30 */
+	859, /* U+001E31 */
+	860, /* U+001E32 */
+	860, /* U+001E33 */
+	861, /* U+001E34 */
+	861, /* U+001E35 */
+	862, /* U+001E36 */
+	862, /* U+001E37 */
+	863, /* U+001E38 */
+	863, /* U+001E39 */
+	864, /* U+001E3A */
+	864, /* U+001E3B */
+	865, /* U+001E3C */
+	865, /* U+001E3D */
+	866, /* U+001E3E */
+	866, /* U+001E3F */
+	867, /* U+001E40 */
+	867, /* U+001E41 */
+	868, /* U+001E42 */
+	868, /* U+001E43 */
+	869, /* U+001E44 */
+	869, /* U+001E45 */
+	870, /* U+001E46 */
+	870, /* U+001E47 */
+	871, /* U+001E48 */
+	871, /* U+001E49 */
+	872, /* U+001E4A */
+	872, /* U+001E4B */
+	873, /* U+001E4C */
+	873, /* U+001E4D */
+	874, /* U+001E4E */
+	874, /* U+001E4F */
+	875, /* U+001E50 */
+	875, /* U+001E51 */
+	876, /* U+001E52 */
+	876, /* U+001E53 */
+	877, /* U+001E54 */
+	877, /* U+001E55 */
+	878, /* U+001E56 */
+	878, /* U+001E57 */
+	879, /* U+001E58 */
+	879, /* U+001E59 */
+	880, /* U+001E5A */
+	880, /* U+001E5B */
+	881, /* U+001E5C */
+	881, /* U+001E5D */
+	882, /* U+001E5E */
+	882, /* U+001E5F */
+	883, /* U+001E60 */
+	883, /* U+001E61 */
+	884, /* U+001E62 */
+	884, /* U+001E63 */
+	885, /* U+001E64 */
+	885, /* U+001E65 */
+	886, /* U+001E66 */
+	886, /* U+001E67 */
+	887, /* U+001E68 */
+	887, /* U+001E69 */
+	888, /* U+001E6A */
+	888, /* U+001E6B */
+	889, /* U+001E6C */
+	889, /* U+001E6D */
+	890, /* U+001E6E */
+	890, /* U+001E6F */
+	891, /* U+001E70 */
+	891, /* U+001E71 */
+	892, /* U+001E72 */
+	892, /* U+001E73 */
+	893, /* U+001E74 */
+	893, /* U+001E75 */
+	894, /* U+001E76 */
+	894, /* U+001E77 */
+	895, /* U+001E78 */
+	895, /* U+001E79 */
+	896, /* U+001E7A */
+	896, /* U+001E7B */
+	897, /* U+001E7C */
+	897, /* U+001E7D */
+	898, /* U+001E7E */
+	898, /* U+001E7F */
+	899, /* U+001E80 */
+	899, /* U+001E81 */
+	900, /* U+001E82 */
+	900, /* U+001E83 */
+	901, /* U+001E84 */
+	901, /* U+001E85 */
+	902, /* U+001E86 */
+	902, /* U+001E87 */
+	903, /* U+001E88 */
+	903, /* U+001E89 */
+	904, /* U+001E8A */
+	904, /* U+001E8B */
+	905, /* U+001E8C */
+	905, /* U+001E8D */
+	906, /* U+001E8E */
+	906, /* U+001E8F */
+	907, /* U+001E90 */
+	907, /* U+001E91 */
+	908, /* U+001E92 */
+	908, /* U+001E93 */
+	909, /* U+001E94 */
+	909, /* U+001E95 */
+	910, /* U+001E96 */
+	911, /* U+001E97 */
+	912, /* U+001E98 */
+	913, /* U+001E99 */
+	914, /* U+001E9A */
+	915, /* U+001E9B */
+	0, /* U+001E9C */
+	0, /* U+001E9D */
+	916, /* U+001E9E */
+	0, /* U+001E9F */
+	917, /* U+001EA0 */
+	917, /* U+001EA1 */
+	918, /* U+001EA2 */
+	918, /* U+001EA3 */
+	919, /* U+001EA4 */
+	919, /* U+001EA5 */
+	920, /* U+001EA6 */
+	920, /* U+001EA7 */
+	921, /* U+001EA8 */
+	921, /* U+001EA9 */
+	922, /* U+001EAA */
+	922, /* U+001EAB */
+	923, /* U+001EAC */
+	923, /* U+001EAD */
+	924, /* U+001EAE */
+	924, /* U+001EAF */
+	925, /* U+001EB0 */
+	925, /* U+001EB1 */
+	926, /* U+001EB2 */
+	926, /* U+001EB3 */
+	927, /* U+001EB4 */
+	927, /* U+001EB5 */
+	928, /* U+001EB6 */
+	928, /* U+001EB7 */
+	929, /* U+001EB8 */
+	929, /* U+001EB9 */
+	930, /* U+001EBA */
+	930, /* U+001EBB */
+	931, /* U+001EBC */
+	931, /* U+001EBD */
+	932, /* U+001EBE */
+	932, /* U+001EBF */
+	933, /* U+001EC0 */
+	933, /* U+001EC1 */
+	934, /* U+001EC2 */
+	934, /* U+001EC3 */
+	935, /* U+001EC4 */
+	935, /* U+001EC5 */
+	936, /* U+001EC6 */
+	936, /* U+001EC7 */
+	937, /* U+001EC8 */
+	937, /* U+001EC9 */
+	938, /* U+001ECA */
+	938, /* U+001ECB */
+	939, /* U+001ECC */
+	939, /* U+001ECD */
+	940, /* U+001ECE */
+	940, /* U+001ECF */
+	941, /* U+001ED0 */
+	941, /* U+001ED1 */
+	942, /* U+001ED2 */
+	942, /* U+001ED3 */
+	943, /* U+001ED4 */
+	943, /* U+001ED5 */
+	944, /* U+001ED6 */
+	944, /* U+001ED7 */
+	945, /* U+001ED8 */
+	945, /* U+001ED9 */
+	946, /* U+001EDA */
+	946, /* U+001EDB */
+	947, /* U+001EDC */
+	947, /* U+001EDD */
+	948, /* U+001EDE */
+	948, /* U+001EDF */
+	949, /* U+001EE0 */
+	949, /* U+001EE1 */
+	950, /* U+001EE2 */
+	950, /* U+001EE3 */
+	951, /* U+001EE4 */
+	951, /* U+001EE5 */
+	952, /* U+001EE6 */
+	952, /* U+001EE7 */
+	953, /* U+001EE8 */
+	953, /* U+001EE9 */
+	954, /* U+001EEA */
+	954, /* U+001EEB */
+	955, /* U+001EEC */
+	955, /* U+001EED */
+	956, /* U+001EEE */
+	956, /* U+001EEF */
+	957, /* U+001EF0 */
+	957, /* U+001EF1 */
+	958, /* U+001EF2 */
+	958, /* U+001EF3 */
+	959, /* U+001EF4 */
+	959, /* U+001EF5 */
+	960, /* U+001EF6 */
+	960, /* U+001EF7 */
+	961, /* U+001EF8 */
+	961, /* U+001EF9 */
+	962, /* U+001EFA */
+	962, /* U+001EFB */
+	963, /* U+001EFC */
+	963, /* U+001EFD */
+	964, /* U+001EFE */
+	964, /* U+001EFF */
+	965, /* U+001F00 */
+	966, /* U+001F01 */
+	967, /* U+001F02 */
+	968, /* U+001F03 */
+	969, /* U+001F04 */
+	970, /* U+001F05 */
+	971, /* U+001F06 */
+	972, /* U+001F07 */
+	965, /* U+001F08 */
+	966, /* U+001F09 */
+	967, /* U+001F0A */
+	968, /* U+001F0B */
+	969, /* U+001F0C */
+	970, /* U+001F0D */
+	971, /* U+001F0E */
+	972, /* U+001F0F */
+	973, /* U+001F10 */
+	974, /* U+001F11 */
+	975, /* U+001F12 */
+	976, /* U+001F13 */
+	977, /* U+001F14 */
+	978, /* U+001F15 */
+	0, /* U+001F16 */
+	0, /* U+001F17 */
+	973, /* U+001F18 */
+	974, /* U+001F19 */
+	975, /* U+001F1A */
+	976, /* U+001F1B */
+	977, /* U+001F1C */
+	978, /* U+001F1D */
+	0, /* U+001F1E */
+	0, /* U+001F1F */
+	979, /* U+001F20 */
+	980, /* U+001F21 */
+	981, /* U+001F22 */
+	982, /* U+001F23 */
+	983, /* U+001F24 */
+	984, /* U+001F25 */
+	985, /* U+001F26 */
+	986, /* U+001F27 */
+	979, /* U+001F28 */
+	980, /* U+001F29 */
+	981, /* U+001F2A */
+	982, /* U+001F2B */
+	983, /* U+001F2C */
+	984, /* U+001F2D */
+	985, /* U+001F2E */
+	986, /* U+001F2F */
+	987, /* U+001F30 */
+	988, /* U+001F31 */
+	989, /* U+001F32 */
+	990, /* U+001F33 */
+	991, /* U+001F34 */
+	992, /* U+001F35 */
+	993, /* U+001F36 */
+	994, /* U+001F37 */
+	987, /* U+001F38 */
+	988, /* U+001F39 */
+	989, /* U+001F3A */
+	990, /* U+001F3B */
+	991, /* U+001F3C */
+	992, /* U+001F3D */
+	993, /* U+001F3E */
+	994, /* U+001F3F */
+	995, /* U+001F40 */
+	996, /* U+001F41 */
+	997, /* U+001F42 */
+	998, /* U+001F43 */
+	999, /* U+001F44 */
+	1000, /* U+001F45 */
+	0, /* U+001F46 */
+	0, /* U+001F47 */
+	995, /* U+001F48 */
+	996, /* U+001F49 */
+	997, /* U+001F4A */
+	998, /* U+001F4B */
+	999, /* U+001F4C */
+	1000, /* U+001F4D */
+	0, /* U+001F4E */
+	0, /* U+001F4F */
+	1001, /* U+001F50 */
+	1002, /* U+001F51 */
+	1003, /* U+001F52 */
+	1004, /* U+001F53 */
+	1005, /* U+001F54 */
+	1006, /* U+001F55 */
+	1007, /* U+001F56 */
+	1008, /* U+001F57 */
+	0, /* U+001F58 */
+	1002, /* U+001F59 */
+	0, /* U+001F5A */
+	1004, /* U+001F5B */
+	0, /* U+001F5C */
+	1006, /* U+001F5D */
+	0, /* U+001F5E */
+	1008, /* U+001F5F */
+	1009, /* U+001F60 */
+	1010, /* U+001F61 */
+	1011, /* U+001F62 */
+	1012, /* U+001F63 */
+	1013, /* U+001F64 */
+	1014, /* U+001F65 */
+	1015, /* U+001F66 */
+	1016, /* U+001F67 */
+	1009, /* U+001F68 */
+	1010, /* U+001F69 */
+	1011, /* U+001F6A */
+	1012, /* U+001F6B */
+	1013, /* U+001F6C */
+	1014, /* U+001F6D */
+	1015, /* U+001F6E */
+	1016, /* U+001F6F */
+	1017, /* U+001F70 */
+	1018, /* U+001F71 */
+	1019, /* U+001F72 */
+	1020, /* U+001F73 */
+	1021, /* U+001F74 */
+	1022, /* U+001F75 */
+	1023, /* U+001F76 */
+	1024, /* U+001F77 */
+	1025, /* U+001F78 */
+	1026, /* U+001F79 */
+	1027, /* U+001F7A */
+	1028, /* U+001F7B */
+	1029, /* U+001F7C */
+	1030, /* U+001F7D */
+	0, /* U+001F7E */
+	0, /* U+001F7F */
+	1031, /* U+001F80 */
+	1032, /* U+001F81 */
+	1033, /* U+001F82 */
+	1034, /* U+001F83 */
+	1035, /* U+001F84 */
+	1036, /* U+001F85 */
+	1037, /* U+001F86 */
+	1038, /* U+001F87 */
+	1039, /* U+001F88 */
+	1040, /* U+001F89 */
+	1041, /* U+001F8A */
+	1042, /* U+001F8B */
+	1043, /* U+001F8C */
+	1044, /* U+001F8D */
+	1045, /* U+001F8E */
+	1046, /* U+001F8F */
+	1047, /* U+001F90 */
+	1048, /* U+001F91 */
+	1049, /* U+001F92 */
+	1050, /* U+001F93 */
+	1051, /* U+001F94 */
+	1052, /* U+001F95 */
+	1053, /* U+001F96 */
+	1054, /* U+001F97 */
+	1055, /* U+001F98 */
+	1056, /* U+001F99 */
+	1057, /* U+001F9A */
+	1058, /* U+001F9B */
+	1059, /* U+001F9C */
+	1060, /* U+001F9D */
+	1061, /* U+001F9E */
+	1062, /* U+001F9F */
+	1063, /* U+001FA0 */
+	1064, /* U+001FA1 */
+	1065, /* U+001FA2 */
+	1066, /* U+001FA3 */
+	1067, /* U+001FA4 */
+	1068, /* U+001FA5 */
+	1069, /* U+001FA6 */
+	1070, /* U+001FA7 */
+	1071, /* U+001FA8 */
+	1072, /* U+001FA9 */
+	1073, /* U+001FAA */
+	1074, /* U+001FAB */
+	1075, /* U+001FAC */
+	1076, /* U+001FAD */
+	1077, /* U+001FAE */
+	1078, /* U+001FAF */
+	1079, /* U+001FB0 */
+	1080, /* U+001FB1 */
+	1081, /* U+001FB2 */
+	1082, /* U+001FB3 */
+	1083, /* U+001FB4 */
+	0, /* U+001FB5 */
+	1084, /* U+001FB6 */
+	1085, /* U+001FB7 */
+	1079, /* U+001FB8 */
+	1080, /* U+001FB9 */
+	1017, /* U+001FBA */
+	1018, /* U+001FBB */
+	1086, /* U+001FBC */
+	0, /* U+001FBD */
+	1087, /* U+001FBE */
+	0, /* U+001FBF */
+	0, /* U+001FC0 */
+	0, /* U+001FC1 */
+	1088, /* U+001FC2 */
+	1089, /* U+001FC3 */
+	1090, /* U+001FC4 */
+	0, /* U+001FC5 */
+	1091, /* U+001FC6 */
+	1092, /* U+001FC7 */
+	1019, /* U+001FC8 */
+	1020, /* U+001FC9 */
+	1021, /* U+001FCA */
+	1022, /* U+001FCB */
+	1093, /* U+001FCC */
+	0, /* U+001FCD */
+	0, /* U+001FCE */
+	0, /* U+001FCF */
+	1094, /* U+001FD0 */
+	1095, /* U+001FD1 */
+	1096, /* U+001FD2 */
+	1097, /* U+001FD3 */
+	0, /* U+001FD4 */
+	0, /* U+001FD5 */
+	1098, /* U+001FD6 */
+	1099, /* U+001FD7 */
+	1094, /* U+001FD8 */
+	1095, /* U+001FD9 */
+	1023, /* U+001FDA */
+	1024, /* U+001FDB */
+	0, /* U+001FDC */
+	0, /* U+001FDD */
+	0, /* U+001FDE */
+	0, /* U+001FDF */
+	1100, /* U+001FE0 */
+	1101, /* U+001FE1 */
+	1102, /* U+001FE2 */
+	1103, /* U+001FE3 */
+	1104, /* U+001FE4 */
+	1105, /* U+001FE5 */
+	1106, /* U+001FE6 */
+	1107, /* U+001FE7 */
+	1100, /* U+001FE8 */
+	1101, /* U+001FE9 */
+	1027, /* U+001FEA */
+	1028, /* U+001FEB */
+	1105, /* U+001FEC */
+	0, /* U+001FED */
+	0, /* U+001FEE */
+	0, /* U+001FEF */
+	0, /* U+001FF0 */
+	0, /* U+001FF1 */
+	1108, /* U+001FF2 */
+	1109, /* U+001FF3 */
+	1110, /* U+001FF4 */
+	0, /* U+001FF5 */
+	1111, /* U+001FF6 */
+	1112, /* U+001FF7 */
+	1025, /* U+001FF8 */
+	1026, /* U+001FF9 */
+	1029, /* U+001FFA */
+	1030, /* U+001FFB */
+	1113, /* U+001FFC */
+	0, /* U+001FFD */
+	0, /* U+001FFE */
+	0, /* U+001FFF */
+	0, /* U+002000 */
+	0, /* U+002001 */
+	0, /* U+002002 */
+	0, /* U+002003 */
+	0, /* U+002004 */
+	0, /* U+002005 */
+	0, /* U+002006 */
+	0, /* U+002007 */
+	0, /* U+002008 */
+	0, /* U+002009 */
+	0, /* U+00200A */
+	0, /* U+00200B */
+	0, /* U+00200C */
+	0, /* U+00200D */
+	0, /* U+00200E */
+	0, /* U+00200F */
+	0, /* U+002010 */
+	0, /* U+002011 */
+	0, /* U+002012 */
+	0, /* U+002013 */
+	0, /* U+002014 */
+	0, /* U+002015 */
+	0, /* U+002016 */
+	0, /* U+002017 */
+	0, /* U+002018 */
+	0, /* U+002019 */
+	0, /* U+00201A */
+	0, /* U+00201B */
+	0, /* U+00201C */
+	0, /* U+00201D */
+	0, /* U+00201E */
+	0, /* U+00201F */
+	0, /* U+002020 */
+	0, /* U+002021 */
+	0, /* U+002022 */
+	0, /* U+002023 */
+	0, /* U+002024 */
+	0, /* U+002025 */
+	0, /* U+002026 */
+	0, /* U+002027 */
+	0, /* U+002028 */
+	0, /* U+002029 */
+	0, /* U+00202A */
+	0, /* U+00202B */
+	0, /* U+00202C */
+	0, /* U+00202D */
+	0, /* U+00202E */
+	0, /* U+00202F */
+	0, /* U+002030 */
+	0, /* U+002031 */
+	0, /* U+002032 */
+	0, /* U+002033 */
+	0, /* U+002034 */
+	0, /* U+002035 */
+	0, /* U+002036 */
+	0, /* U+002037 */
+	0, /* U+002038 */
+	0, /* U+002039 */
+	0, /* U+00203A */
+	0, /* U+00203B */
+	0, /* U+00203C */
+	0, /* U+00203D */
+	0, /* U+00203E */
+	0, /* U+00203F */
+	0, /* U+002040 */
+	0, /* U+002041 */
+	0, /* U+002042 */
+	0, /* U+002043 */
+	0, /* U+002044 */
+	0, /* U+002045 */
+	0, /* U+002046 */
+	0, /* U+002047 */
+	0, /* U+002048 */
+	0, /* U+002049 */
+	0, /* U+00204A */
+	0, /* U+00204B */
+	0, /* U+00204C */
+	0, /* U+00204D */
+	0, /* U+00204E */
+	0, /* U+00204F */
+	0, /* U+002050 */
+	0, /* U+002051 */
+	0, /* U+002052 */
+	0, /* U+002053 */
+	0, /* U+002054 */
+	0, /* U+002055 */
+	0, /* U+002056 */
+	0, /* U+002057 */
+	0, /* U+002058 */
+	0, /* U+002059 */
+	0, /* U+00205A */
+	0, /* U+00205B */
+	0, /* U+00205C */
+	0, /* U+00205D */
+	0, /* U+00205E */
+	0, /* U+00205F */
+	0, /* U+002060 */
+	0, /* U+002061 */
+	0, /* U+002062 */
+	0, /* U+002063 */
+	0, /* U+002064 */
+	0, /* U+002065 */
+	0, /* U+002066 */
+	0, /* U+002067 */
+	0, /* U+002068 */
+	0, /* U+002069 */
+	0, /* U+00206A */
+	0, /* U+00206B */
+	0, /* U+00206C */
+	0, /* U+00206D */
+	0, /* U+00206E */
+	0, /* U+00206F */
+	0, /* U+002070 */
+	0, /* U+002071 */
+	0, /* U+002072 */
+	0, /* U+002073 */
+	0, /* U+002074 */
+	0, /* U+002075 */
+	0, /* U+002076 */
+	0, /* U+002077 */
+	0, /* U+002078 */
+	0, /* U+002079 */
+	0, /* U+00207A */
+	0, /* U+00207B */
+	0, /* U+00207C */
+	0, /* U+00207D */
+	0, /* U+00207E */
+	0, /* U+00207F */
+	0, /* U+002080 */
+	0, /* U+002081 */
+	0, /* U+002082 */
+	0, /* U+002083 */
+	0, /* U+002084 */
+	0, /* U+002085 */
+	0, /* U+002086 */
+	0, /* U+002087 */
+	0, /* U+002088 */
+	0, /* U+002089 */
+	0, /* U+00208A */
+	0, /* U+00208B */
+	0, /* U+00208C */
+	0, /* U+00208D */
+	0, /* U+00208E */
+	0, /* U+00208F */
+	0, /* U+002090 */
+	0, /* U+002091 */
+	0, /* U+002092 */
+	0, /* U+002093 */
+	0, /* U+002094 */
+	0, /* U+002095 */
+	0, /* U+002096 */
+	0, /* U+002097 */
+	0, /* U+002098 */
+	0, /* U+002099 */
+	0, /* U+00209A */
+	0, /* U+00209B */
+	0, /* U+00209C */
+	0, /* U+00209D */
+	0, /* U+00209E */
+	0, /* U+00209F */
+	0, /* U+0020A0 */
+	0, /* U+0020A1 */
+	0, /* U+0020A2 */
+	0, /* U+0020A3 */
+	0, /* U+0020A4 */
+	0, /* U+0020A5 */
+	0, /* U+0020A6 */
+	0, /* U+0020A7 */
+	0, /* U+0020A8 */
+	0, /* U+0020A9 */
+	0, /* U+0020AA */
+	0, /* U+0020AB */
+	0, /* U+0020AC */
+	0, /* U+0020AD */
+	0, /* U+0020AE */
+	0, /* U+0020AF */
+	0, /* U+0020B0 */
+	0, /* U+0020B1 */
+	0, /* U+0020B2 */
+	0, /* U+0020B3 */
+	0, /* U+0020B4 */
+	0, /* U+0020B5 */
+	0, /* U+0020B6 */
+	0, /* U+0020B7 */
+	0, /* U+0020B8 */
+	0, /* U+0020B9 */
+	0, /* U+0020BA */
+	0, /* U+0020BB */
+	0, /* U+0020BC */
+	0, /* U+0020BD */
+	0, /* U+0020BE */
+	0, /* U+0020BF */
+	0, /* U+0020C0 */
+	0, /* U+0020C1 */
+	0, /* U+0020C2 */
+	0, /* U+0020C3 */
+	0, /* U+0020C4 */
+	0, /* U+0020C5 */
+	0, /* U+0020C6 */
+	0, /* U+0020C7 */
+	0, /* U+0020C8 */
+	0, /* U+0020C9 */
+	0, /* U+0020CA */
+	0, /* U+0020CB */
+	0, /* U+0020CC */
+	0, /* U+0020CD */
+	0, /* U+0020CE */
+	0, /* U+0020CF */
+	0, /* U+0020D0 */
+	0, /* U+0020D1 */
+	0, /* U+0020D2 */
+	0, /* U+0020D3 */
+	0, /* U+0020D4 */
+	0, /* U+0020D5 */
+	0, /* U+0020D6 */
+	0, /* U+0020D7 */
+	0, /* U+0020D8 */
+	0, /* U+0020D9 */
+	0, /* U+0020DA */
+	0, /* U+0020DB */
+	0, /* U+0020DC */
+	0, /* U+0020DD */
+	0, /* U+0020DE */
+	0, /* U+0020DF */
+	0, /* U+0020E0 */
+	0, /* U+0020E1 */
+	0, /* U+0020E2 */
+	0, /* U+0020E3 */
+	0, /* U+0020E4 */
+	0, /* U+0020E5 */
+	0, /* U+0020E6 */
+	0, /* U+0020E7 */
+	0, /* U+0020E8 */
+	0, /* U+0020E9 */
+	0, /* U+0020EA */
+	0, /* U+0020EB */
+	0, /* U+0020EC */
+	0, /* U+0020ED */
+	0, /* U+0020EE */
+	0, /* U+0020EF */
+	0, /* U+0020F0 */
+	0, /* U+0020F1 */
+	0, /* U+0020F2 */
+	0, /* U+0020F3 */
+	0, /* U+0020F4 */
+	0, /* U+0020F5 */
+	0, /* U+0020F6 */
+	0, /* U+0020F7 */
+	0, /* U+0020F8 */
+	0, /* U+0020F9 */
+	0, /* U+0020FA */
+	0, /* U+0020FB */
+	0, /* U+0020FC */
+	0, /* U+0020FD */
+	0, /* U+0020FE */
+	0, /* U+0020FF */
+	0, /* U+002100 */
+	0, /* U+002101 */
+	0, /* U+002102 */
+	0, /* U+002103 */
+	0, /* U+002104 */
+	0, /* U+002105 */
+	0, /* U+002106 */
+	0, /* U+002107 */
+	0, /* U+002108 */
+	0, /* U+002109 */
+	0, /* U+00210A */
+	0, /* U+00210B */
+	0, /* U+00210C */
+	0, /* U+00210D */
+	0, /* U+00210E */
+	0, /* U+00210F */
+	0, /* U+002110 */
+	0, /* U+002111 */
+	0, /* U+002112 */
+	0, /* U+002113 */
+	0, /* U+002114 */
+	0, /* U+002115 */
+	0, /* U+002116 */
+	0, /* U+002117 */
+	0, /* U+002118 */
+	0, /* U+002119 */
+	0, /* U+00211A */
+	0, /* U+00211B */
+	0, /* U+00211C */
+	0, /* U+00211D */
+	0, /* U+00211E */
+	0, /* U+00211F */
+	0, /* U+002120 */
+	0, /* U+002121 */
+	0, /* U+002122 */
+	0, /* U+002123 */
+	0, /* U+002124 */
+	0, /* U+002125 */
+	1114, /* U+002126 */
+	0, /* U+002127 */
+	0, /* U+002128 */
+	0, /* U+002129 */
+	1115, /* U+00212A */
+	1116, /* U+00212B */
+	0, /* U+00212C */
+	0, /* U+00212D */
+	0, /* U+00212E */
+	0, /* U+00212F */
+	0, /* U+002130 */
+	0, /* U+002131 */
+	1117, /* U+002132 */
+	0, /* U+002133 */
+	0, /* U+002134 */
+	0, /* U+002135 */
+	0, /* U+002136 */
+	0, /* U+002137 */
+	0, /* U+002138 */
+	0, /* U+002139 */
+	0, /* U+00213A */
+	0, /* U+00213B */
+	0, /* U+00213C */
+	0, /* U+00213D */
+	0, /* U+00213E */
+	0, /* U+00213F */
+	0, /* U+002140 */
+	0, /* U+002141 */
+	0, /* U+002142 */
+	0, /* U+002143 */
+	0, /* U+002144 */
+	0, /* U+002145 */
+	0, /* U+002146 */
+	0, /* U+002147 */
+	0, /* U+002148 */
+	0, /* U+002149 */
+	0, /* U+00214A */
+	0, /* U+00214B */
+	0, /* U+00214C */
+	0, /* U+00214D */
+	1117, /* U+00214E */
+	0, /* U+00214F */
+	0, /* U+002150 */
+	0, /* U+002151 */
+	0, /* U+002152 */
+	0, /* U+002153 */
+	0, /* U+002154 */
+	0, /* U+002155 */
+	0, /* U+002156 */
+	0, /* U+002157 */
+	0, /* U+002158 */
+	0, /* U+002159 */
+	0, /* U+00215A */
+	0, /* U+00215B */
+	0, /* U+00215C */
+	0, /* U+00215D */
+	0, /* U+00215E */
+	0, /* U+00215F */
+	1118, /* U+002160 */
+	1119, /* U+002161 */
+	1120, /* U+002162 */
+	1121, /* U+002163 */
+	1122, /* U+002164 */
+	1123, /* U+002165 */
+	1124, /* U+002166 */
+	1125, /* U+002167 */
+	1126, /* U+002168 */
+	1127, /* U+002169 */
+	1128, /* U+00216A */
+	1129, /* U+00216B */
+	1130, /* U+00216C */
+	1131, /* U+00216D */
+	1132, /* U+00216E */
+	1133, /* U+00216F */
+	1118, /* U+002170 */
+	1119, /* U+002171 */
+	1120, /* U+002172 */
+	1121, /* U+002173 */
+	1122, /* U+002174 */
+	1123, /* U+002175 */
+	1124, /* U+002176 */
+	1125, /* U+002177 */
+	1126, /* U+002178 */
+	1127, /* U+002179 */
+	1128, /* U+00217A */
+	1129, /* U+00217B */
+	1130, /* U+00217C */
+	1131, /* U+00217D */
+	1132, /* U+00217E */
+	1133, /* U+00217F */
+	0, /* U+002180 */
+	0, /* U+002181 */
+	0, /* U+002182 */
+	1134, /* U+002183 */
+	1134, /* U+002184 */
+	1135, /* U+0024B6 */
+	1136, /* U+0024B7 */
+	1137, /* U+0024B8 */
+	1138, /* U+0024B9 */
+	1139, /* U+0024BA */
+	1140, /* U+0024BB */
+	1141, /* U+0024BC */
+	1142, /* U+0024BD */
+	1143, /* U+0024BE */
+	1144, /* U+0024BF */
+	1145, /* U+0024C0 */
+	1146, /* U+0024C1 */
+	1147, /* U+0024C2 */
+	1148, /* U+0024C3 */
+	1149, /* U+0024C4 */
+	1150, /* U+0024C5 */
+	1151, /* U+0024C6 */
+	1152, /* U+0024C7 */
+	1153, /* U+0024C8 */
+	1154, /* U+0024C9 */
+	1155, /* U+0024CA */
+	1156, /* U+0024CB */
+	1157, /* U+0024CC */
+	1158, /* U+0024CD */
+	1159, /* U+0024CE */
+	1160, /* U+0024CF */
+	1135, /* U+0024D0 */
+	1136, /* U+0024D1 */
+	1137, /* U+0024D2 */
+	1138, /* U+0024D3 */
+	1139, /* U+0024D4 */
+	1140, /* U+0024D5 */
+	1141, /* U+0024D6 */
+	1142, /* U+0024D7 */
+	1143, /* U+0024D8 */
+	1144, /* U+0024D9 */
+	1145, /* U+0024DA */
+	1146, /* U+0024DB */
+	1147, /* U+0024DC */
+	1148, /* U+0024DD */
+	1149, /* U+0024DE */
+	1150, /* U+0024DF */
+	1151, /* U+0024E0 */
+	1152, /* U+0024E1 */
+	1153, /* U+0024E2 */
+	1154, /* U+0024E3 */
+	1155, /* U+0024E4 */
+	1156, /* U+0024E5 */
+	1157, /* U+0024E6 */
+	1158, /* U+0024E7 */
+	1159, /* U+0024E8 */
+	1160, /* U+0024E9 */
+	1161, /* U+002C00 */
+	1162, /* U+002C01 */
+	1163, /* U+002C02 */
+	1164, /* U+002C03 */
+	1165, /* U+002C04 */
+	1166, /* U+002C05 */
+	1167, /* U+002C06 */
+	1168, /* U+002C07 */
+	1169, /* U+002C08 */
+	1170, /* U+002C09 */
+	1171, /* U+002C0A */
+	1172, /* U+002C0B */
+	1173, /* U+002C0C */
+	1174, /* U+002C0D */
+	1175, /* U+002C0E */
+	1176, /* U+002C0F */
+	1177, /* U+002C10 */
+	1178, /* U+002C11 */
+	1179, /* U+002C12 */
+	1180, /* U+002C13 */
+	1181, /* U+002C14 */
+	1182, /* U+002C15 */
+	1183, /* U+002C16 */
+	1184, /* U+002C17 */
+	1185, /* U+002C18 */
+	1186, /* U+002C19 */
+	1187, /* U+002C1A */
+	1188, /* U+002C1B */
+	1189, /* U+002C1C */
+	1190, /* U+002C1D */
+	1191, /* U+002C1E */
+	1192, /* U+002C1F */
+	1193, /* U+002C20 */
+	1194, /* U+002C21 */
+	1195, /* U+002C22 */
+	1196, /* U+002C23 */
+	1197, /* U+002C24 */
+	1198, /* U+002C25 */
+	1199, /* U+002C26 */
+	1200, /* U+002C27 */
+	1201, /* U+002C28 */
+	1202, /* U+002C29 */
+	1203, /* U+002C2A */
+	1204, /* U+002C2B */
+	1205, /* U+002C2C */
+	1206, /* U+002C2D */
+	1207, /* U+002C2E */
+	1208, /* U+002C2F */
+	1161, /* U+002C30 */
+	1162, /* U+002C31 */
+	1163, /* U+002C32 */
+	1164, /* U+002C33 */
+	1165, /* U+002C34 */
+	1166, /* U+002C35 */
+	1167, /* U+002C36 */
+	1168, /* U+002C37 */
+	1169, /* U+002C38 */
+	1170, /* U+002C39 */
+	1171, /* U+002C3A */
+	1172, /* U+002C3B */
+	1173, /* U+002C3C */
+	1174, /* U+002C3D */
+	1175, /* U+002C3E */
+	1176, /* U+002C3F */
+	1177, /* U+002C40 */
+	1178, /* U+002C41 */
+	1179, /* U+002C42 */
+	1180, /* U+002C43 */
+	1181, /* U+002C44 */
+	1182, /* U+002C45 */
+	1183, /* U+002C46 */
+	1184, /* U+002C47 */
+	1185, /* U+002C48 */
+	1186, /* U+002C49 */
+	1187, /* U+002C4A */
+	1188, /* U+002C4B */
+	1189, /* U+002C4C */
+	1190, /* U+002C4D */
+	1191, /* U+002C4E */
+	1192, /* U+002C4F */
+	1193, /* U+002C50 */
+	1194, /* U+002C51 */
+	1195, /* U+002C52 */
+	1196, /* U+002C53 */
+	1197, /* U+002C54 */
+	1198, /* U+002C55 */
+	1199, /* U+002C56 */
+	1200, /* U+002C57 */
+	1201, /* U+002C58 */
+	1202, /* U+002C59 */
+	1203, /* U+002C5A */
+	1204, /* U+002C5B */
+	1205, /* U+002C5C */
+	1206, /* U+002C5D */
+	1207, /* U+002C5E */
+	1208, /* U+002C5F */
+	1209, /* U+002C60 */
+	1209, /* U+002C61 */
+	341, /* U+002C62 */
+	833, /* U+002C63 */
+	344, /* U+002C64 */
+	320, /* U+002C65 */
+	322, /* U+002C66 */
+	1210, /* U+002C67 */
+	1210, /* U+002C68 */
+	1211, /* U+002C69 */
+	1211, /* U+002C6A */
+	1212, /* U+002C6B */
+	1212, /* U+002C6C */
+	334, /* U+002C6D */
+	343, /* U+002C6E */
+	333, /* U+002C6F */
+	335, /* U+002C70 */
+	0, /* U+002C71 */
+	1213, /* U+002C72 */
+	1213, /* U+002C73 */
+	0, /* U+002C74 */
+	1214, /* U+002C75 */
+	1214, /* U+002C76 */
+	0, /* U+002C77 */
+	0, /* U+002C78 */
+	0, /* U+002C79 */
+	0, /* U+002C7A */
+	0, /* U+002C7B */
+	0, /* U+002C7C */
+	0, /* U+002C7D */
+	323, /* U+002C7E */
+	324, /* U+002C7F */
+	1215, /* U+002C80 */
+	1215, /* U+002C81 */
+	1216, /* U+002C82 */
+	1216, /* U+002C83 */
+	1217, /* U+002C84 */
+	1217, /* U+002C85 */
+	1218, /* U+002C86 */
+	1218, /* U+002C87 */
+	1219, /* U+002C88 */
+	1219, /* U+002C89 */
+	1220, /* U+002C8A */
+	1220, /* U+002C8B */
+	1221, /* U+002C8C */
+	1221, /* U+002C8D */
+	1222, /* U+002C8E */
+	1222, /* U+002C8F */
+	1223, /* U+002C90 */
+	1223, /* U+002C91 */
+	1224, /* U+002C92 */
+	1224, /* U+002C93 */
+	1225, /* U+002C94 */
+	1225, /* U+002C95 */
+	1226, /* U+002C96 */
+	1226, /* U+002C97 */
+	1227, /* U+002C98 */
+	1227, /* U+002C99 */
+	1228, /* U+002C9A */
+	1228, /* U+002C9B */
+	1229, /* U+002C9C */
+	1229, /* U+002C9D */
+	1230, /* U+002C9E */
+	1230, /* U+002C9F */
+	1231, /* U+002CA0 */
+	1231, /* U+002CA1 */
+	1232, /* U+002CA2 */
+	1232, /* U+002CA3 */
+	1233, /* U+002CA4 */
+	1233, /* U+002CA5 */
+	1234, /* U+002CA6 */
+	1234, /* U+002CA7 */
+	1235, /* U+002CA8 */
+	1235, /* U+002CA9 */
+	1236, /* U+002CAA */
+	1236, /* U+002CAB */
+	1237, /* U+002CAC */
+	1237, /* U+002CAD */
+	1238, /* U+002CAE */
+	1238, /* U+002CAF */
+	1239, /* U+002CB0 */
+	1239, /* U+002CB1 */
+	1240, /* U+002CB2 */
+	1240, /* U+002CB3 */
+	1241, /* U+002CB4 */
+	1241, /* U+002CB5 */
+	1242, /* U+002CB6 */
+	1242, /* U+002CB7 */
+	1243, /* U+002CB8 */
+	1243, /* U+002CB9 */
+	1244, /* U+002CBA */
+	1244, /* U+002CBB */
+	1245, /* U+002CBC */
+	1245, /* U+002CBD */
+	1246, /* U+002CBE */
+	1246, /* U+002CBF */
+	1247, /* U+002CC0 */
+	1247, /* U+002CC1 */
+	1248, /* U+002CC2 */
+	1248, /* U+002CC3 */
+	1249, /* U+002CC4 */
+	1249, /* U+002CC5 */
+	1250, /* U+002CC6 */
+	1250, /* U+002CC7 */
+	1251, /* U+002CC8 */
+	1251, /* U+002CC9 */
+	1252, /* U+002CCA */
+	1252, /* U+002CCB */
+	1253, /* U+002CCC */
+	1253, /* U+002CCD */
+	1254, /* U+002CCE */
+	1254, /* U+002CCF */
+	1255, /* U+002CD0 */
+	1255, /* U+002CD1 */
+	1256, /* U+002CD2 */
+	1256, /* U+002CD3 */
+	1257, /* U+002CD4 */
+	1257, /* U+002CD5 */
+	1258, /* U+002CD6 */
+	1258, /* U+002CD7 */
+	1259, /* U+002CD8 */
+	1259, /* U+002CD9 */
+	1260, /* U+002CDA */
+	1260, /* U+002CDB */
+	1261, /* U+002CDC */
+	1261, /* U+002CDD */
+	1262, /* U+002CDE */
+	1262, /* U+002CDF */
+	1263, /* U+002CE0 */
+	1263, /* U+002CE1 */
+	1264, /* U+002CE2 */
+	1264, /* U+002CE3 */
+	0, /* U+002CE4 */
+	0, /* U+002CE5 */
+	0, /* U+002CE6 */
+	0, /* U+002CE7 */
+	0, /* U+002CE8 */
+	0, /* U+002CE9 */
+	0, /* U+002CEA */
+	1265, /* U+002CEB */
+	1265, /* U+002CEC */
+	1266, /* U+002CED */
+	1266, /* U+002CEE */
+	0, /* U+002CEF */
+	0, /* U+002CF0 */
+	0, /* U+002CF1 */
+	1267, /* U+002CF2 */
+	1267, /* U+002CF3 */
+	0, /* U+002CF4 */
+	0, /* U+002CF5 */
+	0, /* U+002CF6 */
+	0, /* U+002CF7 */
+	0, /* U+002CF8 */
+	0, /* U+002CF9 */
+	0, /* U+002CFA */
+	0, /* U+002CFB */
+	0, /* U+002CFC */
+	0, /* U+002CFD */
+	0, /* U+002CFE */
+	0, /* U+002CFF */
+	605, /* U+002D00 */
+	606, /* U+002D01 */
+	607, /* U+002D02 */
+	608, /* U+002D03 */
+	609, /* U+002D04 */
+	610, /* U+002D05 */
+	611, /* U+002D06 */
+	612, /* U+002D07 */
+	613, /* U+002D08 */
+	614, /* U+002D09 */
+	615, /* U+002D0A */
+	616, /* U+002D0B */
+	617, /* U+002D0C */
+	618, /* U+002D0D */
+	619, /* U+002D0E */
+	620, /* U+002D0F */
+	621, /* U+002D10 */
+	622, /* U+002D11 */
+	623, /* U+002D12 */
+	624, /* U+002D13 */
+	625, /* U+002D14 */
+	626, /* U+002D15 */
+	627, /* U+002D16 */
+	628, /* U+002D17 */
+	629, /* U+002D18 */
+	630, /* U+002D19 */
+	631, /* U+002D1A */
+	632, /* U+002D1B */
+	633, /* U+002D1C */
+	634, /* U+002D1D */
+	635, /* U+002D1E */
+	636, /* U+002D1F */
+	637, /* U+002D20 */
+	638, /* U+002D21 */
+	639, /* U+002D22 */
+	640, /* U+002D23 */
+	641, /* U+002D24 */
+	642, /* U+002D25 */
+	0, /* U+002D26 */
+	643, /* U+002D27 */
+	0, /* U+002D28 */
+	0, /* U+002D29 */
+	0, /* U+002D2A */
+	0, /* U+002D2B */
+	0, /* U+002D2C */
+	644, /* U+002D2D */
+	1268, /* U+00A640 */
+	1268, /* U+00A641 */
+	1269, /* U+00A642 */
+	1269, /* U+00A643 */
+	1270, /* U+00A644 */
+	1270, /* U+00A645 */
+	1271, /* U+00A646 */
+	1271, /* U+00A647 */
+	1272, /* U+00A648 */
+	1272, /* U+00A649 */
+	1273, /* U+00A64A */
+	1273, /* U+00A64B */
+	1274, /* U+00A64C */
+	1274, /* U+00A64D */
+	1275, /* U+00A64E */
+	1275, /* U+00A64F */
+	1276, /* U+00A650 */
+	1276, /* U+00A651 */
+	1277, /* U+00A652 */
+	1277, /* U+00A653 */
+	1278, /* U+00A654 */
+	1278, /* U+00A655 */
+	1279, /* U+00A656 */
+	1279, /* U+00A657 */
+	1280, /* U+00A658 */
+	1280, /* U+00A659 */
+	1281, /* U+00A65A */
+	1281, /* U+00A65B */
+	1282, /* U+00A65C */
+	1282, /* U+00A65D */
+	1283, /* U+00A65E */
+	1283, /* U+00A65F */
+	1284, /* U+00A660 */
+	1284, /* U+00A661 */
+	1285, /* U+00A662 */
+	1285, /* U+00A663 */
+	1286, /* U+00A664 */
+	1286, /* U+00A665 */
+	1287, /* U+00A666 */
+	1287, /* U+00A667 */
+	1288, /* U+00A668 */
+	1288, /* U+00A669 */
+	1289, /* U+00A66A */
+	1289, /* U+00A66B */
+	1290, /* U+00A66C */
+	1290, /* U+00A66D */
+	0, /* U+00A66E */
+	0, /* U+00A66F */
+	0, /* U+00A670 */
+	0, /* U+00A671 */
+	0, /* U+00A672 */
+	0, /* U+00A673 */
+	0, /* U+00A674 */
+	0, /* U+00A675 */
+	0, /* U+00A676 */
+	0, /* U+00A677 */
+	0, /* U+00A678 */
+	0, /* U+00A679 */
+	0, /* U+00A67A */
+	0, /* U+00A67B */
+	0, /* U+00A67C */
+	0, /* U+00A67D */
+	0, /* U+00A67E */
+	0, /* U+00A67F */
+	1291, /* U+00A680 */
+	1291, /* U+00A681 */
+	1292, /* U+00A682 */
+	1292, /* U+00A683 */
+	1293, /* U+00A684 */
+	1293, /* U+00A685 */
+	1294, /* U+00A686 */
+	1294, /* U+00A687 */
+	1295, /* U+00A688 */
+	1295, /* U+00A689 */
+	1296, /* U+00A68A */
+	1296, /* U+00A68B */
+	1297, /* U+00A68C */
+	1297, /* U+00A68D */
+	1298, /* U+00A68E */
+	1298, /* U+00A68F */
+	1299, /* U+00A690 */
+	1299, /* U+00A691 */
+	1300, /* U+00A692 */
+	1300, /* U+00A693 */
+	1301, /* U+00A694 */
+	1301, /* U+00A695 */
+	1302, /* U+00A696 */
+	1302, /* U+00A697 */
+	1303, /* U+00A698 */
+	1303, /* U+00A699 */
+	1304, /* U+00A69A */
+	1304, /* U+00A69B */
+	0, /* U+00A69C */
+	0, /* U+00A69D */
+	0, /* U+00A69E */
+	0, /* U+00A69F */
+	0, /* U+00A6A0 */
+	0, /* U+00A6A1 */
+	0, /* U+00A6A2 */
+	0, /* U+00A6A3 */
+	0, /* U+00A6A4 */
+	0, /* U+00A6A5 */
+	0, /* U+00A6A6 */
+	0, /* U+00A6A7 */
+	0, /* U+00A6A8 */
+	0, /* U+00A6A9 */
+	0, /* U+00A6AA */
+	0, /* U+00A6AB */
+	0, /* U+00A6AC */
+	0, /* U+00A6AD */
+	0, /* U+00A6AE */
+	0, /* U+00A6AF */
+	0, /* U+00A6B0 */
+	0, /* U+00A6B1 */
+	0, /* U+00A6B2 */
+	0, /* U+00A6B3 */
+	0, /* U+00A6B4 */
+	0, /* U+00A6B5 */
+	0, /* U+00A6B6 */
+	0, /* U+00A6B7 */
+	0, /* U+00A6B8 */
+	0, /* U+00A6B9 */
+	0, /* U+00A6BA */
+	0, /* U+00A6BB */
+	0, /* U+00A6BC */
+	0, /* U+00A6BD */
+	0, /* U+00A6BE */
+	0, /* U+00A6BF */
+	0, /* U+00A6C0 */
+	0, /* U+00A6C1 */
+	0, /* U+00A6C2 */
+	0, /* U+00A6C3 */
+	0, /* U+00A6C4 */
+	0, /* U+00A6C5 */
+	0, /* U+00A6C6 */
+	0, /* U+00A6C7 */
+	0, /* U+00A6C8 */
+	0, /* U+00A6C9 */
+	0, /* U+00A6CA */
+	0, /* U+00A6CB */
+	0, /* U+00A6CC */
+	0, /* U+00A6CD */
+	0, /* U+00A6CE */
+	0, /* U+00A6CF */
+	0, /* U+00A6D0 */
+	0, /* U+00A6D1 */
+	0, /* U+00A6D2 */
+	0, /* U+00A6D3 */
+	0, /* U+00A6D4 */
+	0, /* U+00A6D5 */
+	0, /* U+00A6D6 */
+	0, /* U+00A6D7 */
+	0, /* U+00A6D8 */
+	0, /* U+00A6D9 */
+	0, /* U+00A6DA */
+	0, /* U+00A6DB */
+	0, /* U+00A6DC */
+	0, /* U+00A6DD */
+	0, /* U+00A6DE */
+	0, /* U+00A6DF */
+	0, /* U+00A6E0 */
+	0, /* U+00A6E1 */
+	0, /* U+00A6E2 */
+	0, /* U+00A6E3 */
+	0, /* U+00A6E4 */
+	0, /* U+00A6E5 */
+	0, /* U+00A6E6 */
+	0, /* U+00A6E7 */
+	0, /* U+00A6E8 */
+	0, /* U+00A6E9 */
+	0, /* U+00A6EA */
+	0, /* U+00A6EB */
+	0, /* U+00A6EC */
+	0, /* U+00A6ED */
+	0, /* U+00A6EE */
+	0, /* U+00A6EF */
+	0, /* U+00A6F0 */
+	0, /* U+00A6F1 */
+	0, /* U+00A6F2 */
+	0, /* U+00A6F3 */
+	0, /* U+00A6F4 */
+	0, /* U+00A6F5 */
+	0, /* U+00A6F6 */
+	0, /* U+00A6F7 */
+	0, /* U+00A6F8 */
+	0, /* U+00A6F9 */
+	0, /* U+00A6FA */
+	0, /* U+00A6FB */
+	0, /* U+00A6FC */
+	0, /* U+00A6FD */
+	0, /* U+00A6FE */
+	0, /* U+00A6FF */
+	0, /* U+00A700 */
+	0, /* U+00A701 */
+	0, /* U+00A702 */
+	0, /* U+00A703 */
+	0, /* U+00A704 */
+	0, /* U+00A705 */
+	0, /* U+00A706 */
+	0, /* U+00A707 */
+	0, /* U+00A708 */
+	0, /* U+00A709 */
+	0, /* U+00A70A */
+	0, /* U+00A70B */
+	0, /* U+00A70C */
+	0, /* U+00A70D */
+	0, /* U+00A70E */
+	0, /* U+00A70F */
+	0, /* U+00A710 */
+	0, /* U+00A711 */
+	0, /* U+00A712 */
+	0, /* U+00A713 */
+	0, /* U+00A714 */
+	0, /* U+00A715 */
+	0, /* U+00A716 */
+	0, /* U+00A717 */
+	0, /* U+00A718 */
+	0, /* U+00A719 */
+	0, /* U+00A71A */
+	0, /* U+00A71B */
+	0, /* U+00A71C */
+	0, /* U+00A71D */
+	0, /* U+00A71E */
+	0, /* U+00A71F */
+	0, /* U+00A720 */
+	0, /* U+00A721 */
+	1305, /* U+00A722 */
+	1305, /* U+00A723 */
+	1306, /* U+00A724 */
+	1306, /* U+00A725 */
+	1307, /* U+00A726 */
+	1307, /* U+00A727 */
+	1308, /* U+00A728 */
+	1308, /* U+00A729 */
+	1309, /* U+00A72A */
+	1309, /* U+00A72B */
+	1310, /* U+00A72C */
+	1310, /* U+00A72D */
+	1311, /* U+00A72E */
+	1311, /* U+00A72F */
+	0, /* U+00A730 */
+	0, /* U+00A731 */
+	1312, /* U+00A732 */
+	1312, /* U+00A733 */
+	1313, /* U+00A734 */
+	1313, /* U+00A735 */
+	1314, /* U+00A736 */
+	1314, /* U+00A737 */
+	1315, /* U+00A738 */
+	1315, /* U+00A739 */
+	1316, /* U+00A73A */
+	1316, /* U+00A73B */
+	1317, /* U+00A73C */
+	1317, /* U+00A73D */
+	1318, /* U+00A73E */
+	1318, /* U+00A73F */
+	1319, /* U+00A740 */
+	1319, /* U+00A741 */
+	1320, /* U+00A742 */
+	1320, /* U+00A743 */
+	1321, /* U+00A744 */
+	1321, /* U+00A745 */
+	1322, /* U+00A746 */
+	1322, /* U+00A747 */
+	1323, /* U+00A748 */
+	1323, /* U+00A749 */
+	1324, /* U+00A74A */
+	1324, /* U+00A74B */
+	1325, /* U+00A74C */
+	1325, /* U+00A74D */
+	1326, /* U+00A74E */
+	1326, /* U+00A74F */
+	1327, /* U+00A750 */
+	1327, /* U+00A751 */
+	1328, /* U+00A752 */
+	1328, /* U+00A753 */
+	1329, /* U+00A754 */
+	1329, /* U+00A755 */
+	1330, /* U+00A756 */
+	1330, /* U+00A757 */
+	1331, /* U+00A758 */
+	1331, /* U+00A759 */
+	1332, /* U+00A75A */
+	1332, /* U+00A75B */
+	1333, /* U+00A75C */
+	1333, /* U+00A75D */
+	1334, /* U+00A75E */
+	1334, /* U+00A75F */
+	1335, /* U+00A760 */
+	1335, /* U+00A761 */
+	1336, /* U+00A762 */
+	1336, /* U+00A763 */
+	1337, /* U+00A764 */
+	1337, /* U+00A765 */
+	1338, /* U+00A766 */
+	1338, /* U+00A767 */
+	1339, /* U+00A768 */
+	1339, /* U+00A769 */
+	1340, /* U+00A76A */
+	1340, /* U+00A76B */
+	1341, /* U+00A76C */
+	1341, /* U+00A76D */
+	1342, /* U+00A76E */
+	1342, /* U+00A76F */
+	0, /* U+00A770 */
+	0, /* U+00A771 */
+	0, /* U+00A772 */
+	0, /* U+00A773 */
+	0, /* U+00A774 */
+	0, /* U+00A775 */
+	0, /* U+00A776 */
+	0, /* U+00A777 */
+	0, /* U+00A778 */
+	1343, /* U+00A779 */
+	1343, /* U+00A77A */
+	1344, /* U+00A77B */
+	1344, /* U+00A77C */
+	832, /* U+00A77D */
+	1345, /* U+00A77E */
+	1345, /* U+00A77F */
+	1346, /* U+00A780 */
+	1346, /* U+00A781 */
+	1347, /* U+00A782 */
+	1347, /* U+00A783 */
+	1348, /* U+00A784 */
+	1348, /* U+00A785 */
+	1349, /* U+00A786 */
+	1349, /* U+00A787 */
+	0, /* U+00A788 */
+	0, /* U+00A789 */
+	0, /* U+00A78A */
+	1350, /* U+00A78B */
+	1350, /* U+00A78C */
+	338, /* U+00A78D */
+	0, /* U+00A78E */
+	0, /* U+00A78F */
+	1351, /* U+00A790 */
+	1351, /* U+00A791 */
+	1352, /* U+00A792 */
+	1352, /* U+00A793 */
+	1353, /* U+00A794 */
+	0, /* U+00A795 */
+	1354, /* U+00A796 */
+	1354, /* U+00A797 */
+	1355, /* U+00A798 */
+	1355, /* U+00A799 */
+	1356, /* U+00A79A */
+	1356, /* U+00A79B */
+	1357, /* U+00A79C */
+	1357, /* U+00A79D */
+	1358, /* U+00A79E */
+	1358, /* U+00A79F */
+	1359, /* U+00A7A0 */
+	1359, /* U+00A7A1 */
+	1360, /* U+00A7A2 */
+	1360, /* U+00A7A3 */
+	1361, /* U+00A7A4 */
+	1361, /* U+00A7A5 */
+	1362, /* U+00A7A6 */
+	1362, /* U+00A7A7 */
+	1363, /* U+00A7A8 */
+	1363, /* U+00A7A9 */
+	339, /* U+00A7AA */
+	336, /* U+00A7AB */
+	337, /* U+00A7AC */
+	342, /* U+00A7AD */
+	340, /* U+00A7AE */
+	0, /* U+00A7AF */
+	348, /* U+00A7B0 */
+	346, /* U+00A7B1 */
+	347, /* U+00A7B2 */
+	1364, /* U+00A7B3 */
+	1365, /* U+00A7B4 */
+	1365, /* U+00A7B5 */
+	1366, /* U+00A7B6 */
+	1366, /* U+00A7B7 */
+	1367, /* U+00A7B8 */
+	1367, /* U+00A7B9 */
+	1368, /* U+00A7BA */
+	1368, /* U+00A7BB */
+	1369, /* U+00A7BC */
+	1369, /* U+00A7BD */
+	1370, /* U+00A7BE */
+	1370, /* U+00A7BF */
+	1371, /* U+00A7C0 */
+	1371, /* U+00A7C1 */
+	1372, /* U+00A7C2 */
+	1372, /* U+00A7C3 */
+	1353, /* U+00A7C4 */
+	345, /* U+00A7C5 */
+	834, /* U+00A7C6 */
+	1373, /* U+00A7C7 */
+	1373, /* U+00A7C8 */
+	1374, /* U+00A7C9 */
+	1374, /* U+00A7CA */
+	0, /* U+00A7CB */
+	0, /* U+00A7CC */
+	0, /* U+00A7CD */
+	0, /* U+00A7CE */
+	0, /* U+00A7CF */
+	1375, /* U+00A7D0 */
+	1375, /* U+00A7D1 */
+	0, /* U+00A7D2 */
+	0, /* U+00A7D3 */
+	0, /* U+00A7D4 */
+	0, /* U+00A7D5 */
+	1376, /* U+00A7D6 */
+	1376, /* U+00A7D7 */
+	1377, /* U+00A7D8 */
+	1377, /* U+00A7D9 */
+	0, /* U+00A7DA */
+	0, /* U+00A7DB */
+	0, /* U+00A7DC */
+	0, /* U+00A7DD */
+	0, /* U+00A7DE */
+	0, /* U+00A7DF */
+	0, /* U+00A7E0 */
+	0, /* U+00A7E1 */
+	0, /* U+00A7E2 */
+	0, /* U+00A7E3 */
+	0, /* U+00A7E4 */
+	0, /* U+00A7E5 */
+	0, /* U+00A7E6 */
+	0, /* U+00A7E7 */
+	0, /* U+00A7E8 */
+	0, /* U+00A7E9 */
+	0, /* U+00A7EA */
+	0, /* U+00A7EB */
+	0, /* U+00A7EC */
+	0, /* U+00A7ED */
+	0, /* U+00A7EE */
+	0, /* U+00A7EF */
+	0, /* U+00A7F0 */
+	0, /* U+00A7F1 */
+	0, /* U+00A7F2 */
+	0, /* U+00A7F3 */
+	0, /* U+00A7F4 */
+	1378, /* U+00A7F5 */
+	1378, /* U+00A7F6 */
+	1364, /* U+00AB53 */
+	0, /* U+00AB54 */
+	0, /* U+00AB55 */
+	0, /* U+00AB56 */
+	0, /* U+00AB57 */
+	0, /* U+00AB58 */
+	0, /* U+00AB59 */
+	0, /* U+00AB5A */
+	0, /* U+00AB5B */
+	0, /* U+00AB5C */
+	0, /* U+00AB5D */
+	0, /* U+00AB5E */
+	0, /* U+00AB5F */
+	0, /* U+00AB60 */
+	0, /* U+00AB61 */
+	0, /* U+00AB62 */
+	0, /* U+00AB63 */
+	0, /* U+00AB64 */
+	0, /* U+00AB65 */
+	0, /* U+00AB66 */
+	0, /* U+00AB67 */
+	0, /* U+00AB68 */
+	0, /* U+00AB69 */
+	0, /* U+00AB6A */
+	0, /* U+00AB6B */
+	0, /* U+00AB6C */
+	0, /* U+00AB6D */
+	0, /* U+00AB6E */
+	0, /* U+00AB6F */
+	691, /* U+00AB70 */
+	692, /* U+00AB71 */
+	693, /* U+00AB72 */
+	694, /* U+00AB73 */
+	695, /* U+00AB74 */
+	696, /* U+00AB75 */
+	697, /* U+00AB76 */
+	698, /* U+00AB77 */
+	699, /* U+00AB78 */
+	700, /* U+00AB79 */
+	701, /* U+00AB7A */
+	702, /* U+00AB7B */
+	703, /* U+00AB7C */
+	704, /* U+00AB7D */
+	705, /* U+00AB7E */
+	706, /* U+00AB7F */
+	707, /* U+00AB80 */
+	708, /* U+00AB81 */
+	709, /* U+00AB82 */
+	710, /* U+00AB83 */
+	711, /* U+00AB84 */
+	712, /* U+00AB85 */
+	713, /* U+00AB86 */
+	714, /* U+00AB87 */
+	715, /* U+00AB88 */
+	716, /* U+00AB89 */
+	717, /* U+00AB8A */
+	718, /* U+00AB8B */
+	719, /* U+00AB8C */
+	720, /* U+00AB8D */
+	721, /* U+00AB8E */
+	722, /* U+00AB8F */
+	723, /* U+00AB90 */
+	724, /* U+00AB91 */
+	725, /* U+00AB92 */
+	726, /* U+00AB93 */
+	727, /* U+00AB94 */
+	728, /* U+00AB95 */
+	729, /* U+00AB96 */
+	730, /* U+00AB97 */
+	731, /* U+00AB98 */
+	732, /* U+00AB99 */
+	733, /* U+00AB9A */
+	734, /* U+00AB9B */
+	735, /* U+00AB9C */
+	736, /* U+00AB9D */
+	737, /* U+00AB9E */
+	738, /* U+00AB9F */
+	739, /* U+00ABA0 */
+	740, /* U+00ABA1 */
+	741, /* U+00ABA2 */
+	742, /* U+00ABA3 */
+	743, /* U+00ABA4 */
+	744, /* U+00ABA5 */
+	745, /* U+00ABA6 */
+	746, /* U+00ABA7 */
+	747, /* U+00ABA8 */
+	748, /* U+00ABA9 */
+	749, /* U+00ABAA */
+	750, /* U+00ABAB */
+	751, /* U+00ABAC */
+	752, /* U+00ABAD */
+	753, /* U+00ABAE */
+	754, /* U+00ABAF */
+	755, /* U+00ABB0 */
+	756, /* U+00ABB1 */
+	757, /* U+00ABB2 */
+	758, /* U+00ABB3 */
+	759, /* U+00ABB4 */
+	760, /* U+00ABB5 */
+	761, /* U+00ABB6 */
+	762, /* U+00ABB7 */
+	763, /* U+00ABB8 */
+	764, /* U+00ABB9 */
+	765, /* U+00ABBA */
+	766, /* U+00ABBB */
+	767, /* U+00ABBC */
+	768, /* U+00ABBD */
+	769, /* U+00ABBE */
+	770, /* U+00ABBF */
+	1379, /* U+00FB00 */
+	1380, /* U+00FB01 */
+	1381, /* U+00FB02 */
+	1382, /* U+00FB03 */
+	1383, /* U+00FB04 */
+	1384, /* U+00FB05 */
+	1385, /* U+00FB06 */
+	0, /* U+00FB07 */
+	0, /* U+00FB08 */
+	0, /* U+00FB09 */
+	0, /* U+00FB0A */
+	0, /* U+00FB0B */
+	0, /* U+00FB0C */
+	0, /* U+00FB0D */
+	0, /* U+00FB0E */
+	0, /* U+00FB0F */
+	0, /* U+00FB10 */
+	0, /* U+00FB11 */
+	0, /* U+00FB12 */
+	1386, /* U+00FB13 */
+	1387, /* U+00FB14 */
+	1388, /* U+00FB15 */
+	1389, /* U+00FB16 */
+	1390, /* U+00FB17 */
+	1391, /* U+00FF21 */
+	1392, /* U+00FF22 */
+	1393, /* U+00FF23 */
+	1394, /* U+00FF24 */
+	1395, /* U+00FF25 */
+	1396, /* U+00FF26 */
+	1397, /* U+00FF27 */
+	1398, /* U+00FF28 */
+	1399, /* U+00FF29 */
+	1400, /* U+00FF2A */
+	1401, /* U+00FF2B */
+	1402, /* U+00FF2C */
+	1403, /* U+00FF2D */
+	1404, /* U+00FF2E */
+	1405, /* U+00FF2F */
+	1406, /* U+00FF30 */
+	1407, /* U+00FF31 */
+	1408, /* U+00FF32 */
+	1409, /* U+00FF33 */
+	1410, /* U+00FF34 */
+	1411, /* U+00FF35 */
+	1412, /* U+00FF36 */
+	1413, /* U+00FF37 */
+	1414, /* U+00FF38 */
+	1415, /* U+00FF39 */
+	1416, /* U+00FF3A */
+	0, /* U+00FF3B */
+	0, /* U+00FF3C */
+	0, /* U+00FF3D */
+	0, /* U+00FF3E */
+	0, /* U+00FF3F */
+	0, /* U+00FF40 */
+	1391, /* U+00FF41 */
+	1392, /* U+00FF42 */
+	1393, /* U+00FF43 */
+	1394, /* U+00FF44 */
+	1395, /* U+00FF45 */
+	1396, /* U+00FF46 */
+	1397, /* U+00FF47 */
+	1398, /* U+00FF48 */
+	1399, /* U+00FF49 */
+	1400, /* U+00FF4A */
+	1401, /* U+00FF4B */
+	1402, /* U+00FF4C */
+	1403, /* U+00FF4D */
+	1404, /* U+00FF4E */
+	1405, /* U+00FF4F */
+	1406, /* U+00FF50 */
+	1407, /* U+00FF51 */
+	1408, /* U+00FF52 */
+	1409, /* U+00FF53 */
+	1410, /* U+00FF54 */
+	1411, /* U+00FF55 */
+	1412, /* U+00FF56 */
+	1413, /* U+00FF57 */
+	1414, /* U+00FF58 */
+	1415, /* U+00FF59 */
+	1416, /* U+00FF5A */
+	1417, /* U+010400 */
+	1418, /* U+010401 */
+	1419, /* U+010402 */
+	1420, /* U+010403 */
+	1421, /* U+010404 */
+	1422, /* U+010405 */
+	1423, /* U+010406 */
+	1424, /* U+010407 */
+	1425, /* U+010408 */
+	1426, /* U+010409 */
+	1427, /* U+01040A */
+	1428, /* U+01040B */
+	1429, /* U+01040C */
+	1430, /* U+01040D */
+	1431, /* U+01040E */
+	1432, /* U+01040F */
+	1433, /* U+010410 */
+	1434, /* U+010411 */
+	1435, /* U+010412 */
+	1436, /* U+010413 */
+	1437, /* U+010414 */
+	1438, /* U+010415 */
+	1439, /* U+010416 */
+	1440, /* U+010417 */
+	1441, /* U+010418 */
+	1442, /* U+010419 */
+	1443, /* U+01041A */
+	1444, /* U+01041B */
+	1445, /* U+01041C */
+	1446, /* U+01041D */
+	1447, /* U+01041E */
+	1448, /* U+01041F */
+	1449, /* U+010420 */
+	1450, /* U+010421 */
+	1451, /* U+010422 */
+	1452, /* U+010423 */
+	1453, /* U+010424 */
+	1454, /* U+010425 */
+	1455, /* U+010426 */
+	1456, /* U+010427 */
+	1417, /* U+010428 */
+	1418, /* U+010429 */
+	1419, /* U+01042A */
+	1420, /* U+01042B */
+	1421, /* U+01042C */
+	1422, /* U+01042D */
+	1423, /* U+01042E */
+	1424, /* U+01042F */
+	1425, /* U+010430 */
+	1426, /* U+010431 */
+	1427, /* U+010432 */
+	1428, /* U+010433 */
+	1429, /* U+010434 */
+	1430, /* U+010435 */
+	1431, /* U+010436 */
+	1432, /* U+010437 */
+	1433, /* U+010438 */
+	1434, /* U+010439 */
+	1435, /* U+01043A */
+	1436, /* U+01043B */
+	1437, /* U+01043C */
+	1438, /* U+01043D */
+	1439, /* U+01043E */
+	1440, /* U+01043F */
+	1441, /* U+010440 */
+	1442, /* U+010441 */
+	1443, /* U+010442 */
+	1444, /* U+010443 */
+	1445, /* U+010444 */
+	1446, /* U+010445 */
+	1447, /* U+010446 */
+	1448, /* U+010447 */
+	1449, /* U+010448 */
+	1450, /* U+010449 */
+	1451, /* U+01044A */
+	1452, /* U+01044B */
+	1453, /* U+01044C */
+	1454, /* U+01044D */
+	1455, /* U+01044E */
+	1456, /* U+01044F */
+	0, /* U+010450 */
+	0, /* U+010451 */
+	0, /* U+010452 */
+	0, /* U+010453 */
+	0, /* U+010454 */
+	0, /* U+010455 */
+	0, /* U+010456 */
+	0, /* U+010457 */
+	0, /* U+010458 */
+	0, /* U+010459 */
+	0, /* U+01045A */
+	0, /* U+01045B */
+	0, /* U+01045C */
+	0, /* U+01045D */
+	0, /* U+01045E */
+	0, /* U+01045F */
+	0, /* U+010460 */
+	0, /* U+010461 */
+	0, /* U+010462 */
+	0, /* U+010463 */
+	0, /* U+010464 */
+	0, /* U+010465 */
+	0, /* U+010466 */
+	0, /* U+010467 */
+	0, /* U+010468 */
+	0, /* U+010469 */
+	0, /* U+01046A */
+	0, /* U+01046B */
+	0, /* U+01046C */
+	0, /* U+01046D */
+	0, /* U+01046E */
+	0, /* U+01046F */
+	0, /* U+010470 */
+	0, /* U+010471 */
+	0, /* U+010472 */
+	0, /* U+010473 */
+	0, /* U+010474 */
+	0, /* U+010475 */
+	0, /* U+010476 */
+	0, /* U+010477 */
+	0, /* U+010478 */
+	0, /* U+010479 */
+	0, /* U+01047A */
+	0, /* U+01047B */
+	0, /* U+01047C */
+	0, /* U+01047D */
+	0, /* U+01047E */
+	0, /* U+01047F */
+	0, /* U+010480 */
+	0, /* U+010481 */
+	0, /* U+010482 */
+	0, /* U+010483 */
+	0, /* U+010484 */
+	0, /* U+010485 */
+	0, /* U+010486 */
+	0, /* U+010487 */
+	0, /* U+010488 */
+	0, /* U+010489 */
+	0, /* U+01048A */
+	0, /* U+01048B */
+	0, /* U+01048C */
+	0, /* U+01048D */
+	0, /* U+01048E */
+	0, /* U+01048F */
+	0, /* U+010490 */
+	0, /* U+010491 */
+	0, /* U+010492 */
+	0, /* U+010493 */
+	0, /* U+010494 */
+	0, /* U+010495 */
+	0, /* U+010496 */
+	0, /* U+010497 */
+	0, /* U+010498 */
+	0, /* U+010499 */
+	0, /* U+01049A */
+	0, /* U+01049B */
+	0, /* U+01049C */
+	0, /* U+01049D */
+	0, /* U+01049E */
+	0, /* U+01049F */
+	0, /* U+0104A0 */
+	0, /* U+0104A1 */
+	0, /* U+0104A2 */
+	0, /* U+0104A3 */
+	0, /* U+0104A4 */
+	0, /* U+0104A5 */
+	0, /* U+0104A6 */
+	0, /* U+0104A7 */
+	0, /* U+0104A8 */
+	0, /* U+0104A9 */
+	0, /* U+0104AA */
+	0, /* U+0104AB */
+	0, /* U+0104AC */
+	0, /* U+0104AD */
+	0, /* U+0104AE */
+	0, /* U+0104AF */
+	1457, /* U+0104B0 */
+	1458, /* U+0104B1 */
+	1459, /* U+0104B2 */
+	1460, /* U+0104B3 */
+	1461, /* U+0104B4 */
+	1462, /* U+0104B5 */
+	1463, /* U+0104B6 */
+	1464, /* U+0104B7 */
+	1465, /* U+0104B8 */
+	1466, /* U+0104B9 */
+	1467, /* U+0104BA */
+	1468, /* U+0104BB */
+	1469, /* U+0104BC */
+	1470, /* U+0104BD */
+	1471, /* U+0104BE */
+	1472, /* U+0104BF */
+	1473, /* U+0104C0 */
+	1474, /* U+0104C1 */
+	1475, /* U+0104C2 */
+	1476, /* U+0104C3 */
+	1477, /* U+0104C4 */
+	1478, /* U+0104C5 */
+	1479, /* U+0104C6 */
+	1480, /* U+0104C7 */
+	1481, /* U+0104C8 */
+	1482, /* U+0104C9 */
+	1483, /* U+0104CA */
+	1484, /* U+0104CB */
+	1485, /* U+0104CC */
+	1486, /* U+0104CD */
+	1487, /* U+0104CE */
+	1488, /* U+0104CF */
+	1489, /* U+0104D0 */
+	1490, /* U+0104D1 */
+	1491, /* U+0104D2 */
+	1492, /* U+0104D3 */
+	0, /* U+0104D4 */
+	0, /* U+0104D5 */
+	0, /* U+0104D6 */
+	0, /* U+0104D7 */
+	1457, /* U+0104D8 */
+	1458, /* U+0104D9 */
+	1459, /* U+0104DA */
+	1460, /* U+0104DB */
+	1461, /* U+0104DC */
+	1462, /* U+0104DD */
+	1463, /* U+0104DE */
+	1464, /* U+0104DF */
+	1465, /* U+0104E0 */
+	1466, /* U+0104E1 */
+	1467, /* U+0104E2 */
+	1468, /* U+0104E3 */
+	1469, /* U+0104E4 */
+	1470, /* U+0104E5 */
+	1471, /* U+0104E6 */
+	1472, /* U+0104E7 */
+	1473, /* U+0104E8 */
+	1474, /* U+0104E9 */
+	1475, /* U+0104EA */
+	1476, /* U+0104EB */
+	1477, /* U+0104EC */
+	1478, /* U+0104ED */
+	1479, /* U+0104EE */
+	1480, /* U+0104EF */
+	1481, /* U+0104F0 */
+	1482, /* U+0104F1 */
+	1483, /* U+0104F2 */
+	1484, /* U+0104F3 */
+	1485, /* U+0104F4 */
+	1486, /* U+0104F5 */
+	1487, /* U+0104F6 */
+	1488, /* U+0104F7 */
+	1489, /* U+0104F8 */
+	1490, /* U+0104F9 */
+	1491, /* U+0104FA */
+	1492, /* U+0104FB */
+	0, /* U+0104FC */
+	0, /* U+0104FD */
+	0, /* U+0104FE */
+	0, /* U+0104FF */
+	0, /* U+010500 */
+	0, /* U+010501 */
+	0, /* U+010502 */
+	0, /* U+010503 */
+	0, /* U+010504 */
+	0, /* U+010505 */
+	0, /* U+010506 */
+	0, /* U+010507 */
+	0, /* U+010508 */
+	0, /* U+010509 */
+	0, /* U+01050A */
+	0, /* U+01050B */
+	0, /* U+01050C */
+	0, /* U+01050D */
+	0, /* U+01050E */
+	0, /* U+01050F */
+	0, /* U+010510 */
+	0, /* U+010511 */
+	0, /* U+010512 */
+	0, /* U+010513 */
+	0, /* U+010514 */
+	0, /* U+010515 */
+	0, /* U+010516 */
+	0, /* U+010517 */
+	0, /* U+010518 */
+	0, /* U+010519 */
+	0, /* U+01051A */
+	0, /* U+01051B */
+	0, /* U+01051C */
+	0, /* U+01051D */
+	0, /* U+01051E */
+	0, /* U+01051F */
+	0, /* U+010520 */
+	0, /* U+010521 */
+	0, /* U+010522 */
+	0, /* U+010523 */
+	0, /* U+010524 */
+	0, /* U+010525 */
+	0, /* U+010526 */
+	0, /* U+010527 */
+	0, /* U+010528 */
+	0, /* U+010529 */
+	0, /* U+01052A */
+	0, /* U+01052B */
+	0, /* U+01052C */
+	0, /* U+01052D */
+	0, /* U+01052E */
+	0, /* U+01052F */
+	0, /* U+010530 */
+	0, /* U+010531 */
+	0, /* U+010532 */
+	0, /* U+010533 */
+	0, /* U+010534 */
+	0, /* U+010535 */
+	0, /* U+010536 */
+	0, /* U+010537 */
+	0, /* U+010538 */
+	0, /* U+010539 */
+	0, /* U+01053A */
+	0, /* U+01053B */
+	0, /* U+01053C */
+	0, /* U+01053D */
+	0, /* U+01053E */
+	0, /* U+01053F */
+	0, /* U+010540 */
+	0, /* U+010541 */
+	0, /* U+010542 */
+	0, /* U+010543 */
+	0, /* U+010544 */
+	0, /* U+010545 */
+	0, /* U+010546 */
+	0, /* U+010547 */
+	0, /* U+010548 */
+	0, /* U+010549 */
+	0, /* U+01054A */
+	0, /* U+01054B */
+	0, /* U+01054C */
+	0, /* U+01054D */
+	0, /* U+01054E */
+	0, /* U+01054F */
+	0, /* U+010550 */
+	0, /* U+010551 */
+	0, /* U+010552 */
+	0, /* U+010553 */
+	0, /* U+010554 */
+	0, /* U+010555 */
+	0, /* U+010556 */
+	0, /* U+010557 */
+	0, /* U+010558 */
+	0, /* U+010559 */
+	0, /* U+01055A */
+	0, /* U+01055B */
+	0, /* U+01055C */
+	0, /* U+01055D */
+	0, /* U+01055E */
+	0, /* U+01055F */
+	0, /* U+010560 */
+	0, /* U+010561 */
+	0, /* U+010562 */
+	0, /* U+010563 */
+	0, /* U+010564 */
+	0, /* U+010565 */
+	0, /* U+010566 */
+	0, /* U+010567 */
+	0, /* U+010568 */
+	0, /* U+010569 */
+	0, /* U+01056A */
+	0, /* U+01056B */
+	0, /* U+01056C */
+	0, /* U+01056D */
+	0, /* U+01056E */
+	0, /* U+01056F */
+	1493, /* U+010570 */
+	1494, /* U+010571 */
+	1495, /* U+010572 */
+	1496, /* U+010573 */
+	1497, /* U+010574 */
+	1498, /* U+010575 */
+	1499, /* U+010576 */
+	1500, /* U+010577 */
+	1501, /* U+010578 */
+	1502, /* U+010579 */
+	1503, /* U+01057A */
+	0, /* U+01057B */
+	1504, /* U+01057C */
+	1505, /* U+01057D */
+	1506, /* U+01057E */
+	1507, /* U+01057F */
+	1508, /* U+010580 */
+	1509, /* U+010581 */
+	1510, /* U+010582 */
+	1511, /* U+010583 */
+	1512, /* U+010584 */
+	1513, /* U+010585 */
+	1514, /* U+010586 */
+	1515, /* U+010587 */
+	1516, /* U+010588 */
+	1517, /* U+010589 */
+	1518, /* U+01058A */
+	0, /* U+01058B */
+	1519, /* U+01058C */
+	1520, /* U+01058D */
+	1521, /* U+01058E */
+	1522, /* U+01058F */
+	1523, /* U+010590 */
+	1524, /* U+010591 */
+	1525, /* U+010592 */
+	0, /* U+010593 */
+	1526, /* U+010594 */
+	1527, /* U+010595 */
+	0, /* U+010596 */
+	1493, /* U+010597 */
+	1494, /* U+010598 */
+	1495, /* U+010599 */
+	1496, /* U+01059A */
+	1497, /* U+01059B */
+	1498, /* U+01059C */
+	1499, /* U+01059D */
+	1500, /* U+01059E */
+	1501, /* U+01059F */
+	1502, /* U+0105A0 */
+	1503, /* U+0105A1 */
+	0, /* U+0105A2 */
+	1504, /* U+0105A3 */
+	1505, /* U+0105A4 */
+	1506, /* U+0105A5 */
+	1507, /* U+0105A6 */
+	1508, /* U+0105A7 */
+	1509, /* U+0105A8 */
+	1510, /* U+0105A9 */
+	1511, /* U+0105AA */
+	1512, /* U+0105AB */
+	1513, /* U+0105AC */
+	1514, /* U+0105AD */
+	1515, /* U+0105AE */
+	1516, /* U+0105AF */
+	1517, /* U+0105B0 */
+	1518, /* U+0105B1 */
+	0, /* U+0105B2 */
+	1519, /* U+0105B3 */
+	1520, /* U+0105B4 */
+	1521, /* U+0105B5 */
+	1522, /* U+0105B6 */
+	1523, /* U+0105B7 */
+	1524, /* U+0105B8 */
+	1525, /* U+0105B9 */
+	0, /* U+0105BA */
+	1526, /* U+0105BB */
+	1527, /* U+0105BC */
+	1528, /* U+010C80 */
+	1529, /* U+010C81 */
+	1530, /* U+010C82 */
+	1531, /* U+010C83 */
+	1532, /* U+010C84 */
+	1533, /* U+010C85 */
+	1534, /* U+010C86 */
+	1535, /* U+010C87 */
+	1536, /* U+010C88 */
+	1537, /* U+010C89 */
+	1538, /* U+010C8A */
+	1539, /* U+010C8B */
+	1540, /* U+010C8C */
+	1541, /* U+010C8D */
+	1542, /* U+010C8E */
+	1543, /* U+010C8F */
+	1544, /* U+010C90 */
+	1545, /* U+010C91 */
+	1546, /* U+010C92 */
+	1547, /* U+010C93 */
+	1548, /* U+010C94 */
+	1549, /* U+010C95 */
+	1550, /* U+010C96 */
+	1551, /* U+010C97 */
+	1552, /* U+010C98 */
+	1553, /* U+010C99 */
+	1554, /* U+010C9A */
+	1555, /* U+010C9B */
+	1556, /* U+010C9C */
+	1557, /* U+010C9D */
+	1558, /* U+010C9E */
+	1559, /* U+010C9F */
+	1560, /* U+010CA0 */
+	1561, /* U+010CA1 */
+	1562, /* U+010CA2 */
+	1563, /* U+010CA3 */
+	1564, /* U+010CA4 */
+	1565, /* U+010CA5 */
+	1566, /* U+010CA6 */
+	1567, /* U+010CA7 */
+	1568, /* U+010CA8 */
+	1569, /* U+010CA9 */
+	1570, /* U+010CAA */
+	1571, /* U+010CAB */
+	1572, /* U+010CAC */
+	1573, /* U+010CAD */
+	1574, /* U+010CAE */
+	1575, /* U+010CAF */
+	1576, /* U+010CB0 */
+	1577, /* U+010CB1 */
+	1578, /* U+010CB2 */
+	0, /* U+010CB3 */
+	0, /* U+010CB4 */
+	0, /* U+010CB5 */
+	0, /* U+010CB6 */
+	0, /* U+010CB7 */
+	0, /* U+010CB8 */
+	0, /* U+010CB9 */
+	0, /* U+010CBA */
+	0, /* U+010CBB */
+	0, /* U+010CBC */
+	0, /* U+010CBD */
+	0, /* U+010CBE */
+	0, /* U+010CBF */
+	1528, /* U+010CC0 */
+	1529, /* U+010CC1 */
+	1530, /* U+010CC2 */
+	1531, /* U+010CC3 */
+	1532, /* U+010CC4 */
+	1533, /* U+010CC5 */
+	1534, /* U+010CC6 */
+	1535, /* U+010CC7 */
+	1536, /* U+010CC8 */
+	1537, /* U+010CC9 */
+	1538, /* U+010CCA */
+	1539, /* U+010CCB */
+	1540, /* U+010CCC */
+	1541, /* U+010CCD */
+	1542, /* U+010CCE */
+	1543, /* U+010CCF */
+	1544, /* U+010CD0 */
+	1545, /* U+010CD1 */
+	1546, /* U+010CD2 */
+	1547, /* U+010CD3 */
+	1548, /* U+010CD4 */
+	1549, /* U+010CD5 */
+	1550, /* U+010CD6 */
+	1551, /* U+010CD7 */
+	1552, /* U+010CD8 */
+	1553, /* U+010CD9 */
+	1554, /* U+010CDA */
+	1555, /* U+010CDB */
+	1556, /* U+010CDC */
+	1557, /* U+010CDD */
+	1558, /* U+010CDE */
+	1559, /* U+010CDF */
+	1560, /* U+010CE0 */
+	1561, /* U+010CE1 */
+	1562, /* U+010CE2 */
+	1563, /* U+010CE3 */
+	1564, /* U+010CE4 */
+	1565, /* U+010CE5 */
+	1566, /* U+010CE6 */
+	1567, /* U+010CE7 */
+	1568, /* U+010CE8 */
+	1569, /* U+010CE9 */
+	1570, /* U+010CEA */
+	1571, /* U+010CEB */
+	1572, /* U+010CEC */
+	1573, /* U+010CED */
+	1574, /* U+010CEE */
+	1575, /* U+010CEF */
+	1576, /* U+010CF0 */
+	1577, /* U+010CF1 */
+	1578, /* U+010CF2 */
+	1579, /* U+0118A0 */
+	1580, /* U+0118A1 */
+	1581, /* U+0118A2 */
+	1582, /* U+0118A3 */
+	1583, /* U+0118A4 */
+	1584, /* U+0118A5 */
+	1585, /* U+0118A6 */
+	1586, /* U+0118A7 */
+	1587, /* U+0118A8 */
+	1588, /* U+0118A9 */
+	1589, /* U+0118AA */
+	1590, /* U+0118AB */
+	1591, /* U+0118AC */
+	1592, /* U+0118AD */
+	1593, /* U+0118AE */
+	1594, /* U+0118AF */
+	1595, /* U+0118B0 */
+	1596, /* U+0118B1 */
+	1597, /* U+0118B2 */
+	1598, /* U+0118B3 */
+	1599, /* U+0118B4 */
+	1600, /* U+0118B5 */
+	1601, /* U+0118B6 */
+	1602, /* U+0118B7 */
+	1603, /* U+0118B8 */
+	1604, /* U+0118B9 */
+	1605, /* U+0118BA */
+	1606, /* U+0118BB */
+	1607, /* U+0118BC */
+	1608, /* U+0118BD */
+	1609, /* U+0118BE */
+	1610, /* U+0118BF */
+	1579, /* U+0118C0 */
+	1580, /* U+0118C1 */
+	1581, /* U+0118C2 */
+	1582, /* U+0118C3 */
+	1583, /* U+0118C4 */
+	1584, /* U+0118C5 */
+	1585, /* U+0118C6 */
+	1586, /* U+0118C7 */
+	1587, /* U+0118C8 */
+	1588, /* U+0118C9 */
+	1589, /* U+0118CA */
+	1590, /* U+0118CB */
+	1591, /* U+0118CC */
+	1592, /* U+0118CD */
+	1593, /* U+0118CE */
+	1594, /* U+0118CF */
+	1595, /* U+0118D0 */
+	1596, /* U+0118D1 */
+	1597, /* U+0118D2 */
+	1598, /* U+0118D3 */
+	1599, /* U+0118D4 */
+	1600, /* U+0118D5 */
+	1601, /* U+0118D6 */
+	1602, /* U+0118D7 */
+	1603, /* U+0118D8 */
+	1604, /* U+0118D9 */
+	1605, /* U+0118DA */
+	1606, /* U+0118DB */
+	1607, /* U+0118DC */
+	1608, /* U+0118DD */
+	1609, /* U+0118DE */
+	1610, /* U+0118DF */
+	1611, /* U+016E40 */
+	1612, /* U+016E41 */
+	1613, /* U+016E42 */
+	1614, /* U+016E43 */
+	1615, /* U+016E44 */
+	1616, /* U+016E45 */
+	1617, /* U+016E46 */
+	1618, /* U+016E47 */
+	1619, /* U+016E48 */
+	1620, /* U+016E49 */
+	1621, /* U+016E4A */
+	1622, /* U+016E4B */
+	1623, /* U+016E4C */
+	1624, /* U+016E4D */
+	1625, /* U+016E4E */
+	1626, /* U+016E4F */
+	1627, /* U+016E50 */
+	1628, /* U+016E51 */
+	1629, /* U+016E52 */
+	1630, /* U+016E53 */
+	1631, /* U+016E54 */
+	1632, /* U+016E55 */
+	1633, /* U+016E56 */
+	1634, /* U+016E57 */
+	1635, /* U+016E58 */
+	1636, /* U+016E59 */
+	1637, /* U+016E5A */
+	1638, /* U+016E5B */
+	1639, /* U+016E5C */
+	1640, /* U+016E5D */
+	1641, /* U+016E5E */
+	1642, /* U+016E5F */
+	1611, /* U+016E60 */
+	1612, /* U+016E61 */
+	1613, /* U+016E62 */
+	1614, /* U+016E63 */
+	1615, /* U+016E64 */
+	1616, /* U+016E65 */
+	1617, /* U+016E66 */
+	1618, /* U+016E67 */
+	1619, /* U+016E68 */
+	1620, /* U+016E69 */
+	1621, /* U+016E6A */
+	1622, /* U+016E6B */
+	1623, /* U+016E6C */
+	1624, /* U+016E6D */
+	1625, /* U+016E6E */
+	1626, /* U+016E6F */
+	1627, /* U+016E70 */
+	1628, /* U+016E71 */
+	1629, /* U+016E72 */
+	1630, /* U+016E73 */
+	1631, /* U+016E74 */
+	1632, /* U+016E75 */
+	1633, /* U+016E76 */
+	1634, /* U+016E77 */
+	1635, /* U+016E78 */
+	1636, /* U+016E79 */
+	1637, /* U+016E7A */
+	1638, /* U+016E7B */
+	1639, /* U+016E7C */
+	1640, /* U+016E7D */
+	1641, /* U+016E7E */
+	1642, /* U+016E7F */
+	1643, /* U+01E900 */
+	1644, /* U+01E901 */
+	1645, /* U+01E902 */
+	1646, /* U+01E903 */
+	1647, /* U+01E904 */
+	1648, /* U+01E905 */
+	1649, /* U+01E906 */
+	1650, /* U+01E907 */
+	1651, /* U+01E908 */
+	1652, /* U+01E909 */
+	1653, /* U+01E90A */
+	1654, /* U+01E90B */
+	1655, /* U+01E90C */
+	1656, /* U+01E90D */
+	1657, /* U+01E90E */
+	1658, /* U+01E90F */
+	1659, /* U+01E910 */
+	1660, /* U+01E911 */
+	1661, /* U+01E912 */
+	1662, /* U+01E913 */
+	1663, /* U+01E914 */
+	1664, /* U+01E915 */
+	1665, /* U+01E916 */
+	1666, /* U+01E917 */
+	1667, /* U+01E918 */
+	1668, /* U+01E919 */
+	1669, /* U+01E91A */
+	1670, /* U+01E91B */
+	1671, /* U+01E91C */
+	1672, /* U+01E91D */
+	1673, /* U+01E91E */
+	1674, /* U+01E91F */
+	1675, /* U+01E920 */
+	1676, /* U+01E921 */
+	1643, /* U+01E922 */
+	1644, /* U+01E923 */
+	1645, /* U+01E924 */
+	1646, /* U+01E925 */
+	1647, /* U+01E926 */
+	1648, /* U+01E927 */
+	1649, /* U+01E928 */
+	1650, /* U+01E929 */
+	1651, /* U+01E92A */
+	1652, /* U+01E92B */
+	1653, /* U+01E92C */
+	1654, /* U+01E92D */
+	1655, /* U+01E92E */
+	1656, /* U+01E92F */
+	1657, /* U+01E930 */
+	1658, /* U+01E931 */
+	1659, /* U+01E932 */
+	1660, /* U+01E933 */
+	1661, /* U+01E934 */
+	1662, /* U+01E935 */
+	1663, /* U+01E936 */
+	1664, /* U+01E937 */
+	1665, /* U+01E938 */
+	1666, /* U+01E939 */
+	1667, /* U+01E93A */
+	1668, /* U+01E93B */
+	1669, /* U+01E93C */
+	1670, /* U+01E93D */
+	1671, /* U+01E93E */
+	1672, /* U+01E93F */
+	1673, /* U+01E940 */
+	1674, /* U+01E941 */
+	1675, /* U+01E942 */
+	1676, /* U+01E943 */
+};
+
+static inline uint16
+case_index(pg_wchar cp)
+{
+	/* Fast path for codepoints < 0x0588 */
+	if (cp < 0x0588) {
+		return case_map[cp];
+	}
+
+	if (cp < 0xABC0) {
+		if (cp < 0x2185) {
+			if (cp >= 0x10A0 && cp < 0x1100) {
+				return case_map[cp - 0x10A0 + 0x0588];
+			}
+			else if (cp >= 0x13A0) {
+				if (cp < 0x13FE) {
+					return case_map[cp - 0x13A0 + 0x05E8];
+				}
+				else if (cp >= 0x1C80) {
+					return case_map[cp - 0x1C80 + 0x0646];
+				}
+			}
+		}
+		else if (cp >= 0x24B6) {
+			if (cp < 0x2D2E) {
+				if (cp < 0x24EA) {
+					return case_map[cp - 0x24B6 + 0x0B4B];
+				}
+				else if (cp >= 0x2C00) {
+					return case_map[cp - 0x2C00 + 0x0B7F];
+				}
+			}
+			else if (cp >= 0xA640) {
+				if (cp < 0xA7F7) {
+					return case_map[cp - 0xA640 + 0x0CAD];
+				}
+				else if (cp >= 0xAB53) {
+					return case_map[cp - 0xAB53 + 0x0E64];
+				}
+			}
+		}
+	}
+	else if (cp >= 0xFB00) {
+		if (cp < 0x10CF3) {
+			if (cp < 0xFF5B) {
+				if (cp < 0xFB18) {
+					return case_map[cp - 0xFB00 + 0x0ED1];
+				}
+				else if (cp >= 0xFF21) {
+					return case_map[cp - 0xFF21 + 0x0EE9];
+				}
+			}
+			else if (cp >= 0x10400) {
+				if (cp < 0x105BD) {
+					return case_map[cp - 0x10400 + 0x0F23];
+				}
+				else if (cp >= 0x10C80) {
+					return case_map[cp - 0x10C80 + 0x10E0];
+				}
+			}
+		}
+		else if (cp >= 0x118A0) {
+			if (cp < 0x16E80) {
+				if (cp < 0x118E0) {
+					return case_map[cp - 0x118A0 + 0x1153];
+				}
+				else if (cp >= 0x16E40) {
+					return case_map[cp - 0x16E40 + 0x1193];
+				}
+			}
+			else if (cp >= 0x1E900) {
+				if (cp < 0x1E944) {
+					return case_map[cp - 0x1E900 + 0x11D3];
+				}
+			}
+		}
+	}
+
+	return 0;
+}
-- 
2.39.5 (Apple Git-154)

